﻿--		Historion database update script:  6.1.7.5
--		========================================================================================================
--		Produced By   : Cybermynd Information Systems Consulting Pty Ltd  
--		Script URL	  : www.historion.com.au\SQL\UpdateScripts\6\Historion-script-6171.zip
--		Author        : Rob Brown   
--		Date          : 2020-11-10 
--		Purpose       : Update Historion database schema to latest release
--		Dependancy    : SQL Server 2012 or higher required (begin try, begin catch used)
--		Dependancy    : Scipt 6.1.7.3 must be in place, see ChangeScripts table
--		Results/Log   : Please send script execution log to service@cybermynd.com.au
--		SSMS Notes    : For SSMS Under Edit Menu, Outlining, Select Toggle All Outlining
--		Support       : Contact +61 3 9876 0323
-- ============================================================================================================
BEGIN
-- ============================================================================================================
-- Script Settings
-- ============================================================================================================
	SET NOEXEC OFF
	SET ANSI_NULLS ON
	SET QUOTED_IDENTIFIER ON
	END
GO

BEGIN -- SQL Server Version Dependency Check

	DECLARE @intVersion int
	DECLARE @strVersion nvarchar(128)

	SET @strVersion = CAST(serverproperty('ProductVersion') AS nvarchar)
	SET @intVersion = CAST(SUBSTRING(@strVersion, 1, CHARINDEX('.', @strVersion) - 1) AS INT)

	IF @intVersion < 11
		BEGIN
				raiserror('Cannot execute script. SQL Server 2012 or higher is required.',20,-1) with log
		END
	ELSE
		Print 'SQL Version 2012 or higher confirmed, can continue'
	END
GO

BEGIN -- Prior Script Dependancy Check

	IF NOT EXISTS(SELECT 1 FROM ChangeScripts WHERE ScriptNo = '6.1.7.1') 
		BEGIN
		raiserror('Cannot execute script. Change script 6.1.7.1 must be applied first.',20,-1) with log
		END
	ELSE
		Print 'Change script 6.1.7.1 previously run, can continue'
		Print '-----------------------------------------------------------------------------------------------------'
	END
GO

-- Clear Reading Data Quality for recalculation
delete tblStatsReadingDataQuality

-- Clear Grid Settings
BEGIN
delete tblGridSettings
END
GO

-- Remove Custodianship optional display unused tab setting
BEGIN
DELETE tblSystemTabPageUse WHERE TabPageID = 2
END
GO

-- Remove Permit optional display unused tab setting
BEGIN
DELETE tblSystemTabPageUse WHERE TabPageID = 5
END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'FixtureTypeID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		exec sp_rename 'tblEquipment.FixtureTypeID', 'PortabilityID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblEquipment.FixtureTypeID to tblEquipment.PortabilityID',20,-1) with log
	END CATCH
END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadioNuclide' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		exec sp_rename 'tblEquipment.RadioNuclideID', 'RadionuclideID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblEquipment.RadioNuclideID to tblEquipment.RadionuclideID',20,-1) with log
	END CATCH
END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RWLYears' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		exec sp_rename 'tblEquipment.RWLYears', 'RecommendedWorkingLife', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblEquipment.RWLYears to tblEquipment.RecommendedWorkingLife',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------
-- tblSiteLocation data model review
-- ----------------------------------------------------------------------

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteLocationOther' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN SiteLocationOther
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column SiteLocationOther from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetAddressLine1' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetAddressLine1
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetAddressLine1 from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetAddressLine2' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetAddressLine2
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetAddressLine2 from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO
	
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetSuburb' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetSuburb
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetSuburb from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetState' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetState
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetState from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetPostcode' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetPostcode
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetPostcode from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblSiteLocation_tblRefCountry')
		BEGIN TRY
			ALTER TABLE [dbo].[tblSiteLocation]
			DROP CONSTRAINT FK_tblSiteLocation_tblRefCountry
			Print 'Constraint dropped: [FK_tblSiteLocation_tblRefCountry]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblSiteLocation_tblRefCountry]. Script terminated.',20,-1) with log
		END CATCH
	END
GO

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblSiteLocation_tblSiteLocation')
		BEGIN TRY
			ALTER TABLE [dbo].[tblSiteLocation]
			DROP CONSTRAINT FK_tblSiteLocation_tblSiteLocation
			Print 'Constraint dropped: [FK_tblSiteLocation_tblSiteLocation]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblSiteLocation_tblSiteLocation]. Script terminated.',20,-1) with log
		END CATCH
	END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetCountryCode' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetCountryCode
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetCountryCode from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetOther' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StreetOther
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StreetOther from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StartDate' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN StartDate
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column StartDate from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EndDate' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN EndDate
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column EndDate from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	
	
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalSameAsStreet' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalSameAsStreet
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalSameAsStreet from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

	
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalAddressLine1' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalAddressLine1
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalAddressLine1 from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalAddressLine2' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalAddressLine2
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalAddressLine2 from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO
	
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalSuburb' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalSuburb
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalSuburb from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalState' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalState
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalState from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalPostcode' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalPostcode
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalPostcode from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalCountryCode' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalCountryCode
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalCountryCode from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalOther' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN PostalOther
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column PostalOther from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'LocalSiteID' AND Object_ID = Object_ID(N'tblSiteLocation'))
	BEGIN TRY
		ALTER TABLE tblSiteLocation
		DROP COLUMN LocalSiteID
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping column LocalSiteID from table tblSiteLocation',20,-1) with log
	END CATCH
END
GO	

-- -----------------------------------------------------------------------
-- Unused tblLicencePermitBusinessUnit table and associated SPROCS remove
--------------------------------------------------------------------------

-- tblLicencePermitBusinessUnit
BEGIN
   IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblLicencePermitBusinessUnit')
		BEGIN TRY
			DROP TABLE tblLicencePermitBusinessUnit
			Print 'Unused tblLicencePermitBusinessUnit dropped'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping unused table tblLicencePermitBusinessUnit. Script terminated.',20,-1) with log
		END CATCH
	ELSE
		Print 'Unused table not present (OK): tblLicencePermitBusinessUnit'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_Delete
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_Delete]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_Delete dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_Delete. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_Delete'	
	END
GO


-- pr_tblLicencePermitBusinessUnit_DeleteAllWBusinessUnitIDLogic
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_DeleteAllWBusinessUnitIDLogic]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_DeleteAllWBusinessUnitIDLogic dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_DeleteAllWBusinessUnitIDLogic. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_DeleteAllWBusinessUnitIDLogic'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_DeleteAllWLicencePermitIDLogic
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_DeleteAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_DeleteAllWLicencePermitIDLogic]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_DeleteAllWLicencePermitIDLogic dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_DeleteAllWLicencePermitIDLogic. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_DeleteAllWLicencePermitIDLogic'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_Insert
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_Insert]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_Insert dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_Insert. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_Insert'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_SelectAll
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_SelectAll]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_SelectAll dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_SelectAll. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_SelectAll'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_SelectAllWBusinessUnitIDLogic
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_SelectAllWBusinessUnitIDLogic]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_SelectAllWBusinessUnitIDLogic dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_SelectAllWBusinessUnitIDLogic. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_SelectAllWBusinessUnitIDLogic'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_SelectAllWLicencePermitIDLogic
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_SelectAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_SelectAllWLicencePermitIDLogic]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_SelectAllWLicencePermitIDLogic dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_SelectAllWLicencePermitIDLogic. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_SelectAllWLicencePermitIDLogic'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_SelectOne
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_SelectOne]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_SelectOne dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_SelectOne. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_SelectOne'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_Update
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_Update]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_Update dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_Update. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_Update'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_UpdateAllWBusinessUnitIDLogic
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_UpdateAllWBusinessUnitIDLogic]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_UpdateAllWBusinessUnitIDLogic dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_UpdateAllWBusinessUnitIDLogic. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_UpdateAllWBusinessUnitIDLogic'	
	END
GO

-- pr_tblLicencePermitBusinessUnit_UpdateAllWLicencePermitIDLogic
BEGIN
	IF EXISTS (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblLicencePermitBusinessUnit_UpdateAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
		BEGIN TRY
			DROP PROCEDURE [dbo].[pr_tblLicencePermitBusinessUnit_UpdateAllWLicencePermitIDLogic]
			Print 'Unused SPROC pr_tblLicencePermitBusinessUnit_UpdateAllWLicencePermitIDLogic dropped'
		END TRY
			BEGIN CATCH
				Print ERROR_MESSAGE()
				raiserror('Problem dropping unused SPROC pr_tblLicencePermitBusinessUnit_UpdateAllWLicencePermitIDLogic. Script terminated.',20,-1) with log
			END CATCH
	ELSE
		Print 'Unused SPROC not present (OK): pr_tblLicencePermitBusinessUnit_UpdateAllWLicencePermitIDLogic'	
	END
GO

-- ----------------------------------------------
-- New Equipment Security Table
-- ----------------------------------------------

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

BEGIN
   IF NOT EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblEquipmentSecurity')
	CREATE TABLE [dbo].[tblEquipmentSecurity](
		[EquipmentSecurityID] [int] IDENTITY(1,1) NOT NULL,
		[EquipmentID] [int] NOT NULL,
		[EquipmentSecurityGroupType] [int] NOT NULL,
		[EquipmentSecurityMemberID] [int] NOT NULL,
		[EquipmentSecurityMode] [int] NOT NULL,
		[EquipmentSecurityNote] [nvarchar](max) NULL,
		[AddedBy] [varchar](50) NOT NULL,
		[AddedDateTime] [datetime] NOT NULL,
		[LastUpdatedBy] [varchar](50) NOT NULL,
		[LastUpdatedDateTime] [datetime] NOT NULL,
	 CONSTRAINT [PK_tblEquipmentSecurity] PRIMARY KEY CLUSTERED 
	(
		[EquipmentSecurityID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblEquipmentSecurity_tblEquipment')
	BEGIN
		ALTER TABLE [dbo].[tblEquipmentSecurity]  WITH CHECK ADD  CONSTRAINT [FK_tblEquipmentSecurity_tblEquipment] FOREIGN KEY([EquipmentID])
		REFERENCES [dbo].[tblEquipment] ([EquipmentID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblEquipmentSecurity_tblEquipment]'
	END
GO

ALTER TABLE [dbo].[tblEquipmentSecurity] CHECK CONSTRAINT [FK_tblEquipmentSecurity_tblEquipment]
GO

-- ----------------------------------------------
-- Equipment add/change audit mini log mandatory
-- ----------------------------------------------
BEGIN
	UPDATE tblEquipment SET AddedBy = 'Historion' WHERE AddedBy IS NULL
	UPDATE tblEquipment SET AddedDateTime = DateRegistered WHERE AddedDateTime IS NULL
	UPDATE tblEquipment SET ModifiedBy = 'Historion' WHERE ModifiedBy IS NULL
	UPDATE tblEquipment SET ModifiedDateTime = DateRegistered WHERE ModifiedDateTime IS NULL
END
GO

BEGIN
	ALTER TABLE tblEquipment ALTER COLUMN AddedBy nvarchar(20) NOT NULL
	ALTER TABLE tblEquipment ALTER COLUMN AddedDateTime datetime NOT NULL
	ALTER TABLE tblEquipment ALTER COLUMN ModifiedBy nvarchar(20) NOT NULL
	ALTER TABLE tblEquipment ALTER COLUMN ModifiedDateTime datetime NOT NULL
END
GO
-- ----------------------------------------------
-- Equipment View speed table remove and recreate
-- ----------------------------------------------

BEGIN
   IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblEquipmentView')
		BEGIN TRY
			DROP TABLE tblEquipmentView
			Print 'tblEquipmentView dropped, proceed to create'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping tblEquipmentView. Script terminated.',20,-1) with log
		END CATCH
	ELSE
		Print 'tblEquipmentView not present, proceed to create'	
	END
GO

CREATE TABLE [dbo].[tblEquipmentView](
	[EquipmentID] [int] NOT NULL,
	[EquipmentType] [nvarchar](500) NULL,
	[EquipmentStatus] [nvarchar](500) NULL,
	[ApparatusType] [nvarchar](500) NULL,
	[SourceType] [nvarchar](500) NULL,
	[DateRegistered] [datetime] NOT NULL,
	[Brand] [nvarchar](max) NULL,
	[Model] [nvarchar](max) NULL,
	[Classification] [nvarchar](max) NULL,
	[ContactDetails] [nvarchar](max) NULL,
	[RegAuthorityIDNo] [nvarchar](30) NULL,
	[LicenceNumber] [nvarchar](30) NULL,
	[DateAcquired] [datetime] NULL,
	[DateOfDisposal] [datetime] NULL,
	[SerialNo] [nvarchar](50) NULL,
	[ISONumber] [nvarchar](50) NULL,
	[AssetNumber] [nvarchar](12) NULL,
	[DateManufactured] [datetime] NULL,
	[DateLastTested] [datetime] NULL,
	[WorkingLife] [nvarchar](max) NULL,
	[DateWorkingLifeExpiry] [datetime] NULL,
	[Radionuclide] [nvarchar](100) NULL,
	[EquipmentNotes] [nvarchar](max) NULL,
	[EquipmentName] [nvarchar](max) NULL,
	[Manufacturer] [nvarchar](255) NULL,
	[BuildingPrefixName] [nvarchar](max) NULL,
	[BuildingNumber] [nvarchar](20) NULL,
	[UnitNumber] [nvarchar](20) NULL,
	[StreetName] [nvarchar](max) NULL,
	[Suburb] [nvarchar](40) NULL,
	[State] [nvarchar](20) NULL,
	[Postcode] [nvarchar](5) NULL,
	[ControlGenManufacturer] [nvarchar](80) NULL,
	[ControlGenModel] [nvarchar](max) NULL,
	[ControlGenSerial] [nvarchar](20) NULL,
	[TubeHousingManufacturer] [nvarchar](80) NULL,
	[TubeHousingModel] [nvarchar](max) NULL,
	[TubeHousingSerial] [nvarchar](max) NULL,
	[TubeInsertManufacturer] [nvarchar](80) NULL,
	[TubeInsertModel] [nvarchar](max) NULL,
	[TubeInsertSerial] [nvarchar](max) NULL,
	[Category] [nvarchar](max) NULL,
	[NominalActivity] [nvarchar](max) NULL,
	[RegAuthorityIDNoPrev] [nvarchar](max) NULL,
	[LicenceNumberPrev] [nvarchar](max) NULL,
	[HasComplianceCertificate] [nvarchar](10) NULL,
	[AssayDate] [datetime] NULL,
	[ComplianceCertExpiry] [datetime] NULL,
	[SendComplianceCertReminder] [nvarchar](10) NULL,
	[SendComplianceCertReminderTo] [nvarchar](max) NULL,
	[ApparatusDescription] [nvarchar](50) NULL,
	[CostGroup] [nvarchar](max) NULL,
	[SealedSourceDescription] [nvarchar](500) NULL,
	[SecurityClassification] [nvarchar](100) NULL,
	[Campus] [nvarchar](100) NULL,
	[SiteLocationName] [nvarchar](max) NULL,
	[BusinessUnitName] [nvarchar](max) NULL,
	[CentreNo] [varchar](max) NULL,
	[CentreName] [nvarchar](255) NULL,
	[NameOfPremises] [nvarchar](100) NULL,
	[OtherApparatus] [nvarchar](max) NULL,
	[OtherSealedSourceDevice] [nvarchar](max) NULL,
	[PermittedPractice] [nvarchar](max) NULL,
	[PermittedLocation] [nvarchar](max) NULL,
	[PermittedIonisingApparatus] [nvarchar](max) NULL,
	[PermittedPurpose] [nvarchar](max) NULL,
	[PermittedSealedSource] [nvarchar](max) NULL,
	[PermittedRadionuclide] [nvarchar](max) NULL,
	[MaxPermittedActivity] [nvarchar](max) NULL,
	[ResponsibleDepartment] [nvarchar](max) NULL,
	[RequiresTesting] [nvarchar](10) NULL,
	[Vendor] [nvarchar](max) NULL,
	[VendorDetails] [nvarchar](max) NULL,
	[TypicalProcedure] [nvarchar](max) NULL,
	[TypicalShielding] [nvarchar](max) NULL,
	[ServiceCost] [nvarchar](20) NULL,
	[TestingCost] [nvarchar](20) NULL,
	[ReplacementCost] [nvarchar](20) NULL,
	[TotalDepreciation] [nvarchar](20) NULL,
	[DepreciationDesc] [nvarchar](max) NULL,
	[RentalCost] [nvarchar](20) NULL,
	[RunningCost] [nvarchar](20) NULL,
	[OtherCostA] [nvarchar](20) NULL,
	[OtherCostADesc] [nvarchar](max) NULL,
	[OtherCostB] [nvarchar](20) NULL,
	[OtherCostBDesc] [nvarchar](max) NULL,
	[CostsNote] [nvarchar](max) NULL,
	[DatePurchased] [datetime] NULL,
	[DateWarrantyExpires] [datetime] NULL,
	[DateGuaranteeExpires] [datetime] NULL,
	[WarrantyConditions] [nvarchar](max) NULL,
	[GuranteeConditions] [nvarchar](max) NULL,
	[PurchaseCost] [nvarchar](20) NULL,
	[DatePlannedExpiration] [datetime] NULL,
	[DisposalCost] [nvarchar](20) NULL,
	[DisposalVendorContact] [nvarchar](max) NULL,
	[DisposalMethod] [nvarchar](max) NULL,
	[DisposalConfirmed] [nvarchar](10) NULL,
	[DisposalConfirmation] [nvarchar](max) NULL,
	[DisposalEnvironmental] [nvarchar](max) NULL,
	[DisposalPermitRequired] [nvarchar](10) NULL,
	[DisposalPermitObtained] [nvarchar](10) NULL,
	[DisposalPermitNumber] [nvarchar](max) NULL,
	[DisposalPermitDate] [datetime] NULL,
	[DisposalPermitConditions] [nvarchar](max) NULL,
	[TestingFrequency] [nvarchar](20) NULL,
	[DateNextTestExpected] [datetime] NULL,
	[DateNextTestScheduled] [datetime] NULL,
	[RequiresAuditing]  [nvarchar](10) NULL,
	[AuditFrequency] [nvarchar](20) NULL,
	[DateLastAudit] [datetime] NULL,
	[LastAuditConductedBy] [nvarchar](max) NULL,
	[LastAuditConductedLicenceNo] [nvarchar](max) NULL,
	[DateNextAuditExpected] [datetime] NULL,
	[DateNextAuditScheduled] [datetime] NULL,
	[LastAuditOutcomeSummary] [nvarchar](max) NULL,
	[LastAuditOutcomeDetail] [nvarchar](max) NULL,
	[DateDecommissioned] [datetime] NULL,
	[EquipmentFlagFollowup] [nvarchar](20) NULL,
	[Facility] [nvarchar](200) NULL,
	[LocalEquipmentID] [nvarchar](20) NULL,
	[AltLocalEquipmentID] [nvarchar](12) NULL,
	[ARPANSALADNumber] [nvarchar](20) NULL,
	[IntendedPurpose] [nvarchar](255) NULL,
	[ARPANSAStatus] [nvarchar](50) NULL,
	[InventoryStatus] [nvarchar](50) NULL,
	[DisposalStatus] [nvarchar](50) NULL,
	[OperatingParameter] [nvarchar](255) NULL,
	[LikelyExposure] [nvarchar](255) NULL,
	[ChemicalForm] [nvarchar](500) NULL,
	[PhysicalForm] [nvarchar](500) NULL,
	[Portability] [nvarchar](500) NULL,
	[EncapsulationMaterial] [nvarchar](500) NULL,
	[RoomName] [nvarchar](100) NULL,
	[LocationOther] [nvarchar](255) NULL,
	[ApprovalSubmissionDate] [datetime] NULL,
	[Approval] [datetime] NULL,
	[DisposalApprovalGranted] [datetime] NULL,
	[DisposalDetails] [nvarchar](max) NULL,
	[ActivityDate] [datetime] NULL,
	[ActivityBq] [nvarchar](max) NULL,
	[MaxActivityBq] [nvarchar](max) NULL,
	[Max_kVp] [nvarchar](255) NULL,
	[Max_mA] [nvarchar](255) NULL,
	[RecommendedWorkingLife] [nvarchar](20) NULL,
	[CurrentActivity] [nvarchar](max) NULL,
	[SourceAE] [nvarchar](max) NULL,
	[SourceAD] [nvarchar](max) NULL,
	[WipeTestDate] [datetime] NULL,
	[Comments] [nvarchar](max) NULL,
	[InternalComments] [nvarchar](max) NULL,
	[ASNOPermitNo] [nvarchar](20) NULL,
	[ASNOBatchNo] [nvarchar](20) NULL,
	[NonIonisingSource] [nvarchar](500) NULL,
	[NonIonisingApparatusType] [nvarchar](max) NULL,
	[IonisingSource] [nvarchar](max) NULL,
	[IonisingApparatusType] [nvarchar](max) NULL,
	[UnsealedSource] [nvarchar](max) NULL,
	[LastSightedDate] [datetime] NULL,
	[LastSightedBy] [varchar](30) NULL,
	[LastSightedComment] [varchar](max) NULL,
	[AddedBy] [nvarchar](20) NULL,
	[AddedDateTime] [datetime] NULL,
	[ModifiedBy] [nvarchar](20) NULL,
	[ModifiedDateTime] [datetime] NULL,
	[LicencePermitNo] [nvarchar](100) NULL,
	[Latitude] [nvarchar](20) NULL,
	[Longitude] [nvarchar](20) NULL,
	[EquipmentModel] [nvarchar](180) NULL,
	[DxSourceCustodian] [nvarchar](200) NULL,
	[DxAreaCustodian] [nvarchar](200) NULL,
	[DxLineManager] [nvarchar](200) NULL,
	[DxRSO] [nvarchar](200) NULL,
	[ASNOMaterial] [nvarchar](10) NULL,
	[ASNOInventoryBatchNo] [nvarchar](20) NULL,
	[ExemptLimitBq] [nvarchar](20) NULL,
	[ComputedAD] [nvarchar](20) NULL,
	[ComputedAE] [nvarchar](20) NULL,
	[SourceCertificateNo] [nvarchar](30) NULL,
	[SourceCertificateID] [nvarchar](20) NULL,
	[LicencedActivityBq] [nvarchar](max) NULL,
	[DateOfReceipt] [datetime] NULL,
	[DateOfLastSurvey] [datetime] NULL,
 CONSTRAINT [PK_tblEquipmentView] PRIMARY KEY CLUSTERED 
(
	[EquipmentID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

ALTER TABLE [dbo].[tblEquipmentView]  WITH CHECK ADD  CONSTRAINT [FK_tblEquipmentView_tblEquipment] FOREIGN KEY([EquipmentID])
REFERENCES [dbo].[tblEquipment] ([EquipmentID])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[tblEquipmentView] CHECK CONSTRAINT [FK_tblEquipmentView_tblEquipment]
GO



IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblBusinessUnitContact')	 -- tblBusinessUnitContact contents check
	BEGIN 
		BEGIN
			IF EXISTS(SELECT * FROM tblBusinessUnitContact) 
				BEGIN
				raiserror('Cannot execute script. tblBusinessUnitContact contains data.',20,-1) with log
				END
			ELSE
				Print 'tblBusinessUnitContact not used can continue'
				Print '-----------------------------------------------------------------------------------------------------'
			END	
	END
ELSE
	Print 'tblBusinessUnitContact not present can continue'
GO

-- ==================================================================================================================
-- Remove ReferenceType 105 (Duplicate Security Category)
-- ==================================================================================================================
BEGIN
	DELETE tblReferenceItem WHERE ReferenceTypeID = 105
	DELETE tblReferenceType WHERE ReferenceTypeID = 105
END
GO

-- ==================================================================================================================
-- New tblRefFeatureConfiguration entry item 24
-- ==================================================================================================================

   IF NOT EXISTS(SELECT * FROM tblRefFeatureConfiguration WHERE RefFeatureConfigurationID = 24)
	BEGIN
		Insert tblRefFeatureConfiguration
		([RefFeatureConfigurationID],[Name],[Description],[Value])
		Values
		(24,'Strict Source Grouping','Enforces rules requiring Source Custodian and Area Custodian group members to have matching roles for Premises and Rooms. Requires Line Managers to be managers of Source Custodian contacts.',0)
		Print 'Added Reference Type: Strict Source Grouping'
	END
   GO

-- ==================================================================================================================
-- New tblRefConfiguration entry item 68
-- ==================================================================================================================

   IF NOT EXISTS(SELECT * FROM tblRefConfiguration WHERE RefConfigurationID = 68)
	BEGIN
		Insert tblRefConfiguration
		([RefConfigurationID],[Description],[Value])
		Values
		(68,'Require area codes for Contact Landline entries',1)
		Print 'Added Configuration Option: Require area codes for Contact Landline entries, default True'
	END
   GO


-- ==================================================================================================================
-- New Reference Types
-- ==================================================================================================================

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 136)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(136,'Equipment Model Status',2020-01-01)
		Print 'Added Reference Type: Equipment Model Status'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 137)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(137,'Equipment Model Type',2020-01-01)
		Print 'Added Reference Type: Equipment Model Type'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 138)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(138,'Privacy Rating',2020-01-01)
		Print 'Added Reference Type: Information Privacy Rating'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 139)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(139,'Contact Medium Type',2020-01-01)
		Print 'Added Reference Type: Contact Medium Type'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 140)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(140,'Contact Medium Availability',2020-01-01)
		Print 'Added Reference Type: Contact Medium Availability'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 141)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(141,'Contact Address Context',2020-01-01)
		Print 'Added Reference Type: Contact Address Context'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 142)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(142,'Contact Address Type',2020-01-01)
		Print 'Added Reference Type: Contact Address Type'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 143)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(143,'Contact Role - Business Unit',2020-01-01)
		Print 'Added Reference Type: Contact Role - Business Unit'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 144)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(144,'Contact Role - Centre',2020-01-01)
		Print 'Added Reference Type: Contact Role - Centre'
	END
   GO
   
   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 145)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(145,'Contact Role - Equipment',2020-01-01)
		Print 'Added Reference Type: Contact Role - Equipment'
	END
   GO
 
   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 146)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(146,'Contact Role - Organisation',2020-01-01)
		Print 'Added Reference Type: Contact Role - Organisation'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 147)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(147,'Contact Role - Premises',2020-01-01)
		Print 'Added Reference Type: Contact Role - Premises'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 148)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(148,'Contact Role - Room',2020-01-01)
		Print 'Added Reference Type: Contact Role - Room'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 149)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(149,'Contact Role - Site',2020-01-01)
		Print 'Added Reference Type: Contact Role - Site'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 150)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(150,'Contact Role - Training Course',2020-01-01)
		Print 'Added Reference Type: Contact Role - Training Course'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 151)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(151,'Contact Role - Training Institute',2020-01-01)
		Print 'Added Reference Type: Contact Role - Training Institute'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 152)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(152,'Contact Relationship',2020-01-01)
		Print 'Added Reference Type: Contact Relationship'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceType WHERE ReferenceTypeID = 153)
	BEGIN
		Insert tblReferenceType
		([ReferenceTypeID],[Description],[StartDate])
		Values
		(153,'Contact Role - Group',2020-01-01)
		Print 'Added Reference Type: Contact Role - Group'
	END
   GO

-- ==================================================================================================================
-- New Reference Items
-- ==================================================================================================================


-- Rename Non-ionizing Apparatus to Non-ionizing Source
UPDATE tblReferenceItem SET Description = 'Non-ionising Source' WHERE ReferenceTypeID = 48 And Code = 7	
GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 136 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,136,'In Use',2020-01-01)
		Print 'Added Reference Type: Equipment Model Status [In Use]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 136 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,136,'Under Review',2020-01-01)
		Print 'Added Reference Type: Equipment Model Status [Under Review]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 136 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,136,'Decommissioned',2020-01-01)
		Print 'Added Reference Type: Equipment Model Status [Decommissioned]'
	END
   GO


--


   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 137 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,137,'Non-ionising Source',2020-01-01)
		Print 'Added Reference Type: Equipment Model Type [Non-ionising Source]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 137 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,137,'Ionising Source',2020-01-01)
		Print 'Added Reference Type: Equipment Model Type [Ionising Source]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 137 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,137,'Sealed Source',2020-01-01)
		Print 'Added Reference Type: Equipment Model Type [Sealed Source]'
	END
   GO

   update tblReferenceItem SET Description = 'Non-ionising Source'WHERE ReferenceTypeID = 137 AND Code = 1
   update tblReferenceItem SET Description = 'Ionising Source'WHERE ReferenceTypeID = 137 AND Code = 2
   update tblReferenceItem SET Description = 'Sealed Source'WHERE ReferenceTypeID = 137 AND Code = 3

   --

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 13 AND Code = 28)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(28,13,'ARPANSA Source Licence',2020-01-01)
		Print 'Added Reference Type: Document Type [ARPANSA Source Licence]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 13 AND Code = 29)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(29,13,'ARPANSA Source Reissue',2020-01-01)
		Print 'Added Reference Type: Document Type [ARPANSA Source Reissue]'
	END
   GO


-- Information Privacy Ratings

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,138,'General',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [General]'
	END
   GO
   
   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,138,'Health Information',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Health Information]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,138,'Official',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Official]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 4)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(4,138,'Official: Sensitive',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Official: Sensitive]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 5)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(5,138,'Personal',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Personal]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 6)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(6,138,'Private',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Private]'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 7)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(7,138,'Protected',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Protected]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 8)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(8,138,'Public Domain',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Public Domain]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 9)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(9,138,'Secret',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Secret]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 10)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(10,138,'Sensitive',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Sensitive]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 11)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(11,138,'Top Secret',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Top Secret]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 12)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(12,138,'Unclassified',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Unclassified]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 138 AND Code = 13)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(13,138,'Unoffical',2020-01-01)
		Print 'Added Reference Item: Information Privacy Rating [Unoffical]'
	END
   GO

   -- Contact Medium Types

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 139 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,139,'Mobile',2020-01-01)
		Print 'Added Reference Item: Contact Medium Type [Mobile]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 139 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,139,'Landline',2020-01-01)
		Print 'Added Reference Item: Contact Medium Type [Landline]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 139 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,139,'Email',2020-01-01)
		Print 'Added Reference Item: Contact Medium Type [Email]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 139 AND Code = 4)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(4,139,'URL',2020-01-01)
		Print 'Added Reference Item: Contact Medium Type [URL]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 139 AND Code = 5)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(5,139,'Facsimile',2020-01-01)
		Print 'Added Reference Item: Contact Medium Type [Facsimile]'
	END
   GO

   -- Contact Medium Availability

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,140,'Work',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Work]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,140,'Home',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Home]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,140,'Private',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Private]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 4)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(4,140,'Emergency Only',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Emergency Only]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 5)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(5,140,'Shared',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Shared]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 6)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(6,140,'Interim',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Interim]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 7)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(7,140,'Business Unit Limited',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Business Unit Limited]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 8)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(8,140,'Site Specific',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Site Specific]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 9)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(9,140,'Premises Specific',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Premises Specific]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 140 AND Code = 10)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(10,140,'Room Specific',2020-01-01)
		Print 'Added Reference Item: Contact Medium Availability [Room Specific]'
	END
   GO

   -- Contact Address Context

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,141,'Work',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Office]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,141,'Work (Office)',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Work (Office)]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,141,'Work (Facility)',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Work (Facility)]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 4)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(4,141,'Work (Lab)',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Work (Lab)]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 5)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(5,141,'Work (Store)',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Work (Store)]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 6)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(6,141,'Work (Secure Store)',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Work (Secure Store)]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 7)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(7,141,'Private Residence',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Private Residence]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 8)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(8,141,'Public Venue',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Public Venue]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 9)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(9,141,'Site',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Site]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 10)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(10,141,'Room',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Room]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 141 AND Code = 11)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(11,141,'Other',2020-01-01)
		Print 'Added Reference Item: Contact Address Context [Other]'
	END
   GO

   -- DxContact Address Types
   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 142 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,142,'Street Address',2020-01-01)
		Print 'Added Reference Item: Contact Address Type [Street Address]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 142 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,142,'Postal Address',2020-01-01)
		Print 'Added Reference Item: Contact Address Type [Postal Address]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 142 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,142,'Delivery Address',2020-01-01)
		Print 'Added Reference Item: Contact Address Type [Delivery Address]'
	END
   GO

-- Contact Role - Business Unit

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 143 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,143,'Business Unit Member',2020-01-01)
		Print 'Added Reference Item: Contact Role - Business Unit [Business Unit Member]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 143 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,143,'Business Unit RSO',2020-01-01)
		Print 'Added Reference Item: Contact Role - Business Unit [Business Unit RSO]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 144 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,144,'Centre Contact',2020-01-01)
		Print 'Added Reference Item: Contact Role - Centre [Centre Contact]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 144 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,144,'Centre RSO',2020-01-01)
		Print 'Added Reference Item: Contact Role - Centre [Centre RSO]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 145 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,145,'Equipment Custodian',2020-01-01)
		Print 'Added Reference Item: Contact Role - Equipment [Equipment Custodian]'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 146 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,146,'Organisation Contact',2020-01-01)
		Print 'Added Reference Item: Contact Role - Organisation [Organisation Contact]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 147 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,147,'Source Custodian',2020-01-01)
		Print 'Added Reference Item: Contact Role - Premises [Source Custodian]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 147 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,147,'Area Custodian',2020-01-01)
		Print 'Added Reference Item: Contact Role - Premises [Area Custodian]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 148 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,148,'Source Custodian',2020-01-01)
		Print 'Added Reference Item: Contact Role - Room [Source Custodian]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 148 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,148,'Area Custodian',2020-01-01)
		Print 'Added Reference Item: Contact Role - Room [Area Custodian]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 149 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,149,'Site RSO',2020-01-01)
		Print 'Added Reference Item: Contact Role - Site [Site RSO]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 150 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,150,'Trainer',2020-01-01)
		Print 'Added Reference Item: Contact Role - Training Course [Trainer]'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 151 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,151,'Course Coordinator',2020-01-01)
		Print 'Added Reference Item: Contact Role - Training Institute [Course Coordinator]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 151 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,151,'Intake Officer',2020-01-01)
		Print 'Added Reference Item: Contact Role - Training Institute [Intake Officer]'
	END
   GO


   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 152 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,152,'Line Manager',2020-01-01)
		Print 'Added Reference Item: Contact Relationship [Line Manager]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 152 AND Code = 2)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(2,152,'Personal - Family',2020-01-01)
		Print 'Added Reference Item: Contact Relationship [Personal - Family]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 152 AND Code = 3)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(3,152,'Personal - Partner',2020-01-01)
		Print 'Added Reference Item: Contact Relationship [Personal - Partner]'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 152 AND Code = 4)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(4,152,'Professional - Associate',2020-01-01)
		Print 'Added Reference Item: Contact Relationship [Professional - Associate]'
	END
   GO


   -- --------------------------------------------------------------------------------------------

   IF NOT EXISTS(SELECT * FROM tblReferenceItem WHERE ReferenceTypeID = 153 AND Code = 1)
	BEGIN
		Insert tblReferenceItem
		([Code],[ReferenceTypeID],[Description],[StartDate])
		Values
		(1,153,'Member',2020-01-01)
		Print 'Added Reference Item: Contact Role - Group [Member]'
	END
   GO



   -- Populate ARPANSA Sources
   

IF (SELECT COUNT(*) FROM tblSource) <88
BEGIN
delete tblLicencePermitSource
DBCC CHECKIDENT(tblLicencePermitSource,RESEED,0)
END
GO

IF (SELECT COUNT(*) FROM tblSource) <88
BEGIN
delete tblSource
DBCC CHECKIDENT(tblSource,RESEED,1)
END
GO

IF (SELECT COUNT(*) FROM tblSource) <88
BEGIN
SET IDENTITY_INSERT [dbo].[tblSource] ON 
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (1, 1, N'G1-1', N'1', N'Sealed source for calibration purposes of activity of 40 MBq or less', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (2, 1, N'G1-2', N'2', N'Sealed source in a fully enclosed analytical device', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (3, 1, N'G1-3', N'3', N'Sealed source with activity of 400 MBq or less in a fixed gauge', N'Radiation Protection Series 13: Code of Practice and Safety Guide for Safe Use of Fixed Radiation Gauges (2007)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (4, 1, N'G1-4', N'4', N'Sealed source in a blood irradiator', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (5, 1, N'G1-5', N'5', N'Sealed source in a bone densitometer', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (6, 1, N'G1-6', N'6', N'Sealed source that:
(a) is in storage and awaiting disposal; and
(b) has a nuclide with a maximum activity of not more than 109 times the activity value for that nuclide set out in Part 1 of Schedule 1 of the Regulations.', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (7, 1, N'G1-7', N'7', N'Unsealed source, or sources, in a laboratory or particular premises, having nuclides of one kind only with a maximum activity not more than 102 times the activity value for that nuclide set out in Part 1 of Schedule 1 (of the Regulations)', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (8, 1, N'G1-8', N'8', N'Unsealed source, or sources, in a laboratory or particular premises, having nuclides such that when the maximum activity of each nuclide in the source, or sources, is divided by the activity value for that nuclide set out in Part 1 of Schedule 1 (of the Regulations), the total of the results for all nuclides in the source, or sources, is not more than 102.', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (9, 1, N'G1-9', N'9', N'Mammographic X-ray unit', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (10, 1, N'G1-10', N'10', N'Conventional dental X-ray unit', N'Radiation Protection Series 10: Code of Practice and Safety Guide for Radiation Protection in Dentistry (2005)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (11, 1, N'G1-11', N'11', N'X-ray unit used for bone densitometry', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (12, 1, N'G1-12', N'12', N'X-ray unit used for veterinary radiography', N'Radiation Protection Series 17: Code of Practice and Safety Guide for Radiation Protection in Veterinary Medicine (2009)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (13, 1, N'G1-13', N'13', N'Fully enclosed X-ray analysis unit', N'Radiation Health Series 9: Code of practice for protection against ionizing radiation emitted from X-ray Analysis Equipment (1984)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (14, 1, N'G1-14', N'14', N'Baggage inspection X-ray unit', N'Radiation Health Series 21: Statement on cabinet X-ray equipment for examination of letters, packages, baggage, freight and other articles for security, quality control and other purposes (1987)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (15, 1, N'G1-15', N'15', N'Mobile or portable medical X-ray unit', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (16, 1, N'G1-16', N'16', N'Magnetic field non-destructive testing device', N'Radiation Protection Series 3: Radiation Protection Standards for Maximum Exposure Levels to Radiofrequency Fields - 3 kHz to 300 GHz (2002)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (17, 1, N'G1-17', N'17', N'Induction heater or induction furnace', N'Radiation Protection Series 3: Radiation Protection Standards for Maximum Exposure Levels to Radiofrequency Fields - 3 kHz to 300 GHz (2002)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (18, 1, N'G1-18', N'18', N'Industrial radiofrequency heater or welder', N'Radiation Protection Series 3: Radiation Protection Standards for Maximum Exposure Levels to Radiofrequency Fields - 3 kHz to 300 GHz (2002)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (19, 1, N'G1-19', N'19', N'Radiofrequency plasma tube', N'Radiation Protection Series 3: Radiation Protection Standards for Maximum Exposure Levels to Radiofrequency Fields - 3 kHz to 300 GHz (2002)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (20, 1, N'G1-20', N'20', N'Microwave or radiofrequency diathermy equipment', N'Radiation Protection Series 3: Radiation Protection Standards for Maximum Exposure Levels to Radiofrequency Fields - 3 kHz to 300 GHz (2002)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (21, 1, N'G1-21', N'21', N'Industrial microwave or radiofrequency processing system', N'Radiation Protection Series 3: Radiation Protection Standards for Maximum Exposure Levels to Radiofrequency Fields - 3 kHz to 300 GHz (2002)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (22, 1, N'G1-22', N'22', N'Optical source, other than a laser product, emitting ultraviolet radiation, infra-red or visible light', N'Australian/New Zealand Standard: Safety in laboratories - Non-ionizing radiations -Electromagnetic, sound and ultrasound (AS/NZS 2243.5:2004)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (23, 1, N'G1-23', N'23', N'Laser product with an accessible emission that exceeds the accessible emission limits of a Class 3R laser product, as set out in AS/NZS IEC 60825.1:2014', N'Australian/New Zealand Standard: Safety of laser products Part 1: Equipment classification and requirements (AS/NZS IEC 60825-1:2014')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (24, 1, N'G1-24', N'24', N'Optical fibre communication system exceeding Hazard Level 3R, as defined by AS/NZS IEC 60825.2:2011', N'Australian/New Zealand Standard: Safety of laser products Part 2: Safety of optical fibre communications systems (OFCS) (AS/NZS IEC 60825.2:2011')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (25, 1, N'G1-25', N'24A', N'
Sealed source not mentioned in another item in this (Group 1) table or in the definition of Group 2 or Group 3 (in section 4 of the Regulations), dealings with which do not have the potential for accidental exposure likely to exceed the dose limits mentioned in sections 77 and 79 (of the Regulations)', N'Has Sections (a) to (g)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (26, 1, N'G1-25 (a)', N'24A', N'(a) Sealed source for training and education purposes of 40 MBq or less','Australian/New Zealand Standard: Safety of laser products Part 2: Safety of optical fibre communications systems (OFCS) (AS/NZS IEC 60825.2:2011)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (27, 1, N'G1-25 (b)', N'24A', N'(b) Manufactured item or component containing thorium','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (28, 1, N'G1-25 (c)', N'24A', N'(c) Clock, watch, heritage object, luminous dial or indicator with paint containing radium 226 of activity of 1 MBq or less and no other controlled material','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (29, 1, N'G1-25 (d)', N'24A', N'(d) Clock, watch, heritage object, luminous dial or indicator with paint containing promethium 147 of activity of 1 GBq or less and no other controlled material','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (30, 1, N'G1-25 (e)', N'24A', N'(e) Clock, watch, heritage object, military device or electronic component containing tritium of activity of 100 GBq or less and no other controlled material','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (31, 1, N'G1-25 (f)', N'24A', N'(f) Tritium as an ionisation source','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (32, 1, N'G1-25 (g)', N'24A', N'(g) Sealed source in a static eliminator or aerosol neutraliser','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (33, 1, N'G1-26', N'24B', N'
Controlled apparatus that produces ionising radiation not mentioned in another item of this (Group 1) table or in the definition of Group 2 or Group 3 (in section 4 of the Regulations), dealings with which do not have the potential for accidental exposure likely to exceed the dose limits mentioned in sections 77 and 79 (of the Regulations)', N'Has Sections (a) to (k)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (34, 1, N'G1-26 (a)', N'24B', N'(a) Fully enclosed X-ray unit (radiography for special purposes)','Radiation Health Series 22: Statement on enclosed X-ray equipment for special applications (1987)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (35, 1, N'G1-26 (b)', N'24B', N'(b) Portable handheld dental X-ray apparatus','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (36, 1, N'G1-26 (c)', N'24B', N'(c) Optical source, other than a laser product, emitting ultraviolet radiation, infrared or visible light - solar tower array','Australian/New Zealand Standard: Safety in laboratories - Non-ionizing radiations -Electromagnetic, sound and ultrasound (AS/NZS 2243.5:2004)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (37, 1, N'G1-26 (d)', N'24B', N'(d) Ion beam etching unit','Australian/New Zealand Standard: Safety in laboratories - Non-ionizing radiations -Electromagnetic, sound and ultrasound (AS/NZS 2243.5:2004)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (38, 1, N'G1-26 (e)', N'24B', N'(e) Intentionally blank','')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (39, 1, N'G1-26 (f)', N'24B', N'(f) Dual energy X-ray absorptiometry (DEXA) unit for veterinary studies','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (40, 1, N'G1-26 (g)', N'24B', N'(g) Fully enclosed X-ray biological irradiator (low power)','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (41, 1, N'G1-26 (h)', N'24B', N'(h) CT, SPECT/CT or PET/CT scanner for imaging of small animals','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (42, 1, N'G1-26 (i)', N'24B', N'(i) Klystron amplifier for radio communication or radar','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (43, 1, N'G1-26 (j)', N'24B', N'(j) Laser used on animals','Australian/New Zealand Standard: Safety of laser products Part 1: Equipment classification and requirements (AS/NZS IEC 60825-1:2014)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (44, 1, N'G1-26 (k)', N'24B', N'(k) Handheld backscatter X-ray security inspection system','')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (45, 2, N'G2-1', N'25', N'Sealed source for calibration purposes of activity of more than 40 MBq', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (46, 2, N'G2-2', N'26', N'Sealed source in a partially enclosed analytical device', N'Sealed source in a partially enclosed analytical device')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (47, 2, N'G2-3', N'27', N'Sealed source of activity of more than 400 MBq in a fixed gauge', N'Radiation Protection Series 13: Code of Practice and Safety Guide for Safe Use of Fixed Radiation Gauges (2007)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (48, 2, N'G2-4', N'28', N'Sealed source in a mobile gauge', N'Radiation Protection Series 5: Code of Practice and Safety Guide for Portable Density/Moisture Gauges Containing Radioactive Sources (2004)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (49, 2, N'G2-5', N'29', N'Sealed source for medical or veterinary diagnostic nuclear medicine use', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (50, 2, N'G2-6', N'30', N'Unsealed source, or sources, in a laboratory or particular premises, having nuclides of one kind only with a maximum activity of more than 102, but not more than 104, times the activity value for that nuclide set out in Part 1 of Schedule 1 (of the Regulations)', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (51, 2, N'G2-7', N'31', N'Unsealed source, or sources, in a laboratory or particular premises, having nuclides such that when the maximum activity of each nuclide in the source, or sources, is divided by the activity value for that nuclide set out in Part 1 of Schedule 1 (of the Regulations), the total of the results for all nuclides in the source, or sources, is more than 102 but not more than 104', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (52, 2, N'G2-8', N'32', N'Unsealed sources used for tracer studies in the environment', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (53, 2, N'G2-9', N'33', N'Industrial radiography X-ray unit', N'Radiation Protection Series C-4: Code of Radiation Protection Requirements for Industrial Radiography (2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (54, 2, N'G2-10', N'34', N'Fixed medical X-ray unit, including a unit used for fluoroscopy, tomography and chiropractic radiography', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (55, 2, N'G2-11', N'35', N'Partially enclosed X-ray analysis unit', N'Radiation Health Series 9: Code of practice for protection against ionizing radiation emitted from X-ray Analysis Equipment (1984)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (56, 2, N'G2-12', N'36', N'Medical therapy simulator', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (57, 2, N'G2-13', N'37', N'CT scanner', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (58, 2, N'G2-14', N'37A', N'Sealed source of controlled material not mentioned in another item of this (Group 2) table or in the definition of Group 1 or Group 3 (in section 4 of the Regulations), dealings with which have the potential for accidental exposure likely to exceed a dose limit mentioned in sections 77 and 79 (of the Regulations) but unlikely to result in acute effects', N'Has sections (a) to (d)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (59, 2, N'G2-14 (a)', N'37A', N'(a) Sealed source for training and education purposes of activity more than 40 MBq','')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (60, 2, N'G2-14 (b)', N'37A', N'(b) Clock, watch, heritage object, luminous dial or indicator with paint containing radium 226 of activity of more than 1 MBq and no other controlled material','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:201)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (61, 2, N'G2-14 (c)', N'37A', N'(c) Clock, watch, heritage object, luminous dial or indicator with paint containing promethium 147 of activity of more than 1 GBq and no other controlled material','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (62, 2, N'G2-14 (d)', N'37A', N'(d) Clock, watch, heritage object, military device or electronic component containing tritium of activity of more than 100 GBq and no other controlled material','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (63, 2, N'G2-15', N'37B', N'Controlled apparatus that produces ionizing radiation not mentioned in another item of this (Group 2) table or in the definition of Group 1 or Group 3 (in section 4 of the Regulations), dealings with which have the potential for accidental exposure likely to exceed a dose limit mentioned in sections 77 and 79 (of the Regulations) but unlikely to result in acute effects', N'Has sections (a) to (j)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (64, 2, N'G2-15 (a)', N'37B', N'(a) Mobile backscatter X-ray security inspection system','')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (65, 2, N'G2-15 (b)', N'37B', N'(b) Mobile fluoroscopic X-ray apparatus','Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (66, 2, N'G2-15 (c)', N'37B', N'(c) CT scanner for imaging of non-human objects','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (67, 2, N'G2-15 (d)', N'37B', N'(d) Fixed medical X-ray unit used for research purposes (other than medical trials), including a unit designed for fluoroscopy, tomography, mammography and chiropractic radiography','')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (68, 2, N'G2-15 (e)', N'37B', N'(e) Personnel security screening system using backscatter X-rays','American National Standard: Radiation Safety For Personnel Security Screening Systems Using X-rays or Gamma Radiation (ANSI/HPS N43.17-2009)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (69, 2, N'G2-15 (f)', N'37B', N'(f) Orthopantomogram (OPG) (dental panoramic X-ray unit)','Radiation Protection Series 10: Code of Practice and Safety Guide for Radiation Protection in Dentistry (2005)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (70, 2, N'G2-15 (g)', N'37B', N'(g) Fully enclosed X-ray biological irradiator','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (71, 2, N'G2-15 (h)', N'37B', N'(h) Personnel anti-smuggling screening system using transmission X-rays','American National Standard: Radiation Safety For Personnel Security Screening Systems Using X-rays or Gamma Radiation (ANSI/HPS N43.17-2009)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (72, 2, N'G2-15 (i)', N'37B', N'(i) Handheld X-ray Fluorescence Analyser','')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (73, 2, N'G2-15 (j)', N'37B', N'(j) Portable Deuterium/Deuterium Neutron Generator for materials analysis','Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (74, 3, N'G3-1', N'38', N'Sealed source for industrial radiography', N'Radiation Protection Series C-4: Code of Radiation Protection Requirements for Industrial Radiography (2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (75, 3, N'G3-2', N'39', N'Sealed source for medical and veterinary radiotherapy', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (76, 3, N'G3-3', N'40', N'Sealed source in a bore hole logger', N'Radiation Health Series 28: Code of practice for the safe use of sealed radioactive sources in borehole logging (1989)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (77, 3, N'G3-4', N'41', N'Sealed source not mentioned in another item of this (Group 3) table or in the definition of Group 1 or Group 2 (in section 4 of the Regulations), dealings with which have the potential for accidental exposure likely to exceed a dose limit mentioned in sections 77 and 79 (of the Regulations) and likely to result in acute effects. Has (a) Reactor start-up source',N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (78, 3, N'G3-5', N'42', N'Unsealed source, or sources, in a laboratory or particular premises, having nuclides of one kind only with a maximum activity of more than 104, but not more than 106, times the activity value for that nuclide set out in Part 1 of Schedule 1 (of the Regulations)', N'Radiation Protection Series C-6: Code for Disposal of Radioactive Waste by the User (2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (79, 3, N'G3-6', N'43', N'Unsealed source, or sources, in a laboratory or particular premises, having nuclides such that when the maximum activity of each nuclide in the source, or sources, is divided by the activity value for that nuclide set out in Part 1 of Schedule 1 (of the Regulations), the total of the results for all nuclides in the source, or sources, is more than 104 but not more than 10​​​​​​6', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (80, 3, N'G3-7', N'44', N'Veterinary or medical radiotherapy unit', N'Radiation Protection Series C-5: Code for Radiation Protection in Medical Exposure (2019)')

INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (81, 3, N'G3-8', N'45', N'Controlled apparatus that produces ionizing radiation not mentioned in another item of this (Group 3) table and in the definition of Group 1 or Group 2 (in section 4 of the Regulations), dealings with which have the potential for accidental exposure likely to exceed a dose limit mentioned in sections 77 and 79 (of the Regulations) and likely to result in acute effects', N'Has sections (a) to (g)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (82, 3, N'G3-8 (a)', N'45', N'(a) Industrial irradiator containing less than 100 TBq of a controlled material', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (83, 3, N'G3-8 (b)', N'45', N'(b) Neutron Beam Instrument', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (84, 3, N'G3-8 (c)', N'45', N'(c) Low Energy Implanter', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (85, 3, N'G3-8 (d)', N'45', N'(d) Portable/mobile deuterium-tritium (± deuterium-deuterium) neutron generator', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (86, 3, N'G3-8 (e)', N'45', N'(e) Industrial irradiator containing 100 TBq or more but less than 1 PBq of a controlled material and that is shielded and interlocked', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (87, 3, N'G3-8 (f)', N'45', N'(f) Sealed source in a fully enclosed and interlocked cabinet used for calibration purposes', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
INSERT [dbo].[tblSource] ([SourceID], [SourceGroupNo], [SourceCode], [SourceItemNo], [SourceDescription], [SourceReference]) VALUES (88, 3, N'G3-8 (g)', N'45', N'(g) X-ray based industrial irradiator', N'Australian/New Zealand Standard: Safety in laboratories Part 4: Ionizing radiations (AS/NZS 2243.4:2018)')
SET IDENTITY_INSERT [dbo].[tblSource] OFF
END
GO



-- ------------------------------------
-- tblEquipment remove replaced fields
-- ------------------------------------

--AreaCustodian
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'AreaCustodian' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN AreaCustodian
		Print ' '
		Print 'Column removed: AreaCustodian from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: AreaCustodian from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): AreaCustodian in tblEquipment'
GO

--AreaCustodianContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'AreaCustodianContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN AreaCustodianContact
		Print 'Column removed: AreaCustodianContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: AreaCustodianContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): AreaCustodianContact in tblEquipment'
GO

--LineManager
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'LineManager' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN LineManager
		Print 'Column removed: LineManager from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: LineManager from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): LineManager in tblEquipment'
GO

--LineManagerContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'LineManagerContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN LineManagerContact
		Print 'Column removed: LineManagerContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: LineManagerContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): LineManagerContact in tblEquipment'
GO

--RadiationSafetyOfficer
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficer' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN RadiationSafetyOfficer
		Print 'Column removed: RadiationSafetyOfficer from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: RadiationSafetyOfficer from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): RadiationSafetyOfficer in tblEquipment'
GO

--RadiationSafetyOfficerContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficerContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN RadiationSafetyOfficerContact
		Print 'Column removed: RadiationSafetyOfficerContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: RadiationSafetyOfficerContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): RadiationSafetyOfficerContact in tblEquipment'
GO

--Responsibility
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Responsibility' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN Responsibility
		Print 'Column removed: Responsibility from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Responsibility from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Responsibility in tblEquipment'
GO

--ResponsibilityContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ResponsibilityContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN ResponsibilityContact
		Print 'Column removed: ResponsibilityContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ResponsibilityContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ResponsibilityContact in tblEquipment'
GO

--ResponsibilityOf
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ResponsibilityOf' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN ResponsibilityOf
		Print 'Column removed: ResponsibilityOf from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ResponsibilityOf from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ResponsibilityOf in tblEquipment'
GO

--RepsonsibilityContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RepsonsibilityContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN RepsonsibilityContact
		Print 'Column removed: RepsonsibilityContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: RepsonsibilityContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): RepsonsibilityContact in tblEquipment'
GO

--RepsonsibilityOf
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RepsonsibilityOf' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN RepsonsibilityOf
		Print 'Column removed: RepsonsibilityOf from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: RepsonsibilityOf from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): RepsonsibilityOf in tblEquipment'
GO


--Custodian
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Custodian' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN Custodian
		Print 'Column removed: Custodian from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Custodian from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Custodian in tblEquipment'
GO


--CustodianContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'CustodianContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN CustodianContact
		Print 'Column removed: CustodianContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: CustodianContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): CustodianContact in tblEquipment'
GO

--Manager
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Manager' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN Manager
		Print 'Column removed: Manager from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Manager from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Manager in tblEquipment'
GO

--ManagerContact
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ManagerContact' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN ManagerContact
		Print 'Column removed: ManagerContact from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ManagerContact from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ManagerContact in tblEquipment'
GO


--Portability Text
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Portability' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN TRY
		ALTER TABLE tblEquipment
		DROP COLUMN Portability
		Print ' '
		Print 'Column removed: Portability from tblEquipment'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Portability from tblEquipment. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): Portability in tblEquipment'
GO


-------------------------------------
-- tblDxGroup data changes
-------------------------------------

-- ChairID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ChairID' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN ChairID
		Print ' '
		Print 'Column removed: ChairID from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ChairID from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): ChairID in tblDxGroup'
GO

-- SecretaryID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SecretaryID' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN SecretaryID
		Print 'Column removed: SecretaryID from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: SecretaryID from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): SecretaryID in tblDxGroup'
GO

-- AssistantID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'AssistantID' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN AssistantID
		Print 'Column removed: AssistantID from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: AssistantID from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): AssistantID in tblDxGroup'
GO

--SiteID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteID' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN SiteID
		Print 'Column removed: SiteID from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: SiteID from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): SiteID in tblDxGroup'
GO

--OrganisationID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrganisationID' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN OrganisationID
		Print 'Column removed: OrganisationID from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrganisationID from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrganisationID in tblDxGroup'
GO

--BusinessUnitID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'BusinessUnitID' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN BusinessUnitID
		Print 'Column removed: BusinessUnitID from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: BusinessUnitID from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): BusinessUnitID in tblDxGroup'
GO

--OrgName
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgName' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN OrgName
		Print 'Column removed: OrgName from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgName from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrgName in tblDxGroup'
GO

--Site
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Site' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN Site
		Print 'Column removed: Site from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Site from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Site in tblDxGroup'
GO

--Branch
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Branch' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN Branch
		Print 'Column removed: Branch from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Branch from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Branch in tblDxGroup'
GO

--BusinessUnit
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'BusinessUnit' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN BusinessUnit
		Print 'Column removed: BusinessUnit from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: BusinessUnit from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): BusinessUnit in tblDxGroup'
GO

--MainEmail
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'MainEmail' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN MainEmail
		Print 'Column removed: MainEmail from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: MainEmail from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): MainEmail in tblDxGroup'
GO

--MainTel
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'MainTel' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN MainTel
		Print 'Column removed: MainTel from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: MainTel from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): MainTel in tblDxGroup'
GO

--MainMob
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'MainMob' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN MainMob
		Print 'Column removed: MainMob from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: MainMob from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): MainMob in tblDxGroup'
GO

--Chair
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Chair' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN Chair
		Print 'Column removed: Chair from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Chair from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Chair in tblDxGroup'
GO

--Secretary
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Secretary' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN Secretary
		Print 'Column removed: Secretary from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Secretary from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Secretary in tblDxGroup'
GO

--Assistant
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Assistant' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN Assistant
		Print 'Column removed: Assistant from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Assistant from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Assistant in tblDxGroup'
GO

--Notes
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Notes' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		DROP COLUMN Notes
		Print 'Column removed: Notes from tblDxGroup'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Notes from tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Notes in tblDxGroup'
GO

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'GroupNotes' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN TRY
		ALTER TABLE tblDxGroup
		ADD GroupNotes nvarchar(max)
		Print 'Field added: GroupNotes to tblDxGroup, nvarchar(max)'	
		Print ' '
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem adding Column: GroupNotes to tblDxGroup. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Column already present (OK): GroupNotes in tblDxGroup'
GO



-------------------------------------
-- tblDxContact data changes
-------------------------------------

-- Remove DF_tblDxContact_PostalSameAsStreet Default Constraint

BEGIN 
	IF object_id(N'DF_tblDxContact_PostalSameAsStreet', 'D') IS NOT NULL
		BEGIN TRY
			ALTER TABLE [dbo].[tblDxContact]
			DROP CONSTRAINT DF_tblDxContact_PostalSameAsStreet
			Print 'Constraint dropped: [DF_tblDxContact_PostalSameAsStreet]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [DF_tblDxContact_PostalSameAsStreet]. Script terminated.',20,-1) with log
		END CATCH
	END
GO

-- Remove FK_tblDxContactCentre_tblDxContact

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxContactCentre_tblDxContact')
		BEGIN TRY
			ALTER TABLE [dbo].[tblDxContactCentre]
			DROP CONSTRAINT FK_tblDxContactCentre_tblDxContact
			Print 'Constraint dropped: [FK_tblDxContactCentre_tblDxContact]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblDxContactCentre_tblDxContact]. Script terminated.',20,-1) with log
		END CATCH
	END
GO

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxContactCentre_tblCentreContact')
		BEGIN TRY
			ALTER TABLE [dbo].[tblDxContactCentre]
			DROP CONSTRAINT FK_tblDxContactCentre_tblCentreContact
			Print 'Constraint dropped: [FK_tblDxContactCentre_tblCentreContact]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblDxContactCentre_tblCentreContact]. Script terminated.',20,-1) with log
		END CATCH
	END
GO

BEGIN
   IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblDxContactCentre')
		BEGIN TRY
			DROP TABLE tblDxContactCentre
			Print 'tblDxContactCentre dropped'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping tblDxContactCentre. Script terminated.',20,-1) with log
		END CATCH
END
GO


BEGIN
   IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'ChangeScriptsOld')
		BEGIN TRY
			DROP TABLE ChangeScriptsOld
			Print 'ChangeScriptsOld dropped'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping ChangeScriptsOld. Script terminated.',20,-1) with log
		END CATCH
END
GO


--DxContact fields to remove

--SchoolID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SchoolID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN SchoolID
		Print ' '
		Print 'Column removed: SchoolID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: SchoolID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): SchoolID in tblDxContact'
GO

--FacultyID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'FacultyID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN FacultyID
		Print 'Column removed: FacultyID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: FacultyID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): FacultyID in tblDxContact'
GO

--ProgramID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ProgramID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN ProgramID
		Print 'Column removed: ProgramID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ProgramID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ProgramID in tblDxContact'
GO


--ProjectID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ProjectID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN ProjectID
		Print 'Column removed: ProjectID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ProjectID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ProjectID in tblDxContact'
GO

--ManagerID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ManagerID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN ManagerID
		Print 'Column removed: ManagerID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ManagerID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ManagerID in tblDxContact'
GO

--AssistantID
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'AssistantID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN AssistantID
		Print 'Column removed: AssistantID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: AssistantID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): AssistantID in tblDxContact'
GO


IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'BusinessUnitID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN BusinessUnitID
		Print 'Column removed: BusinessUnitID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: BusinessUnitID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): BusinessUnitID in tblDxContact'
GO


IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'CampusID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN CampusID
		Print 'Column removed: CampusID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: CampusID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): CampusID in tblDxContact'
GO

IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrganisationID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrganisationID
		Print 'Column removed: OrganisationID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrganisationID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrganisationID in tblDxContact'
GO


IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteLocationID' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN SiteLocationID
		Print 'Column removed: SiteLocationID from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: SiteLocationID from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): SiteLocationID in tblDxContact'
GO

--EmergencyName
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmergencyName' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN EmergencyName
		Print 'Column removed: EmergencyName from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: EmergencyName from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): EmergencyName in tblDxContact'
GO

--EmergencyTelMob
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmergencyTelMob' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN EmergencyTelMob
		Print 'Column removed: EmergencyTelMob from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: EmergencyTelMob from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): EmergencyTelMob in tblDxContact'
GO

--EmergencyContext
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmergencyContext' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN EmergencyContext
		Print 'Column removed: EmergencyContext from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: EmergencyContext from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): EmergencyContext in tblDxContact'
GO

--Email1
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Email1' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Email1
		Print 'Column removed: Email1 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Email1 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Email1 in tblDxContact'
GO

--Email2
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Email2' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Email2
		Print 'Column removed: Email2 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Email2 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Email2 in tblDxContact'
GO

--TelMobile
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'TelMobile' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN TelMobile
		Print 'Column removed: TelMobile from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: TelMobile from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): TelMobile in tblDxContact'
GO


--TelWork
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'TelWork' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN TelWork
		Print 'Column removed: TelWork from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: TelWork from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): TelWork in tblDxContact'
GO


--TelHome
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'TelHome' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN TelHome
		Print 'Column removed: TelHome from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: TelHome from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): TelHome in tblDxContact'
GO


--TelOther
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'TelOther' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN TelOther
		Print 'Column removed: TelOther from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: TelOther from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): TelOther in tblDxContact'
GO

--StreetAddressLine1
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetAddressLine1' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetAddressLine1
		Print 'Column removed: StreetAddressLine1 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetAddressLine1 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetAddressLine1 in tblDxContact'
GO

--StreetAddressLine2
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetAddressLine2' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetAddressLine2
		Print 'Column removed: StreetAddressLine2 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetAddressLine2 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetAddressLine2 in tblDxContact'
GO

--StreetSuburb
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetSuburb' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetSuburb
		Print 'Column removed: StreetSuburb from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetSuburb from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetSuburb in tblDxContact'
GO

--StreetState
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetState' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetState
		Print 'Column removed: StreetState from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetState from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetState in tblDxContact'
GO

--StreetPostcode
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetPostcode' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetPostcode
		Print 'Column removed: StreetPostcode from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetPostcode from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetPostcode in tblDxContact'
GO


--StreetCountryCode
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetCountryCode' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetCountryCode
		Print 'Column removed: StreetCountryCode from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetCountryCode from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetCountryCode in tblDxContact'
GO

--StreetOther
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StreetOther' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN StreetOther
		Print 'Column removed: StreetOther from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: StreetOther from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): StreetOther in tblDxContact'
GO

--PostalSameAsStreet
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalSameAsStreet' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalSameAsStreet
		Print 'Column removed: PostalSameAsStreet from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalSameAsStreet from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalSameAsStreet in tblDxContact'
GO

--PostalAddressLine1
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalAddressLine1' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalAddressLine1
		Print 'Column removed: PostalAddressLine1 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalAddressLine1 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalAddressLine1 in tblDxContact'
GO


--PostalAddressLine2
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalAddressLine2' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalAddressLine2
		Print 'Column removed: PostalAddressLine2 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalAddressLine2 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalAddressLine2 in tblDxContact'
GO


--PostalSuburb
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalSuburb' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalSuburb
		Print 'Column removed: PostalSuburb from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalSuburb from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalSuburb in tblDxContact'
GO

--PostalState
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalState' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalState
		Print 'Column removed: PostalState from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalState from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalState in tblDxContact'
GO

--PostalPostcode
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalPostcode' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalPostcode
		Print 'Column removed: PostalPostcode from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalPostcode from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalPostcode in tblDxContact'
GO

--PostalCountryCode
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalCountryCode' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalCountryCode
		Print 'Column removed: PostalCountryCode from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalCountryCode from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalCountryCode in tblDxContact'
GO

--PostalOther
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'PostalOther' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN PostalOther
		Print 'Column removed: PostalOther from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: PostalOther from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): PostalOther in tblDxContact'
GO

--OrgName
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgName' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrgName
		Print 'Column removed: OrgName from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgName from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrgName in tblDxContact'
GO

--Branch
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Branch' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Branch
		Print 'Column removed: Branch from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Branch from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Branch in tblDxContact'
GO

--Region
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Region' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Region
		Print 'Column removed: Region from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Region from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Region in tblDxContact'
GO


--District
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'District' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN District
		Print 'Column removed: District from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: District from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): District in tblDxContact'
GO

--BusinessUnit
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'BusinessUnit' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN BusinessUnit
		Print 'Column removed: BusinessUnit from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: BusinessUnit from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): BusinessUnit in tblDxContact'
GO

--Site
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Site' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN [Site]
		Print 'Column removed: Site from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Site from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Site in tblDxContact'
GO

--Campus
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Campus' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Campus
		Print 'Column removed: Campus from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Campus from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Campus in tblDxContact'
GO

--School
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'School' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN School
		Print 'Column removed: School from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: School from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): School in tblDxContact'
GO

--Faculty
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Faculty' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Faculty
		Print 'Column removed: Faculty from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Faculty from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Faculty in tblDxContact'
GO

--Department
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Department' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Department
		Print 'Column removed: Department from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Department from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Department in tblDxContact'
GO

--Program
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Program' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Program
		Print 'Column removed: Program from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Program from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Program in tblDxContact'
GO

--Project
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Project' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Project
		Print 'Column removed: Project from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Project from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Project in tblDxContact'
GO

--OrgRole
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgRole' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrgRole
		Print 'Column removed: OrgRole from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgRole from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrgRole in tblDxContact'
GO

--HRNo
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'HRNo' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN HRNo
		Print 'Column removed: HRNo from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: HRNo from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): HRNo in tblDxContact'
GO

--Manager
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Manager' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Manager
		Print 'Column removed: Manager from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Manager from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Manager in tblDxContact'
GO

--Assistant
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Assistant' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN Assistant
		Print 'Column removed: Assistant from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Assistant from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Assistant in tblDxContact'
GO

--OrgEmail
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgEmail' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrgEmail
		Print 'Column removed: OrgEmail from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgEmail from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): AssOrgEmailistant in tblDxContact'
GO

--OrgTel
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgTel' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrgTel
		Print 'Column removed: OrgTel from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgTel from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrgTel in tblDxContact'
GO

--OrgMob
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgMob' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrgMob
		Print 'Column removed: OrgMob from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgMob from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrgMob in tblDxContact'
GO

--OrgFax
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgFax' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN OrgFax
		Print 'Column removed: OrgFax from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrgFax from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): OrgFax in tblDxContact'
GO

--URL1
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'URL1' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN URL1
		Print 'Column removed: URL1 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: URL1 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): URL1 in tblDxContact'
GO

--URL2
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'URL2' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN TRY
		ALTER TABLE tblDxContact
		DROP COLUMN URL2
		Print 'Column removed: URL2 from tblDxContact'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: URL2 from tblDxContact. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): URL2 in tblDxContact'
GO


-------------------------------------
-- New Column on tblDxContact
-------------------------------------


IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'PrivacyRating' AND Object_ID = Object_ID(N'tblDxContact'))
	BEGIN
		ALTER TABLE tblDxContact
		ADD PrivacyRating int NULL
		Print ' '
		Print 'Field added: PrivacyRating to tblDxContact, int NULL'		
	END
GO

IF EXISTS(SELECT * FROM tblDxContact)
	BEGIN
		UPDATE tblDxContact SET PrivacyRating = 1 WHERE PrivacyRating IS NULL		
	END
GO

ALTER TABLE tblDxContact
ALTER COLUMN PrivacyRating int NOT NULL
GO


-------------------------------------
-- Remove Business Unit Contact table
-------------------------------------

-- Remove tblBusinessUnitContact Constraint FK_tblBusinessUnitContact_tblBusinessUnit if present

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblBusinessUnitContact_tblBusinessUnit')
		BEGIN TRY
			ALTER TABLE [dbo].[tblBusinessUnitContact]
			DROP CONSTRAINT FK_tblBusinessUnitContact_tblBusinessUnit
			Print 'Constraint dropped: [FK_tblBusinessUnitContact_tblBusinessUnit]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblBusinessUnitContact_tblBusinessUnit]. Script terminated.',20,-1) with log
		END CATCH
	END
GO

-- Remove tblBusinessUnitContact Constraint FK_tblBusinessUnitContact_tblSiteLocation if present

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblBusinessUnitContact_tblSiteLocation')
		BEGIN TRY
			ALTER TABLE [dbo].[tblBusinessUnitContact]
			DROP CONSTRAINT FK_tblBusinessUnitContact_tblSiteLocation
			Print 'Constraint dropped: [FK_tblBusinessUnitContact_tblSiteLocation]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblBusinessUnitContact_tblSiteLocation]. Script terminated.',20,-1) with log
		END CATCH
END
GO

-- Remove tblBusinessUnitContact Constraint FK_tblBusinessUnitContact_tblDxContact if present

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblBusinessUnitContact_tblDxContact')
		BEGIN TRY
			ALTER TABLE [dbo].[tblBusinessUnitContact]
			DROP CONSTRAINT FK_tblBusinessUnitContact_tblDxContact
			Print 'Constraint dropped: [FK_tblBusinessUnitContact_tblDxContact]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblBusinessUnitContact_tblDxContact]. Script terminated.',20,-1) with log
		END CATCH
END
GO

-- Remove tblBusinessUnitContact Constraint FK_tblReference_tblBusinessUnitContact if present

BEGIN 
	IF EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblReference_tblBusinessUnitContact')
		BEGIN TRY
			ALTER TABLE [dbo].[tblReference]
			DROP CONSTRAINT FK_tblReference_tblBusinessUnitContact
			Print 'Constraint dropped: [FK_tblReference_tblBusinessUnitContact]'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Constraint: [FK_tblReference_tblBusinessUnitContact]. Script terminated.',20,-1) with log
		END CATCH
END
GO

-- Remove tblBusinessUnitContact if present list rows first if any retain log

BEGIN
   IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblBusinessUnitContact')
		BEGIN TRY
			DROP TABLE tblBusinessUnitContact
			Print 'tblBusinessUnitContact dropped'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping tblBusinessUnitContact. Script terminated.',20,-1) with log
		END CATCH
END
GO

   --------------------------------------
   -- Remove Business Unit Contact SPROCS
   --------------------------------------

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN TRY
		drop procedure [dbo].[pr_tblBusinessUnitContact_Delete]
		print 'pr_tblBusinessUnitContact_Delete dropped'
	END TRY
   	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping SPROC pr_tblBusinessUnitContact_Delete. Script terminated.',20,-1) with log
	END CATCH
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   BEGIN
   drop procedure [dbo].[pr_tblBusinessUnitContact_DeleteAllWBusinessUnitIDLogic]
   print 'pr_tblBusinessUnitContact_DeleteAllWBusinessUnitIDLogic dropped'
   END
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_DeleteAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_DeleteAllWDxContactIDLogic]
   print 'pr_tblBusinessUnitContact_DeleteAllWDxContactIDLogic dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_Insert]
   print 'pr_tblBusinessUnitContact_Insert dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_SelectAll]
   print 'pr_tblBusinessUnitContact_SelectAll dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_SelectAllWBusinessUnitIDLogic]
   print 'pr_tblBusinessUnitContact_SelectAllWBusinessUnitIDLogic dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_SelectAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_SelectAllWDxContactIDLogic]
   print 'pr_tblBusinessUnitContact_SelectAllWDxContactIDLogic dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_SelectOne]
   print 'pr_tblBusinessUnitContact_SelectOne dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_Update]
   print 'pr_tblBusinessUnitContact_Update dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_UpdateAllWBusinessUnitIDLogic]
   print 'pr_tblBusinessUnitContact_UpdateAllWBusinessUnitIDLogic dropped'
GO

   if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnitContact_UpdateAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblBusinessUnitContact_UpdateAllWDxContactIDLogic]
   print 'pr_tblBusinessUnitContact_UpdateAllWDxContactIDLogic dropped'
GO

--  -----------------------------------------------------------------------------------------------------------------
--  Table renaming supporting ANRDR constellation tidy up
--  -----------------------------------------------------------------------------------------------------------------

-- tblProvider constraint

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite') AND NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorksite_tblProvider')
		BEGIN TRY
			declare @name varchar(255),
			@table varchar(255) = 'tblSite',
			@column varchar(255) = 'DefaultProviderID'
			SELECT @name = CONSTRAINT_NAME
			FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
			WHERE TABLE_NAME = @table AND COLUMN_NAME =  @column
			declare @sql varchar(1023) = 'alter table ' + @table + ' drop ' + @name 
			exec (@sql)
			print 'Constraint ' + @name + ' removed'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			declare @errtxt varchar(255) = 'Problem dropping Constraint: ' + @name + 'Script terminated'
			raiserror(@Errtxt,20,-1) with log
		END CATCH
END
GO

-- tblOrganisation constraint

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite') AND NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorksite_tblOrganisation')
		BEGIN TRY
			declare @name2 varchar(255),
			@table2 varchar(255) = 'tblSite',
			@column2 varchar(255) = 'OrganisationID'
			SELECT @name2 = CONSTRAINT_NAME
			FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
			WHERE TABLE_NAME = @table2 AND COLUMN_NAME =  @column2
			declare @sql2 varchar(1023) = 'alter table ' + @table2 + ' drop ' + @name2 
			exec (@sql2)
			print 'Constraint ' + @name2 + ' removed'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			declare @errtxt2 varchar(255) = 'Problem dropping Constraint: ' + @name2 + 'Script terminated'
			raiserror(@Errtxt2,20,-1) with log
		END CATCH
END
GO

-- tblANRDRSubmissionHistoryWorkSite constraint

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite') AND NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRSubmissionHistoryWorkSite_tblANRDRWorksite')
		BEGIN TRY
			declare @name3 varchar(255),
			@table3 varchar(255) = 'tblANRDRSubmissionHistoryWorkSite',
			@column3 varchar(255) = 'SiteID'
			SELECT @name3 = CONSTRAINT_NAME
			FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
			WHERE TABLE_NAME = @table3 AND COLUMN_NAME =  @column3
			declare @sql3 varchar(1023) = 'alter table ' + @table3 + ' drop ' + @name3 
			exec (@sql3)
			print 'Constraint ' + @name3 + ' removed'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			declare @errtxt3 varchar(255) = 'Problem dropping Constraint: ' + @name3 + 'Script terminated'
			raiserror(@Errtxt3,20,-1) with log
		END CATCH
END
GO

-- tblANRDRWorkSiteDefaultDoseParameter constraint

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite') AND NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorkSiteDefaultDoseParameter_tblANRDRWorksite')
		BEGIN TRY
			declare @name4 varchar(255),
			@table4 varchar(255) = 'tblANRDRWorkSiteDefaultDoseParameter',
			@column4 varchar(255) = 'SiteID'
			SELECT @name4 = CONSTRAINT_NAME
			FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
			WHERE TABLE_NAME = @table4 AND COLUMN_NAME =  @column4
			declare @sql4 varchar(1023) = 'alter table ' + @table4 + ' drop ' + @name4 
			exec (@sql4)
			print 'Constraint ' + @name4 + ' removed'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			declare @errtxt4 varchar(255) = 'Problem dropping Constraint: ' + @name4 + 'Script terminated'
			raiserror(@Errtxt4,20,-1) with log
		END CATCH
END
GO

-- tblSystemInstance constraint

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite') AND NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblSite_tblSystemInstance')
		BEGIN TRY
			declare @name5 varchar(255),
			@table5 varchar(255) = 'tblSite',
			@column5 varchar(255) = 'SystemInstanceID'
			SELECT @name5 = CONSTRAINT_NAME
			FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
			WHERE TABLE_NAME = @table5 AND COLUMN_NAME =  @column5
			declare @sql5 varchar(1023) = 'alter table ' + @table5 + ' drop ' + @name5 
			exec (@sql5)
			print 'Constraint ' + @name5 + ' removed'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			declare @errtxt5 varchar(255) = 'Problem dropping Constraint: ' + @name5 + 'Script terminated'
			raiserror(@Errtxt5,20,-1) with log
		END CATCH
END
GO


-- tblCentre constraint

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite') AND NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblCentre_tblSite')
		BEGIN TRY
			declare @name6 varchar(255),
			@table6 varchar(255) = 'tblCentre',
			@column6 varchar(255) = 'SiteID'
			SELECT @name6 = CONSTRAINT_NAME
			FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
			WHERE TABLE_NAME = @table6 AND COLUMN_NAME =  @column6
			declare @sql6 varchar(1023) = 'alter table ' + @table6 + ' drop ' + @name6 
			exec (@sql6)
			print 'Constraint ' + @name6 + ' removed'
		END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			declare @errtxt6 varchar(255) = 'Problem dropping Constraint: ' + @name6 + 'Script terminated'
			raiserror(@Errtxt6,20,-1) with log
		END CATCH
END
GO


-- tblRefEstablishment type not used.
	BEGIN TRY
		declare @name7 varchar(255),
		@table7 varchar(255) = 'tblOrganisation',
		@column7 varchar(255) = 'EstablishmentType'
		SELECT @name7 = CONSTRAINT_NAME
		FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
		WHERE TABLE_NAME = @table7 AND COLUMN_NAME =  @column7
		declare @sql7 varchar(1023) = 'alter table ' + @table7 + ' drop ' + @name7 
		exec (@sql7)
		print 'Constraint ' + @name7 + ' removed'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		declare @errtxt7 varchar(255) = 'Problem dropping Constraint: ' + @name7 + 'Script terminated'
		raiserror(@Errtxt7,20,-1) with log
	END CATCH
GO


-- Drop DxGroupContact joining table (DxRole accomplishes original intentions plus much more)

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblDxGroupContact')
	BEGIN TRY
		DROP TABLE tblDxGroupContact
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem dropping tblDxGroupContact',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------
IF EXISTS(SELECT dbo.tblWearer.WearerInternalID, dbo.tblWearer.OrganisationID
FROM  dbo.tblWearer LEFT OUTER JOIN
         dbo.tblOrganisation ON dbo.tblWearer.OrganisationID = dbo.tblOrganisation.OrganisationID
WHERE (dbo.tblOrganisation.OrganisationID IS NULL) AND (dbo.tblWearer.OrganisationID IS NOT NULL))
BEGIN
UPDATE dbo.tblWearer SET OrganisationID = NULL
FROM  dbo.tblWearer LEFT OUTER JOIN
         dbo.tblOrganisation ON dbo.tblWearer.OrganisationID = dbo.tblOrganisation.OrganisationID
WHERE (dbo.tblOrganisation.OrganisationID IS NULL) AND (dbo.tblWearer.OrganisationID IS NOT NULL)
END
GO


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblWearer_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblWearer]  WITH CHECK ADD  CONSTRAINT [FK_tblWearer_tblOrganisation] FOREIGN KEY([OrganisationID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		ON DELETE SET NULL
		Print 'Constraint added: [FK_tblWearer_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblWearer] CHECK CONSTRAINT [FK_tblWearer_tblOrganisation]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

DECLARE @Collation Nvarchar(50) 
DECLARE @SQL Nvarchar(1000)

SET @Collation = ( SELECT collation_name FROM sys.columns WHERE OBJECT_ID IN ( SELECT OBJECT_ID FROM sys.objects WHERE type = 'U' AND name = 'tblUser' ) AND name = 'UserID' )
SET @SQL = 'ALTER TABLE tblUserFolder ALTER COLUMN UserID VARCHAR(50) COLLATE ' + @Collation
EXECUTE( @SQL )
GO


IF EXISTS(SELECT dbo.tblUserFolder.UserID
FROM  dbo.tblUserFolder LEFT OUTER JOIN
         dbo.tblUser ON dbo.tblUserFolder.UserID = dbo.tblUser.UserID
WHERE (dbo.tblUser.UserID IS NULL) AND (dbo.tblUserFolder.UserID IS NOT NULL))
BEGIN
DELETE dbo.tblUserFolder
FROM  dbo.tblUserFolder LEFT OUTER JOIN
         dbo.tblUser ON dbo.tblUserFolder.UserID = dbo.tblUser.UserID
WHERE (dbo.tblUser.UserID IS NULL) AND (dbo.tblUserFolder.UserID IS NOT NULL)
END
GO


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblUserFolder_tblUser')
	BEGIN
		ALTER TABLE [dbo].[tblUserFolder]  WITH CHECK ADD  CONSTRAINT [FK_tblUserFolder_tblUser] FOREIGN KEY([UserID])
		REFERENCES [dbo].[tblUser] ([UserID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblUserFolder_tblUser]'
	END
GO


ALTER TABLE [dbo].[tblUserFolder] CHECK CONSTRAINT [FK_tblUserFolder_tblUser]
GO



-- ----------------------------------------------------------------------------------------------------------------------------
-- SiteID key

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteID' AND Object_ID = Object_ID(N'tblSite'))
	BEGIN TRY
		exec sp_rename 'tblSite.SiteID', 'ANRDRWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblSite.SiteID to tblSite.ANRDRWorksiteID',20,-1) with log
	END CATCH
END
GO

-- tblSite table

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblSite')
	BEGIN TRY
		exec sp_rename 'tblSite', 'tblANRDRWorksite'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblSite to tblANRDRWorksite',20,-1) with log
	END CATCH
END
GO


-- tblANRDRSubmissionHistoryWorksite Description field to ANRDRWorksiteName
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Description' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryWorksite'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryWorksite.Description', 'ANRDRWorksiteName', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryWorksite.Description to tblANRDRSubmissionHistoryWorksite.ANRDRWorksiteName',20,-1) with log
	END CATCH
END
GO


-- tblANRDRSubmissionHistoryCentre Name field to CentreName
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Name' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryCentre'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryCentre.Name', 'CentreName', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryCentre.Name to tblANRDRSubmissionHistoryCentre.CentreName',20,-1) with log
	END CATCH
END
GO

-- tblANRDRSubmissionHistoryCentre Description field to CentreName
BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Description' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryCentre'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryCentre.Description', 'CentreDescription', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryCentre.Description to tblANRDRSubmissionHistoryCentre.CentreDescription',20,-1) with log
	END CATCH
END
GO


-- Legacy Site SPROCS

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_Delete]
   print ' '
   print 'pr_tblSite_Delete dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_DeleteAllWDefaultProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_DeleteAllWDefaultProviderIDLogic]
   print 'pr_tblSite_DeleteAllWDefaultProviderIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_DeleteAllWOrganisationIDLogic]
   print 'pr_tblSite_DeleteAllWOrganisationIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_DeleteAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_DeleteAllWSystemInstanceIDLogic]
   print 'pr_tblSite_DeleteAllWSystemInstanceIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_Insert]
   print 'pr_tblSite_Insert dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_SelectAll]
   print 'pr_tblSite_SelectAll dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_SelectAllWDefaultProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_SelectAllWDefaultProviderIDLogic]
   print 'pr_tblSite_SelectAllWDefaultProviderIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_SelectAllWOrganisationIDLogic]
   print 'pr_tblSite_SelectAllWOrganisationIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_SelectAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_SelectAllWSystemInstanceIDLogic]
   print 'pr_tblSite_SelectAllWSystemInstanceIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_SelectOne]
   print 'pr_tblSite_SelectOne dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_Update]
   print 'pr_tblSite_Update dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_UpdateAllWDefaultProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_UpdateAllWDefaultProviderIDLogic]
   print 'pr_tblSite_UpdateAllWDefaultProviderIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_UpdateAllWOrganisationIDLogic]
   print 'pr_tblSite_UpdateAllWOrganisationIDLogic dropped'
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSite_UpdateAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblSite_UpdateAllWSystemInstanceIDLogic]
   print 'pr_tblSite_UpdateAllWSystemInstanceIDLogic dropped'
GO

-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorksite_tblProvider')
	BEGIN
		ALTER TABLE [dbo].[tblANRDRWorksite]  WITH CHECK ADD  CONSTRAINT [FK_tblANRDRWorksite_tblProvider] FOREIGN KEY([DefaultProviderID])
		REFERENCES [dbo].[tblProvider] ([ProviderID])
		Print 'Constraint added: [FK_tblANRDRWorksite_tblProvider]'
	END
GO

ALTER TABLE [dbo].[tblANRDRWorksite] CHECK CONSTRAINT [FK_tblANRDRWorksite_tblProvider]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorksite_tblSystemInstance')
	BEGIN
		ALTER TABLE [dbo].[tblANRDRWorksite]  WITH CHECK ADD  CONSTRAINT [FK_tblANRDRWorksite_tblSystemInstance] FOREIGN KEY([SystemInstanceID])
		REFERENCES [dbo].[tblSystemInstance] ([SystemInstanceID])
		Print 'Constraint added: [FK_tblANRDRWorksite_tblSystemInstance]'
	END
GO

ALTER TABLE [dbo].[tblANRDRWorksite] CHECK CONSTRAINT [FK_tblANRDRWorksite_tblSystemInstance]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorksite_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblANRDRWorksite]  WITH CHECK ADD  CONSTRAINT [FK_tblANRDRWorksite_tblOrganisation] FOREIGN KEY([OrganisationID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		Print 'Constraint added: [FK_tblANRDRWorksite_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblANRDRWorksite] CHECK CONSTRAINT [FK_tblANRDRWorksite_tblOrganisation]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- ANRDRSubmissionHistoryWorkSiteID key

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRSubmissionHistoryWorkSiteID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryWorkSite'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryWorkSite.ANRDRSubmissionHistoryWorkSiteID', 'ANRDRSubmissionHistoryWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryWorkSite.ANRDRSubmissionHistoryWorkSiteID to tblANRDRSubmissionHistoryWorkSite.ANRDRSubmissionHistoryWorksiteID',20,-1) with log
	END CATCH
END
GO

-- tblANRDRSubmissionHistoryWorkSite table

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblANRDRSubmissionHistoryWorkSite')
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryWorkSite', 'tblANRDRSubmissionHistoryWorksite'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryWorkSite to tblANRDRSubmissionHistoryWorksite',20,-1) with log
	END CATCH
END
GO

-- ANRDRWorkSiteDefaultDoseParameterID key

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRWorkSiteDefaultDoseParameterID' AND Object_ID = Object_ID(N'tblANRDRWorkSiteDefaultDoseParameter'))
	BEGIN TRY
		exec sp_rename 'tblANRDRWorkSiteDefaultDoseParameter.ANRDRWorkSiteDefaultDoseParameterID', 'ANRDRWorksiteDefaultDoseParameterID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRWorkSiteDefaultDoseParameter.ANRDRWorkSiteDefaultDoseParameterID to tblANRDRWorkSiteDefaultDoseParameter.ANRDRWorksiteDefaultDoseParameterID',20,-1) with log
	END CATCH
END
GO

-- tblANRDRWorkSiteDefaultDoseParameter table

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblANRDRWorkSiteDefaultDoseParameter')
	BEGIN TRY
		exec sp_rename 'tblANRDRWorkSiteDefaultDoseParameter', 'tblANRDRWorksiteDefaultDoseParameter'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRWorkSiteDefaultDoseParameter to tblANRDRWorksiteDefaultDoseParameter',20,-1) with log
	END CATCH
END
GO


-- tblANRDRSubmissionHistoryCentre ANRDRSubmissionHistoryWorkSiteID foreign key

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRSubmissionHistoryWorkSiteID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryCentre'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryCentre.ANRDRSubmissionHistoryWorkSiteID', 'ANRDRSubmissionHistoryWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryCentre.ANRDRWorkSiteDefaultDoseParameterID to tblANRDRSubmissionHistoryCentre.ANRDRSubmissionHistoryWorksiteID',20,-1) with log
	END CATCH
END
GO


-- tblANRDRSubmissionHistoryEmployee ANRDRSubmissionHistoryWorkSiteID foreign key

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRSubmissionHistoryWorkSiteID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.ANRDRSubmissionHistoryWorkSiteID', 'ANRDRSubmissionHistoryWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.ANRDRSubmissionHistoryWorkSiteID to tblANRDRSubmissionHistoryEmployee.ANRDRSubmissionHistoryWorksiteID',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRWorkSiteNumber' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryWorksite'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryWorksite.ANRDRWorkSiteNumber', 'ANRDRWorksiteNumber', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryWorksite.ANRDRWorkSiteNumber to tblANRDRSubmissionHistoryWorksite.ANRDRWorksiteNumber',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryWorksite'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryWorksite.SiteID', 'ANRDRWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryWorksite.SiteID to tblANRDRSubmissionHistoryWorksite.ANRDRWorksiteID',20,-1) with log
	END CATCH
END
GO
-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRSubmissionHistoryWorksite_tblANRDRWorksite')
	BEGIN
		ALTER TABLE [dbo].[tblANRDRSubmissionHistoryWorksite]  WITH CHECK ADD  CONSTRAINT [FK_tblANRDRSubmissionHistoryWorksite_tblANRDRWorksite] FOREIGN KEY([ANRDRWorksiteID])
		REFERENCES [dbo].[tblANRDRWorksite] ([ANRDRWorksiteID])
		Print 'Constraint added: [FK_tblANRDRSubmissionHistoryWorksite_tblANRDRWorksite]'
	END
GO

ALTER TABLE [dbo].[tblANRDRSubmissionHistoryWorksite] CHECK CONSTRAINT [FK_tblANRDRSubmissionHistoryWorksite_tblANRDRWorksite]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteID' AND Object_ID = Object_ID(N'tblANRDRWorksiteDefaultDoseParameter'))
	BEGIN TRY
		exec sp_rename 'tblANRDRWorksiteDefaultDoseParameter.SiteID', 'ANRDRWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRWorksiteDefaultDoseParameter.SiteID to tblANRDRWorksiteDefaultDoseParameter.ANRDRWorksiteID',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblANRDRWorksiteDefaultDoseParameter_tblANRDRWorksite')
	BEGIN
		ALTER TABLE [dbo].[tblANRDRWorksiteDefaultDoseParameter]  WITH CHECK ADD  CONSTRAINT [FK_tblANRDRWorksiteDefaultDoseParameter_tblANRDRWorksite] FOREIGN KEY([ANRDRWorksiteID])
		REFERENCES [dbo].[tblANRDRWorksite] ([ANRDRWorksiteID])
		Print 'Constraint added: [FK_tblANRDRWorksiteDefaultDoseParameter_tblANRDRWorksite]'
	END
GO

ALTER TABLE [dbo].[tblANRDRWorksiteDefaultDoseParameter] CHECK CONSTRAINT [FK_tblANRDRWorksiteDefaultDoseParameter_tblANRDRWorksite]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRSubmissionHistoryWorkSiteID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryDoseParameter'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryDoseParameter.ANRDRSubmissionHistoryWorkSiteID', 'ANRDRSubmissionHistoryWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryDoseParameter.ANRDRSubmissionHistoryWorkSiteID to tblANRDRSubmissionHistoryDoseParameter.ANRDRSubmissionHistoryWorksiteID',20,-1) with log
	END CATCH
END
GO

-- pr_tblANRDRReminder_Delete
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRReminder_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblANRDRReminder_Delete]
   print 'pr_tblANRDRReminder_Delete dropped'
GO

-- pr_tblANRDRReminder_Insert
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRReminder_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblANRDRReminder_Insert]
   print 'pr_tblANRDRReminder_Insert dropped'
GO

-- pr_tblANRDRReminder_SelectAll
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRReminder_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblANRDRReminder_SelectAll]
   print 'pr_tblANRDRReminder_SelectAll dropped'
GO

-- pr_tblANRDRReminder_SelectOne
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRReminder_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblANRDRReminder_SelectOne]
   print 'pr_tblANRDRReminder_SelectOne dropped'
GO

-- pr_tblANRDRReminder_Update
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRReminder_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) 
   drop procedure [dbo].[pr_tblANRDRReminder_Update]
   print 'pr_tblANRDRReminder_Update dropped'
GO

-- Table removal tblAddressBook
IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblAddressBook')
	BEGIN
	DROP TABLE tblAddressBook
	END
GO

-- Table removal tblANRDRReminder
IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblANRDRReminder')
	BEGIN
	DROP TABLE tblANRDRReminder
	END
GO

-- tblCentre SiteID key

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteID' AND Object_ID = Object_ID(N'tblCentre'))
	BEGIN TRY
		exec sp_rename 'tblCentre.SiteID', 'ANRDRWorksiteID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblCentre.SiteID to tblCentre.ANRDRWorksiteID',20,-1) with log
	END CATCH
END
GO


-- tblANRDRWorksite ANRDRWorkSiteNumber

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRWorkSiteNumber' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		exec sp_rename 'tblANRDRWorksite.ANRDRWorkSiteNumber', 'ANRDRWorksiteNumber', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRWorksite.ANRDRWorkSiteNumber to tblANRDRWorksite.ANRDRWorksiteNumber',20,-1) with log
	END CATCH
END
GO


-- tblANRDRWorksite column Description field to ANRDRWorksiteName

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Description' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		exec sp_rename 'tblANRDRWorksite.Description', 'ANRDRWorksiteName', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRWorksite.Description to tblANRDRWorksite.ANRDRWorksiteName',20,-1) with log
	END CATCH
END
GO

-- tblANRDRWorksite Location column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Location' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		ALTER TABLE tblANRDRWorksite
		DROP COLUMN [Location]
		Print ' '
		Print 'Column removed: Location from tblANRDRWorksite'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Location from tblANRDRWorksite. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): Location in tblANRDRWorksite'
GO

-- tblANRDRWorksite Contact column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Contact' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		ALTER TABLE tblANRDRWorksite
		DROP COLUMN Contact
		Print 'Column removed: Location from tblANRDRWorksite'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Contact from tblANRDRWorksite. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Contact in tblANRDRWorksite'
GO

-- tblANRDRWorksite Extension column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Extension' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		ALTER TABLE tblANRDRWorksite
		DROP COLUMN Extension
		Print 'Column removed: Extension from tblANRDRWorksite'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Extension from tblANRDRWorksite. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Extension in tblANRDRWorksite'
GO

-- tblANRDRWorksite Email column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Email' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		ALTER TABLE tblANRDRWorksite
		DROP COLUMN Email
		Print 'Column removed: Email from tblANRDRWorksite'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Email from tblANRDRWorksite. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Email in tblANRDRWorksite'
GO


-- tblANRDRWorksite Notes column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Notes' AND Object_ID = Object_ID(N'tblANRDRWorksite'))
	BEGIN TRY
		ALTER TABLE tblANRDRWorksite
		DROP COLUMN Notes
		Print 'Column removed: Notes from tblANRDRWorksite'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Notes from tblANRDRWorksite. Script terminated.',20,-1) with log
		END CATCH
ELSE	
	Print 'Unused column not present (OK): Notes in tblANRDRWorksite'
GO

-- ----------------------------------------------------------------------------------------------------------------------------


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblCentre_tblANRDRWorksite')
	BEGIN
		ALTER TABLE [dbo].[tblCentre]  WITH CHECK ADD  CONSTRAINT [FK_tblCentre_tblANRDRWorksite] FOREIGN KEY([ANRDRWorksiteID])
		REFERENCES [dbo].[tblANRDRWorksite] ([ANRDRWorksiteID])
		Print 'Constraint added: [FK_tblCentre_tblANRDRWorksite]'
	END
GO

ALTER TABLE [dbo].[tblCentre] CHECK CONSTRAINT [FK_tblCentre_tblANRDRWorksite]
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeSurname field to Surname to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeSurname' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeSurname', 'Surname', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeSurname to tblANRDRSubmissionHistoryEmployee.Surname',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeFirstGivenName field to GivenName to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeFirstGivenName' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeFirstGivenName', 'GivenName', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeFirstGivenName to tblANRDRSubmissionHistoryEmployee.GivenName',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeOtherGivenNames field to SecondGivenName to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeOtherGivenNames' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeOtherGivenNames', 'SecondGivenName', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeOtherGivenNames to tblANRDRSubmissionHistoryEmployee.SecondGivenName',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeSex field to Gender to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeSex' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeSex', 'Gender', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeSex to tblANRDRSubmissionHistoryEmployee.Gender',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeUniqueIdentifier field to EmployeeNumber to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeUniqueIdentifier' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeUniqueIdentifier', 'EmployeeNumber', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeUniqueIdentifier to tblANRDRSubmissionHistoryEmployee.EmployeeNumber',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeClassification field to WorkerClassification to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeClassification' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeClassification', 'WorkerClassification', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeClassification to tblANRDRSubmissionHistoryEmployee.WorkerClassification',20,-1) with log
	END CATCH
END
GO

-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee EmployeeDateOfBirth field to DateOfBirth to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EmployeeDateOfBirth' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryEmployee'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee.EmployeeDateOfBirth', 'DateOfBirth', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee.EmployeeDateOfBirth to tblANRDRSubmissionHistoryEmployee.DateOfBirth',20,-1) with log
	END CATCH
END
GO


-- ----------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryEmployee table to tblANRDRSubmissionHistoryWorker to match ANRDR portal

BEGIN 
	IF EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblANRDRSubmissionHistoryEmployee')
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryEmployee', 'tblANRDRSubmissionHistoryWorker'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryEmployee to tblANRDRSubmissionHistoryWorker',20,-1) with log
	END CATCH
END
GO


-- ---------------------------------------------------------------------------------------------------------------------------

-- ANRDRNumber field required on tblANRDRSubmissionHistoryWorker

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRNumber' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryWorker'))
	BEGIN
		ALTER TABLE tblANRDRSubmissionHistoryWorker
		ADD ANRDRNumber nvarchar(max) null
		Print ' '
		Print 'Field added: ANRDRNumber to tblANRDRSubmissionHistoryWorker, nvarchar(max)(null)'		
	END
GO

-- ---------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryWorker table ANRDRSubmissionHistoryEmployeeID to ANRDRSubmissionHistoryWorkerID to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRSubmissionHistoryEmployeeID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryWorker'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryWorker.ANRDRSubmissionHistoryEmployeeID', 'ANRDRSubmissionHistoryWorkerID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryWorker.ANRDRSubmissionHistoryEmployeeID to tblANRDRSubmissionHistoryWorker.ANRDRSubmissionHistoryWorkerID',20,-1) with log
	END CATCH
END
GO

-- ---------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmissionHistoryDose table ANRDRSubmissionHistoryEmployeeID to ANRDRSubmissionHistoryWorkerID to match ANRDR portal

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRSubmissionHistoryEmployeeID' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryDose'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmissionHistoryDose.ANRDRSubmissionHistoryEmployeeID', 'ANRDRSubmissionHistoryWorkerID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmissionHistoryDose.ANRDRSubmissionHistoryEmployeeID to tblANRDRSubmissionHistoryDose.ANRDRSubmissionHistoryWorkerID',20,-1) with log
	END CATCH
END
GO

-- ---------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmission table NoOfWorkSites to NoOfWorksites

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'NoOfWorkSites' AND Object_ID = Object_ID(N'tblANRDRSubmission'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmission.NoOfWorkSites', 'NoOfWorksites', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmission.NoOfWorkSites to tblANRDRSubmission.NoOfWorksites',20,-1) with log
	END CATCH
END
GO

-- ---------------------------------------------------------------------------------------------------------------------------

-- tblANRDRSubmission table ANRDREmployerNumber to ReportingGroupNumber

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDREmployerNo' AND Object_ID = Object_ID(N'tblANRDRSubmission'))
	BEGIN TRY
		exec sp_rename 'tblANRDRSubmission.ANRDREmployerNo', 'ReportingGroupNumber', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblANRDRSubmission.ANRDREmployerNo to tblANRDRSubmission.ReportingGroupNumber',20,-1) with log
	END CATCH
END
GO

-- tblOrganisation table ANRDREmployerNumber to ReportingGroupNumber

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDREmployerNumber' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		exec sp_rename 'tblOrganisation.ANRDREmployerNumber', 'ReportingGroupNumber', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblOrganisation.ANRDREmployerNumber to tblOrganisation.ReportingGroupNumber',20,-1) with log
	END CATCH
END
GO


IF EXISTS(SELECT * FROM tblOrganisation WHERE ISNUMERIC(ReportingGroupNumber) = 0)
BEGIN
UPDATE tblOrganisation SET ReportingGroupNumber = NULL WHERE ISNUMERIC(ReportingGroupNumber) = 0
END
GO

ALTER TABLE tblOrganisation
ALTER COLUMN ReportingGroupNumber INT NULL
GO


IF EXISTS(SELECT * FROM tblOrganisation WHERE ISNUMERIC(ABN) = 0)
BEGIN
UPDATE tblOrganisation SET ABN = NULL WHERE ISNUMERIC(ABN) = 0
END
GO

ALTER TABLE tblOrganisation
ALTER COLUMN ABN BIGINT NULL
GO



IF EXISTS(SELECT * FROM tblOrganisation WHERE ISNUMERIC(ACN) = 0)
BEGIN
UPDATE tblOrganisation SET ACN = NULL WHERE ISNUMERIC(ACN) = 0
END
GO

ALTER TABLE tblOrganisation
ALTER COLUMN ACN BIGINT NULL
GO



-- ==================================================================================================================
-- New Tables
-- ==================================================================================================================

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


IF NOT EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblDxAddress')
	BEGIN
		CREATE TABLE [dbo].[tblDxAddress](
			[DxAddressID] [int] IDENTITY(1,1) NOT NULL,
			[DxContactID] [int] NULL,
			[OrganisationID] [int] NULL,
			[SiteLocationID] [int] NULL,
			[IsActive] [bit] NOT NULL,
			[PrivacyRating] [int] NOT NULL,
			[AddressContext] [int] NOT NULL,
			[AddressType] [int] NOT NULL,
			[AddressLine1] [nvarchar](max) NULL,
			[AddressLine2] [nvarchar](max) NULL,
			[Suburb] [nvarchar](max) NULL,
			[State] [nvarchar](max) NULL,
			[Postcode] [nvarchar](max) NULL,
			[CountryCode] [int] NULL,
			[AddressOther] [nvarchar](max) NULL,
			[UseNote] [nvarchar](max) NULL,
			[ListPriority] [int] NOT NULL,
		 CONSTRAINT [aaaaatblDxAddress_PK] PRIMARY KEY NONCLUSTERED 
		(
			[DxAddressID] ASC
		)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
		) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
		Print 'New table added: [tblDxAddress]'
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxAddress_tblDxContact')
	BEGIN
		ALTER TABLE [dbo].[tblDxAddress]  WITH CHECK ADD  CONSTRAINT [FK_tblDxAddress_tblDxContact] FOREIGN KEY([DxContactID])
		REFERENCES [dbo].[tblDxContact] ([DxContactID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxAddress_tblDxContact]'
	END
GO

ALTER TABLE [dbo].[tblDxAddress] CHECK CONSTRAINT [FK_tblDxAddress_tblDxContact]
GO



IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxAddress_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblDxAddress]  WITH CHECK ADD  CONSTRAINT [FK_tblDxAddress_tblOrganisation] FOREIGN KEY([OrganisationID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxAddress_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblDxAddress] CHECK CONSTRAINT [FK_tblDxAddress_tblOrganisation]
GO



IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxAddress_tblSiteLocation')
	BEGIN
		ALTER TABLE [dbo].[tblDxAddress]  WITH CHECK ADD  CONSTRAINT [FK_tblDxAddress_tblSiteLocation] FOREIGN KEY([SiteLocationID])
		REFERENCES [dbo].[tblSiteLocation] ([SiteLocationID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxAddress_tblSiteLocation]'
	END
GO

ALTER TABLE [dbo].[tblDxAddress] CHECK CONSTRAINT [FK_tblDxAddress_tblSiteLocation]
GO



-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblDxMedium')
	BEGIN
		CREATE TABLE [dbo].[tblDxMedium](
			[DxMediumID] [int] IDENTITY(1,1) NOT NULL,
			[DxContactID] [int] NULL,
			[OrganisationID] [int] NULL,
			[SiteLocationID] [int] NULL,
			[IsActive] [bit] NOT NULL,
			[PrivacyRating] [int] NOT NULL,
			[MediumType] [int] NOT NULL,
			[DxMedium] [nvarchar](max) NOT NULL,
			[Availability] [int] NULL,
			[UseNote] [nvarchar](max) NULL,
			[ListPriority] [int] NOT NULL,
		 CONSTRAINT [PK_tblDxMedium] PRIMARY KEY CLUSTERED 
		(
			[DxMediumID] ASC
		)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
		) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
		Print 'New table added: [tblDxMedium]'
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxMedium_tblDxContact')
	BEGIN
		ALTER TABLE [dbo].[tblDxMedium]  WITH CHECK ADD  CONSTRAINT [FK_tblDxMedium_tblDxContact] FOREIGN KEY([DxContactID])
		REFERENCES [dbo].[tblDxContact] ([DxContactID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxMedium_tblDxContact]'
	END
GO

ALTER TABLE [dbo].[tblDxMedium] CHECK CONSTRAINT [FK_tblDxMedium_tblDxContact]
GO


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxMedium_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblDxMedium]  WITH CHECK ADD  CONSTRAINT [FK_tblDxMedium_tblOrganisation] FOREIGN KEY([OrganisationID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxMedium_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblDxMedium] CHECK CONSTRAINT [FK_tblDxMedium_tblOrganisation]
GO





IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxMedium_tblSiteLocation')
	BEGIN
		ALTER TABLE [dbo].[tblDxMedium]  WITH CHECK ADD  CONSTRAINT [FK_tblDxMedium_tblSiteLocation] FOREIGN KEY([SiteLocationID])
		REFERENCES [dbo].[tblSiteLocation] ([SiteLocationID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxMedium_tblSiteLocation]'
	END
GO

ALTER TABLE [dbo].[tblDxMedium] CHECK CONSTRAINT [FK_tblDxMedium_tblSiteLocation]
GO



-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblDxRole')
	BEGIN
		CREATE TABLE [dbo].[tblDxRole](
			[DxRoleID] [int] IDENTITY(1,1) NOT NULL,
			[DxContactID] [int] NULL,
			[RoleType] [int] NOT NULL,
			[IsActive] [bit] NOT NULL,
			[DxContactLinkID] [int] NULL,
			[DxContactRelationshipType] [int] NULL,
			[BusinessUnitID] [int] NULL,
			[BusinessUnitRole] [int] NULL,
			[CentreInternalID] [int] NULL,
			[CentreRole] [int] NULL,
			[DxGroupID] [int] NULL,
			[DxGroupRole] [int] NULL,
			[EquipmentID] [int] NULL,
			[EquipmentRole] [int] NULL,
			[OrganisationID] [int] NULL,
			[OrganisationRole] [int] NULL,
			[PremisesID] [int] NULL,
			[PremisesRole] [int] NULL,
			[RoomID] [int] NULL,
			[RoomRole] [int] NULL,
			[SiteLocationID] [int] NULL,
			[SiteLocationRole] [int] NULL,
			[TrainingCourseID] [int] NULL,
			[TrainingCourseRole] [int] NULL,
			[TrainingInstituteID] [int] NULL,
			[TrainingInstituteRole] [int] NULL,
			[RoleNote] [nvarchar](max) NULL,
			[ListPriority] [int] NOT NULL,
		 CONSTRAINT [PK_tblDxRole] PRIMARY KEY CLUSTERED 
		(
			[DxRoleID] ASC
		)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
		) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
		Print 'New table added: [tblDxRole]'
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblBusinessUnit')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblBusinessUnit] FOREIGN KEY([BusinessUnitID])
		REFERENCES [dbo].[tblBusinessUnit] ([BusinessUnitID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblBusinessUnit]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblBusinessUnit]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblDxContact')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblDxContact] FOREIGN KEY([DxContactID])
		REFERENCES [dbo].[tblDxContact] ([DxContactID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblDxContact]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblDxContact]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblCentre')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblCentre] FOREIGN KEY([CentreInternalID])
		REFERENCES [dbo].[tblCentre] ([CentreInternalID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblCentre]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblCentre]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblDxContactLink')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblDxContactLink] FOREIGN KEY([DxContactLinkID])
		REFERENCES [dbo].[tblDxContact] ([DxContactID])
		Print 'Constraint added: [FK_tblDxRole_tblDxContactLink]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblDxContactLink]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblEquipment')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblEquipment] FOREIGN KEY([EquipmentID])
		REFERENCES [dbo].[tblEquipment] ([EquipmentID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblEquipment]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblEquipment]
GO

--

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblDxGroup')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblDxGroup] FOREIGN KEY([DxGroupID])
		REFERENCES [dbo].[tblDxGroup] ([DxGroupID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblDxGroup]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblDxGroup]
GO

--
IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblOrganisation] FOREIGN KEY([OrganisationID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblOrganisation]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblPremises')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblPremises] FOREIGN KEY([PremisesID])
		REFERENCES [dbo].[tblPremises] ([PremisesID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblPremises]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblPremises]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblRoom')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblRoom] FOREIGN KEY([RoomID])
		REFERENCES [dbo].[tblRoom] ([RoomID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblRoom]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblRoom]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblSiteLocation')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblSiteLocation] FOREIGN KEY([SiteLocationID])
		REFERENCES [dbo].[tblSiteLocation] ([SiteLocationID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblSiteLocation]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblSiteLocation]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblTrainingCourse')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblTrainingCourse] FOREIGN KEY([TrainingCourseID])
		REFERENCES [dbo].[tblTrainingCourse] ([TrainingCourseID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblTrainingCourse]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblTrainingCourse]
GO

-- --

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblTrainingInstitute')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblTrainingInstitute] FOREIGN KEY([TrainingInstituteID])
		REFERENCES [dbo].[tblTrainingInstitute] ([TrainingInstituteID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblTrainingInstitute]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblTrainingInstitute]
GO
-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM sys.tables WHERE Name = N'tblEquipmentModel')
	BEGIN
		CREATE TABLE [dbo].[tblEquipmentModel](
			[EquipmentModelID] [int] IDENTITY(1,1) NOT NULL,
			[ManufacturerID] [int] NOT NULL,
			[ModelName] [nvarchar](150) NOT NULL,
			[ModelNumber] [nvarchar](30) NULL,
			[ModelNumberPrior] [nvarchar](30) NULL,
			[ModelCode] [nvarchar](30) NULL,
			[ModelDescription] [nvarchar](max) NULL,
			[ModelTypeID] [int] NOT NULL,
			[OtherModelType] [nvarchar](100) NULL,
			[ModelStatusID] [int] NOT NULL,
			[ModelSeries] [nvarchar](100) NULL,
			[ModelCategory] [nvarchar](100) NULL,
			[ModelGenre] [nvarchar](100) NULL,
			[OtherClassification] [nvarchar](50) NULL,
			[GeneralSpecifications] [nvarchar](max) NULL,
			[DeviceLifeExpectancy] [nvarchar](20) NULL,
			[TypicalProcedure] [nvarchar](200) NULL,
			[PurchaseCost] [decimal](10, 2) NULL,
			[TestingCost] [decimal](10, 2) NULL,
			[ReplacementCost] [decimal](10, 2) NULL,
			[RequiredTestFrequencyMonths] [int] NULL,
			[PlannedReplacementFrequencyYears] [int] NULL,
			[DeviceModelOtherNote] [nvarchar](max) NULL,
			[DeviceModelFlagFollowup] [int] NULL,
			[OtherCodeOrNumber] [nvarchar](50) NULL,
			[DateCommissioned] [datetime] NULL,
			[DateDecommissioned] [datetime] NULL,
			[ModelNotes] [nvarchar](max) NULL,
		 CONSTRAINT [PK_tblEquipmentModel] PRIMARY KEY CLUSTERED 
	(
		[EquipmentModelID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

		Print 'New table added: [tblEquipmentModel]'
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblEquipmentModel_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblEquipmentModel]  WITH CHECK ADD  CONSTRAINT [FK_tblEquipmentModel_tblOrganisation] FOREIGN KEY([ManufacturerID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		Print 'Constraint added: [FK_tblEquipmentModel_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblEquipmentModel] CHECK CONSTRAINT [FK_tblEquipmentModel_tblOrganisation]
GO

IF object_id(N'DF_tblEquipmentModel_ModelStatusID', 'D') IS NULL 
	BEGIN
		ALTER TABLE [dbo].[tblEquipmentModel] ADD  CONSTRAINT [DF_tblEquipmentModel_ModelStatusID]  DEFAULT ((1)) FOR [ModelStatusID]
		Print 'Constraint added: [DF_tblEquipmentModel_ModelStatusID] mandated default 1'
	END
GO

IF object_id(N'DF_tblEquipmentModel_PurchaseCost', 'D') IS NULL 
	BEGIN
		ALTER TABLE [dbo].[tblEquipmentModel] ADD  CONSTRAINT [DF_tblEquipmentModel_PurchaseCost]  DEFAULT ((0)) FOR [PurchaseCost]
		Print 'Constraint added: [DF_tblEquipmentModel_PurchaseCost] default 0'
	END
GO

IF object_id(N'DF_tblEquipmentModel_TestingCost', 'D') IS NULL 
	BEGIN
		ALTER TABLE [dbo].[tblEquipmentModel] ADD  CONSTRAINT [DF_tblEquipmentModel_TestingCost]  DEFAULT ((0)) FOR [TestingCost]
		Print 'Constraint added: [DF_tblEquipmentModel_TestingCost] default 0'
	END
GO

IF object_id(N'DF_tblEquipmentModel_ReplacementCost', 'D') IS NULL 
	BEGIN
		ALTER TABLE [dbo].[tblEquipmentModel] ADD  CONSTRAINT [DF_tblEquipmentModel_ReplacementCost]  DEFAULT ((0)) FOR [ReplacementCost]
		Print 'Constraint added: [DF_tblEquipmentModel_ReplacementCost] mandated default 0'
	END
GO


-- -----------------------------------------------------------------------------------------------------------

-- ===========================================================================================================
-- New Fields 
-- ===========================================================================================================

-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DxGroupID' AND Object_ID = Object_ID(N'tblDxRole'))
	BEGIN
		ALTER TABLE tblDxRole
		ADD DxGroupID int NULL
		Print ' '
		Print 'Field added: DxGroupID to tblDxRole, int NULL'		
	END
GO


-- ----------------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDxRole_tblDxGroup')
	BEGIN
		ALTER TABLE [dbo].[tblDxRole]  WITH CHECK ADD  CONSTRAINT [FK_tblDxRole_tblDxGroup] FOREIGN KEY([DxGroupID])
		REFERENCES [dbo].[tblDxGroup] ([DxGroupID])
		ON UPDATE CASCADE
		ON DELETE CASCADE
		Print 'Constraint added: [FK_tblDxRole_tblDxGroup]'
	END
GO

ALTER TABLE [dbo].[tblDxRole] CHECK CONSTRAINT [FK_tblDxRole_tblDxGroup]
GO


-- tblDxGroup GroupCode

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'GroupCode' AND Object_ID = Object_ID(N'tblDxGroup'))
	BEGIN
		ALTER TABLE tblDxGroup
		ADD GroupCode int null
		Print ' '
		Print 'Field added: GroupCode to tblDxGroup, int (null)'		
	END
GO


-- tblANRDRSubmissionHistoryDose ANRDRDosimetryProviderCode

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ANRDRDosimetryProviderCode' AND Object_ID = Object_ID(N'tblANRDRSubmissionHistoryDose'))
	BEGIN
		ALTER TABLE tblANRDRSubmissionHistoryDose
		ADD ANRDRDosimetryProviderCode int null
		Print ' '
		Print 'Field added: ANRDRDosimetryProviderCode to tblANRDRSubmissionHistoryDose, int (null)'		
	END
GO

IF EXISTS(SELECT * FROM tblANRDRSubmissionHistoryDose WHERE ANRDRDosimetryProviderCode IS NULL)
	BEGIN
		UPDATE tblANRDRSubmissionHistoryDose SET ANRDRDosimetryProviderCode = 0 WHERE ANRDRDosimetryProviderCode IS NULL
		ALTER TABLE tblANRDRSubmissionHistoryDose
		ALTER COLUMN ANRDRDosimetryProviderCode int NOT NULL
	END
GO

-- -----------------------------------------------------------------------------------------------------------

-- Rename tblOrganisation OrgName to TradingName

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrgName' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		exec sp_rename 'tblOrganisation.OrgName', 'TradingName', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblOrganisation.OrgName to tblOrganisation.TradingName',20,-1) with log
	END CATCH
END
GO

-- OrganisationNo removal  
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrganisationNo' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN OrganisationNo
		Print ' '
		Print 'Column removed: OrganisationNo from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: OrganisationNo from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): OrganisationNo in tblOrganisation'
GO


-- Description removal  
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Description' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Description
		Print ' '
		Print 'Column removed: Description from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Description from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): Description in tblOrganisation'
GO



-- EstablishmentType removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EstablishmentType' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN EstablishmentType
		Print ' '
		Print 'Column removed: EstablishmentType from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: EstablishmentType from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): EstablishmentType in tblOrganisation'
GO

-- EstablishmentTypeOther removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'EstablishmentTypeOther' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN EstablishmentTypeOther
		Print ' '
		Print 'Column removed: EstablishmentTypeOther from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: EstablishmentTypeOther from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): EstablishmentTypeOther in tblOrganisation'
GO

-- AddressLine1 column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'AddressLine1' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN AddressLine1
		Print ' '
		Print 'Column removed: AddressLine1 from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: AddressLine1 from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print ' '
	Print 'Unused column not present (OK): AddressLine1 in tblOrganisation'
GO


-- AddressLine2 column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'AddressLine2' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN AddressLine2
		Print 'Column removed: AddressLine2 from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: AddressLine2 from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): AddressLine2 in tblOrganisation'
GO


-- Suburb column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Suburb' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Suburb
		Print 'Column removed: Suburb from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Suburb from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Suburb in tblOrganisation'
GO


-- Postcode column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Postcode' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Postcode
		Print 'Column removed: Postcode from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Postcode from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Postcode in tblOrganisation'
GO


-- State column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'State' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN [State]
		Print 'Column removed: State from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: State from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): State in tblOrganisation'
GO


-- Country column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Country' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Country
		Print 'Column removed: Country from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Country from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Country in tblOrganisation'
GO


-- Phone column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Phone' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Phone
		Print 'Column removed: Phone from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Phone from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Phone in tblOrganisation'
GO


-- Fax column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Fax' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Fax
		Print 'Column removed: Fax from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Fax from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Fax in tblOrganisation'
GO


-- Email column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Email' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN Email
		Print 'Column removed: Email from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: Email from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): Email in tblOrganisation'
GO


-- ContactName column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ContactName' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN ContactName
		Print 'Column removed: ContactName from tblOrganisation'		
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ContactName from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ContactName in tblOrganisation'
GO


-- ContactPosition column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ContactPosition' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN ContactPosition
		Print 'Column removed: ContactPosition from tblOrganisation'		
		Print ' '
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: ContactPosition from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): ContactPosition in tblOrganisation'
	Print ' '
GO


-- DateOfGSTRegistration column removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'DateOfGSTRegistration' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		ALTER TABLE tblOrganisation
		DROP COLUMN DateOfGSTRegistration
		Print 'Column removed: DateOfGSTRegistration from tblOrganisation'		
		Print ' '
	END TRY
		BEGIN CATCH
			Print ERROR_MESSAGE()
			raiserror('Problem dropping Column: DateOfGSTRegistration from tblOrganisation. Script terminated.',20,-1) with log
		END CATCH
ELSE
	Print 'Unused column not present (OK): DateOfGSTRegistration in tblOrganisation'
	Print ' '
GO

-- Change tblOrganisation TradingName to NOT NULL

BEGIN
IF EXISTS(SELECT * FROM tblOrganisation WHERE TradingName IS NULL)
	BEGIN TRY
		UPDATE tblOrganisation SET TradingName = '< Trading Name? >' WHERE TradingName IS NULL
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem setting NULL tblOrganisation.TradingName to < Organisation Trading Name? > placeholder',20,-1) with log
	END CATCH
END
GO

BEGIN
	BEGIN TRY
		ALTER TABLE tblOrganisation
		ALTER COLUMN TradingName varchar(255) not null
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem altering column tblOrganisation.TradingName to NOT NULL',20,-1) with log
	END CATCH
END
GO


-- Rename tblOrganisation Notes to OrgNotes

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Notes' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		exec sp_rename 'tblOrganisation.Notes', 'OrgNotes', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblOrganisation.Notes to tblOrganisation.OrgNotes',20,-1) with log
	END CATCH
END
GO

-- Rename tblOrganisation StatusID to OrgStatusID

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'StatusID' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		exec sp_rename 'tblOrganisation.StatusID', 'OrgStatusID', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblOrganisation.StatusID to tblOrganisation.OrgStatusID',20,-1) with log
	END CATCH
END
GO

-- Rename tblOrganisation IsDefaultOrganisation to IsWearerDefault

BEGIN
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'IsDefaultOrganisation' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN TRY
		exec sp_rename 'tblOrganisation.IsDefaultOrganisation', 'IsWearerDefault', 'COLUMN'
	END TRY
	BEGIN CATCH
		Print ERROR_MESSAGE()
		raiserror('Problem renaming tblOrganisation.IsDefaultOrganisation to tblOrganisation.IsWearerDefault',20,-1) with log
	END CATCH
END
GO

-- --------------------------------------------------------------------------------------------------------------------


IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'IsANRDREmployer' AND Object_ID = Object_ID(N'tblOrganisation'))
	BEGIN
		ALTER TABLE tblOrganisation
		ADD IsANRDREmployer bit NULL
		Print ' '
		Print 'Field added: IsANRDREmployer to tblOrganisation, bit NULL'		
	END
GO

-- --------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'EquipmentModelID' AND Object_ID = Object_ID(N'tblReference'))
	BEGIN
		ALTER TABLE tblReference
		ADD EquipmentModelID int NULL
		Print ' '
		Print 'Field added: EquipmentModelID to tblReference, int NULL'		
	END
GO


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblReference_tblEquipmentModel')
	BEGIN
		ALTER TABLE [dbo].[tblReference]  WITH CHECK ADD  CONSTRAINT [FK_tblReference_tblEquipmentModel] FOREIGN KEY([EquipmentModelID])
		REFERENCES [dbo].[tblEquipmentModel] ([EquipmentModelID])
		Print 'Constraint added: [FK_tblReference_tblEquipmentModel]'
	END
GO

ALTER TABLE [dbo].[tblReference] CHECK CONSTRAINT [FK_tblReference_tblEquipmentModel]
GO

-- ----------------------

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'Approval' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD Approval DateTime NULL
		Print ' '
		Print 'Field added: Approval to tblEquipment, DateTime NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'EquipmentModelID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD EquipmentModelID int NULL
		Print ' '
		Print 'Field added: EquipmentModelID to tblEquipment, int NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblEquipment_tblEquipmentModel')
	BEGIN
		ALTER TABLE [dbo].[tblEquipment]  WITH CHECK ADD  CONSTRAINT [FK_tblEquipment_tblEquipmentModel] FOREIGN KEY([EquipmentModelID])
		REFERENCES [dbo].[tblEquipmentModel] ([EquipmentModelID])
		Print 'Constraint added: [FK_tblEquipment_tblEquipmentModel]'
	END
GO

ALTER TABLE [dbo].[tblEquipment] CHECK CONSTRAINT [FK_tblEquipment_tblEquipmentModel]
GO


-- ----------------------

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ManufacturerID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD ManufacturerID int NULL
		Print ' '
		Print 'Field added: ManufacturerID to tblEquipment, int NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblEquipment_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblEquipment]  WITH CHECK ADD  CONSTRAINT [FK_tblEquipment_tblOrganisation] FOREIGN KEY([ManufacturerID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		Print 'Constraint added: [FK_tblEquipment_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblEquipment] CHECK CONSTRAINT [FK_tblEquipment_tblOrganisation]
GO


IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DxSourceCustodianID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD DxSourceCustodianID int NULL
		Print ' '
		Print 'Field added: DxSourceCustodianID to tblEquipment, int NULL'		
	END
GO


IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DxAreaCustodianID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD DxAreaCustodianID int NULL
		Print ' '
		Print 'Field added: DxAreaCustodianID to tblEquipment, int NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DxLineManagerID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD DxLineManagerID int NULL
		Print ' '
		Print 'Field added: DxLineManagerID to tblEquipment, int NULL'		
	END
GO


IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DxRSOid' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD DxRSOid int NULL
		Print ' '
		Print 'Field added: DxRSOid to tblEquipment, int NULL'		
	END
GO

-- -----------------------

-- ASNOMaterialYesNo
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ASNOMaterial' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD ASNOMaterial int NULL
		Print ' '
		Print 'Field added: ASNOMaterial to tblEquipment, int NULL'		
	END
GO

-- ASNOInventoryBatchNo
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ASNOInventoryBatchNo' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD ASNOInventoryBatchNo int NULL
		Print ' '
		Print 'Field added: ASNOInventoryBatchNo to tblEquipment, int NULL'		
	END
GO

-- WipeTestDate
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'WipeTestDate' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD WipeTestDate DateTime NULL
		Print ' '
		Print 'Field added: WipeTestDate to tblEquipment, DateTime NULL'		
	END
GO
-- ExemptLimitBq
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ExemptLimitBq' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD ExemptLimitBq int NULL
		Print ' '
		Print 'Field added: ExemptLimitBq to tblEquipment, int NULL'		
	END
GO

-- ComputedAD
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ComputedAD' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD ComputedAD int NULL
		Print ' '
		Print 'Field added: ComputedAD to tblEquipment, int NULL'		
	END
GO

-- ComputedAE
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'ComputedAE' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD ComputedAE int NULL
		Print ' '
		Print 'Field added: ComputedAE to tblEquipment, int NULL'		
	END
GO

-- SourceCertificateNo
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'SourceCertificateNo' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD SourceCertificateNo nvarchar(30) null
		Print ' '
		Print 'Field added: SourceCertificateNo to tblEquipment, nvarchar(30) null'		
	END
GO

-- SourceCertificateID
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'SourceCertificateID' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD SourceCertificateID int NULL
		Print ' '
		Print 'Field added: SourceCertificateID to tblEquipment, int NULL'		
	END
GO

-- LicencedActivityBq
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'LicencedActivityBq' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD LicencedActivityBq int NULL
		Print ' '
		Print 'Field added: LicencedActivityBq to tblEquipment, int NULL'		
	END
GO

-- DateOfReceipt
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DateOfReceipt' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD DateOfReceipt DateTime NULL
		Print ' '
		Print 'Field added: DateOfReceipt to tblEquipment, DateTime NULL'		
	END
GO

-- DateOfLastSurvey
IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'DateOfLastSurvey' AND Object_ID = Object_ID(N'tblEquipment'))
	BEGIN
		ALTER TABLE tblEquipment
		ADD DateOfLastSurvey DateTime NULL
		Print ' '
		Print 'Field added: DateOfLastSurvey to tblEquipment, DateTime NULL'		
	END
GO

-- ----------------------------------------------------------------------------------------------------------------------
-- ----------------------------------------------------------------------------------------------------------------------

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'EquipmentModelID' AND Object_ID = Object_ID(N'tblDocument'))
	BEGIN
		ALTER TABLE tblDocument
		ADD EquipmentModelID int NULL
		Print ' '
		Print 'Field added: EquipmentModelID to tblDocument, int NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDocument_tblEquipmentModel')
	BEGIN
		ALTER TABLE [dbo].[tblDocument]  WITH CHECK ADD  CONSTRAINT [FK_tblDocument_tblEquipmentModel] FOREIGN KEY([EquipmentModelID])
		REFERENCES [dbo].[tblEquipmentModel] ([EquipmentModelID])
		Print 'Constraint added: [FK_tblDocument_tblEquipmentModel]'
	END
GO

ALTER TABLE [dbo].[tblDocument] CHECK CONSTRAINT [FK_tblDocument_tblEquipmentModel]
GO


-- ----------------------

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'OrganisationID' AND Object_ID = Object_ID(N'tblDocument'))
	BEGIN
		ALTER TABLE tblDocument
		ADD OrganisationID int NULL
		Print ' '
		Print 'Field added: OrganisationID to tblDocument, int NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS WHERE CONSTRAINT_NAME =N'FK_tblDocument_tblOrganisation')
	BEGIN
		ALTER TABLE [dbo].[tblDocument]  WITH CHECK ADD  CONSTRAINT [FK_tblDocument_tblOrganisation] FOREIGN KEY([OrganisationID])
		REFERENCES [dbo].[tblOrganisation] ([OrganisationID])
		Print 'Constraint added: [FK_tblDocument_tblOrganisation]'
	END
GO

ALTER TABLE [dbo].[tblDocument] CHECK CONSTRAINT [FK_tblDocument_tblOrganisation]
GO

-- ----------------------


-- tblSourceRefItem rules
IF (SELECT COUNT(*) FROM tblSourceRefItem) <27
BEGIN
delete tblSourceRefItem
DBCC CHECKIDENT(tblSourceRefItem,RESEED,0)
END
GO

IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RefItemCode' AND Object_ID = Object_ID(N'tblSourceRefItem'))
	BEGIN
		ALTER TABLE tblSourceRefItem
		DROP COLUMN RefItemCode
		Print ' '
		Print 'Column removed: RefItemCode from tblSourceRefItem'		
	END
GO

IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SubSourceCode' AND Object_ID = Object_ID(N'tblSourceRefItem'))
	BEGIN
		ALTER TABLE tblSourceRefItem
		DROP COLUMN SubSourceCode
		Print ' '
		Print 'Column removed: SubSourceCode from tblSourceRefItem'		
	END
GO

IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SubSourceDescription' AND Object_ID = Object_ID(N'tblSourceRefItem'))
	BEGIN
		ALTER TABLE tblSourceRefItem
		DROP COLUMN SubSourceDescription
		Print ' '
		Print 'Column removed: SubSourceDescription from tblSourceRefItem'		
	END
GO



IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'PrimaryTypeID' AND Object_ID = Object_ID(N'tblSourceRefItem'))
	BEGIN
		ALTER TABLE tblSourceRefItem
		ADD PrimaryTypeID int NOT NULL
		Print ' '
		Print 'Field added: PrimaryTypeID to tblSourceRefItem, int NULL'		
	END
GO

IF NOT EXISTS(SELECT * FROM sys.columns WHERE Name = N'HxSourceTypeID' AND Object_ID = Object_ID(N'tblSourceRefItem'))
	BEGIN
		ALTER TABLE tblSourceRefItem
		ADD HxSourceTypeID int NOT NULL
		Print ' '
		Print 'Field added: HxSourceTypeID to tblSourceRefItem, int NULL'		
	END
GO

-- SourceID must allow null for excempt items
	BEGIN
		ALTER TABLE tblSourceRefItem
		ALTER COLUMN SourceID int NULL
		Print ' '
		Print 'Field set to allow NULL: SourceID on tblSourceRefItem'		
	END
GO

-- ==================================================================================================================
-- Starting Organisation and Contact Groups
-- ==================================================================================================================

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 1)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Manufacturers','Organisations that are members of this group appear in the Manufacturer selection dropdown of the Model Details page.',1,1)
		Print 'Added Organisation System Group - Manufacturers'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 2)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'All Radiation Safety Officers','People that are members of this group are designated Radiation Safety Officers for specific Sites,Centres or Business Units.',2,2)
		Print 'Added Contact System Group - All Radiation Safety Officers'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 3)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Business Unit Radiation Safety Officers','People that are members of this group are designated Business Unit Radiation Safety Officers.',2,3)
		Print 'Added Contact System Group - Business Unit Radiation Safety Officers'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 4)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Centre Radiation Safety Officers','People that are members of this group are designated Centre Radiation Safety Officers.',2,4)
		Print 'Added Contact System Group - Centre Radiation Safety Officers'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 5)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Site Radiation Safety Officers','People that are members of this group are designated Site Radiation Safety Officers.',2,5)
		Print 'Added Contact System Group - Site Radiation Safety Officers'
	END
   GO

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 6)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Source Custodians','People that are members of this group are designated Source Custodians.',2,6)
		Print 'Added Contact System Group - Source Custodians'
	END
   GO

    IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 7)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Line Managers','People that are members of this group are Managers of other contacts.',2,7)
		Print 'Added Contact System Group - Managers'
	END
  GO

   IF NOT EXISTS(SELECT * FROM tblDxGroup WHERE GroupCode = 8)
	BEGIN
		Insert tblDxGroup
		([IsSystemGroup],[IsActive],[GroupName],[GroupDescription],[GroupTypeID],[GroupCode])
		Values
		(1,1,'Area Custodians','People that are members of this group are designated Area Custodians.',2,8)
		Print 'Added Contact System Group - Area Custodians'
	END
   GO

-- ==================================================================================================================
-- Cross-type mapping rules
-- ==================================================================================================================


IF (SELECT COUNT(*) FROM tblSourceRefItem) <27
BEGIN
SET IDENTITY_INSERT [dbo].[tblSourceRefItem] ON 
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (1, 1, 1, 11, 123)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (2, 1, 2, 13, 125)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (3, 1, 3, 14, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (4, 1, 4, 15, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (5, 1, 5, 34, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (6, 1, 6, 35, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (7, 1, 7, 42, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (8, 1, 8, 53, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (9, 1, 9, 55, 131)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (10, 3, 1, 7, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (11, 3, 2, 8, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (12, 3, 3, 50, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (13, 3, 4, 51, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (14, 3, 5, 52, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (15, 3, 6, 78, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (16, 3, 7, 79, 0)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (17, 7, 1, 23, 117)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (18, 7, 2, 22, 116)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (19, 7, 3, NULL, 130)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (20, 7, 4, 36, 119)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (21, 7, 5, 24, 118)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (22, 7, 6, 16, 111)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (23, 7, 7, 17, 112)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (24, 7, 8, 18, 113)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (25, 7, 9, 19, 114)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (26, 7, 10, 21, 115)
INSERT [dbo].[tblSourceRefItem] ([SourceRefItemID], [PrimaryTypeID], [HxSourceTypeID], [SourceID], [RefItemTypeID]) VALUES (27, 7, 11, 43, 120)
SET IDENTITY_INSERT [dbo].[tblSourceRefItem] OFF
END
GO


 -- tblBusinessUnit RadiationSafetyOfficer field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficer' AND Object_ID = Object_ID(N'tblBusinessUnit'))
BEGIN
	ALTER TABLE [dbo].[tblBusinessUnit]
	DROP COLUMN RadiationSafetyOfficer
	Print 'Column drop confirmed: [tblBusinessUnit] [RadiationSafetyOfficer]'
	END
GO

-- tblBusinessUnit RadiationSafetyOfficerContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficerContact' AND Object_ID = Object_ID(N'tblBusinessUnit'))
BEGIN
	ALTER TABLE [dbo].[tblBusinessUnit]
	DROP COLUMN RadiationSafetyOfficerContact
	Print 'Column drop confirmed: [tblBusinessUnit] [RadiationSafetyOfficerContact]'
	END
GO

 -- tblPremises CampusID field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'CampusID' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN CampusID
	Print 'Column drop confirmed: [tblPremises] [CampusID]'
	END
GO


 -- tblPremises SiteLocation field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'SiteLocation' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN SiteLocation
	Print 'Column drop confirmed: [tblPremises] [SiteLocation]'
	END
GO


 -- tblPremises ContactDetails field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ContactDetails' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN ContactDetails
	Print 'Column drop confirmed: [tblPremises] [ContactDetails]'
	END
GO


 -- tblPremises RadiationSafetyOfficer field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficer' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN RadiationSafetyOfficer
	Print 'Column drop confirmed: [tblPremises] [RadiationSafetyOfficer]'
	END
GO

-- tblPremises RadiationSafetyOfficerContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficerContact' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN RadiationSafetyOfficerContact
	Print 'Column drop confirmed: [tblPremises] [RadiationSafetyOfficerContact]'
	END
GO

-- tblPremises Contact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Contact' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN Contact
	Print 'Column drop confirmed: [tblPremises] [Contact]'
	END
GO


-- tblPremises Custodian field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Custodian' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN Custodian
	Print 'Column drop confirmed: [tblPremises] [Custodian]'
	END
GO

-- tblPremises CustodianContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'CustodianContact' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN CustodianContact
	Print 'Column drop confirmed: [tblPremises] [CustodianContact]'
	END
GO

-- tblPremises Manager field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Manager' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN Manager
	Print 'Column drop confirmed: [tblPremises] [Manager]'
	END
GO

-- tblPremises ManagerContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ManagerContact' AND Object_ID = Object_ID(N'tblPremises'))
BEGIN
	ALTER TABLE [dbo].[tblPremises]
	DROP COLUMN ManagerContact
	Print 'Column drop confirmed: [tblPremises] [ManagerContact]'
	END
GO


-- tblRoom Contact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Contact' AND Object_ID = Object_ID(N'tblRoom'))
BEGIN
	ALTER TABLE [dbo].[tblRoom]
	DROP COLUMN Contact
	Print 'Column drop confirmed: [tblRoom] [Contact]'
	END
GO

 -- tblRoom ContactDetails field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ContactDetails' AND Object_ID = Object_ID(N'tblRoom'))
BEGIN
	ALTER TABLE [dbo].[tblRoom]
	DROP COLUMN ContactDetails
	Print 'Column drop confirmed: [tblRoom] [ContactDetails]'
	END
GO

-- tblRoom Custodian field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Custodian' AND Object_ID = Object_ID(N'tblRoom'))
BEGIN
	ALTER TABLE [dbo].[tblRoom]
	DROP COLUMN Custodian
	Print 'Column drop confirmed: [tblRoom] [Custodian]'
	END
GO

-- tblRoom CustodianContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'CustodianContact' AND Object_ID = Object_ID(N'tblRoom'))
BEGIN
	ALTER TABLE [dbo].[tblRoom]
	DROP COLUMN CustodianContact
	Print 'Column drop confirmed: [tblRoom] [CustodianContact]'
	END
GO

-- tblRoom Manager field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Manager' AND Object_ID = Object_ID(N'tblRoom'))
BEGIN
	ALTER TABLE [dbo].[tblRoom]
	DROP COLUMN Manager
	Print 'Column drop confirmed: [tblRoom] [Manager]'
	END
GO

-- tblRoom ManagerContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ManagerContact' AND Object_ID = Object_ID(N'tblRoom'))
BEGIN
	ALTER TABLE [dbo].[tblRoom]
	DROP COLUMN ManagerContact
	Print 'Column drop confirmed: [tblRoom] [ManagerContact]'
	END
GO

 -- tblSiteLocation RadiationSafetyOfficer field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficer' AND Object_ID = Object_ID(N'tblSiteLocation'))
BEGIN
	ALTER TABLE [dbo].[tblSiteLocation]
	DROP COLUMN RadiationSafetyOfficer
	Print 'Column drop confirmed: [tblSiteLocation] [RadiationSafetyOfficer]'
	END
GO

-- tblSiteLocation RadiationSafetyOfficerContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'RadiationSafetyOfficerContact' AND Object_ID = Object_ID(N'tblSiteLocation'))
BEGIN
	ALTER TABLE [dbo].[tblSiteLocation]
	DROP COLUMN RadiationSafetyOfficerContact
	Print 'Column drop confirmed: [tblSiteLocation] [RadiationSafetyOfficerContact]'
	END
GO


-- tblSiteLocation Custodian field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Custodian' AND Object_ID = Object_ID(N'tblSiteLocation'))
BEGIN
	ALTER TABLE [dbo].[tblSiteLocation]
	DROP COLUMN Custodian
	Print 'Column drop confirmed: [tblSiteLocation] [Custodian]'
	END
GO

-- tblSiteLocation CustodianContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'CustodianContact' AND Object_ID = Object_ID(N'tblSiteLocation'))
BEGIN
	ALTER TABLE [dbo].[tblSiteLocation]
	DROP COLUMN CustodianContact
	Print 'Column drop confirmed: [tblSiteLocation] [CustodianContact]'
	END
GO

-- tblSiteLocation Manager field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'Manager' AND Object_ID = Object_ID(N'tblSiteLocation'))
BEGIN
	ALTER TABLE [dbo].[tblSiteLocation]
	DROP COLUMN Manager
	Print 'Column drop confirmed: [tblSiteLocation] [Manager]'
	END
GO

-- tblSiteLocation ManagerContact field removal
IF EXISTS(SELECT * FROM sys.columns WHERE Name = N'ManagerContact' AND Object_ID = Object_ID(N'tblSiteLocation'))
BEGIN
	ALTER TABLE [dbo].[tblSiteLocation]
	DROP COLUMN ManagerContact
	Print 'Column drop confirmed: [tblSiteLocation] [ManagerContact]'
	END
GO

-- ===========================================================================================================
-- New Views
-- ===========================================================================================================


-- vwRef_ExceptionType --------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwRef_ExceptionType') 
	BEGIN
		DROP VIEW vwRef_ExceptionType
		Print ' '
		Print 'Dropped vwRef_ExceptionType'
	END
GO

CREATE VIEW [dbo].[vwRef_ExceptionType]
AS
SELECT        Code AS ExceptionTypeID, Description AS ExceptionType
FROM            dbo.tblReferenceItem
WHERE        (ReferenceTypeID = 1)
GO

Print 'Recreated vwRef_ExceptionType'
GO

-- ----------------------------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwExceptionsAll') 
	BEGIN
		DROP VIEW vwExceptionsAll
	END
GO

Print 'Dropped vwExceptionsAll'
GO


CREATE VIEW [dbo].[vwExceptionsAll]
AS
SELECT        dbo.tblReadingException.ReadingExceptionID, dbo.vwRef_ExceptionType.ExceptionType, dbo.tblWearer.Wearer, dbo.tblCentre.Name AS Centre, dbo.tblCentre.CentreNo, dbo.tblReadingException.DoseReportReadingID, 
                         dbo.tblReadingException.WearerInternalID, dbo.tblReadingException.CentreInternalID, dbo.tblReadingException.ExceptionMemo, dbo.tblReadingException.Acknowledged, dbo.tblReadingException.ExceptionTypeID, 
                         dbo.tblReadingException.CustomExceptionResult, dbo.tblReadingException.CustomNotificationID, dbo.tblWearer.PrimaryWearerNumber
FROM            dbo.tblReadingException LEFT OUTER JOIN
                         dbo.tblCentre ON dbo.tblReadingException.CentreInternalID = dbo.tblCentre.CentreInternalID LEFT OUTER JOIN
                         dbo.tblWearer ON dbo.tblReadingException.WearerInternalID = dbo.tblWearer.WearerInternalID LEFT OUTER JOIN
                         dbo.vwRef_ExceptionType ON dbo.tblReadingException.ExceptionTypeID = dbo.vwRef_ExceptionType.ExceptionTypeID
GO

Print 'Created vwExceptionsAll'
GO

-- ----------------------------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwExceptionsWearers') 
	BEGIN
		DROP VIEW vwExceptionsWearers
	END
GO

Print 'Dropped vwExceptionsWearers'
GO

CREATE VIEW [dbo].[vwExceptionsWearers]
AS
SELECT        dbo.tblReadingException.ReadingExceptionID, dbo.vwRef_ExceptionType.ExceptionType, dbo.tblWearer.Wearer, dbo.tblCentre.Name AS Centre, dbo.tblCentre.CentreNo, dbo.tblReadingException.DoseReportReadingID, 
                         dbo.tblReadingException.WearerInternalID, dbo.tblReadingException.CentreInternalID, dbo.tblReadingException.ExceptionMemo, dbo.tblReadingException.Acknowledged, dbo.tblReadingException.ExceptionTypeID, 
                         dbo.tblReadingException.CustomExceptionResult, dbo.tblReadingException.CustomNotificationID, dbo.tblWearer.PrimaryWearerNumber
FROM            dbo.tblReadingException LEFT OUTER JOIN
                         dbo.tblCentre ON dbo.tblReadingException.CentreInternalID = dbo.tblCentre.CentreInternalID LEFT OUTER JOIN
                         dbo.tblWearer ON dbo.tblReadingException.WearerInternalID = dbo.tblWearer.WearerInternalID LEFT OUTER JOIN
                         dbo.vwRef_ExceptionType ON dbo.tblReadingException.ExceptionTypeID = dbo.vwRef_ExceptionType.ExceptionTypeID
WHERE        (NOT (dbo.tblWearer.Wearer LIKE N'PET') AND NOT (dbo.tblWearer.Wearer LIKE N'CONTROL')) AND (dbo.tblReadingException.ExceptionTypeID <> 3 AND dbo.tblReadingException.ExceptionTypeID <> 5)
GO

Print 'Created vwExceptionsWearers'
GO




IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountDxGroupMembers') 
	BEGIN
		DROP VIEW vwRpt_CountDxGroupMembers
		Print ' '
		Print 'Dropped vwRpt_CountDxGroupMembers'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountDxGroupMembers]
AS
SELECT        dbo.tblDxGroup.DxGroupID, COUNT(dbo.tblDxRole.DxGroupID) AS Members
FROM            dbo.tblDxRole RIGHT OUTER JOIN
                         dbo.tblDxGroup ON dbo.tblDxRole.DxGroupID = dbo.tblDxGroup.DxGroupID
GROUP BY dbo.tblDxGroup.DxGroupID
GO

Print 'Recreated vwRpt_CountDxGroupMembers'
GO

-- vwDxGroups -------------------------------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwDxGroups') 
	BEGIN
		DROP VIEW vwDxGroups
		Print ' '
		Print 'Dropped vwDxGroups'
	END
GO

CREATE VIEW [dbo].[vwDxGroups]
AS
SELECT        dbo.tblDxGroup.DxGroupID, dbo.tblDxGroup.GroupTypeID, dbo.tblDxGroup.IsSystemGroup, dbo.tblDxGroup.IsActive, dbo.tblDxGroup.GroupName, 
                         CASE GroupTypeID WHEN 1 THEN 'Organisations' WHEN 2 THEN 'Contacts' END AS GroupType, CASE IsActive WHEN 1 THEN 'Yes' WHEN 0 THEN 'No' ELSE '' END AS Active, 
                         CASE IsSystemGroup WHEN 1 THEN 'Yes' WHEN 0 THEN 'No' ELSE '' END AS SystemGroup, dbo.vwRpt_CountDxGroupMembers.Members, dbo.tblDxGroup.GroupDescription, dbo.tblDxGroup.GroupNotes
FROM            dbo.tblDxGroup LEFT OUTER JOIN
                         dbo.vwRpt_CountDxGroupMembers ON dbo.tblDxGroup.DxGroupID = dbo.vwRpt_CountDxGroupMembers.DxGroupID
GO


Print 'Recreated vwDxGroups'
GO

-- vwDxGroupMembers -------------------------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwDxGroupMembers') 
	BEGIN
		DROP VIEW vwDxGroupMembers
		Print ' '
		Print 'Dropped vwDxGroupMembers'
	END
GO

CREATE VIEW [dbo].[vwDxGroupMembers]
AS
SELECT dbo.tblDxRole.DxRoleID, dbo.tblDxRole.DxContactID, dbo.tblDxRole.OrganisationID, dbo.tblDxGroup.GroupTypeID, dbo.tblDxGroup.GroupName, dbo.tblDxGroup.DxGroupID, CASE GroupTypeID WHEN 1 THEN tblOrganisation.OrganisationID WHEN 2 THEN tblDxContact.DxContactID END AS MemberID, CASE GroupTypeID WHEN 1 THEN tblOrganisation.TradingName WHEN 2 THEN tblDxContact.Firstname + ' ' + tblDxContact.Surname END AS Member
FROM   dbo.tblDxRole INNER JOIN
         dbo.tblDxGroup ON dbo.tblDxRole.DxGroupID = dbo.tblDxGroup.DxGroupID LEFT OUTER JOIN
         dbo.tblDxContact ON dbo.tblDxRole.DxContactID = dbo.tblDxContact.DxContactID LEFT OUTER JOIN
         dbo.tblOrganisation ON dbo.tblDxRole.OrganisationID = dbo.tblOrganisation.OrganisationID
GO

Print 'Recreated vwDxGroupMembers'
GO


-- vwCentres---------------------------------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwCentres') 
	BEGIN
		DROP VIEW vwCentres
		Print ' '
		Print 'Dropped vwCentres'
	END
GO

CREATE VIEW [dbo].[vwCentres]
AS
SELECT DISTINCT 
                         tblCentre_1.CentreInternalID, tblCentre_1.CentreNo, tblCentre_1.Name, tblCentre_1.ANRDRWorksiteID, tblCentre_1.Description, tblCentre_1.Location, tblCentre_1.CostCentre, tblCentre_1.Notes, 
                         dbo.tblReferenceItem.Description AS Status, tblCentre_1.ProviderID, tblCentre_1.CampusID, tblCentre_1.ReportingDescription, p.AccountNumber, tblCentre_1.ReportAsCentreInternalID, 
                         dbo.tblCentre.CentreNo AS ReportAsCentreNo, dbo.tblCentre.Name AS ReportAsCentreName, ISNULL(dbo.vwCentres_ImportedDoseReadings.ImportedDoseReadings, 0) AS ImportedDoseReadings, 
                         ISNULL(dbo.vwCentres_ReportingDoseReadings.ReportingDoseReadings, 0) AS ReportingDoseReadings, ISNULL(dbo.vwCentres_CurrentMonitoredWearers.CurrentMonitoredWearers, 0) AS CurrentMonitoredWearers, 
                         ISNULL(dbo.vwCentres_CurrentNotMonitoredWearers.CurrentNotMonitoredWearers, 0) AS CurrentNotMonitoredWearers, ISNULL(dbo.vwCentres_CurrentUnknownStatusWearers.CurrentUnknownStatusWearers, 0) 
                         AS CurrentUnknownStatusWearers, ISNULL(dbo.vwCentres_HistoricalWearers.HistoricalWearers, 0) AS HistoricalWearers, ISNULL(dbo.vwCentres_CurrentMonitoredWearers.CurrentMonitoredWearers, 0) 
                         + ISNULL(dbo.vwCentres_CurrentNotMonitoredWearers.CurrentNotMonitoredWearers, 0) + ISNULL(dbo.vwCentres_CurrentUnknownStatusWearers.CurrentUnknownStatusWearers, 0) 
                         + ISNULL(dbo.vwCentres_HistoricalWearers.HistoricalWearers, 0) AS TotalWearers, dbo.vwRef_NationalRegisterEmployeeClassification.EmployeeClassification AS DefaultEmployeeClassification
FROM            dbo.tblCentre AS tblCentre_1 INNER JOIN
                         dbo.vwHxAllowedCentres ON tblCentre_1.CentreInternalID = dbo.vwHxAllowedCentres.CentreInternalID LEFT OUTER JOIN
                         dbo.vwRef_NationalRegisterEmployeeClassification ON tblCentre_1.WearerDefaultNationalRegisterClassification = dbo.vwRef_NationalRegisterEmployeeClassification.Code LEFT OUTER JOIN
                         dbo.vwCentres_ImportedDoseReadings ON tblCentre_1.CentreInternalID = dbo.vwCentres_ImportedDoseReadings.CentreInternalID LEFT OUTER JOIN
                         dbo.vwCentres_ReportingDoseReadings ON tblCentre_1.CentreInternalID = dbo.vwCentres_ReportingDoseReadings.CentreInternalID LEFT OUTER JOIN
                         dbo.vwCentres_CurrentMonitoredWearers ON tblCentre_1.CentreInternalID = dbo.vwCentres_CurrentMonitoredWearers.CentreInternalID LEFT OUTER JOIN
                         dbo.vwCentres_CurrentNotMonitoredWearers ON tblCentre_1.CentreInternalID = dbo.vwCentres_CurrentNotMonitoredWearers.CentreInternalID LEFT OUTER JOIN
                         dbo.vwCentres_CurrentUnknownStatusWearers ON tblCentre_1.CentreInternalID = dbo.vwCentres_CurrentUnknownStatusWearers.CentreInternalID LEFT OUTER JOIN
                         dbo.vwCentres_HistoricalWearers ON tblCentre_1.CentreInternalID = dbo.vwCentres_HistoricalWearers.CentreInternalID LEFT OUTER JOIN
                         dbo.tblReferenceItem ON tblCentre_1.StatusID = dbo.tblReferenceItem.Code AND dbo.tblReferenceItem.ReferenceTypeID = 4 AND (dbo.tblReferenceItem.StartDate <= GETDATE() OR
                         dbo.tblReferenceItem.StartDate IS NULL) AND (dbo.tblReferenceItem.EndDate >= GETDATE() OR
                         dbo.tblReferenceItem.EndDate IS NULL) LEFT OUTER JOIN
                         dbo.tblCentreProviderDetail AS p ON tblCentre_1.ProviderID = p.ProviderID AND tblCentre_1.CentreInternalID = p.CentreInternalID LEFT OUTER JOIN
                         dbo.tblCentre ON tblCentre_1.ReportAsCentreInternalID = dbo.tblCentre.CentreInternalID
GO

Print 'Recreated vwCentres'
GO


-- vwRef_PrivacyRating-----------------------------------------------

IF EXISTS(select * FROM sys.views where name = 'vwRef_PrivacyRating') 
	BEGIN
		DROP VIEW vwRef_PrivacyRating
		Print ' '
		Print 'Dropped vwRef_PrivacyRating'
	END
GO

CREATE VIEW [dbo].[vwRef_PrivacyRating]
AS
SELECT        Code AS PrivacyRatingCode, Description AS PrivacyRating, ReferenceTypeID
FROM            dbo.tblReferenceItem
WHERE        (ReferenceTypeID = 138)
GO

Print 'Created vwRef_PrivacyRating'
GO


-- vwPostcodes-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwPostcodes') 
	BEGIN
		DROP VIEW vwPostcodes
		Print ' '
		Print 'Dropped vwPostcodes'
	END
GO


CREATE VIEW [dbo].[vwPostcodes]
AS
SELECT        TOP (100) PERCENT Suburb, State, Postcode, Suburb + ' (' + State + ' ' + CAST(Postcode AS varchar(10)) + ')' AS SuburbSelect
FROM            dbo.tblRefPostcode
ORDER BY SuburbSelect
GO

Print 'Created vwPostcodes'
GO


-- vwContactNames-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwContactNames') 
	BEGIN
		DROP VIEW vwContactNames
		Print ' '
		Print 'Dropped vwContactNames'
	END
GO


CREATE VIEW [dbo].[vwContactNames]
AS
SELECT        TOP (100) PERCENT DxContactID, Surname + N', ' + FirstName AS Contact, IsActive
FROM            dbo.tblDxContact
ORDER BY Surname + N', ' + FirstName
GO


Print 'Created vwContactNames'
GO


-- vwRpt_CountLicencePermitSources-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountLicencePermitSources') 
	BEGIN
		DROP VIEW vwRpt_CountLicencePermitSources
		Print ' '
		Print 'Dropped vwRpt_CountLicencePermitSources'
	END
GO


CREATE VIEW [dbo].[vwRpt_CountLicencePermitSources]
AS
SELECT        dbo.tblLicencePermit.LicencePermitID, COUNT(dbo.tblLicencePermitSource.LicencePermitSourceID) AS Sources
FROM            dbo.tblLicencePermit LEFT OUTER JOIN
                         dbo.tblLicencePermitSource ON dbo.tblLicencePermit.LicencePermitID = dbo.tblLicencePermitSource.LicencePermitID
GROUP BY dbo.tblLicencePermit.LicencePermitID
GO


Print 'Created vwRpt_CountLicencePermitSources'
GO



--vwLicencesPermits---------------------------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwLicencesPermits') 
	BEGIN
		DROP VIEW vwLicencesPermits
		Print ' '
		Print 'Dropped vwLicencesPermits'
	END
GO


CREATE VIEW [dbo].[vwLicencesPermits]
AS
SELECT        dbo.tblLicencePermit.LicencePermitID, dbo.tblLicencePermit.LicenceName, dbo.tblLicencePermit.LicenceDate, dbo.tblLicencePermit.LicenceExpiry, dbo.tblLicencePermit.LicenceNumber, dbo.tblLicencePermit.LicenceConditions, 
                         dbo.tblLicencePermit.LicenceNotes, dbo.vwRpt_CountLicencePermitSources.Sources
FROM            dbo.tblLicencePermit INNER JOIN
                         dbo.vwRpt_CountLicencePermitSources ON dbo.tblLicencePermit.LicencePermitID = dbo.vwRpt_CountLicencePermitSources.LicencePermitID
GO


Print 'Created vwLicencesPermits'
GO


-- vwRef_EquipmentModelStatus-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwRef_EquipmentModelStatus') 
	BEGIN
		DROP VIEW vwRef_EquipmentModelStatus
		Print ' '
		Print 'Dropped vwRef_EquipmentModelStatus'
	END
GO

	CREATE VIEW [dbo].[vwRef_EquipmentModelStatus]
	AS
	SELECT        Code AS EquipmentModelStatusID, Description AS EquipmentModelStatus
	FROM            dbo.tblReferenceItem
	WHERE        (ReferenceTypeID = 136)
	GO

Print 'Created vwRef_Campus'
GO

-- vwRef_EquipmentModelType-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwRef_EquipmentModelType') 
	BEGIN
		DROP VIEW vwRef_EquipmentModelType
		Print ' '
		Print 'Dropped vwRef_EquipmentModelType'
	END
GO

	CREATE VIEW [dbo].[vwRef_EquipmentModelType]
	AS
	SELECT        Code AS EquipmentModelTypeID, Description AS EquipmentModelType
	FROM            dbo.tblReferenceItem
	WHERE        (ReferenceTypeID = 137)
	GO

Print 'Created vwRef_EquipmentModelType'
GO


-- vwRpt_CountEquipmentModelUse-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountEquipmentModelUse') 
	BEGIN
		DROP VIEW vwRpt_CountEquipmentModelUse
		Print ' '
		Print 'Dropped vwRpt_CountEquipmentModelUse'
	END
GO

	CREATE VIEW [dbo].[vwRpt_CountEquipmentModelUse]
	AS
	SELECT        dbo.tblEquipmentModel.EquipmentModelID, COUNT(dbo.tblEquipment.EquipmentID) AS ModelUse
	FROM            dbo.tblEquipmentModel LEFT OUTER JOIN
							 dbo.tblEquipment ON dbo.tblEquipmentModel.EquipmentModelID = dbo.tblEquipment.EquipmentModelID
	GROUP BY dbo.tblEquipmentModel.EquipmentModelID
	GO


Print 'Created vwRpt_CountEquipmentModelUse'
GO


-- vwRpt_CountEquipmentModelAttachments ----------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountEquipmentModelAttachments') 
	BEGIN
		DROP VIEW vwRpt_CountEquipmentModelAttachments
		Print ' '
		Print 'Dropped vwRpt_CountEquipmentModelAttachments'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountEquipmentModelAttachments]
AS
SELECT        dbo.tblEquipmentModel.EquipmentModelID, COUNT(dbo.tblDocument.DocumentID) AS Attachments
FROM            dbo.tblDocument RIGHT OUTER JOIN
                         dbo.tblEquipmentModel ON dbo.tblDocument.EquipmentModelID = dbo.tblEquipmentModel.EquipmentModelID
GROUP BY dbo.tblEquipmentModel.EquipmentModelID
GO

Print 'Created vwRpt_CountEquipmentModelAttachments'
GO



-- vwRpt_CountEquipmentModelReferences-----------------------------------------------
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountEquipmentModelReferences') 
	BEGIN
		DROP VIEW vwRpt_CountEquipmentModelReferences
		Print ' '
		Print 'Dropped vwRpt_CountEquipmentModelReferences'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountEquipmentModelReferences]
AS
SELECT        dbo.tblEquipmentModel.EquipmentModelID, COUNT(dbo.tblReference.ReferenceID) AS [References]
FROM            dbo.tblEquipmentModel LEFT OUTER JOIN
                         dbo.tblReference ON dbo.tblEquipmentModel.EquipmentModelID = dbo.tblReference.EquipmentModelID
GROUP BY dbo.tblEquipmentModel.EquipmentModelID
GO

Print 'Created vwRpt_CountEquipmentModelReferences'
GO



-- vwEquipmentModels
IF EXISTS(select * FROM sys.views where name = 'vwEquipmentModels') 
	BEGIN
		DROP VIEW vwEquipmentModels
		Print ' '
		Print 'Dropped vwEquipmentModels'
	END
GO



CREATE VIEW [dbo].[vwEquipmentModels]
AS
SELECT        dbo.tblEquipmentModel.EquipmentModelID, dbo.tblEquipmentModel.ManufacturerID, dbo.tblOrganisation.TradingName AS Manufacturer, dbo.tblEquipmentModel.ModelName, dbo.tblEquipmentModel.ModelNumber, 
                         dbo.tblEquipmentModel.ModelNumberPrior, dbo.tblEquipmentModel.ModelCode, dbo.tblEquipmentModel.ModelDescription, dbo.tblEquipmentModel.ModelTypeID, 
                         dbo.vwRef_EquipmentModelType.EquipmentModelType AS ModelType, dbo.tblEquipmentModel.OtherModelType, dbo.tblEquipmentModel.ModelStatusID, 
                         dbo.vwRef_EquipmentModelStatus.EquipmentModelStatus AS ModelStatus, dbo.tblEquipmentModel.ModelSeries, dbo.tblEquipmentModel.ModelCategory, dbo.tblEquipmentModel.ModelGenre, 
                         dbo.tblEquipmentModel.OtherClassification, dbo.tblEquipmentModel.GeneralSpecifications, dbo.tblEquipmentModel.DeviceLifeExpectancy, dbo.tblEquipmentModel.TypicalProcedure, dbo.tblEquipmentModel.PurchaseCost, 
                         dbo.tblEquipmentModel.TestingCost, dbo.tblEquipmentModel.ReplacementCost, dbo.tblEquipmentModel.RequiredTestFrequencyMonths, dbo.tblEquipmentModel.PlannedReplacementFrequencyYears, 
                         dbo.tblEquipmentModel.DeviceModelOtherNote, dbo.tblEquipmentModel.DeviceModelFlagFollowup, dbo.tblEquipmentModel.OtherCodeOrNumber, dbo.tblEquipmentModel.DateCommissioned, 
                         dbo.tblEquipmentModel.DateDecommissioned, dbo.tblEquipmentModel.ModelNotes, dbo.vwRpt_CountEquipmentModelUse.ModelUse, dbo.vwRpt_CountEquipmentModelAttachments.Attachments, 
                         dbo.vwRpt_CountEquipmentModelReferences.[References]
FROM            dbo.tblEquipmentModel LEFT OUTER JOIN
                         dbo.vwRpt_CountEquipmentModelReferences ON dbo.tblEquipmentModel.EquipmentModelID = dbo.vwRpt_CountEquipmentModelReferences.EquipmentModelID LEFT OUTER JOIN
                         dbo.vwRpt_CountEquipmentModelAttachments ON dbo.tblEquipmentModel.EquipmentModelID = dbo.vwRpt_CountEquipmentModelAttachments.EquipmentModelID LEFT OUTER JOIN
                         dbo.tblOrganisation ON dbo.tblEquipmentModel.ManufacturerID = dbo.tblOrganisation.OrganisationID LEFT OUTER JOIN
                         dbo.vwRef_EquipmentModelType ON dbo.tblEquipmentModel.ModelTypeID = dbo.vwRef_EquipmentModelType.EquipmentModelTypeID LEFT OUTER JOIN
                         dbo.vwRpt_CountEquipmentModelUse ON dbo.tblEquipmentModel.EquipmentModelID = dbo.vwRpt_CountEquipmentModelUse.EquipmentModelID LEFT OUTER JOIN
                         dbo.vwRef_EquipmentModelStatus ON dbo.tblEquipmentModel.ModelStatusID = dbo.vwRef_EquipmentModelStatus.EquipmentModelStatusID
GO

Print 'Created vwEquipmentModels'
GO

-- vwRpt_CountPremisesEquipment
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountPremisesEquipment') 
	BEGIN
		DROP VIEW vwRpt_CountPremisesEquipment
		Print ' '
		Print 'Dropped vwRpt_CountPremisesEquipment'
	END
GO

-- vwRpt_CountPremisesSources
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountPremisesSources') 
	BEGIN
		DROP VIEW vwRpt_CountPremisesSources
		Print ' '
		Print 'Dropped vwRpt_CountPremisesSources'
	END
GO


CREATE VIEW [dbo].[vwRpt_CountPremisesSources]
AS
SELECT dbo.tblPremises.PremisesID, COUNT(dbo.tblEquipment.EquipmentID) AS Sources
FROM   dbo.tblPremises LEFT OUTER JOIN
         dbo.tblEquipment ON dbo.tblPremises.PremisesID = dbo.tblEquipment.PremisesID
GROUP BY dbo.tblPremises.PremisesID
GO

Print 'Created vwRpt_CountPremisesSources'
GO


-- vwRpt_CountPremisesContacts
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountPremisesContacts') 
	BEGIN
		DROP VIEW vwRpt_CountPremisesContacts
		Print ' '
		Print 'Dropped vwRpt_CountPremisesContacts'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountPremisesContacts]
AS
SELECT        dbo.tblPremises.PremisesID, COUNT(DISTINCT dbo.tblDxRole.DxContactID) AS Contacts
FROM            dbo.tblPremises LEFT OUTER JOIN
                         dbo.tblDxRole ON dbo.tblPremises.PremisesID = dbo.tblDxRole.PremisesID
GROUP BY dbo.tblPremises.PremisesID
GO

Print 'Created vwRpt_CountPremisesContacts'
GO



-- vwRpt_CountPremisesAttachments
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountPremisesAttachments') 
	BEGIN
		DROP VIEW vwRpt_CountPremisesAttachments
		Print ' '
		Print 'Dropped vwRpt_CountPremisesAttachments'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountPremisesAttachments]
AS
SELECT        dbo.tblPremises.PremisesID, COUNT(dbo.tblDocument.DocumentID) AS Attachments
FROM            dbo.tblDocument RIGHT OUTER JOIN
                         dbo.tblPremises ON dbo.tblDocument.PremisesID = dbo.tblPremises.PremisesID
GROUP BY dbo.tblPremises.PremisesID
GO

Print 'Created vwRpt_CountPremisesAttachments'
GO



-- vwRpt_CountPremisesReferences
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountPremisesReferences') 
	BEGIN
		DROP VIEW vwRpt_CountPremisesReferences
		Print ' '
		Print 'Dropped vwRpt_CountPremisesReferences'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountPremisesReferences]
AS
SELECT        dbo.tblPremises.PremisesID, COUNT(dbo.tblReference.ReferenceID) AS [References]
FROM            dbo.tblReference RIGHT OUTER JOIN
                         dbo.tblPremises ON dbo.tblReference.PremisesID = dbo.tblPremises.PremisesID
GROUP BY dbo.tblPremises.PremisesID
GO


Print 'Created vwRpt_CountPremisesReferences'
GO

-- vwPremises
IF EXISTS(select * FROM sys.views where name = 'vwPremises') 
	BEGIN
		DROP VIEW vwPremises
		Print ' '
		Print 'Dropped vwPremises'
	END
GO


CREATE VIEW [dbo].[vwPremises]
AS
SELECT dbo.vwRef_Campus.Campus, dbo.vwRef_Campus.CampusAbbrev, dbo.tblSiteLocation.SiteLocationName, dbo.tblPremises.NameOfPremises AS PremisesName, dbo.tblPremises.Classification AS PremisesClassification, dbo.tblPremises.Type AS PremisesType, dbo.tblPremises.PremisesLocalGroup, dbo.tblPremises.PremisesLocalCategory, dbo.tblPremises.RegAuthorityIDNo, dbo.tblPremises.LicenceNumber, dbo.tblPremises.PremisesDescription, 
         dbo.tblPremises.PremisesNotes, dbo.tblPremises.LocalPremisesID, dbo.tblPremises.AltLocalPremisesID, dbo.vwRpt_CountPremisesContacts.Contacts, dbo.vwRpt_CountPremisesSources.Sources, dbo.vwRpt_CountPremisesRooms.Rooms, dbo.vwRpt_CountPremisesProtectiveDevices.ProtectiveDevices, dbo.vwRpt_CountPremisesAttachments.Attachments, dbo.vwRpt_CountPremisesReferences.[References], dbo.tblPremises.DateRegistered, 
         dbo.tblPremises.Latitude, dbo.tblPremises.Longitude, dbo.tblPremises.StartDate, dbo.tblPremises.EndDate, dbo.tblSiteLocation.CampusID, dbo.tblPremises.SiteLocationID, dbo.tblPremises.PremisesID
FROM   dbo.tblSiteLocation LEFT OUTER JOIN
         dbo.vwRef_Campus ON dbo.tblSiteLocation.CampusID = dbo.vwRef_Campus.CampusID RIGHT OUTER JOIN
         dbo.tblPremises LEFT OUTER JOIN
         dbo.vwRpt_CountPremisesAttachments ON dbo.tblPremises.PremisesID = dbo.vwRpt_CountPremisesAttachments.PremisesID LEFT OUTER JOIN
         dbo.vwRpt_CountPremisesReferences ON dbo.tblPremises.PremisesID = dbo.vwRpt_CountPremisesReferences.PremisesID LEFT OUTER JOIN
         dbo.vwRpt_CountPremisesContacts ON dbo.tblPremises.PremisesID = dbo.vwRpt_CountPremisesContacts.PremisesID LEFT OUTER JOIN
         dbo.vwRpt_CountPremisesRooms ON dbo.tblPremises.PremisesID = dbo.vwRpt_CountPremisesRooms.PremisesID LEFT OUTER JOIN
         dbo.vwRpt_CountPremisesSources ON dbo.tblPremises.PremisesID = dbo.vwRpt_CountPremisesSources.PremisesID LEFT OUTER JOIN
         dbo.vwRpt_CountPremisesProtectiveDevices ON dbo.tblPremises.PremisesID = dbo.vwRpt_CountPremisesProtectiveDevices.PremisesID ON dbo.tblSiteLocation.SiteLocationID = dbo.tblPremises.SiteLocationID
GO

Print 'Created vwPremises'
GO

-- vwRpt_CountSiteLocationContacts
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountSiteLocationContacts') 
	BEGIN
		DROP VIEW vwRpt_CountSiteLocationContacts
		Print ' '
		Print 'Dropped vwRpt_CountSiteLocationContacts'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountSiteLocationContacts]
AS
SELECT        dbo.tblSiteLocation.SiteLocationID, COUNT(DISTINCT dbo.tblDxRole.DxRoleID) AS Contacts
FROM            dbo.tblSiteLocation LEFT OUTER JOIN
                         dbo.tblDxRole ON dbo.tblSiteLocation.SiteLocationID = dbo.tblDxRole.SiteLocationID
GROUP BY dbo.tblSiteLocation.SiteLocationID
GO

Print 'Created vwRpt_CountSiteLocationContacts'
GO


-- vwRpt_CountSiteLocationAttachments
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountSiteLocationAttachments') 
	BEGIN
		DROP VIEW vwRpt_CountSiteLocationAttachments
		Print ' '
		Print 'Dropped vwRpt_CountSiteLocationAttachments'
	END
GO


CREATE VIEW [dbo].[vwRpt_CountSiteLocationAttachments]
AS
SELECT        dbo.tblSiteLocation.SiteLocationID, COUNT(dbo.tblDocument.DocumentID) AS Attachments
FROM            dbo.tblSiteLocation LEFT OUTER JOIN
                         dbo.tblDocument ON dbo.tblSiteLocation.SiteLocationID = dbo.tblDocument.SiteLocationID
GROUP BY dbo.tblSiteLocation.SiteLocationID
GO

Print 'Created vwRpt_CountSiteLocationAttachments'
GO




-- vwRpt_CountSiteLocationReferences
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountSiteLocationReferences') 
	BEGIN
		DROP VIEW vwRpt_CountSiteLocationReferences
		Print ' '
		Print 'Dropped vwRpt_CountSiteLocationReferences'
	END
GO


CREATE VIEW [dbo].[vwRpt_CountSiteLocationReferences]
AS
SELECT        dbo.tblSiteLocation.SiteLocationID, COUNT(dbo.tblReference.ReferenceID) AS [References]
FROM            dbo.tblSiteLocation LEFT OUTER JOIN
                         dbo.tblReference ON dbo.tblSiteLocation.SiteLocationID = dbo.tblReference.SiteLocationID
GROUP BY dbo.tblSiteLocation.SiteLocationID
GO

Print 'Created vwRpt_CountSiteLocationReferences'
GO


 -- Remove vwRpt_CountSiteLocationsEquipment
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountSiteLocationsEquipment') 
	BEGIN
		DROP VIEW vwRpt_CountSiteLocationsEquipment
		Print ' '
		Print 'Dropped vwRpt_CountSiteLocationsEquipment'
	END
GO

 -- vwRpt_CountSiteLocationsSources
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountSiteLocationsSources') 
	BEGIN
		DROP VIEW vwRpt_CountSiteLocationsSources
		Print ' '
		Print 'Dropped vwRpt_CountSiteLocationsSources'
	END
GO


CREATE VIEW [dbo].[vwRpt_CountSiteLocationsSources]
AS
SELECT dbo.tblSiteLocation.SiteLocationID, COUNT(dbo.tblEquipment.EquipmentID) AS Sources
FROM   dbo.tblSiteLocation LEFT OUTER JOIN
         dbo.tblEquipment ON dbo.tblSiteLocation.SiteLocationID = dbo.tblEquipment.SiteLocationID
GROUP BY dbo.tblSiteLocation.SiteLocationID
GO

Print 'Created vwRpt_CountSiteLocationsSources'
GO

 -- vwSiteLocations
IF EXISTS(select * FROM sys.views where name = 'vwSiteLocations') 
	BEGIN
		DROP VIEW vwSiteLocations
		Print ' '
		Print 'Dropped vwSiteLocations'
	END
GO

CREATE VIEW [dbo].[vwSiteLocations]
AS
SELECT dbo.tblSiteLocation.SiteLocationID, dbo.tblSiteLocation.SiteLocationName, dbo.vwRef_Region.Region AS SiteRegion, dbo.vwRef_Campus.Campus, dbo.vwRef_Campus.CampusAbbrev, dbo.tblSiteLocation.Latitude, dbo.tblSiteLocation.Longitude, dbo.tblSiteLocation.SiteLocationLocalCategory, dbo.tblSiteLocation.SiteLocationLocalGroup, dbo.tblSiteLocation.SiteLocationDescription, dbo.tblSiteLocation.SiteLocationNote, dbo.vwRpt_CountSiteLocationContacts.Contacts, 
         dbo.vwRpt_CountSiteLocationsSources.Sources, dbo.vwRpt_CountSiteLocationsPremises.Premises, dbo.vwRpt_CountSiteLocationsRooms.Rooms, dbo.vwRpt_CountSiteLocationsProtectiveDevices.ProtectiveDevices, dbo.vwRpt_CountSiteLocationAttachments.Attachments, dbo.vwRpt_CountSiteLocationReferences.[References], dbo.tblSiteLocation.RegionID, dbo.tblSiteLocation.AltLocalSiteLocationID, dbo.tblSiteLocation.LocalSiteLocationID, 
         dbo.tblSiteLocation.CampusID
FROM   dbo.tblSiteLocation INNER JOIN
         dbo.vwRpt_CountSiteLocationsPremises ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationsPremises.SiteLocationID LEFT OUTER JOIN
         dbo.vwRef_Campus ON dbo.tblSiteLocation.CampusID = dbo.vwRef_Campus.CampusID LEFT OUTER JOIN
         dbo.vwRef_Region ON dbo.tblSiteLocation.RegionID = dbo.vwRef_Region.RegionID LEFT OUTER JOIN
         dbo.vwRpt_CountSiteLocationReferences ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationReferences.SiteLocationID LEFT OUTER JOIN
         dbo.vwRpt_CountSiteLocationsSources ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationsSources.SiteLocationID LEFT OUTER JOIN
         dbo.vwRpt_CountSiteLocationContacts ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationContacts.SiteLocationID LEFT OUTER JOIN
         dbo.vwRpt_CountSiteLocationsRooms ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationsRooms.SiteLocationID LEFT OUTER JOIN
         dbo.vwRpt_CountSiteLocationAttachments ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationAttachments.SiteLocationID LEFT OUTER JOIN
         dbo.vwRpt_CountSiteLocationsProtectiveDevices ON dbo.tblSiteLocation.SiteLocationID = dbo.vwRpt_CountSiteLocationsProtectiveDevices.SiteLocationID
GO

Print 'Created vwSiteLocations'
GO


-- ---------------------
-- vwRpt_CountRoomsEquipment
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountRoomsEquipment') 
	BEGIN
		DROP VIEW vwRpt_CountRoomsEquipment
		Print ' '
		Print 'Dropped vwRpt_CountRoomsEquipment'
	END
GO

-- ---------------------
-- vwRpt_CountRoomsSources
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountRoomsSources') 
	BEGIN
		DROP VIEW vwRpt_CountRoomsSources
		Print ' '
		Print 'Dropped vwRpt_CountRoomsSources'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountRoomsSources]
AS
SELECT dbo.tblRoom.RoomID, COUNT(dbo.tblEquipment.EquipmentID) AS Sources
FROM   dbo.tblRoom LEFT OUTER JOIN
         dbo.tblEquipment ON dbo.tblRoom.RoomID = dbo.tblEquipment.RoomID
GROUP BY dbo.tblRoom.RoomID
GO

Print 'Created vwRpt_CountRoomsSources'
GO

-- ---------------------
-- vwRpt_CountRoomContacts
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountRoomContacts') 
	BEGIN
		DROP VIEW vwRpt_CountRoomContacts
		Print ' '
		Print 'Dropped vwRpt_CountRoomContacts'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountRoomContacts]
AS
SELECT        dbo.tblRoom.RoomID, COUNT(DISTINCT dbo.tblDxRole.DxRoleID) AS Contacts
FROM            dbo.tblRoom LEFT OUTER JOIN
                         dbo.tblDxRole ON dbo.tblRoom.RoomID = dbo.tblDxRole.RoomID
GROUP BY dbo.tblRoom.RoomID
GO

Print 'Created vwRpt_CountRoomContacts'
GO


-- ---------------------
-- vwRpt_CountRoomAttachments
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountRoomAttachments') 
	BEGIN
		DROP VIEW vwRpt_CountRoomAttachments
		Print ' '
		Print 'Dropped vwRpt_CountRoomAttachments'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountRoomAttachments]
AS
SELECT        dbo.tblRoom.RoomID, COUNT(dbo.tblDocument.DocumentID) AS Attachments
FROM            dbo.tblRoom LEFT OUTER JOIN
                         dbo.tblDocument ON dbo.tblRoom.RoomID = dbo.tblDocument.RoomID
GROUP BY dbo.tblRoom.RoomID
GO

Print 'Created vwRpt_CountRoomAttachments'
GO

-- ---------------------
-- vwRpt_CountRoomReferences
IF EXISTS(select * FROM sys.views where name = 'vwRpt_CountRoomReferences') 
	BEGIN
		DROP VIEW vwRpt_CountRoomReferences
		Print ' '
		Print 'Dropped vwRpt_CountRoomReferences'
	END
GO

CREATE VIEW [dbo].[vwRpt_CountRoomReferences]
AS
SELECT        dbo.tblRoom.RoomID, COUNT(dbo.tblReference.ReferenceID) AS [References]
FROM            dbo.tblRoom LEFT OUTER JOIN
                         dbo.tblReference ON dbo.tblRoom.RoomID = dbo.tblReference.RoomID
GROUP BY dbo.tblRoom.RoomID
GO

Print 'Created vwRpt_CountRoomReferences'
GO

-- vwRooms
IF EXISTS(select * FROM sys.views where name = 'vwRooms') 
	BEGIN
		DROP VIEW vwRooms
		Print ' '
		Print 'Dropped vwRooms'
	END
GO


CREATE VIEW [dbo].[vwRooms]
AS
SELECT dbo.vwRef_Campus.Campus, dbo.vwRef_Campus.CampusAbbrev, dbo.tblSiteLocation.SiteLocationName, dbo.tblPremises.NameOfPremises AS Premises, dbo.vwRef_RoomType.RoomType, dbo.tblRoom.RoomName, dbo.tblRoom.RoomNumber, dbo.tblRoom.RoomCode, dbo.tblRoom.FloorLevel, dbo.tblRoom.LocalRoomID, dbo.tblRoom.AltLocalRoomID, dbo.tblRoom.RoomDescription, dbo.tblRoom.Capacity, dbo.tblRoom.Dimensions, dbo.tblRoom.Ventilation, 
         dbo.tblRoom.SafetyFeatures, dbo.tblRoom.EmergencyAssembly, dbo.tblRoom.RoomNotes, dbo.tblRoom.RoomLocalGroup, dbo.tblRoom.RoomLocalCategory, dbo.vwRpt_CountRoomContacts.Contacts, dbo.vwRpt_CountRoomsSources.Sources, dbo.vwRpt_CountRoomsProtectiveDevices.ProtectiveDevices, dbo.vwRpt_CountRoomAttachments.Attachments, dbo.vwRpt_CountRoomReferences.[References], dbo.tblRoom.Latitude, dbo.tblRoom.Longitude, 
         dbo.tblRoom.StartDate, dbo.tblRoom.EndDate, dbo.tblRoom.RoomTypeID, dbo.tblPremises.SiteLocationID, dbo.tblRoom.PremisesID, dbo.tblRoom.RoomID, dbo.vwRef_Campus.CampusID
FROM   dbo.tblPremises LEFT OUTER JOIN
         dbo.tblSiteLocation LEFT OUTER JOIN
         dbo.vwRef_Campus ON dbo.tblSiteLocation.CampusID = dbo.vwRef_Campus.CampusID ON dbo.tblPremises.SiteLocationID = dbo.tblSiteLocation.SiteLocationID RIGHT OUTER JOIN
         dbo.vwRef_RoomType RIGHT OUTER JOIN
         dbo.tblRoom ON dbo.vwRef_RoomType.RoomTypeID = dbo.tblRoom.RoomTypeID ON dbo.tblPremises.PremisesID = dbo.tblRoom.PremisesID LEFT OUTER JOIN
         dbo.vwRpt_CountRoomAttachments ON dbo.tblRoom.RoomID = dbo.vwRpt_CountRoomAttachments.RoomID LEFT OUTER JOIN
         dbo.vwRpt_CountRoomContacts ON dbo.tblRoom.RoomID = dbo.vwRpt_CountRoomContacts.RoomID LEFT OUTER JOIN
         dbo.vwRpt_CountRoomReferences ON dbo.tblRoom.RoomID = dbo.vwRpt_CountRoomReferences.RoomID LEFT OUTER JOIN
         dbo.vwRpt_CountRoomsProtectiveDevices ON dbo.tblRoom.RoomID = dbo.vwRpt_CountRoomsProtectiveDevices.RoomID LEFT OUTER JOIN
         dbo.vwRpt_CountRoomsSources ON dbo.tblRoom.RoomID = dbo.vwRpt_CountRoomsSources.RoomID
GO

Print 'Created vwRooms'
GO

-- --------------------------------------

-- vwSiteLocationContacts
IF EXISTS(select * FROM sys.views where name = 'vwSiteLocationContacts') 
	BEGIN
		DROP VIEW vwSiteLocationContacts
		Print ' '
		Print 'Dropped vwSiteLocationContacts'
	END
GO


CREATE VIEW [dbo].[vwSiteLocationContacts]
AS
SELECT        dbo.tblSiteLocation.SiteLocationID, dbo.tblDxContact.DxContactID, dbo.tblDxContact.IsActive, dbo.tblDxContact.DetailSetting, dbo.tblDxContact.PrivacyRating, dbo.tblDxContact.UserID, dbo.tblDxContact.WearerInternalID, 
                         dbo.tblDxContact.Title, dbo.tblDxContact.FirstName, dbo.tblDxContact.Surname, dbo.tblDxContact.OtherGivenNames, dbo.tblDxContact.Sex, dbo.tblDxContact.DOB, dbo.tblDxContact.Notes, 
                         dbo.tblSiteLocation.SiteLocationName
FROM            dbo.tblDxContact INNER JOIN
                         dbo.tblDxRole ON dbo.tblDxContact.DxContactID = dbo.tblDxRole.DxContactID INNER JOIN
                         dbo.tblSiteLocation ON dbo.tblDxRole.SiteLocationID = dbo.tblSiteLocation.SiteLocationID
GO


Print 'Created vwSiteLocationContacts'
GO


-- vwSel_Contact_Mobiles
IF EXISTS(select * FROM sys.views where name = 'vwSel_Contact_Mobiles') 
	BEGIN
		DROP VIEW vwSel_Contact_Mobiles
		Print ' '
		Print 'Dropped vwSel_Contact_Mobiles'
	END
GO


CREATE VIEW [dbo].[vwSel_Contact_Mobiles]
AS
SELECT        DxContactID, MediumType, DxMedium AS Mobile
FROM            dbo.tblDxMedium
WHERE        (DxContactID IS NOT NULL)
GROUP BY DxContactID, MediumType, DxMedium
HAVING        (MediumType = 1)
GO


Print 'Created vwSel_Contact_Mobiles'
GO

-- vwSel_Contact_Landlines
IF EXISTS(select * FROM sys.views where name = 'vwSel_Contact_Landlines') 
	BEGIN
		DROP VIEW vwSel_Contact_Landlines
		Print ' '
		Print 'Dropped vwSel_Contact_Landlines'
	END
GO

CREATE VIEW [dbo].[vwSel_Contact_Landlines]
AS
SELECT        DxContactID, MediumType, DxMedium AS Landline
FROM            dbo.tblDxMedium
WHERE        (DxContactID IS NOT NULL)
GROUP BY DxContactID, MediumType, DxMedium
HAVING        (MediumType = 2)
GO

Print 'Created vwSel_Contact_Landlines'
GO

-- vwSel_Contact_Emails
IF EXISTS(select * FROM sys.views where name = 'vwSel_Contact_Emails') 
	BEGIN
		DROP VIEW vwSel_Contact_Emails
		Print ' '
		Print 'Dropped vwSel_Contact_Emails'
	END
GO

CREATE VIEW [dbo].[vwSel_Contact_Emails]
AS
SELECT        DxContactID, MediumType, DxMedium AS Email
FROM            dbo.tblDxMedium
WHERE        (DxContactID IS NOT NULL)
GROUP BY DxContactID, MediumType, DxMedium
HAVING        (MediumType = 3)
GO

Print 'Created vwSel_Contact_Emails'
GO

-- vwDxContacts
IF EXISTS(select * FROM sys.views where name = 'vwDxContacts') 
	BEGIN
		DROP VIEW vwDxContacts
		Print ' '
		Print 'Dropped vwDxContacts'
	END
GO

CREATE VIEW [dbo].[vwDxContacts]
AS
SELECT        dbo.tblDxContact.DxContactID, CASE WHEN dbo.tblDxContact.IsActive = 1 THEN 'Yes' ELSE 'No' END AS ActiveContact, dbo.tblDxContact.DetailSetting, dbo.vwRef_PrivacyRating.PrivacyRatingCode, 
                         dbo.vwRef_PrivacyRating.PrivacyRating, dbo.tblDxContact.WearerInternalID, dbo.tblDxContact.UserID, dbo.tblDxContact.Title, dbo.tblDxContact.FirstName, dbo.tblDxContact.Surname, dbo.tblDxContact.OtherGivenNames, 
                         dbo.tblDxContact.Sex, dbo.tblDxContact.DOB, dbo.vwSel_Contact_Mobiles.Mobile, dbo.vwSel_Contact_Landlines.Landline, dbo.vwSel_Contact_Emails.Email, dbo.tblDxContact.Notes
FROM            dbo.tblDxContact LEFT OUTER JOIN
                         dbo.vwSel_Contact_Landlines ON dbo.tblDxContact.DxContactID = dbo.vwSel_Contact_Landlines.DxContactID LEFT OUTER JOIN
                         dbo.vwSel_Contact_Mobiles ON dbo.tblDxContact.DxContactID = dbo.vwSel_Contact_Mobiles.DxContactID LEFT OUTER JOIN
                         dbo.vwSel_Contact_Emails ON dbo.tblDxContact.DxContactID = dbo.vwSel_Contact_Emails.DxContactID LEFT OUTER JOIN
                         dbo.vwRef_PrivacyRating ON dbo.tblDxContact.PrivacyRating = dbo.vwRef_PrivacyRating.PrivacyRatingCode
GO

Print 'Created vwDxContacts'
GO

-- ===========================================================================================================
-- Replacement SPROCS 
-- ===========================================================================================================

-- tblDocument

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_Insert]
	@daDateCreated datetime,
	@sUserID varchar(50),
	@iDocumentTypeID int,
	@blobContent image,
	@sDocumentFormat varchar(10),
	@sDocumentTitle varchar(max),
	@sDocumentNotes nvarchar(max),
	@iFileNoteID int,
	@iEquipmentID int,
	@iPremisesID int,
	@iEquipmentServiceID int,
	@iEquipmentDefectID int,
	@iEquipmentTestID int,
	@iSpecificationID int,
	@iEquipmentWearerID int,
	@iWearerTrainingID int,
	@iTrainingQualificationIndustryID int,
	@iTrainingCourseID int,
	@iLicencePermitID int,
	@iLicencePermitEquipmentID int,
	@iPregnancyID int,
	@iProviderID int,
	@iRoomID int,
	@iSiteLocationID int,
	@iSourceID int,
	@iCustomNotificationID int,
	@iDoseAlertSettingID int,
	@iDoseReportTypeID int,
	@iEquipmentModelID int,
	@iOrganisationID int,
	@iDocumentID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDocument]
(
	[DateCreated],
	[UserID],
	[DocumentTypeID],
	[Content],
	[DocumentFormat],
	[DocumentTitle],
	[DocumentNotes],
	[FileNoteID],
	[EquipmentID],
	[PremisesID],
	[EquipmentServiceID],
	[EquipmentDefectID],
	[EquipmentTestID],
	[SpecificationID],
	[EquipmentWearerID],
	[WearerTrainingID],
	[TrainingQualificationIndustryID],
	[TrainingCourseID],
	[LicencePermitID],
	[LicencePermitEquipmentID],
	[PregnancyID],
	[ProviderID],
	[RoomID],
	[SiteLocationID],
	[SourceID],
	[CustomNotificationID],
	[DoseAlertSettingID],
	[DoseReportTypeID],
	[EquipmentModelID],
	[OrganisationID]
)
VALUES
(
	@daDateCreated,
	@sUserID,
	@iDocumentTypeID,
	@blobContent,
	@sDocumentFormat,
	@sDocumentTitle,
	@sDocumentNotes,
	@iFileNoteID,
	@iEquipmentID,
	@iPremisesID,
	@iEquipmentServiceID,
	@iEquipmentDefectID,
	@iEquipmentTestID,
	@iSpecificationID,
	@iEquipmentWearerID,
	@iWearerTrainingID,
	@iTrainingQualificationIndustryID,
	@iTrainingCourseID,
	@iLicencePermitID,
	@iLicencePermitEquipmentID,
	@iPregnancyID,
	@iProviderID,
	@iRoomID,
	@iSiteLocationID,
	@iSourceID,
	@iCustomNotificationID,
	@iDoseAlertSettingID,
	@iDoseReportTypeID,
	@iEquipmentModelID,
	@iOrganisationID
)
SELECT @iErrorCode=@@ERROR
SELECT @iDocumentID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_Update]
	@iDocumentID int,
	@daDateCreated datetime,
	@sUserID varchar(50),
	@iDocumentTypeID int,
	@blobContent image,
	@sDocumentFormat varchar(10),
	@sDocumentTitle varchar(max),
	@sDocumentNotes nvarchar(max),
	@iFileNoteID int,
	@iEquipmentID int,
	@iPremisesID int,
	@iEquipmentServiceID int,
	@iEquipmentDefectID int,
	@iEquipmentTestID int,
	@iSpecificationID int,
	@iEquipmentWearerID int,
	@iWearerTrainingID int,
	@iTrainingQualificationIndustryID int,
	@iTrainingCourseID int,
	@iLicencePermitID int,
	@iLicencePermitEquipmentID int,
	@iPregnancyID int,
	@iProviderID int,
	@iRoomID int,
	@iSiteLocationID int,
	@iSourceID int,
	@iCustomNotificationID int,
	@iDoseAlertSettingID int,
	@iDoseReportTypeID int,
	@iEquipmentModelID int,
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET 
	[DateCreated] = @daDateCreated,
	[UserID] = @sUserID,
	[DocumentTypeID] = @iDocumentTypeID,
	[Content] = @blobContent,
	[DocumentFormat] = @sDocumentFormat,
	[DocumentTitle] = @sDocumentTitle,
	[DocumentNotes] = @sDocumentNotes,
	[FileNoteID] = @iFileNoteID,
	[EquipmentID] = @iEquipmentID,
	[PremisesID] = @iPremisesID,
	[EquipmentServiceID] = @iEquipmentServiceID,
	[EquipmentDefectID] = @iEquipmentDefectID,
	[EquipmentTestID] = @iEquipmentTestID,
	[SpecificationID] = @iSpecificationID,
	[EquipmentWearerID] = @iEquipmentWearerID,
	[WearerTrainingID] = @iWearerTrainingID,
	[TrainingQualificationIndustryID] = @iTrainingQualificationIndustryID,
	[TrainingCourseID] = @iTrainingCourseID,
	[LicencePermitID] = @iLicencePermitID,
	[LicencePermitEquipmentID] = @iLicencePermitEquipmentID,
	[PregnancyID] = @iPregnancyID,
	[ProviderID] = @iProviderID,
	[RoomID] = @iRoomID,
	[SiteLocationID] = @iSiteLocationID,
	[SourceID] = @iSourceID,
	[CustomNotificationID] = @iCustomNotificationID,
	[DoseAlertSettingID] = @iDoseAlertSettingID,
	[DoseReportTypeID] = @iDoseReportTypeID,
	[EquipmentModelID] = @iEquipmentModelID,
	[OrganisationID] = @iOrganisationID
WHERE
	[DocumentID] = @iDocumentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWUserIDLogic]
	@sUserID varchar(50),
	@sUserIDOld varchar(50),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[UserID] = @sUserID
WHERE
	[UserID] = @sUserIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWFileNoteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWFileNoteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWFileNoteIDLogic]
	@iFileNoteID int,
	@iFileNoteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[FileNoteID] = @iFileNoteID
WHERE
	[FileNoteID] = @iFileNoteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iEquipmentIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[EquipmentID] = @iEquipmentID
WHERE
	[EquipmentID] = @iEquipmentIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWEquipmentServiceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWEquipmentServiceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWEquipmentServiceIDLogic]
	@iEquipmentServiceID int,
	@iEquipmentServiceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[EquipmentServiceID] = @iEquipmentServiceID
WHERE
	[EquipmentServiceID] = @iEquipmentServiceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWEquipmentDefectIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWEquipmentDefectIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWEquipmentDefectIDLogic]
	@iEquipmentDefectID int,
	@iEquipmentDefectIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[EquipmentDefectID] = @iEquipmentDefectID
WHERE
	[EquipmentDefectID] = @iEquipmentDefectIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWEquipmentTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWEquipmentTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWEquipmentTestIDLogic]
	@iEquipmentTestID int,
	@iEquipmentTestIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[EquipmentTestID] = @iEquipmentTestID
WHERE
	[EquipmentTestID] = @iEquipmentTestIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWSpecificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWSpecificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWSpecificationIDLogic]
	@iSpecificationID int,
	@iSpecificationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[SpecificationID] = @iSpecificationID
WHERE
	[SpecificationID] = @iSpecificationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWEquipmentWearerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWEquipmentWearerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWEquipmentWearerIDLogic]
	@iEquipmentWearerID int,
	@iEquipmentWearerIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[EquipmentWearerID] = @iEquipmentWearerID
WHERE
	[EquipmentWearerID] = @iEquipmentWearerIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWWearerTrainingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWWearerTrainingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWWearerTrainingIDLogic]
	@iWearerTrainingID int,
	@iWearerTrainingIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[WearerTrainingID] = @iWearerTrainingID
WHERE
	[WearerTrainingID] = @iWearerTrainingIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWTrainingQualificationIndustryIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWTrainingQualificationIndustryIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWTrainingQualificationIndustryIDLogic]
	@iTrainingQualificationIndustryID int,
	@iTrainingQualificationIndustryIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[TrainingQualificationIndustryID] = @iTrainingQualificationIndustryID
WHERE
	[TrainingQualificationIndustryID] = @iTrainingQualificationIndustryIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWTrainingCourseIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWTrainingCourseIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWTrainingCourseIDLogic]
	@iTrainingCourseID int,
	@iTrainingCourseIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[TrainingCourseID] = @iTrainingCourseID
WHERE
	[TrainingCourseID] = @iTrainingCourseIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iLicencePermitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[LicencePermitID] = @iLicencePermitID
WHERE
	[LicencePermitID] = @iLicencePermitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWLicencePermitEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWLicencePermitEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWLicencePermitEquipmentIDLogic]
	@iLicencePermitEquipmentID int,
	@iLicencePermitEquipmentIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[LicencePermitEquipmentID] = @iLicencePermitEquipmentID
WHERE
	[LicencePermitEquipmentID] = @iLicencePermitEquipmentIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWPregnancyIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWPregnancyIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWPregnancyIDLogic]
	@iPregnancyID int,
	@iPregnancyIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[PregnancyID] = @iPregnancyID
WHERE
	[PregnancyID] = @iPregnancyIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWProviderIDLogic]
	@iProviderID int,
	@iProviderIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[ProviderID] = @iProviderID
WHERE
	[ProviderID] = @iProviderIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWRoomIDLogic]
	@iRoomID int,
	@iRoomIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[RoomID] = @iRoomID
WHERE
	[RoomID] = @iRoomIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWSourceIDLogic]
	@iSourceID int,
	@iSourceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[SourceID] = @iSourceID
WHERE
	[SourceID] = @iSourceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWCustomNotificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWCustomNotificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWCustomNotificationIDLogic]
	@iCustomNotificationID int,
	@iCustomNotificationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[CustomNotificationID] = @iCustomNotificationID
WHERE
	[CustomNotificationID] = @iCustomNotificationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWDoseAlertSettingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWDoseAlertSettingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWDoseAlertSettingIDLogic]
	@iDoseAlertSettingID int,
	@iDoseAlertSettingIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[DoseAlertSettingID] = @iDoseAlertSettingID
WHERE
	[DoseAlertSettingID] = @iDoseAlertSettingIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWDoseReportTypeIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWDoseReportTypeIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWDoseReportTypeIDLogic]
	@iDoseReportTypeID int,
	@iDoseReportTypeIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[DoseReportTypeID] = @iDoseReportTypeID
WHERE
	[DoseReportTypeID] = @iDoseReportTypeIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iEquipmentModelIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[EquipmentModelID] = @iEquipmentModelID
WHERE
	[EquipmentModelID] = @iEquipmentModelIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDocument]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_Delete]
	@iDocumentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDocument]
WHERE
	[DocumentID] = @iDocumentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWUserIDLogic]
	@sUserID varchar(50),
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[UserID] = @sUserID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWFileNoteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWFileNoteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWFileNoteIDLogic]
	@iFileNoteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[FileNoteID] = @iFileNoteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWEquipmentServiceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWEquipmentServiceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWEquipmentServiceIDLogic]
	@iEquipmentServiceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[EquipmentServiceID] = @iEquipmentServiceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWEquipmentDefectIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWEquipmentDefectIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWEquipmentDefectIDLogic]
	@iEquipmentDefectID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[EquipmentDefectID] = @iEquipmentDefectID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWEquipmentTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWEquipmentTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWEquipmentTestIDLogic]
	@iEquipmentTestID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[EquipmentTestID] = @iEquipmentTestID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWSpecificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWSpecificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWSpecificationIDLogic]
	@iSpecificationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[SpecificationID] = @iSpecificationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWEquipmentWearerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWEquipmentWearerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWEquipmentWearerIDLogic]
	@iEquipmentWearerID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[EquipmentWearerID] = @iEquipmentWearerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWWearerTrainingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWWearerTrainingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWWearerTrainingIDLogic]
	@iWearerTrainingID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[WearerTrainingID] = @iWearerTrainingID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWTrainingQualificationIndustryIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWTrainingQualificationIndustryIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWTrainingQualificationIndustryIDLogic]
	@iTrainingQualificationIndustryID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[TrainingQualificationIndustryID] = @iTrainingQualificationIndustryID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWTrainingCourseIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWTrainingCourseIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWTrainingCourseIDLogic]
	@iTrainingCourseID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[TrainingCourseID] = @iTrainingCourseID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[LicencePermitID] = @iLicencePermitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWLicencePermitEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWLicencePermitEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWLicencePermitEquipmentIDLogic]
	@iLicencePermitEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[LicencePermitEquipmentID] = @iLicencePermitEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWPregnancyIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWPregnancyIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWPregnancyIDLogic]
	@iPregnancyID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[PregnancyID] = @iPregnancyID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWProviderIDLogic]
	@iProviderID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[ProviderID] = @iProviderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWSourceIDLogic]
	@iSourceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[SourceID] = @iSourceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWCustomNotificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWCustomNotificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWCustomNotificationIDLogic]
	@iCustomNotificationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[CustomNotificationID] = @iCustomNotificationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWDoseAlertSettingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWDoseAlertSettingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWDoseAlertSettingIDLogic]
	@iDoseAlertSettingID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[DoseAlertSettingID] = @iDoseAlertSettingID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWDoseReportTypeIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWDoseReportTypeIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWDoseReportTypeIDLogic]
	@iDoseReportTypeID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[DoseReportTypeID] = @iDoseReportTypeID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDocument]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectOne]
	@iDocumentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[DocumentID] = @iDocumentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWUserIDLogic]
	@sUserID varchar(50),
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[UserID] = @sUserID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWFileNoteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWFileNoteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWFileNoteIDLogic]
	@iFileNoteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[FileNoteID] = @iFileNoteID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[EquipmentID] = @iEquipmentID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWEquipmentServiceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWEquipmentServiceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWEquipmentServiceIDLogic]
	@iEquipmentServiceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[EquipmentServiceID] = @iEquipmentServiceID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWEquipmentDefectIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWEquipmentDefectIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWEquipmentDefectIDLogic]
	@iEquipmentDefectID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[EquipmentDefectID] = @iEquipmentDefectID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWEquipmentTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWEquipmentTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWEquipmentTestIDLogic]
	@iEquipmentTestID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[EquipmentTestID] = @iEquipmentTestID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWSpecificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWSpecificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWSpecificationIDLogic]
	@iSpecificationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[SpecificationID] = @iSpecificationID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWEquipmentWearerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWEquipmentWearerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWEquipmentWearerIDLogic]
	@iEquipmentWearerID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[EquipmentWearerID] = @iEquipmentWearerID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWWearerTrainingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWWearerTrainingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWWearerTrainingIDLogic]
	@iWearerTrainingID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[WearerTrainingID] = @iWearerTrainingID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWTrainingQualificationIndustryIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWTrainingQualificationIndustryIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWTrainingQualificationIndustryIDLogic]
	@iTrainingQualificationIndustryID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[TrainingQualificationIndustryID] = @iTrainingQualificationIndustryID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWTrainingCourseIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWTrainingCourseIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWTrainingCourseIDLogic]
	@iTrainingCourseID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[TrainingCourseID] = @iTrainingCourseID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[LicencePermitID] = @iLicencePermitID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWLicencePermitEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWLicencePermitEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWLicencePermitEquipmentIDLogic]
	@iLicencePermitEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[LicencePermitEquipmentID] = @iLicencePermitEquipmentID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWPregnancyIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWPregnancyIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWPregnancyIDLogic]
	@iPregnancyID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[PregnancyID] = @iPregnancyID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWProviderIDLogic]
	@iProviderID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[ProviderID] = @iProviderID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[RoomID] = @iRoomID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWSourceIDLogic]
	@iSourceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[SourceID] = @iSourceID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWCustomNotificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWCustomNotificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWCustomNotificationIDLogic]
	@iCustomNotificationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[CustomNotificationID] = @iCustomNotificationID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWDoseAlertSettingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWDoseAlertSettingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWDoseAlertSettingIDLogic]
	@iDoseAlertSettingID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[DoseAlertSettingID] = @iDoseAlertSettingID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWDoseReportTypeIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWDoseReportTypeIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWDoseReportTypeIDLogic]
	@iDoseReportTypeID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[DoseReportTypeID] = @iDoseReportTypeID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDocument_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDocument_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDocument_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDocument]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[DocumentID] ASC
SELECT @iErrorCode=@@ERROR
GO

---------------------------------------------------------------------------------------------------------------------------------------------------
-- tblEquipment replacement SPROCS
---------------------------------------------------------------------------------------------------------------------------------------------------

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_Insert]
	@iEquipmentTypeID int,
	@sEquipmentStatus nvarchar(30),
	@daDateRegistered datetime,
	@sBrand nvarchar(max),
	@sModel nvarchar(max),
	@sClassification nvarchar(max),
	@sSiteLocation nvarchar(max),
	@sContactDetails nvarchar(max),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@daDateAcquired datetime,
	@daDateOfDisposal datetime,
	@sSerialNo nvarchar(50),
	@sISONumber nvarchar(50),
	@sAssetNumber nvarchar(12),
	@daDateManufactured datetime,
	@daDateLastTested datetime,
	@sWorkingLife nvarchar(max),
	@daDateWorkingLifeExpiry datetime,
	@iRadioNuclideID int,
	@sEquipmentNotes nvarchar(max),
	@iEquipmentStatusID int,
	@sEquipmentName nvarchar(max),
	@sManufacturer nvarchar(80),
	@sBuildingPrefixName nvarchar(max),
	@sBuildingNumber nvarchar(20),
	@sUnitNumber nvarchar(20),
	@sStreetName nvarchar(max),
	@sSuburb nvarchar(40),
	@sState nvarchar(20),
	@sPostcode nvarchar(5),
	@sControlGenManufacturer nvarchar(80),
	@sControlGenModel nvarchar(max),
	@sControlGenSerial nvarchar(20),
	@sTubeHousingManufacturer nvarchar(80),
	@sTubeHousingModel nvarchar(max),
	@sTubeHousingSerial nvarchar(max),
	@sTubeInsertManufacturer nvarchar(80),
	@sTubeInsertModel nvarchar(max),
	@sTubeInsertSerial nvarchar(max),
	@sCategory nvarchar(max),
	@sNominalActivity nvarchar(max),
	@sRegAuthorityIDNoPrev nvarchar(max),
	@sLicenceNumberPrev nvarchar(max),
	@iHasComplianceCertificate int,
	@daAssayDate datetime,
	@daComplianceCertExpiry datetime,
	@iSendComplianceCertReminder int,
	@sSendComplianceCertReminderTo nvarchar(max),
	@iApparatusDescriptionID int,
	@iCostGroupID int,
	@iSealedSourceDescriptionID int,
	@iSecurityClassificationID int,
	@iCampusID int,
	@iSiteLocationID int,
	@iBusinessUnitID int,
	@iCentreInternalID int,
	@iPremisesID int,
	@sOtherApparatus nvarchar(max),
	@sOtherSealedSourceDevice nvarchar(max),
	@sPermittedPractice nvarchar(max),
	@sPermittedLocation nvarchar(max),
	@sPermittedIonisingApparatus nvarchar(max),
	@sPermittedPurpose nvarchar(max),
	@sPermittedSealedSource nvarchar(max),
	@sPermittedRadionuclide nvarchar(max),
	@sMaxPermittedActivity nvarchar(max),
	@sResponsibleDepartment nvarchar(max),
	@sEquipmentType nvarchar(50),
	@iRequiresTesting int,
	@sVendor nvarchar(max),
	@sVendorDetails nvarchar(max),
	@sTypicalProcedure nvarchar(max),
	@sTypicalShielding nvarchar(max),
	@dcServiceCost decimal(10, 2),
	@dcTestingCost decimal(10, 2),
	@dcReplacementCost decimal(10, 2),
	@dcTotalDepreciation decimal(10, 2),
	@sDepreciationDesc nvarchar(max),
	@dcRentalCost decimal(10, 2),
	@dcRunningCost decimal(10, 2),
	@dcOtherCostA decimal(10, 2),
	@sOtherCostADesc nvarchar(max),
	@dcOtherCostB decimal(10, 2),
	@sOtherCostBDesc nvarchar(max),
	@sCostsNote nvarchar(max),
	@daDatePurchased datetime,
	@daDateWarrantyExpires datetime,
	@daDateGuaranteeExpires datetime,
	@sWarrantyConditions nvarchar(max),
	@sGuranteeConditions nvarchar(max),
	@dcPurchaseCost decimal(10, 2),
	@daDatePlannedExpiration datetime,
	@dcDisposalCost decimal(10, 2),
	@sDisposalVendorContact nvarchar(max),
	@sDisposalMethod nvarchar(max),
	@iDisposalConfirmed int,
	@sDisposalConfirmation nvarchar(max),
	@sDisposalEnvironmental nvarchar(max),
	@iDisposalPermitRequired int,
	@iDisposalPermitObtained int,
	@sDisposalPermitNumber nvarchar(max),
	@daDisposalPermitDate datetime,
	@sDisposalPermitConditions nvarchar(max),
	@iTestingFrequency int,
	@daDateNextTestExpected datetime,
	@daDateNextTestScheduled datetime,
	@iRequiresAuditing int,
	@iAuditFrequency int,
	@daDateLastAudit datetime,
	@sLastAuditConductedBy nvarchar(max),
	@sLastAuditConductedLicenceNo nvarchar(max),
	@daDateNextAuditExpected datetime,
	@daDateNextAuditScheduled datetime,
	@sLastAuditOutcomeSummary nvarchar(max),
	@sLastAuditOutcomeDetail nvarchar(max),
	@daDateDecommissioned datetime,
	@iEquipmentFlagFollowup int,
	@iFacilityID int,
	@iLocalEquipmentID int,
	@sAltLocalEquipmentID nvarchar(20),
	@iARPANSALADNumber int,
	@sIntendedPurpose nvarchar(255),
	@iARPANSAStatusID int,
	@iInventoryStatusID int,
	@iDisposalStatusID int,
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sOperatingParameter nvarchar(255),
	@sLikelyExposure nvarchar(255),
	@iChemicalFormID int,
	@iPhysicalFormID int,
	@iPortabilityID int,
	@iEncapsulationMaterialID int,
	@iRoomID int,
	@sLocationOther nvarchar(255),
	@daApprovalSubmissionDate datetime,
	@daDisposalApprovalGranted datetime,
	@sDisposalDetails nvarchar(max),
	@daActivityDate datetime,
	@fActivityBq float(53),
	@fMaxActivityBq float(53),
	@sMax_kVp nvarchar(255),
	@sMax_mA nvarchar(255),
	@iRecommendedWorkingLife int,
	@fCurrentActivity float(53),
	@fSourceAE float(53),
	@fSourceAD float(53),
	@daWipeTestDate datetime,
	@sComments nvarchar(max),
	@sInternalComments nvarchar(max),
	@sASNOPermitNo nvarchar(20),
	@sASNOBatchNo nvarchar(20),
	@iNonIonisingSourceID int,
	@iNonIonisingApparatusTypeID int,
	@iIonisingSourceID int,
	@iIonisingApparatusTypeID int,
	@iUnsealedSourceID int,
	@daLastSightedDate datetime,
	@sLastSightedBy nvarchar(30),
	@sLastSightedComment nvarchar(max),
	@iLicencePermitID int,
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@daApproval datetime,
	@iEquipmentModelID int,
	@iManufacturerID int,
	@iDxSourceCustodianID int,
	@iDxAreaCustodianID int,
	@iDxLineManagerID int,
	@iDxRSOid int,
	@iASNOMaterial int,
	@iASNOInventoryBatchNo int,
	@iExemptLimitBq int,
	@iComputedAD int,
	@iComputedAE int,
	@sSourceCertificateNo nvarchar(30),
	@iSourceCertificateID int,
	@iLicencedActivityBq int,
	@daDateOfReceipt datetime,
	@daDateOfLastSurvey datetime,
	@iEquipmentID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblEquipment]
(
	[EquipmentTypeID],
	[EquipmentStatus],
	[DateRegistered],
	[Brand],
	[Model],
	[Classification],
	[SiteLocation],
	[ContactDetails],
	[RegAuthorityIDNo],
	[LicenceNumber],
	[DateAcquired],
	[DateOfDisposal],
	[SerialNo],
	[ISONumber],
	[AssetNumber],
	[DateManufactured],
	[DateLastTested],
	[WorkingLife],
	[DateWorkingLifeExpiry],
	[RadioNuclideID],
	[EquipmentNotes],
	[EquipmentStatusID],
	[EquipmentName],
	[Manufacturer],
	[BuildingPrefixName],
	[BuildingNumber],
	[UnitNumber],
	[StreetName],
	[Suburb],
	[State],
	[Postcode],
	[ControlGenManufacturer],
	[ControlGenModel],
	[ControlGenSerial],
	[TubeHousingManufacturer],
	[TubeHousingModel],
	[TubeHousingSerial],
	[TubeInsertManufacturer],
	[TubeInsertModel],
	[TubeInsertSerial],
	[Category],
	[NominalActivity],
	[RegAuthorityIDNoPrev],
	[LicenceNumberPrev],
	[HasComplianceCertificate],
	[AssayDate],
	[ComplianceCertExpiry],
	[SendComplianceCertReminder],
	[SendComplianceCertReminderTo],
	[ApparatusDescriptionID],
	[CostGroupID],
	[SealedSourceDescriptionID],
	[SecurityClassificationID],
	[CampusID],
	[SiteLocationID],
	[BusinessUnitID],
	[CentreInternalID],
	[PremisesID],
	[OtherApparatus],
	[OtherSealedSourceDevice],
	[PermittedPractice],
	[PermittedLocation],
	[PermittedIonisingApparatus],
	[PermittedPurpose],
	[PermittedSealedSource],
	[PermittedRadionuclide],
	[MaxPermittedActivity],
	[ResponsibleDepartment],
	[EquipmentType],
	[RequiresTesting],
	[Vendor],
	[VendorDetails],
	[TypicalProcedure],
	[TypicalShielding],
	[ServiceCost],
	[TestingCost],
	[ReplacementCost],
	[TotalDepreciation],
	[DepreciationDesc],
	[RentalCost],
	[RunningCost],
	[OtherCostA],
	[OtherCostADesc],
	[OtherCostB],
	[OtherCostBDesc],
	[CostsNote],
	[DatePurchased],
	[DateWarrantyExpires],
	[DateGuaranteeExpires],
	[WarrantyConditions],
	[GuranteeConditions],
	[PurchaseCost],
	[DatePlannedExpiration],
	[DisposalCost],
	[DisposalVendorContact],
	[DisposalMethod],
	[DisposalConfirmed],
	[DisposalConfirmation],
	[DisposalEnvironmental],
	[DisposalPermitRequired],
	[DisposalPermitObtained],
	[DisposalPermitNumber],
	[DisposalPermitDate],
	[DisposalPermitConditions],
	[TestingFrequency],
	[DateNextTestExpected],
	[DateNextTestScheduled],
	[RequiresAuditing],
	[AuditFrequency],
	[DateLastAudit],
	[LastAuditConductedBy],
	[LastAuditConductedLicenceNo],
	[DateNextAuditExpected],
	[DateNextAuditScheduled],
	[LastAuditOutcomeSummary],
	[LastAuditOutcomeDetail],
	[DateDecommissioned],
	[EquipmentFlagFollowup],
	[FacilityID],
	[LocalEquipmentID],
	[AltLocalEquipmentID],
	[ARPANSALADNumber],
	[IntendedPurpose],
	[ARPANSAStatusID],
	[InventoryStatusID],
	[DisposalStatusID],
	[Latitude],
	[Longitude],
	[OperatingParameter],
	[LikelyExposure],
	[ChemicalFormID],
	[PhysicalFormID],
	[PortabilityID],
	[EncapsulationMaterialID],
	[RoomID],
	[LocationOther],
	[ApprovalSubmissionDate],
	[DisposalApprovalGranted],
	[DisposalDetails],
	[ActivityDate],
	[ActivityBq],
	[MaxActivityBq],
	[Max_kVp],
	[Max_mA],
	[RecommendedWorkingLife],
	[CurrentActivity],
	[SourceAE],
	[SourceAD],
	[WipeTestDate],
	[Comments],
	[InternalComments],
	[ASNOPermitNo],
	[ASNOBatchNo],
	[NonIonisingSourceID],
	[NonIonisingApparatusTypeID],
	[IonisingSourceID],
	[IonisingApparatusTypeID],
	[UnsealedSourceID],
	[LastSightedDate],
	[LastSightedBy],
	[LastSightedComment],
	[LicencePermitID],
	[AddedBy],
	[AddedDateTime],
	[ModifiedBy],
	[ModifiedDateTime],
	[Approval],
	[EquipmentModelID],
	[ManufacturerID],
	[DxSourceCustodianID],
	[DxAreaCustodianID],
	[DxLineManagerID],
	[DxRSOid],
	[ASNOMaterial],
	[ASNOInventoryBatchNo],
	[ExemptLimitBq],
	[ComputedAD],
	[ComputedAE],
	[SourceCertificateNo],
	[SourceCertificateID],
	[LicencedActivityBq],
	[DateOfReceipt],
	[DateOfLastSurvey]
)
VALUES
(
	@iEquipmentTypeID,
	@sEquipmentStatus,
	@daDateRegistered,
	@sBrand,
	@sModel,
	@sClassification,
	@sSiteLocation,
	@sContactDetails,
	@sRegAuthorityIDNo,
	@sLicenceNumber,
	@daDateAcquired,
	@daDateOfDisposal,
	@sSerialNo,
	@sISONumber,
	@sAssetNumber,
	@daDateManufactured,
	@daDateLastTested,
	@sWorkingLife,
	@daDateWorkingLifeExpiry,
	@iRadioNuclideID,
	@sEquipmentNotes,
	ISNULL(@iEquipmentStatusID, ((1))),
	@sEquipmentName,
	@sManufacturer,
	@sBuildingPrefixName,
	@sBuildingNumber,
	@sUnitNumber,
	@sStreetName,
	@sSuburb,
	@sState,
	@sPostcode,
	@sControlGenManufacturer,
	@sControlGenModel,
	@sControlGenSerial,
	@sTubeHousingManufacturer,
	@sTubeHousingModel,
	@sTubeHousingSerial,
	@sTubeInsertManufacturer,
	@sTubeInsertModel,
	@sTubeInsertSerial,
	@sCategory,
	@sNominalActivity,
	@sRegAuthorityIDNoPrev,
	@sLicenceNumberPrev,
	@iHasComplianceCertificate,
	@daAssayDate,
	@daComplianceCertExpiry,
	@iSendComplianceCertReminder,
	@sSendComplianceCertReminderTo,
	@iApparatusDescriptionID,
	@iCostGroupID,
	@iSealedSourceDescriptionID,
	@iSecurityClassificationID,
	@iCampusID,
	@iSiteLocationID,
	@iBusinessUnitID,
	@iCentreInternalID,
	@iPremisesID,
	@sOtherApparatus,
	@sOtherSealedSourceDevice,
	@sPermittedPractice,
	@sPermittedLocation,
	@sPermittedIonisingApparatus,
	@sPermittedPurpose,
	@sPermittedSealedSource,
	@sPermittedRadionuclide,
	@sMaxPermittedActivity,
	@sResponsibleDepartment,
	@sEquipmentType,
	@iRequiresTesting,
	@sVendor,
	@sVendorDetails,
	@sTypicalProcedure,
	@sTypicalShielding,
	@dcServiceCost,
	@dcTestingCost,
	@dcReplacementCost,
	@dcTotalDepreciation,
	@sDepreciationDesc,
	@dcRentalCost,
	@dcRunningCost,
	@dcOtherCostA,
	@sOtherCostADesc,
	@dcOtherCostB,
	@sOtherCostBDesc,
	@sCostsNote,
	@daDatePurchased,
	@daDateWarrantyExpires,
	@daDateGuaranteeExpires,
	@sWarrantyConditions,
	@sGuranteeConditions,
	@dcPurchaseCost,
	@daDatePlannedExpiration,
	@dcDisposalCost,
	@sDisposalVendorContact,
	@sDisposalMethod,
	@iDisposalConfirmed,
	@sDisposalConfirmation,
	@sDisposalEnvironmental,
	@iDisposalPermitRequired,
	@iDisposalPermitObtained,
	@sDisposalPermitNumber,
	@daDisposalPermitDate,
	@sDisposalPermitConditions,
	@iTestingFrequency,
	@daDateNextTestExpected,
	@daDateNextTestScheduled,
	@iRequiresAuditing,
	@iAuditFrequency,
	@daDateLastAudit,
	@sLastAuditConductedBy,
	@sLastAuditConductedLicenceNo,
	@daDateNextAuditExpected,
	@daDateNextAuditScheduled,
	@sLastAuditOutcomeSummary,
	@sLastAuditOutcomeDetail,
	@daDateDecommissioned,
	@iEquipmentFlagFollowup,
	@iFacilityID,
	@iLocalEquipmentID,
	@sAltLocalEquipmentID,
	@iARPANSALADNumber,
	@sIntendedPurpose,
	@iARPANSAStatusID,
	@iInventoryStatusID,
	@iDisposalStatusID,
	@sLatitude,
	@sLongitude,
	@sOperatingParameter,
	@sLikelyExposure,
	@iChemicalFormID,
	@iPhysicalFormID,
	@iPortabilityID,
	@iEncapsulationMaterialID,
	@iRoomID,
	@sLocationOther,
	@daApprovalSubmissionDate,
	@daDisposalApprovalGranted,
	@sDisposalDetails,
	@daActivityDate,
	@fActivityBq,
	@fMaxActivityBq,
	@sMax_kVp,
	@sMax_mA,
	@iRecommendedWorkingLife,
	@fCurrentActivity,
	@fSourceAE,
	@fSourceAD,
	@daWipeTestDate,
	@sComments,
	@sInternalComments,
	@sASNOPermitNo,
	@sASNOBatchNo,
	@iNonIonisingSourceID,
	@iNonIonisingApparatusTypeID,
	@iIonisingSourceID,
	@iIonisingApparatusTypeID,
	@iUnsealedSourceID,
	@daLastSightedDate,
	@sLastSightedBy,
	@sLastSightedComment,
	@iLicencePermitID,
	@sAddedBy,
	@daAddedDateTime,
	@sModifiedBy,
	@daModifiedDateTime,
	@daApproval,
	@iEquipmentModelID,
	@iManufacturerID,
	@iDxSourceCustodianID,
	@iDxAreaCustodianID,
	@iDxLineManagerID,
	@iDxRSOid,
	@iASNOMaterial,
	@iASNOInventoryBatchNo,
	@iExemptLimitBq,
	@iComputedAD,
	@iComputedAE,
	@sSourceCertificateNo,
	@iSourceCertificateID,
	@iLicencedActivityBq,
	@daDateOfReceipt,
	@daDateOfLastSurvey
)
SELECT @iErrorCode=@@ERROR
SELECT @iEquipmentID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_Update]
	@iEquipmentID int,
	@iEquipmentTypeID int,
	@sEquipmentStatus nvarchar(30),
	@daDateRegistered datetime,
	@sBrand nvarchar(max),
	@sModel nvarchar(max),
	@sClassification nvarchar(max),
	@sSiteLocation nvarchar(max),
	@sContactDetails nvarchar(max),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@daDateAcquired datetime,
	@daDateOfDisposal datetime,
	@sSerialNo nvarchar(50),
	@sISONumber nvarchar(50),
	@sAssetNumber nvarchar(12),
	@daDateManufactured datetime,
	@daDateLastTested datetime,
	@sWorkingLife nvarchar(max),
	@daDateWorkingLifeExpiry datetime,
	@iRadioNuclideID int,
	@sEquipmentNotes nvarchar(max),
	@iEquipmentStatusID int,
	@sEquipmentName nvarchar(max),
	@sManufacturer nvarchar(80),
	@sBuildingPrefixName nvarchar(max),
	@sBuildingNumber nvarchar(20),
	@sUnitNumber nvarchar(20),
	@sStreetName nvarchar(max),
	@sSuburb nvarchar(40),
	@sState nvarchar(20),
	@sPostcode nvarchar(5),
	@sControlGenManufacturer nvarchar(80),
	@sControlGenModel nvarchar(max),
	@sControlGenSerial nvarchar(20),
	@sTubeHousingManufacturer nvarchar(80),
	@sTubeHousingModel nvarchar(max),
	@sTubeHousingSerial nvarchar(max),
	@sTubeInsertManufacturer nvarchar(80),
	@sTubeInsertModel nvarchar(max),
	@sTubeInsertSerial nvarchar(max),
	@sCategory nvarchar(max),
	@sNominalActivity nvarchar(max),
	@sRegAuthorityIDNoPrev nvarchar(max),
	@sLicenceNumberPrev nvarchar(max),
	@iHasComplianceCertificate int,
	@daAssayDate datetime,
	@daComplianceCertExpiry datetime,
	@iSendComplianceCertReminder int,
	@sSendComplianceCertReminderTo nvarchar(max),
	@iApparatusDescriptionID int,
	@iCostGroupID int,
	@iSealedSourceDescriptionID int,
	@iSecurityClassificationID int,
	@iCampusID int,
	@iSiteLocationID int,
	@iBusinessUnitID int,
	@iCentreInternalID int,
	@iPremisesID int,
	@sOtherApparatus nvarchar(max),
	@sOtherSealedSourceDevice nvarchar(max),
	@sPermittedPractice nvarchar(max),
	@sPermittedLocation nvarchar(max),
	@sPermittedIonisingApparatus nvarchar(max),
	@sPermittedPurpose nvarchar(max),
	@sPermittedSealedSource nvarchar(max),
	@sPermittedRadionuclide nvarchar(max),
	@sMaxPermittedActivity nvarchar(max),
	@sResponsibleDepartment nvarchar(max),
	@sEquipmentType nvarchar(50),
	@iRequiresTesting int,
	@sVendor nvarchar(max),
	@sVendorDetails nvarchar(max),
	@sTypicalProcedure nvarchar(max),
	@sTypicalShielding nvarchar(max),
	@dcServiceCost decimal(10, 2),
	@dcTestingCost decimal(10, 2),
	@dcReplacementCost decimal(10, 2),
	@dcTotalDepreciation decimal(10, 2),
	@sDepreciationDesc nvarchar(max),
	@dcRentalCost decimal(10, 2),
	@dcRunningCost decimal(10, 2),
	@dcOtherCostA decimal(10, 2),
	@sOtherCostADesc nvarchar(max),
	@dcOtherCostB decimal(10, 2),
	@sOtherCostBDesc nvarchar(max),
	@sCostsNote nvarchar(max),
	@daDatePurchased datetime,
	@daDateWarrantyExpires datetime,
	@daDateGuaranteeExpires datetime,
	@sWarrantyConditions nvarchar(max),
	@sGuranteeConditions nvarchar(max),
	@dcPurchaseCost decimal(10, 2),
	@daDatePlannedExpiration datetime,
	@dcDisposalCost decimal(10, 2),
	@sDisposalVendorContact nvarchar(max),
	@sDisposalMethod nvarchar(max),
	@iDisposalConfirmed int,
	@sDisposalConfirmation nvarchar(max),
	@sDisposalEnvironmental nvarchar(max),
	@iDisposalPermitRequired int,
	@iDisposalPermitObtained int,
	@sDisposalPermitNumber nvarchar(max),
	@daDisposalPermitDate datetime,
	@sDisposalPermitConditions nvarchar(max),
	@iTestingFrequency int,
	@daDateNextTestExpected datetime,
	@daDateNextTestScheduled datetime,
	@iRequiresAuditing int,
	@iAuditFrequency int,
	@daDateLastAudit datetime,
	@sLastAuditConductedBy nvarchar(max),
	@sLastAuditConductedLicenceNo nvarchar(max),
	@daDateNextAuditExpected datetime,
	@daDateNextAuditScheduled datetime,
	@sLastAuditOutcomeSummary nvarchar(max),
	@sLastAuditOutcomeDetail nvarchar(max),
	@daDateDecommissioned datetime,
	@iEquipmentFlagFollowup int,
	@iFacilityID int,
	@iLocalEquipmentID int,
	@sAltLocalEquipmentID nvarchar(20),
	@iARPANSALADNumber int,
	@sIntendedPurpose nvarchar(255),
	@iARPANSAStatusID int,
	@iInventoryStatusID int,
	@iDisposalStatusID int,
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sOperatingParameter nvarchar(255),
	@sLikelyExposure nvarchar(255),
	@iChemicalFormID int,
	@iPhysicalFormID int,
	@iPortabilityID int,
	@iEncapsulationMaterialID int,
	@iRoomID int,
	@sLocationOther nvarchar(255),
	@daApprovalSubmissionDate datetime,
	@daDisposalApprovalGranted datetime,
	@sDisposalDetails nvarchar(max),
	@daActivityDate datetime,
	@fActivityBq float(53),
	@fMaxActivityBq float(53),
	@sMax_kVp nvarchar(255),
	@sMax_mA nvarchar(255),
	@iRecommendedWorkingLife int,
	@fCurrentActivity float(53),
	@fSourceAE float(53),
	@fSourceAD float(53),
	@daWipeTestDate datetime,
	@sComments nvarchar(max),
	@sInternalComments nvarchar(max),
	@sASNOPermitNo nvarchar(20),
	@sASNOBatchNo nvarchar(20),
	@iNonIonisingSourceID int,
	@iNonIonisingApparatusTypeID int,
	@iIonisingSourceID int,
	@iIonisingApparatusTypeID int,
	@iUnsealedSourceID int,
	@daLastSightedDate datetime,
	@sLastSightedBy nvarchar(30),
	@sLastSightedComment nvarchar(max),
	@iLicencePermitID int,
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@daApproval datetime,
	@iEquipmentModelID int,
	@iManufacturerID int,
	@iDxSourceCustodianID int,
	@iDxAreaCustodianID int,
	@iDxLineManagerID int,
	@iDxRSOid int,
	@iASNOMaterial int,
	@iASNOInventoryBatchNo int,
	@iExemptLimitBq int,
	@iComputedAD int,
	@iComputedAE int,
	@sSourceCertificateNo nvarchar(30),
	@iSourceCertificateID int,
	@iLicencedActivityBq int,
	@daDateOfReceipt datetime,
	@daDateOfLastSurvey datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET 
	[EquipmentTypeID] = @iEquipmentTypeID,
	[EquipmentStatus] = @sEquipmentStatus,
	[DateRegistered] = @daDateRegistered,
	[Brand] = @sBrand,
	[Model] = @sModel,
	[Classification] = @sClassification,
	[SiteLocation] = @sSiteLocation,
	[ContactDetails] = @sContactDetails,
	[RegAuthorityIDNo] = @sRegAuthorityIDNo,
	[LicenceNumber] = @sLicenceNumber,
	[DateAcquired] = @daDateAcquired,
	[DateOfDisposal] = @daDateOfDisposal,
	[SerialNo] = @sSerialNo,
	[ISONumber] = @sISONumber,
	[AssetNumber] = @sAssetNumber,
	[DateManufactured] = @daDateManufactured,
	[DateLastTested] = @daDateLastTested,
	[WorkingLife] = @sWorkingLife,
	[DateWorkingLifeExpiry] = @daDateWorkingLifeExpiry,
	[RadioNuclideID] = @iRadioNuclideID,
	[EquipmentNotes] = @sEquipmentNotes,
	[EquipmentStatusID] = @iEquipmentStatusID,
	[EquipmentName] = @sEquipmentName,
	[Manufacturer] = @sManufacturer,
	[BuildingPrefixName] = @sBuildingPrefixName,
	[BuildingNumber] = @sBuildingNumber,
	[UnitNumber] = @sUnitNumber,
	[StreetName] = @sStreetName,
	[Suburb] = @sSuburb,
	[State] = @sState,
	[Postcode] = @sPostcode,
	[ControlGenManufacturer] = @sControlGenManufacturer,
	[ControlGenModel] = @sControlGenModel,
	[ControlGenSerial] = @sControlGenSerial,
	[TubeHousingManufacturer] = @sTubeHousingManufacturer,
	[TubeHousingModel] = @sTubeHousingModel,
	[TubeHousingSerial] = @sTubeHousingSerial,
	[TubeInsertManufacturer] = @sTubeInsertManufacturer,
	[TubeInsertModel] = @sTubeInsertModel,
	[TubeInsertSerial] = @sTubeInsertSerial,
	[Category] = @sCategory,
	[NominalActivity] = @sNominalActivity,
	[RegAuthorityIDNoPrev] = @sRegAuthorityIDNoPrev,
	[LicenceNumberPrev] = @sLicenceNumberPrev,
	[HasComplianceCertificate] = @iHasComplianceCertificate,
	[AssayDate] = @daAssayDate,
	[ComplianceCertExpiry] = @daComplianceCertExpiry,
	[SendComplianceCertReminder] = @iSendComplianceCertReminder,
	[SendComplianceCertReminderTo] = @sSendComplianceCertReminderTo,
	[ApparatusDescriptionID] = @iApparatusDescriptionID,
	[CostGroupID] = @iCostGroupID,
	[SealedSourceDescriptionID] = @iSealedSourceDescriptionID,
	[SecurityClassificationID] = @iSecurityClassificationID,
	[CampusID] = @iCampusID,
	[SiteLocationID] = @iSiteLocationID,
	[BusinessUnitID] = @iBusinessUnitID,
	[CentreInternalID] = @iCentreInternalID,
	[PremisesID] = @iPremisesID,
	[OtherApparatus] = @sOtherApparatus,
	[OtherSealedSourceDevice] = @sOtherSealedSourceDevice,
	[PermittedPractice] = @sPermittedPractice,
	[PermittedLocation] = @sPermittedLocation,
	[PermittedIonisingApparatus] = @sPermittedIonisingApparatus,
	[PermittedPurpose] = @sPermittedPurpose,
	[PermittedSealedSource] = @sPermittedSealedSource,
	[PermittedRadionuclide] = @sPermittedRadionuclide,
	[MaxPermittedActivity] = @sMaxPermittedActivity,
	[ResponsibleDepartment] = @sResponsibleDepartment,
	[EquipmentType] = @sEquipmentType,
	[RequiresTesting] = @iRequiresTesting,
	[Vendor] = @sVendor,
	[VendorDetails] = @sVendorDetails,
	[TypicalProcedure] = @sTypicalProcedure,
	[TypicalShielding] = @sTypicalShielding,
	[ServiceCost] = @dcServiceCost,
	[TestingCost] = @dcTestingCost,
	[ReplacementCost] = @dcReplacementCost,
	[TotalDepreciation] = @dcTotalDepreciation,
	[DepreciationDesc] = @sDepreciationDesc,
	[RentalCost] = @dcRentalCost,
	[RunningCost] = @dcRunningCost,
	[OtherCostA] = @dcOtherCostA,
	[OtherCostADesc] = @sOtherCostADesc,
	[OtherCostB] = @dcOtherCostB,
	[OtherCostBDesc] = @sOtherCostBDesc,
	[CostsNote] = @sCostsNote,
	[DatePurchased] = @daDatePurchased,
	[DateWarrantyExpires] = @daDateWarrantyExpires,
	[DateGuaranteeExpires] = @daDateGuaranteeExpires,
	[WarrantyConditions] = @sWarrantyConditions,
	[GuranteeConditions] = @sGuranteeConditions,
	[PurchaseCost] = @dcPurchaseCost,
	[DatePlannedExpiration] = @daDatePlannedExpiration,
	[DisposalCost] = @dcDisposalCost,
	[DisposalVendorContact] = @sDisposalVendorContact,
	[DisposalMethod] = @sDisposalMethod,
	[DisposalConfirmed] = @iDisposalConfirmed,
	[DisposalConfirmation] = @sDisposalConfirmation,
	[DisposalEnvironmental] = @sDisposalEnvironmental,
	[DisposalPermitRequired] = @iDisposalPermitRequired,
	[DisposalPermitObtained] = @iDisposalPermitObtained,
	[DisposalPermitNumber] = @sDisposalPermitNumber,
	[DisposalPermitDate] = @daDisposalPermitDate,
	[DisposalPermitConditions] = @sDisposalPermitConditions,
	[TestingFrequency] = @iTestingFrequency,
	[DateNextTestExpected] = @daDateNextTestExpected,
	[DateNextTestScheduled] = @daDateNextTestScheduled,
	[RequiresAuditing] = @iRequiresAuditing,
	[AuditFrequency] = @iAuditFrequency,
	[DateLastAudit] = @daDateLastAudit,
	[LastAuditConductedBy] = @sLastAuditConductedBy,
	[LastAuditConductedLicenceNo] = @sLastAuditConductedLicenceNo,
	[DateNextAuditExpected] = @daDateNextAuditExpected,
	[DateNextAuditScheduled] = @daDateNextAuditScheduled,
	[LastAuditOutcomeSummary] = @sLastAuditOutcomeSummary,
	[LastAuditOutcomeDetail] = @sLastAuditOutcomeDetail,
	[DateDecommissioned] = @daDateDecommissioned,
	[EquipmentFlagFollowup] = @iEquipmentFlagFollowup,
	[FacilityID] = @iFacilityID,
	[LocalEquipmentID] = @iLocalEquipmentID,
	[AltLocalEquipmentID] = @sAltLocalEquipmentID,
	[ARPANSALADNumber] = @iARPANSALADNumber,
	[IntendedPurpose] = @sIntendedPurpose,
	[ARPANSAStatusID] = @iARPANSAStatusID,
	[InventoryStatusID] = @iInventoryStatusID,
	[DisposalStatusID] = @iDisposalStatusID,
	[Latitude] = @sLatitude,
	[Longitude] = @sLongitude,
	[OperatingParameter] = @sOperatingParameter,
	[LikelyExposure] = @sLikelyExposure,
	[ChemicalFormID] = @iChemicalFormID,
	[PhysicalFormID] = @iPhysicalFormID,
	[PortabilityID] = @iPortabilityID,
	[EncapsulationMaterialID] = @iEncapsulationMaterialID,
	[RoomID] = @iRoomID,
	[LocationOther] = @sLocationOther,
	[ApprovalSubmissionDate] = @daApprovalSubmissionDate,
	[DisposalApprovalGranted] = @daDisposalApprovalGranted,
	[DisposalDetails] = @sDisposalDetails,
	[ActivityDate] = @daActivityDate,
	[ActivityBq] = @fActivityBq,
	[MaxActivityBq] = @fMaxActivityBq,
	[Max_kVp] = @sMax_kVp,
	[Max_mA] = @sMax_mA,
	[RecommendedWorkingLife] = @iRecommendedWorkingLife,
	[CurrentActivity] = @fCurrentActivity,
	[SourceAE] = @fSourceAE,
	[SourceAD] = @fSourceAD,
	[WipeTestDate] = @daWipeTestDate,
	[Comments] = @sComments,
	[InternalComments] = @sInternalComments,
	[ASNOPermitNo] = @sASNOPermitNo,
	[ASNOBatchNo] = @sASNOBatchNo,
	[NonIonisingSourceID] = @iNonIonisingSourceID,
	[NonIonisingApparatusTypeID] = @iNonIonisingApparatusTypeID,
	[IonisingSourceID] = @iIonisingSourceID,
	[IonisingApparatusTypeID] = @iIonisingApparatusTypeID,
	[UnsealedSourceID] = @iUnsealedSourceID,
	[LastSightedDate] = @daLastSightedDate,
	[LastSightedBy] = @sLastSightedBy,
	[LastSightedComment] = @sLastSightedComment,
	[LicencePermitID] = @iLicencePermitID,
	[AddedBy] = @sAddedBy,
	[AddedDateTime] = @daAddedDateTime,
	[ModifiedBy] = @sModifiedBy,
	[ModifiedDateTime] = @daModifiedDateTime,
	[Approval] = @daApproval,
	[EquipmentModelID] = @iEquipmentModelID,
	[ManufacturerID] = @iManufacturerID,
	[DxSourceCustodianID] = @iDxSourceCustodianID,
	[DxAreaCustodianID] = @iDxAreaCustodianID,
	[DxLineManagerID] = @iDxLineManagerID,
	[DxRSOid] = @iDxRSOid,
	[ASNOMaterial] = @iASNOMaterial,
	[ASNOInventoryBatchNo] = @iASNOInventoryBatchNo,
	[ExemptLimitBq] = @iExemptLimitBq,
	[ComputedAD] = @iComputedAD,
	[ComputedAE] = @iComputedAE,
	[SourceCertificateNo] = @sSourceCertificateNo,
	[SourceCertificateID] = @iSourceCertificateID,
	[LicencedActivityBq] = @iLicencedActivityBq,
	[DateOfReceipt] = @daDateOfReceipt,
	[DateOfLastSurvey] = @daDateOfLastSurvey
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWRadioNuclideIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWRadioNuclideIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWRadioNuclideIDLogic]
	@iRadioNuclideID int,
	@iRadioNuclideIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[RadioNuclideID] = @iRadioNuclideID
WHERE
	[RadioNuclideID] = @iRadioNuclideIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iBusinessUnitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[BusinessUnitID] = @iBusinessUnitID
WHERE
	[BusinessUnitID] = @iBusinessUnitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iCentreInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[CentreInternalID] = @iCentreInternalID
WHERE
	[CentreInternalID] = @iCentreInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWFacilityIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWFacilityIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWFacilityIDLogic]
	@iFacilityID int,
	@iFacilityIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[FacilityID] = @iFacilityID
WHERE
	[FacilityID] = @iFacilityIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWRoomIDLogic]
	@iRoomID int,
	@iRoomIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[RoomID] = @iRoomID
WHERE
	[RoomID] = @iRoomIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iLicencePermitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[LicencePermitID] = @iLicencePermitID
WHERE
	[LicencePermitID] = @iLicencePermitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iEquipmentModelIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[EquipmentModelID] = @iEquipmentModelID
WHERE
	[EquipmentModelID] = @iEquipmentModelIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_UpdateAllWManufacturerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_UpdateAllWManufacturerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_UpdateAllWManufacturerIDLogic]
	@iManufacturerID int,
	@iManufacturerIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipment]
SET
	[ManufacturerID] = @iManufacturerID
WHERE
	[ManufacturerID] = @iManufacturerIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_Delete]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblEquipment]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWRadioNuclideIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWRadioNuclideIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWRadioNuclideIDLogic]
	@iRadioNuclideID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[RadioNuclideID] = @iRadioNuclideID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWFacilityIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWFacilityIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWFacilityIDLogic]
	@iFacilityID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[FacilityID] = @iFacilityID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[LicencePermitID] = @iLicencePermitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_DeleteAllWManufacturerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_DeleteAllWManufacturerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_DeleteAllWManufacturerIDLogic]
	@iManufacturerID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipment]
WHERE
	[ManufacturerID] = @iManufacturerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectOne]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWRadioNuclideIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWRadioNuclideIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWRadioNuclideIDLogic]
	@iRadioNuclideID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[RadioNuclideID] = @iRadioNuclideID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[CentreInternalID] = @iCentreInternalID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWFacilityIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWFacilityIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWFacilityIDLogic]
	@iFacilityID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[FacilityID] = @iFacilityID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[RoomID] = @iRoomID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[LicencePermitID] = @iLicencePermitID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipment_SelectAllWManufacturerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipment_SelectAllWManufacturerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipment_SelectAllWManufacturerIDLogic]
	@iManufacturerID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipment]
WHERE
	[ManufacturerID] = @iManufacturerID
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO



------------------------------------------
-- End tblEquipment replacement SPROCS
------------------------------------------
SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_Insert]
	@iEquipmentID int,
	@sEquipmentType nvarchar(500),
	@sEquipmentStatus nvarchar(500),
	@sApparatusType nvarchar(500),
	@sSourceType nvarchar(500),
	@daDateRegistered datetime,
	@sBrand nvarchar(max),
	@sModel nvarchar(max),
	@sClassification nvarchar(max),
	@sContactDetails nvarchar(max),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@daDateAcquired datetime,
	@daDateOfDisposal datetime,
	@sSerialNo nvarchar(50),
	@sISONumber nvarchar(50),
	@sAssetNumber nvarchar(12),
	@daDateManufactured datetime,
	@daDateLastTested datetime,
	@sWorkingLife nvarchar(max),
	@daDateWorkingLifeExpiry datetime,
	@sRadionuclide nvarchar(100),
	@sEquipmentNotes nvarchar(max),
	@sEquipmentName nvarchar(max),
	@sManufacturer nvarchar(255),
	@sBuildingPrefixName nvarchar(max),
	@sBuildingNumber nvarchar(20),
	@sUnitNumber nvarchar(20),
	@sStreetName nvarchar(max),
	@sSuburb nvarchar(40),
	@sState nvarchar(20),
	@sPostcode nvarchar(5),
	@sControlGenManufacturer nvarchar(80),
	@sControlGenModel nvarchar(max),
	@sControlGenSerial nvarchar(20),
	@sTubeHousingManufacturer nvarchar(80),
	@sTubeHousingModel nvarchar(max),
	@sTubeHousingSerial nvarchar(max),
	@sTubeInsertManufacturer nvarchar(80),
	@sTubeInsertModel nvarchar(max),
	@sTubeInsertSerial nvarchar(max),
	@sCategory nvarchar(max),
	@sNominalActivity nvarchar(max),
	@sRegAuthorityIDNoPrev nvarchar(max),
	@sLicenceNumberPrev nvarchar(max),
	@sHasComplianceCertificate nvarchar(10),
	@daAssayDate datetime,
	@daComplianceCertExpiry datetime,
	@sSendComplianceCertReminder nvarchar(10),
	@sSendComplianceCertReminderTo nvarchar(max),
	@sApparatusDescription nvarchar(50),
	@sCostGroup nvarchar(max),
	@sSealedSourceDescription nvarchar(500),
	@sSecurityClassification nvarchar(100),
	@sCampus nvarchar(100),
	@sSiteLocationName nvarchar(max),
	@sBusinessUnitName nvarchar(max),
	@sCentreNo varchar(max),
	@sCentreName nvarchar(255),
	@sNameOfPremises nvarchar(100),
	@sOtherApparatus nvarchar(max),
	@sOtherSealedSourceDevice nvarchar(max),
	@sPermittedPractice nvarchar(max),
	@sPermittedLocation nvarchar(max),
	@sPermittedIonisingApparatus nvarchar(max),
	@sPermittedPurpose nvarchar(max),
	@sPermittedSealedSource nvarchar(max),
	@sPermittedRadionuclide nvarchar(max),
	@sMaxPermittedActivity nvarchar(max),
	@sResponsibleDepartment nvarchar(max),
	@sRequiresTesting nvarchar(10),
	@sVendor nvarchar(max),
	@sVendorDetails nvarchar(max),
	@sTypicalProcedure nvarchar(max),
	@sTypicalShielding nvarchar(max),
	@dcServiceCost decimal(10, 2),
	@dcTestingCost decimal(10, 2),
	@dcReplacementCost decimal(10, 2),
	@dcTotalDepreciation decimal(10, 2),
	@sDepreciationDesc nvarchar(max),
	@dcRentalCost decimal(10, 2),
	@dcRunningCost decimal(10, 2),
	@dcOtherCostA decimal(10, 2),
	@sOtherCostADesc nvarchar(max),
	@dcOtherCostB decimal(10, 2),
	@sOtherCostBDesc nvarchar(max),
	@sCostsNote nvarchar(max),
	@daDatePurchased datetime,
	@daDateWarrantyExpires datetime,
	@daDateGuaranteeExpires datetime,
	@sWarrantyConditions nvarchar(max),
	@sGuranteeConditions nvarchar(max),
	@dcPurchaseCost decimal(10, 2),
	@daDatePlannedExpiration datetime,
	@dcDisposalCost decimal(10, 2),
	@sDisposalVendorContact nvarchar(max),
	@sDisposalMethod nvarchar(max),
	@sDisposalConfirmed nvarchar(10),
	@sDisposalConfirmation nvarchar(max),
	@sDisposalEnvironmental nvarchar(max),
	@sDisposalPermitRequired nvarchar(10),
	@sDisposalPermitObtained nvarchar(10),
	@sDisposalPermitNumber nvarchar(max),
	@daDisposalPermitDate datetime,
	@sDisposalPermitConditions nvarchar(max),
	@iTestingFrequency int,
	@daDateNextTestExpected datetime,
	@daDateNextTestScheduled datetime,
	@sRequiresAuditing nvarchar(10),
	@iAuditFrequency int,
	@daDateLastAudit datetime,
	@sLastAuditConductedBy nvarchar(max),
	@sLastAuditConductedLicenceNo nvarchar(max),
	@daDateNextAuditExpected datetime,
	@daDateNextAuditScheduled datetime,
	@sLastAuditOutcomeSummary nvarchar(max),
	@sLastAuditOutcomeDetail nvarchar(max),
	@daDateDecommissioned datetime,
	@sEquipmentFlagFollowup nvarchar(20),
	@sFacility nvarchar(200),
	@iLocalEquipmentID int,
	@sAltLocalEquipmentID nvarchar(12),
	@iARPANSALADNumber int,
	@sIntendedPurpose nvarchar(255),
	@sARPANSAStatus nvarchar(50),
	@sInventoryStatus nvarchar(50),
	@sDisposalStatus nvarchar(50),
	@sOperatingParameter nvarchar(255),
	@sLikelyExposure nvarchar(255),
	@sChemicalForm nvarchar(500),
	@sPhysicalForm nvarchar(500),
	@sPortability nvarchar(500),
	@sEncapsulationMaterial nvarchar(500),
	@sRoomName nvarchar(100),
	@sLocationOther nvarchar(255),
	@daApprovalSubmissionDate datetime,
	@daApproval datetime,
	@daDisposalApprovalGranted datetime,
	@sDisposalDetails nvarchar(max),
	@daActivityDate datetime,
	@fActivityBq float(53),
	@fMaxActivityBq float(53),
	@sMax_kVp nvarchar(255),
	@sMax_mA nvarchar(255),
	@iRecommendedWorkingLife int,
	@fCurrentActivity float(53),
	@fSourceAE float(53),
	@fSourceAD float(53),
	@daWipeTestDate datetime,
	@sComments nvarchar(max),
	@sInternalComments nvarchar(max),
	@sASNOPermitNo nvarchar(20),
	@sASNOBatchNo nvarchar(20),
	@sNonIonisingSource nvarchar(500),
	@sNonIonisingApparatusType nvarchar(max),
	@sIonisingSource nvarchar(max),
	@sIonisingApparatusType nvarchar(max),
	@sUnsealedSource nvarchar(max),
	@daLastSightedDate datetime,
	@sLastSightedBy varchar(30),
	@sLastSightedComment varchar(max),
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@sLicencePermitNo nvarchar(100),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sEquipmentModel nvarchar(180),
	@sDxSourceCustodian nvarchar(200),
	@sDxAreaCustodian nvarchar(200),
	@sDxLineManager nvarchar(200),
	@sDxRSO nvarchar(200),
	@sASNOMaterial nvarchar(10),
	@sASNOInventoryBatchNo nvarchar(20),
	@iExemptLimitBq int,
	@iComputedAD int,
	@iComputedAE int,
	@sSourceCertificateNo nvarchar(30),
	@iSourceCertificateID int,
	@iLicencedActivityBq int,
	@daDateOfReceipt datetime,
	@daDateOfLastSurvey datetime,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblEquipmentView]
(
	[EquipmentID],
	[EquipmentType],
	[EquipmentStatus],
	[ApparatusType],
	[SourceType],
	[DateRegistered],
	[Brand],
	[Model],
	[Classification],
	[ContactDetails],
	[RegAuthorityIDNo],
	[LicenceNumber],
	[DateAcquired],
	[DateOfDisposal],
	[SerialNo],
	[ISONumber],
	[AssetNumber],
	[DateManufactured],
	[DateLastTested],
	[WorkingLife],
	[DateWorkingLifeExpiry],
	[Radionuclide],
	[EquipmentNotes],
	[EquipmentName],
	[Manufacturer],
	[BuildingPrefixName],
	[BuildingNumber],
	[UnitNumber],
	[StreetName],
	[Suburb],
	[State],
	[Postcode],
	[ControlGenManufacturer],
	[ControlGenModel],
	[ControlGenSerial],
	[TubeHousingManufacturer],
	[TubeHousingModel],
	[TubeHousingSerial],
	[TubeInsertManufacturer],
	[TubeInsertModel],
	[TubeInsertSerial],
	[Category],
	[NominalActivity],
	[RegAuthorityIDNoPrev],
	[LicenceNumberPrev],
	[HasComplianceCertificate],
	[AssayDate],
	[ComplianceCertExpiry],
	[SendComplianceCertReminder],
	[SendComplianceCertReminderTo],
	[ApparatusDescription],
	[CostGroup],
	[SealedSourceDescription],
	[SecurityClassification],
	[Campus],
	[SiteLocationName],
	[BusinessUnitName],
	[CentreNo],
	[CentreName],
	[NameOfPremises],
	[OtherApparatus],
	[OtherSealedSourceDevice],
	[PermittedPractice],
	[PermittedLocation],
	[PermittedIonisingApparatus],
	[PermittedPurpose],
	[PermittedSealedSource],
	[PermittedRadionuclide],
	[MaxPermittedActivity],
	[ResponsibleDepartment],
	[RequiresTesting],
	[Vendor],
	[VendorDetails],
	[TypicalProcedure],
	[TypicalShielding],
	[ServiceCost],
	[TestingCost],
	[ReplacementCost],
	[TotalDepreciation],
	[DepreciationDesc],
	[RentalCost],
	[RunningCost],
	[OtherCostA],
	[OtherCostADesc],
	[OtherCostB],
	[OtherCostBDesc],
	[CostsNote],
	[DatePurchased],
	[DateWarrantyExpires],
	[DateGuaranteeExpires],
	[WarrantyConditions],
	[GuranteeConditions],
	[PurchaseCost],
	[DatePlannedExpiration],
	[DisposalCost],
	[DisposalVendorContact],
	[DisposalMethod],
	[DisposalConfirmed],
	[DisposalConfirmation],
	[DisposalEnvironmental],
	[DisposalPermitRequired],
	[DisposalPermitObtained],
	[DisposalPermitNumber],
	[DisposalPermitDate],
	[DisposalPermitConditions],
	[TestingFrequency],
	[DateNextTestExpected],
	[DateNextTestScheduled],
	[RequiresAuditing],
	[AuditFrequency],
	[DateLastAudit],
	[LastAuditConductedBy],
	[LastAuditConductedLicenceNo],
	[DateNextAuditExpected],
	[DateNextAuditScheduled],
	[LastAuditOutcomeSummary],
	[LastAuditOutcomeDetail],
	[DateDecommissioned],
	[EquipmentFlagFollowup],
	[Facility],
	[LocalEquipmentID],
	[AltLocalEquipmentID],
	[ARPANSALADNumber],
	[IntendedPurpose],
	[ARPANSAStatus],
	[InventoryStatus],
	[DisposalStatus],
	[OperatingParameter],
	[LikelyExposure],
	[ChemicalForm],
	[PhysicalForm],
	[Portability],
	[EncapsulationMaterial],
	[RoomName],
	[LocationOther],
	[ApprovalSubmissionDate],
	[Approval],
	[DisposalApprovalGranted],
	[DisposalDetails],
	[ActivityDate],
	[ActivityBq],
	[MaxActivityBq],
	[Max_kVp],
	[Max_mA],
	[RecommendedWorkingLife],
	[CurrentActivity],
	[SourceAE],
	[SourceAD],
	[WipeTestDate],
	[Comments],
	[InternalComments],
	[ASNOPermitNo],
	[ASNOBatchNo],
	[NonIonisingSource],
	[NonIonisingApparatusType],
	[IonisingSource],
	[IonisingApparatusType],
	[UnsealedSource],
	[LastSightedDate],
	[LastSightedBy],
	[LastSightedComment],
	[AddedBy],
	[AddedDateTime],
	[ModifiedBy],
	[ModifiedDateTime],
	[LicencePermitNo],
	[Latitude],
	[Longitude],
	[EquipmentModel],
	[DxSourceCustodian],
	[DxAreaCustodian],
	[DxLineManager],
	[DxRSO],
	[ASNOMaterial],
	[ASNOInventoryBatchNo],
	[ExemptLimitBq],
	[ComputedAD],
	[ComputedAE],
	[SourceCertificateNo],
	[SourceCertificateID],
	[LicencedActivityBq],
	[DateOfReceipt],
	[DateOfLastSurvey]
)
VALUES
(
	@iEquipmentID,
	@sEquipmentType,
	@sEquipmentStatus,
	@sApparatusType,
	@sSourceType,
	@daDateRegistered,
	@sBrand,
	@sModel,
	@sClassification,
	@sContactDetails,
	@sRegAuthorityIDNo,
	@sLicenceNumber,
	@daDateAcquired,
	@daDateOfDisposal,
	@sSerialNo,
	@sISONumber,
	@sAssetNumber,
	@daDateManufactured,
	@daDateLastTested,
	@sWorkingLife,
	@daDateWorkingLifeExpiry,
	@sRadionuclide,
	@sEquipmentNotes,
	@sEquipmentName,
	@sManufacturer,
	@sBuildingPrefixName,
	@sBuildingNumber,
	@sUnitNumber,
	@sStreetName,
	@sSuburb,
	@sState,
	@sPostcode,
	@sControlGenManufacturer,
	@sControlGenModel,
	@sControlGenSerial,
	@sTubeHousingManufacturer,
	@sTubeHousingModel,
	@sTubeHousingSerial,
	@sTubeInsertManufacturer,
	@sTubeInsertModel,
	@sTubeInsertSerial,
	@sCategory,
	@sNominalActivity,
	@sRegAuthorityIDNoPrev,
	@sLicenceNumberPrev,
	@sHasComplianceCertificate,
	@daAssayDate,
	@daComplianceCertExpiry,
	@sSendComplianceCertReminder,
	@sSendComplianceCertReminderTo,
	@sApparatusDescription,
	@sCostGroup,
	@sSealedSourceDescription,
	@sSecurityClassification,
	@sCampus,
	@sSiteLocationName,
	@sBusinessUnitName,
	@sCentreNo,
	@sCentreName,
	@sNameOfPremises,
	@sOtherApparatus,
	@sOtherSealedSourceDevice,
	@sPermittedPractice,
	@sPermittedLocation,
	@sPermittedIonisingApparatus,
	@sPermittedPurpose,
	@sPermittedSealedSource,
	@sPermittedRadionuclide,
	@sMaxPermittedActivity,
	@sResponsibleDepartment,
	@sRequiresTesting,
	@sVendor,
	@sVendorDetails,
	@sTypicalProcedure,
	@sTypicalShielding,
	@dcServiceCost,
	@dcTestingCost,
	@dcReplacementCost,
	@dcTotalDepreciation,
	@sDepreciationDesc,
	@dcRentalCost,
	@dcRunningCost,
	@dcOtherCostA,
	@sOtherCostADesc,
	@dcOtherCostB,
	@sOtherCostBDesc,
	@sCostsNote,
	@daDatePurchased,
	@daDateWarrantyExpires,
	@daDateGuaranteeExpires,
	@sWarrantyConditions,
	@sGuranteeConditions,
	@dcPurchaseCost,
	@daDatePlannedExpiration,
	@dcDisposalCost,
	@sDisposalVendorContact,
	@sDisposalMethod,
	@sDisposalConfirmed,
	@sDisposalConfirmation,
	@sDisposalEnvironmental,
	@sDisposalPermitRequired,
	@sDisposalPermitObtained,
	@sDisposalPermitNumber,
	@daDisposalPermitDate,
	@sDisposalPermitConditions,
	@iTestingFrequency,
	@daDateNextTestExpected,
	@daDateNextTestScheduled,
	@sRequiresAuditing,
	@iAuditFrequency,
	@daDateLastAudit,
	@sLastAuditConductedBy,
	@sLastAuditConductedLicenceNo,
	@daDateNextAuditExpected,
	@daDateNextAuditScheduled,
	@sLastAuditOutcomeSummary,
	@sLastAuditOutcomeDetail,
	@daDateDecommissioned,
	@sEquipmentFlagFollowup,
	@sFacility,
	@iLocalEquipmentID,
	@sAltLocalEquipmentID,
	@iARPANSALADNumber,
	@sIntendedPurpose,
	@sARPANSAStatus,
	@sInventoryStatus,
	@sDisposalStatus,
	@sOperatingParameter,
	@sLikelyExposure,
	@sChemicalForm,
	@sPhysicalForm,
	@sPortability,
	@sEncapsulationMaterial,
	@sRoomName,
	@sLocationOther,
	@daApprovalSubmissionDate,
	@daApproval,
	@daDisposalApprovalGranted,
	@sDisposalDetails,
	@daActivityDate,
	@fActivityBq,
	@fMaxActivityBq,
	@sMax_kVp,
	@sMax_mA,
	@iRecommendedWorkingLife,
	@fCurrentActivity,
	@fSourceAE,
	@fSourceAD,
	@daWipeTestDate,
	@sComments,
	@sInternalComments,
	@sASNOPermitNo,
	@sASNOBatchNo,
	@sNonIonisingSource,
	@sNonIonisingApparatusType,
	@sIonisingSource,
	@sIonisingApparatusType,
	@sUnsealedSource,
	@daLastSightedDate,
	@sLastSightedBy,
	@sLastSightedComment,
	@sAddedBy,
	@daAddedDateTime,
	@sModifiedBy,
	@daModifiedDateTime,
	@sLicencePermitNo,
	@sLatitude,
	@sLongitude,
	@sEquipmentModel,
	@sDxSourceCustodian,
	@sDxAreaCustodian,
	@sDxLineManager,
	@sDxRSO,
	@sASNOMaterial,
	@sASNOInventoryBatchNo,
	@iExemptLimitBq,
	@iComputedAD,
	@iComputedAE,
	@sSourceCertificateNo,
	@iSourceCertificateID,
	@iLicencedActivityBq,
	@daDateOfReceipt,
	@daDateOfLastSurvey
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_Update]
	@iEquipmentID int,
	@sEquipmentType nvarchar(500),
	@sEquipmentStatus nvarchar(500),
	@sApparatusType nvarchar(500),
	@sSourceType nvarchar(500),
	@daDateRegistered datetime,
	@sBrand nvarchar(max),
	@sModel nvarchar(max),
	@sClassification nvarchar(max),
	@sContactDetails nvarchar(max),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@daDateAcquired datetime,
	@daDateOfDisposal datetime,
	@sSerialNo nvarchar(50),
	@sISONumber nvarchar(50),
	@sAssetNumber nvarchar(12),
	@daDateManufactured datetime,
	@daDateLastTested datetime,
	@sWorkingLife nvarchar(max),
	@daDateWorkingLifeExpiry datetime,
	@sRadionuclide nvarchar(100),
	@sEquipmentNotes nvarchar(max),
	@sEquipmentName nvarchar(max),
	@sManufacturer nvarchar(255),
	@sBuildingPrefixName nvarchar(max),
	@sBuildingNumber nvarchar(20),
	@sUnitNumber nvarchar(20),
	@sStreetName nvarchar(max),
	@sSuburb nvarchar(40),
	@sState nvarchar(20),
	@sPostcode nvarchar(5),
	@sControlGenManufacturer nvarchar(80),
	@sControlGenModel nvarchar(max),
	@sControlGenSerial nvarchar(20),
	@sTubeHousingManufacturer nvarchar(80),
	@sTubeHousingModel nvarchar(max),
	@sTubeHousingSerial nvarchar(max),
	@sTubeInsertManufacturer nvarchar(80),
	@sTubeInsertModel nvarchar(max),
	@sTubeInsertSerial nvarchar(max),
	@sCategory nvarchar(max),
	@sNominalActivity nvarchar(max),
	@sRegAuthorityIDNoPrev nvarchar(max),
	@sLicenceNumberPrev nvarchar(max),
	@sHasComplianceCertificate nvarchar(10),
	@daAssayDate datetime,
	@daComplianceCertExpiry datetime,
	@sSendComplianceCertReminder nvarchar(10),
	@sSendComplianceCertReminderTo nvarchar(max),
	@sApparatusDescription nvarchar(50),
	@sCostGroup nvarchar(max),
	@sSealedSourceDescription nvarchar(500),
	@sSecurityClassification nvarchar(100),
	@sCampus nvarchar(100),
	@sSiteLocationName nvarchar(max),
	@sBusinessUnitName nvarchar(max),
	@sCentreNo varchar(max),
	@sCentreName nvarchar(255),
	@sNameOfPremises nvarchar(100),
	@sOtherApparatus nvarchar(max),
	@sOtherSealedSourceDevice nvarchar(max),
	@sPermittedPractice nvarchar(max),
	@sPermittedLocation nvarchar(max),
	@sPermittedIonisingApparatus nvarchar(max),
	@sPermittedPurpose nvarchar(max),
	@sPermittedSealedSource nvarchar(max),
	@sPermittedRadionuclide nvarchar(max),
	@sMaxPermittedActivity nvarchar(max),
	@sResponsibleDepartment nvarchar(max),
	@sRequiresTesting nvarchar(10),
	@sVendor nvarchar(max),
	@sVendorDetails nvarchar(max),
	@sTypicalProcedure nvarchar(max),
	@sTypicalShielding nvarchar(max),
	@dcServiceCost decimal(10, 2),
	@dcTestingCost decimal(10, 2),
	@dcReplacementCost decimal(10, 2),
	@dcTotalDepreciation decimal(10, 2),
	@sDepreciationDesc nvarchar(max),
	@dcRentalCost decimal(10, 2),
	@dcRunningCost decimal(10, 2),
	@dcOtherCostA decimal(10, 2),
	@sOtherCostADesc nvarchar(max),
	@dcOtherCostB decimal(10, 2),
	@sOtherCostBDesc nvarchar(max),
	@sCostsNote nvarchar(max),
	@daDatePurchased datetime,
	@daDateWarrantyExpires datetime,
	@daDateGuaranteeExpires datetime,
	@sWarrantyConditions nvarchar(max),
	@sGuranteeConditions nvarchar(max),
	@dcPurchaseCost decimal(10, 2),
	@daDatePlannedExpiration datetime,
	@dcDisposalCost decimal(10, 2),
	@sDisposalVendorContact nvarchar(max),
	@sDisposalMethod nvarchar(max),
	@sDisposalConfirmed nvarchar(10),
	@sDisposalConfirmation nvarchar(max),
	@sDisposalEnvironmental nvarchar(max),
	@sDisposalPermitRequired nvarchar(10),
	@sDisposalPermitObtained nvarchar(10),
	@sDisposalPermitNumber nvarchar(max),
	@daDisposalPermitDate datetime,
	@sDisposalPermitConditions nvarchar(max),
	@iTestingFrequency int,
	@daDateNextTestExpected datetime,
	@daDateNextTestScheduled datetime,
	@sRequiresAuditing nvarchar(10),
	@iAuditFrequency int,
	@daDateLastAudit datetime,
	@sLastAuditConductedBy nvarchar(max),
	@sLastAuditConductedLicenceNo nvarchar(max),
	@daDateNextAuditExpected datetime,
	@daDateNextAuditScheduled datetime,
	@sLastAuditOutcomeSummary nvarchar(max),
	@sLastAuditOutcomeDetail nvarchar(max),
	@daDateDecommissioned datetime,
	@sEquipmentFlagFollowup nvarchar(20),
	@sFacility nvarchar(200),
	@iLocalEquipmentID int,
	@sAltLocalEquipmentID nvarchar(12),
	@iARPANSALADNumber int,
	@sIntendedPurpose nvarchar(255),
	@sARPANSAStatus nvarchar(50),
	@sInventoryStatus nvarchar(50),
	@sDisposalStatus nvarchar(50),
	@sOperatingParameter nvarchar(255),
	@sLikelyExposure nvarchar(255),
	@sChemicalForm nvarchar(500),
	@sPhysicalForm nvarchar(500),
	@sPortability nvarchar(500),
	@sEncapsulationMaterial nvarchar(500),
	@sRoomName nvarchar(100),
	@sLocationOther nvarchar(255),
	@daApprovalSubmissionDate datetime,
	@daApproval datetime,
	@daDisposalApprovalGranted datetime,
	@sDisposalDetails nvarchar(max),
	@daActivityDate datetime,
	@fActivityBq float(53),
	@fMaxActivityBq float(53),
	@sMax_kVp nvarchar(255),
	@sMax_mA nvarchar(255),
	@iRecommendedWorkingLife int,
	@fCurrentActivity float(53),
	@fSourceAE float(53),
	@fSourceAD float(53),
	@daWipeTestDate datetime,
	@sComments nvarchar(max),
	@sInternalComments nvarchar(max),
	@sASNOPermitNo nvarchar(20),
	@sASNOBatchNo nvarchar(20),
	@sNonIonisingSource nvarchar(500),
	@sNonIonisingApparatusType nvarchar(max),
	@sIonisingSource nvarchar(max),
	@sIonisingApparatusType nvarchar(max),
	@sUnsealedSource nvarchar(max),
	@daLastSightedDate datetime,
	@sLastSightedBy varchar(30),
	@sLastSightedComment varchar(max),
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@sLicencePermitNo nvarchar(100),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sEquipmentModel nvarchar(180),
	@sDxSourceCustodian nvarchar(200),
	@sDxAreaCustodian nvarchar(200),
	@sDxLineManager nvarchar(200),
	@sDxRSO nvarchar(200),
	@sASNOMaterial nvarchar(10),
	@sASNOInventoryBatchNo nvarchar(20),
	@iExemptLimitBq int,
	@iComputedAD int,
	@iComputedAE int,
	@sSourceCertificateNo nvarchar(30),
	@iSourceCertificateID int,
	@iLicencedActivityBq int,
	@daDateOfReceipt datetime,
	@daDateOfLastSurvey datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipmentView]
SET 
	[EquipmentType] = @sEquipmentType,
	[EquipmentStatus] = @sEquipmentStatus,
	[ApparatusType] = @sApparatusType,
	[SourceType] = @sSourceType,
	[DateRegistered] = @daDateRegistered,
	[Brand] = @sBrand,
	[Model] = @sModel,
	[Classification] = @sClassification,
	[ContactDetails] = @sContactDetails,
	[RegAuthorityIDNo] = @sRegAuthorityIDNo,
	[LicenceNumber] = @sLicenceNumber,
	[DateAcquired] = @daDateAcquired,
	[DateOfDisposal] = @daDateOfDisposal,
	[SerialNo] = @sSerialNo,
	[ISONumber] = @sISONumber,
	[AssetNumber] = @sAssetNumber,
	[DateManufactured] = @daDateManufactured,
	[DateLastTested] = @daDateLastTested,
	[WorkingLife] = @sWorkingLife,
	[DateWorkingLifeExpiry] = @daDateWorkingLifeExpiry,
	[Radionuclide] = @sRadionuclide,
	[EquipmentNotes] = @sEquipmentNotes,
	[EquipmentName] = @sEquipmentName,
	[Manufacturer] = @sManufacturer,
	[BuildingPrefixName] = @sBuildingPrefixName,
	[BuildingNumber] = @sBuildingNumber,
	[UnitNumber] = @sUnitNumber,
	[StreetName] = @sStreetName,
	[Suburb] = @sSuburb,
	[State] = @sState,
	[Postcode] = @sPostcode,
	[ControlGenManufacturer] = @sControlGenManufacturer,
	[ControlGenModel] = @sControlGenModel,
	[ControlGenSerial] = @sControlGenSerial,
	[TubeHousingManufacturer] = @sTubeHousingManufacturer,
	[TubeHousingModel] = @sTubeHousingModel,
	[TubeHousingSerial] = @sTubeHousingSerial,
	[TubeInsertManufacturer] = @sTubeInsertManufacturer,
	[TubeInsertModel] = @sTubeInsertModel,
	[TubeInsertSerial] = @sTubeInsertSerial,
	[Category] = @sCategory,
	[NominalActivity] = @sNominalActivity,
	[RegAuthorityIDNoPrev] = @sRegAuthorityIDNoPrev,
	[LicenceNumberPrev] = @sLicenceNumberPrev,
	[HasComplianceCertificate] = @sHasComplianceCertificate,
	[AssayDate] = @daAssayDate,
	[ComplianceCertExpiry] = @daComplianceCertExpiry,
	[SendComplianceCertReminder] = @sSendComplianceCertReminder,
	[SendComplianceCertReminderTo] = @sSendComplianceCertReminderTo,
	[ApparatusDescription] = @sApparatusDescription,
	[CostGroup] = @sCostGroup,
	[SealedSourceDescription] = @sSealedSourceDescription,
	[SecurityClassification] = @sSecurityClassification,
	[Campus] = @sCampus,
	[SiteLocationName] = @sSiteLocationName,
	[BusinessUnitName] = @sBusinessUnitName,
	[CentreNo] = @sCentreNo,
	[CentreName] = @sCentreName,
	[NameOfPremises] = @sNameOfPremises,
	[OtherApparatus] = @sOtherApparatus,
	[OtherSealedSourceDevice] = @sOtherSealedSourceDevice,
	[PermittedPractice] = @sPermittedPractice,
	[PermittedLocation] = @sPermittedLocation,
	[PermittedIonisingApparatus] = @sPermittedIonisingApparatus,
	[PermittedPurpose] = @sPermittedPurpose,
	[PermittedSealedSource] = @sPermittedSealedSource,
	[PermittedRadionuclide] = @sPermittedRadionuclide,
	[MaxPermittedActivity] = @sMaxPermittedActivity,
	[ResponsibleDepartment] = @sResponsibleDepartment,
	[RequiresTesting] = @sRequiresTesting,
	[Vendor] = @sVendor,
	[VendorDetails] = @sVendorDetails,
	[TypicalProcedure] = @sTypicalProcedure,
	[TypicalShielding] = @sTypicalShielding,
	[ServiceCost] = @dcServiceCost,
	[TestingCost] = @dcTestingCost,
	[ReplacementCost] = @dcReplacementCost,
	[TotalDepreciation] = @dcTotalDepreciation,
	[DepreciationDesc] = @sDepreciationDesc,
	[RentalCost] = @dcRentalCost,
	[RunningCost] = @dcRunningCost,
	[OtherCostA] = @dcOtherCostA,
	[OtherCostADesc] = @sOtherCostADesc,
	[OtherCostB] = @dcOtherCostB,
	[OtherCostBDesc] = @sOtherCostBDesc,
	[CostsNote] = @sCostsNote,
	[DatePurchased] = @daDatePurchased,
	[DateWarrantyExpires] = @daDateWarrantyExpires,
	[DateGuaranteeExpires] = @daDateGuaranteeExpires,
	[WarrantyConditions] = @sWarrantyConditions,
	[GuranteeConditions] = @sGuranteeConditions,
	[PurchaseCost] = @dcPurchaseCost,
	[DatePlannedExpiration] = @daDatePlannedExpiration,
	[DisposalCost] = @dcDisposalCost,
	[DisposalVendorContact] = @sDisposalVendorContact,
	[DisposalMethod] = @sDisposalMethod,
	[DisposalConfirmed] = @sDisposalConfirmed,
	[DisposalConfirmation] = @sDisposalConfirmation,
	[DisposalEnvironmental] = @sDisposalEnvironmental,
	[DisposalPermitRequired] = @sDisposalPermitRequired,
	[DisposalPermitObtained] = @sDisposalPermitObtained,
	[DisposalPermitNumber] = @sDisposalPermitNumber,
	[DisposalPermitDate] = @daDisposalPermitDate,
	[DisposalPermitConditions] = @sDisposalPermitConditions,
	[TestingFrequency] = @iTestingFrequency,
	[DateNextTestExpected] = @daDateNextTestExpected,
	[DateNextTestScheduled] = @daDateNextTestScheduled,
	[RequiresAuditing] = @sRequiresAuditing,
	[AuditFrequency] = @iAuditFrequency,
	[DateLastAudit] = @daDateLastAudit,
	[LastAuditConductedBy] = @sLastAuditConductedBy,
	[LastAuditConductedLicenceNo] = @sLastAuditConductedLicenceNo,
	[DateNextAuditExpected] = @daDateNextAuditExpected,
	[DateNextAuditScheduled] = @daDateNextAuditScheduled,
	[LastAuditOutcomeSummary] = @sLastAuditOutcomeSummary,
	[LastAuditOutcomeDetail] = @sLastAuditOutcomeDetail,
	[DateDecommissioned] = @daDateDecommissioned,
	[EquipmentFlagFollowup] = @sEquipmentFlagFollowup,
	[Facility] = @sFacility,
	[LocalEquipmentID] = @iLocalEquipmentID,
	[AltLocalEquipmentID] = @sAltLocalEquipmentID,
	[ARPANSALADNumber] = @iARPANSALADNumber,
	[IntendedPurpose] = @sIntendedPurpose,
	[ARPANSAStatus] = @sARPANSAStatus,
	[InventoryStatus] = @sInventoryStatus,
	[DisposalStatus] = @sDisposalStatus,
	[OperatingParameter] = @sOperatingParameter,
	[LikelyExposure] = @sLikelyExposure,
	[ChemicalForm] = @sChemicalForm,
	[PhysicalForm] = @sPhysicalForm,
	[Portability] = @sPortability,
	[EncapsulationMaterial] = @sEncapsulationMaterial,
	[RoomName] = @sRoomName,
	[LocationOther] = @sLocationOther,
	[ApprovalSubmissionDate] = @daApprovalSubmissionDate,
	[Approval] = @daApproval,
	[DisposalApprovalGranted] = @daDisposalApprovalGranted,
	[DisposalDetails] = @sDisposalDetails,
	[ActivityDate] = @daActivityDate,
	[ActivityBq] = @fActivityBq,
	[MaxActivityBq] = @fMaxActivityBq,
	[Max_kVp] = @sMax_kVp,
	[Max_mA] = @sMax_mA,
	[RecommendedWorkingLife] = @iRecommendedWorkingLife,
	[CurrentActivity] = @fCurrentActivity,
	[SourceAE] = @fSourceAE,
	[SourceAD] = @fSourceAD,
	[WipeTestDate] = @daWipeTestDate,
	[Comments] = @sComments,
	[InternalComments] = @sInternalComments,
	[ASNOPermitNo] = @sASNOPermitNo,
	[ASNOBatchNo] = @sASNOBatchNo,
	[NonIonisingSource] = @sNonIonisingSource,
	[NonIonisingApparatusType] = @sNonIonisingApparatusType,
	[IonisingSource] = @sIonisingSource,
	[IonisingApparatusType] = @sIonisingApparatusType,
	[UnsealedSource] = @sUnsealedSource,
	[LastSightedDate] = @daLastSightedDate,
	[LastSightedBy] = @sLastSightedBy,
	[LastSightedComment] = @sLastSightedComment,
	[AddedBy] = @sAddedBy,
	[AddedDateTime] = @daAddedDateTime,
	[ModifiedBy] = @sModifiedBy,
	[ModifiedDateTime] = @daModifiedDateTime,
	[LicencePermitNo] = @sLicencePermitNo,
	[Latitude] = @sLatitude,
	[Longitude] = @sLongitude,
	[EquipmentModel] = @sEquipmentModel,
	[DxSourceCustodian] = @sDxSourceCustodian,
	[DxAreaCustodian] = @sDxAreaCustodian,
	[DxLineManager] = @sDxLineManager,
	[DxRSO] = @sDxRSO,
	[ASNOMaterial] = @sASNOMaterial,
	[ASNOInventoryBatchNo] = @sASNOInventoryBatchNo,
	[ExemptLimitBq] = @iExemptLimitBq,
	[ComputedAD] = @iComputedAD,
	[ComputedAE] = @iComputedAE,
	[SourceCertificateNo] = @sSourceCertificateNo,
	[SourceCertificateID] = @iSourceCertificateID,
	[LicencedActivityBq] = @iLicencedActivityBq,
	[DateOfReceipt] = @daDateOfReceipt,
	[DateOfLastSurvey] = @daDateOfLastSurvey
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_Delete]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblEquipmentView]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_SelectOne]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentView]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentView]
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO


---------------------------------------------------------------------------------------------------------------------------------------------------
-- tblEquipmentView replacement SPROCS
---------------------------------------------------------------------------------------------------------------------------------------------------

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_Insert]
	@iEquipmentID int,
	@sEquipmentType nvarchar(500),
	@sEquipmentStatus nvarchar(500),
	@sApparatusType nvarchar(500),
	@sSourceType nvarchar(500),
	@daDateRegistered datetime,
	@sBrand nvarchar(max),
	@sModel nvarchar(max),
	@sClassification nvarchar(max),
	@sContactDetails nvarchar(max),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@daDateAcquired datetime,
	@daDateOfDisposal datetime,
	@sSerialNo nvarchar(50),
	@sISONumber nvarchar(50),
	@sAssetNumber nvarchar(12),
	@daDateManufactured datetime,
	@daDateLastTested datetime,
	@sWorkingLife nvarchar(max),
	@daDateWorkingLifeExpiry datetime,
	@sRadionuclide nvarchar(100),
	@sEquipmentNotes nvarchar(max),
	@sEquipmentName nvarchar(max),
	@sManufacturer nvarchar(255),
	@sBuildingPrefixName nvarchar(max),
	@sBuildingNumber nvarchar(20),
	@sUnitNumber nvarchar(20),
	@sStreetName nvarchar(max),
	@sSuburb nvarchar(40),
	@sState nvarchar(20),
	@sPostcode nvarchar(5),
	@sControlGenManufacturer nvarchar(80),
	@sControlGenModel nvarchar(max),
	@sControlGenSerial nvarchar(20),
	@sTubeHousingManufacturer nvarchar(80),
	@sTubeHousingModel nvarchar(max),
	@sTubeHousingSerial nvarchar(max),
	@sTubeInsertManufacturer nvarchar(80),
	@sTubeInsertModel nvarchar(max),
	@sTubeInsertSerial nvarchar(max),
	@sCategory nvarchar(max),
	@sNominalActivity nvarchar(max),
	@sRegAuthorityIDNoPrev nvarchar(max),
	@sLicenceNumberPrev nvarchar(max),
	@sHasComplianceCertificate nvarchar(10),
	@daAssayDate datetime,
	@daComplianceCertExpiry datetime,
	@sSendComplianceCertReminder nvarchar(10),
	@sSendComplianceCertReminderTo nvarchar(max),
	@sApparatusDescription nvarchar(50),
	@sCostGroup nvarchar(max),
	@sSealedSourceDescription nvarchar(500),
	@sSecurityClassification nvarchar(100),
	@sCampus nvarchar(100),
	@sSiteLocationName nvarchar(max),
	@sBusinessUnitName nvarchar(max),
	@sCentreNo varchar(max),
	@sCentreName nvarchar(255),
	@sNameOfPremises nvarchar(100),
	@sOtherApparatus nvarchar(max),
	@sOtherSealedSourceDevice nvarchar(max),
	@sPermittedPractice nvarchar(max),
	@sPermittedLocation nvarchar(max),
	@sPermittedIonisingApparatus nvarchar(max),
	@sPermittedPurpose nvarchar(max),
	@sPermittedSealedSource nvarchar(max),
	@sPermittedRadionuclide nvarchar(max),
	@sMaxPermittedActivity nvarchar(max),
	@sResponsibleDepartment nvarchar(max),
	@sRequiresTesting nvarchar(10),
	@sVendor nvarchar(max),
	@sVendorDetails nvarchar(max),
	@sTypicalProcedure nvarchar(max),
	@sTypicalShielding nvarchar(max),
	@sServiceCost nvarchar(20),
	@sTestingCost nvarchar(20),
	@sReplacementCost nvarchar(20),
	@sTotalDepreciation nvarchar(20),
	@sDepreciationDesc nvarchar(max),
	@sRentalCost nvarchar(20),
	@sRunningCost nvarchar(20),
	@sOtherCostA nvarchar(20),
	@sOtherCostADesc nvarchar(max),
	@sOtherCostB nvarchar(20),
	@sOtherCostBDesc nvarchar(max),
	@sCostsNote nvarchar(max),
	@daDatePurchased datetime,
	@daDateWarrantyExpires datetime,
	@daDateGuaranteeExpires datetime,
	@sWarrantyConditions nvarchar(max),
	@sGuranteeConditions nvarchar(max),
	@sPurchaseCost nvarchar(20),
	@daDatePlannedExpiration datetime,
	@sDisposalCost nvarchar(20),
	@sDisposalVendorContact nvarchar(max),
	@sDisposalMethod nvarchar(max),
	@sDisposalConfirmed nvarchar(10),
	@sDisposalConfirmation nvarchar(max),
	@sDisposalEnvironmental nvarchar(max),
	@sDisposalPermitRequired nvarchar(10),
	@sDisposalPermitObtained nvarchar(10),
	@sDisposalPermitNumber nvarchar(max),
	@daDisposalPermitDate datetime,
	@sDisposalPermitConditions nvarchar(max),
	@sTestingFrequency nvarchar(20),
	@daDateNextTestExpected datetime,
	@daDateNextTestScheduled datetime,
	@sRequiresAuditing nvarchar(10),
	@sAuditFrequency nvarchar(20),
	@daDateLastAudit datetime,
	@sLastAuditConductedBy nvarchar(max),
	@sLastAuditConductedLicenceNo nvarchar(max),
	@daDateNextAuditExpected datetime,
	@daDateNextAuditScheduled datetime,
	@sLastAuditOutcomeSummary nvarchar(max),
	@sLastAuditOutcomeDetail nvarchar(max),
	@daDateDecommissioned datetime,
	@sEquipmentFlagFollowup nvarchar(20),
	@sFacility nvarchar(200),
	@sLocalEquipmentID nvarchar(20),
	@sAltLocalEquipmentID nvarchar(12),
	@sARPANSALADNumber nvarchar(20),
	@sIntendedPurpose nvarchar(255),
	@sARPANSAStatus nvarchar(50),
	@sInventoryStatus nvarchar(50),
	@sDisposalStatus nvarchar(50),
	@sOperatingParameter nvarchar(255),
	@sLikelyExposure nvarchar(255),
	@sChemicalForm nvarchar(500),
	@sPhysicalForm nvarchar(500),
	@sPortability nvarchar(500),
	@sEncapsulationMaterial nvarchar(500),
	@sRoomName nvarchar(100),
	@sLocationOther nvarchar(255),
	@daApprovalSubmissionDate datetime,
	@daApproval datetime,
	@daDisposalApprovalGranted datetime,
	@sDisposalDetails nvarchar(max),
	@daActivityDate datetime,
	@sActivityBq nvarchar(max),
	@sMaxActivityBq nvarchar(max),
	@sMax_kVp nvarchar(255),
	@sMax_mA nvarchar(255),
	@sRecommendedWorkingLife nvarchar(20),
	@sCurrentActivity nvarchar(max),
	@sSourceAE nvarchar(max),
	@sSourceAD nvarchar(max),
	@daWipeTestDate datetime,
	@sComments nvarchar(max),
	@sInternalComments nvarchar(max),
	@sASNOPermitNo nvarchar(20),
	@sASNOBatchNo nvarchar(20),
	@sNonIonisingSource nvarchar(500),
	@sNonIonisingApparatusType nvarchar(max),
	@sIonisingSource nvarchar(max),
	@sIonisingApparatusType nvarchar(max),
	@sUnsealedSource nvarchar(max),
	@daLastSightedDate datetime,
	@sLastSightedBy varchar(30),
	@sLastSightedComment varchar(max),
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@sLicencePermitNo nvarchar(100),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sEquipmentModel nvarchar(180),
	@sDxSourceCustodian nvarchar(200),
	@sDxAreaCustodian nvarchar(200),
	@sDxLineManager nvarchar(200),
	@sDxRSO nvarchar(200),
	@sASNOMaterial nvarchar(10),
	@sASNOInventoryBatchNo nvarchar(20),
	@sExemptLimitBq nvarchar(20),
	@sComputedAD nvarchar(20),
	@sComputedAE nvarchar(20),
	@sSourceCertificateNo nvarchar(30),
	@sSourceCertificateID nvarchar(20),
	@sLicencedActivityBq nvarchar(max),
	@daDateOfReceipt datetime,
	@daDateOfLastSurvey datetime,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblEquipmentView]
(
	[EquipmentID],
	[EquipmentType],
	[EquipmentStatus],
	[ApparatusType],
	[SourceType],
	[DateRegistered],
	[Brand],
	[Model],
	[Classification],
	[ContactDetails],
	[RegAuthorityIDNo],
	[LicenceNumber],
	[DateAcquired],
	[DateOfDisposal],
	[SerialNo],
	[ISONumber],
	[AssetNumber],
	[DateManufactured],
	[DateLastTested],
	[WorkingLife],
	[DateWorkingLifeExpiry],
	[Radionuclide],
	[EquipmentNotes],
	[EquipmentName],
	[Manufacturer],
	[BuildingPrefixName],
	[BuildingNumber],
	[UnitNumber],
	[StreetName],
	[Suburb],
	[State],
	[Postcode],
	[ControlGenManufacturer],
	[ControlGenModel],
	[ControlGenSerial],
	[TubeHousingManufacturer],
	[TubeHousingModel],
	[TubeHousingSerial],
	[TubeInsertManufacturer],
	[TubeInsertModel],
	[TubeInsertSerial],
	[Category],
	[NominalActivity],
	[RegAuthorityIDNoPrev],
	[LicenceNumberPrev],
	[HasComplianceCertificate],
	[AssayDate],
	[ComplianceCertExpiry],
	[SendComplianceCertReminder],
	[SendComplianceCertReminderTo],
	[ApparatusDescription],
	[CostGroup],
	[SealedSourceDescription],
	[SecurityClassification],
	[Campus],
	[SiteLocationName],
	[BusinessUnitName],
	[CentreNo],
	[CentreName],
	[NameOfPremises],
	[OtherApparatus],
	[OtherSealedSourceDevice],
	[PermittedPractice],
	[PermittedLocation],
	[PermittedIonisingApparatus],
	[PermittedPurpose],
	[PermittedSealedSource],
	[PermittedRadionuclide],
	[MaxPermittedActivity],
	[ResponsibleDepartment],
	[RequiresTesting],
	[Vendor],
	[VendorDetails],
	[TypicalProcedure],
	[TypicalShielding],
	[ServiceCost],
	[TestingCost],
	[ReplacementCost],
	[TotalDepreciation],
	[DepreciationDesc],
	[RentalCost],
	[RunningCost],
	[OtherCostA],
	[OtherCostADesc],
	[OtherCostB],
	[OtherCostBDesc],
	[CostsNote],
	[DatePurchased],
	[DateWarrantyExpires],
	[DateGuaranteeExpires],
	[WarrantyConditions],
	[GuranteeConditions],
	[PurchaseCost],
	[DatePlannedExpiration],
	[DisposalCost],
	[DisposalVendorContact],
	[DisposalMethod],
	[DisposalConfirmed],
	[DisposalConfirmation],
	[DisposalEnvironmental],
	[DisposalPermitRequired],
	[DisposalPermitObtained],
	[DisposalPermitNumber],
	[DisposalPermitDate],
	[DisposalPermitConditions],
	[TestingFrequency],
	[DateNextTestExpected],
	[DateNextTestScheduled],
	[RequiresAuditing],
	[AuditFrequency],
	[DateLastAudit],
	[LastAuditConductedBy],
	[LastAuditConductedLicenceNo],
	[DateNextAuditExpected],
	[DateNextAuditScheduled],
	[LastAuditOutcomeSummary],
	[LastAuditOutcomeDetail],
	[DateDecommissioned],
	[EquipmentFlagFollowup],
	[Facility],
	[LocalEquipmentID],
	[AltLocalEquipmentID],
	[ARPANSALADNumber],
	[IntendedPurpose],
	[ARPANSAStatus],
	[InventoryStatus],
	[DisposalStatus],
	[OperatingParameter],
	[LikelyExposure],
	[ChemicalForm],
	[PhysicalForm],
	[Portability],
	[EncapsulationMaterial],
	[RoomName],
	[LocationOther],
	[ApprovalSubmissionDate],
	[Approval],
	[DisposalApprovalGranted],
	[DisposalDetails],
	[ActivityDate],
	[ActivityBq],
	[MaxActivityBq],
	[Max_kVp],
	[Max_mA],
	[RecommendedWorkingLife],
	[CurrentActivity],
	[SourceAE],
	[SourceAD],
	[WipeTestDate],
	[Comments],
	[InternalComments],
	[ASNOPermitNo],
	[ASNOBatchNo],
	[NonIonisingSource],
	[NonIonisingApparatusType],
	[IonisingSource],
	[IonisingApparatusType],
	[UnsealedSource],
	[LastSightedDate],
	[LastSightedBy],
	[LastSightedComment],
	[AddedBy],
	[AddedDateTime],
	[ModifiedBy],
	[ModifiedDateTime],
	[LicencePermitNo],
	[Latitude],
	[Longitude],
	[EquipmentModel],
	[DxSourceCustodian],
	[DxAreaCustodian],
	[DxLineManager],
	[DxRSO],
	[ASNOMaterial],
	[ASNOInventoryBatchNo],
	[ExemptLimitBq],
	[ComputedAD],
	[ComputedAE],
	[SourceCertificateNo],
	[SourceCertificateID],
	[LicencedActivityBq],
	[DateOfReceipt],
	[DateOfLastSurvey]
)
VALUES
(
	@iEquipmentID,
	@sEquipmentType,
	@sEquipmentStatus,
	@sApparatusType,
	@sSourceType,
	@daDateRegistered,
	@sBrand,
	@sModel,
	@sClassification,
	@sContactDetails,
	@sRegAuthorityIDNo,
	@sLicenceNumber,
	@daDateAcquired,
	@daDateOfDisposal,
	@sSerialNo,
	@sISONumber,
	@sAssetNumber,
	@daDateManufactured,
	@daDateLastTested,
	@sWorkingLife,
	@daDateWorkingLifeExpiry,
	@sRadionuclide,
	@sEquipmentNotes,
	@sEquipmentName,
	@sManufacturer,
	@sBuildingPrefixName,
	@sBuildingNumber,
	@sUnitNumber,
	@sStreetName,
	@sSuburb,
	@sState,
	@sPostcode,
	@sControlGenManufacturer,
	@sControlGenModel,
	@sControlGenSerial,
	@sTubeHousingManufacturer,
	@sTubeHousingModel,
	@sTubeHousingSerial,
	@sTubeInsertManufacturer,
	@sTubeInsertModel,
	@sTubeInsertSerial,
	@sCategory,
	@sNominalActivity,
	@sRegAuthorityIDNoPrev,
	@sLicenceNumberPrev,
	@sHasComplianceCertificate,
	@daAssayDate,
	@daComplianceCertExpiry,
	@sSendComplianceCertReminder,
	@sSendComplianceCertReminderTo,
	@sApparatusDescription,
	@sCostGroup,
	@sSealedSourceDescription,
	@sSecurityClassification,
	@sCampus,
	@sSiteLocationName,
	@sBusinessUnitName,
	@sCentreNo,
	@sCentreName,
	@sNameOfPremises,
	@sOtherApparatus,
	@sOtherSealedSourceDevice,
	@sPermittedPractice,
	@sPermittedLocation,
	@sPermittedIonisingApparatus,
	@sPermittedPurpose,
	@sPermittedSealedSource,
	@sPermittedRadionuclide,
	@sMaxPermittedActivity,
	@sResponsibleDepartment,
	@sRequiresTesting,
	@sVendor,
	@sVendorDetails,
	@sTypicalProcedure,
	@sTypicalShielding,
	@sServiceCost,
	@sTestingCost,
	@sReplacementCost,
	@sTotalDepreciation,
	@sDepreciationDesc,
	@sRentalCost,
	@sRunningCost,
	@sOtherCostA,
	@sOtherCostADesc,
	@sOtherCostB,
	@sOtherCostBDesc,
	@sCostsNote,
	@daDatePurchased,
	@daDateWarrantyExpires,
	@daDateGuaranteeExpires,
	@sWarrantyConditions,
	@sGuranteeConditions,
	@sPurchaseCost,
	@daDatePlannedExpiration,
	@sDisposalCost,
	@sDisposalVendorContact,
	@sDisposalMethod,
	@sDisposalConfirmed,
	@sDisposalConfirmation,
	@sDisposalEnvironmental,
	@sDisposalPermitRequired,
	@sDisposalPermitObtained,
	@sDisposalPermitNumber,
	@daDisposalPermitDate,
	@sDisposalPermitConditions,
	@sTestingFrequency,
	@daDateNextTestExpected,
	@daDateNextTestScheduled,
	@sRequiresAuditing,
	@sAuditFrequency,
	@daDateLastAudit,
	@sLastAuditConductedBy,
	@sLastAuditConductedLicenceNo,
	@daDateNextAuditExpected,
	@daDateNextAuditScheduled,
	@sLastAuditOutcomeSummary,
	@sLastAuditOutcomeDetail,
	@daDateDecommissioned,
	@sEquipmentFlagFollowup,
	@sFacility,
	@sLocalEquipmentID,
	@sAltLocalEquipmentID,
	@sARPANSALADNumber,
	@sIntendedPurpose,
	@sARPANSAStatus,
	@sInventoryStatus,
	@sDisposalStatus,
	@sOperatingParameter,
	@sLikelyExposure,
	@sChemicalForm,
	@sPhysicalForm,
	@sPortability,
	@sEncapsulationMaterial,
	@sRoomName,
	@sLocationOther,
	@daApprovalSubmissionDate,
	@daApproval,
	@daDisposalApprovalGranted,
	@sDisposalDetails,
	@daActivityDate,
	@sActivityBq,
	@sMaxActivityBq,
	@sMax_kVp,
	@sMax_mA,
	@sRecommendedWorkingLife,
	@sCurrentActivity,
	@sSourceAE,
	@sSourceAD,
	@daWipeTestDate,
	@sComments,
	@sInternalComments,
	@sASNOPermitNo,
	@sASNOBatchNo,
	@sNonIonisingSource,
	@sNonIonisingApparatusType,
	@sIonisingSource,
	@sIonisingApparatusType,
	@sUnsealedSource,
	@daLastSightedDate,
	@sLastSightedBy,
	@sLastSightedComment,
	@sAddedBy,
	@daAddedDateTime,
	@sModifiedBy,
	@daModifiedDateTime,
	@sLicencePermitNo,
	@sLatitude,
	@sLongitude,
	@sEquipmentModel,
	@sDxSourceCustodian,
	@sDxAreaCustodian,
	@sDxLineManager,
	@sDxRSO,
	@sASNOMaterial,
	@sASNOInventoryBatchNo,
	@sExemptLimitBq,
	@sComputedAD,
	@sComputedAE,
	@sSourceCertificateNo,
	@sSourceCertificateID,
	@sLicencedActivityBq,
	@daDateOfReceipt,
	@daDateOfLastSurvey
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_Update]
	@iEquipmentID int,
	@sEquipmentType nvarchar(500),
	@sEquipmentStatus nvarchar(500),
	@sApparatusType nvarchar(500),
	@sSourceType nvarchar(500),
	@daDateRegistered datetime,
	@sBrand nvarchar(max),
	@sModel nvarchar(max),
	@sClassification nvarchar(max),
	@sContactDetails nvarchar(max),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@daDateAcquired datetime,
	@daDateOfDisposal datetime,
	@sSerialNo nvarchar(50),
	@sISONumber nvarchar(50),
	@sAssetNumber nvarchar(12),
	@daDateManufactured datetime,
	@daDateLastTested datetime,
	@sWorkingLife nvarchar(max),
	@daDateWorkingLifeExpiry datetime,
	@sRadionuclide nvarchar(100),
	@sEquipmentNotes nvarchar(max),
	@sEquipmentName nvarchar(max),
	@sManufacturer nvarchar(255),
	@sBuildingPrefixName nvarchar(max),
	@sBuildingNumber nvarchar(20),
	@sUnitNumber nvarchar(20),
	@sStreetName nvarchar(max),
	@sSuburb nvarchar(40),
	@sState nvarchar(20),
	@sPostcode nvarchar(5),
	@sControlGenManufacturer nvarchar(80),
	@sControlGenModel nvarchar(max),
	@sControlGenSerial nvarchar(20),
	@sTubeHousingManufacturer nvarchar(80),
	@sTubeHousingModel nvarchar(max),
	@sTubeHousingSerial nvarchar(max),
	@sTubeInsertManufacturer nvarchar(80),
	@sTubeInsertModel nvarchar(max),
	@sTubeInsertSerial nvarchar(max),
	@sCategory nvarchar(max),
	@sNominalActivity nvarchar(max),
	@sRegAuthorityIDNoPrev nvarchar(max),
	@sLicenceNumberPrev nvarchar(max),
	@sHasComplianceCertificate nvarchar(10),
	@daAssayDate datetime,
	@daComplianceCertExpiry datetime,
	@sSendComplianceCertReminder nvarchar(10),
	@sSendComplianceCertReminderTo nvarchar(max),
	@sApparatusDescription nvarchar(50),
	@sCostGroup nvarchar(max),
	@sSealedSourceDescription nvarchar(500),
	@sSecurityClassification nvarchar(100),
	@sCampus nvarchar(100),
	@sSiteLocationName nvarchar(max),
	@sBusinessUnitName nvarchar(max),
	@sCentreNo varchar(max),
	@sCentreName nvarchar(255),
	@sNameOfPremises nvarchar(100),
	@sOtherApparatus nvarchar(max),
	@sOtherSealedSourceDevice nvarchar(max),
	@sPermittedPractice nvarchar(max),
	@sPermittedLocation nvarchar(max),
	@sPermittedIonisingApparatus nvarchar(max),
	@sPermittedPurpose nvarchar(max),
	@sPermittedSealedSource nvarchar(max),
	@sPermittedRadionuclide nvarchar(max),
	@sMaxPermittedActivity nvarchar(max),
	@sResponsibleDepartment nvarchar(max),
	@sRequiresTesting nvarchar(10),
	@sVendor nvarchar(max),
	@sVendorDetails nvarchar(max),
	@sTypicalProcedure nvarchar(max),
	@sTypicalShielding nvarchar(max),
	@sServiceCost nvarchar(20),
	@sTestingCost nvarchar(20),
	@sReplacementCost nvarchar(20),
	@sTotalDepreciation nvarchar(20),
	@sDepreciationDesc nvarchar(max),
	@sRentalCost nvarchar(20),
	@sRunningCost nvarchar(20),
	@sOtherCostA nvarchar(20),
	@sOtherCostADesc nvarchar(max),
	@sOtherCostB nvarchar(20),
	@sOtherCostBDesc nvarchar(max),
	@sCostsNote nvarchar(max),
	@daDatePurchased datetime,
	@daDateWarrantyExpires datetime,
	@daDateGuaranteeExpires datetime,
	@sWarrantyConditions nvarchar(max),
	@sGuranteeConditions nvarchar(max),
	@sPurchaseCost nvarchar(20),
	@daDatePlannedExpiration datetime,
	@sDisposalCost nvarchar(20),
	@sDisposalVendorContact nvarchar(max),
	@sDisposalMethod nvarchar(max),
	@sDisposalConfirmed nvarchar(10),
	@sDisposalConfirmation nvarchar(max),
	@sDisposalEnvironmental nvarchar(max),
	@sDisposalPermitRequired nvarchar(10),
	@sDisposalPermitObtained nvarchar(10),
	@sDisposalPermitNumber nvarchar(max),
	@daDisposalPermitDate datetime,
	@sDisposalPermitConditions nvarchar(max),
	@sTestingFrequency nvarchar(20),
	@daDateNextTestExpected datetime,
	@daDateNextTestScheduled datetime,
	@sRequiresAuditing nvarchar(10),
	@sAuditFrequency nvarchar(20),
	@daDateLastAudit datetime,
	@sLastAuditConductedBy nvarchar(max),
	@sLastAuditConductedLicenceNo nvarchar(max),
	@daDateNextAuditExpected datetime,
	@daDateNextAuditScheduled datetime,
	@sLastAuditOutcomeSummary nvarchar(max),
	@sLastAuditOutcomeDetail nvarchar(max),
	@daDateDecommissioned datetime,
	@sEquipmentFlagFollowup nvarchar(20),
	@sFacility nvarchar(200),
	@sLocalEquipmentID nvarchar(20),
	@sAltLocalEquipmentID nvarchar(12),
	@sARPANSALADNumber nvarchar(20),
	@sIntendedPurpose nvarchar(255),
	@sARPANSAStatus nvarchar(50),
	@sInventoryStatus nvarchar(50),
	@sDisposalStatus nvarchar(50),
	@sOperatingParameter nvarchar(255),
	@sLikelyExposure nvarchar(255),
	@sChemicalForm nvarchar(500),
	@sPhysicalForm nvarchar(500),
	@sPortability nvarchar(500),
	@sEncapsulationMaterial nvarchar(500),
	@sRoomName nvarchar(100),
	@sLocationOther nvarchar(255),
	@daApprovalSubmissionDate datetime,
	@daApproval datetime,
	@daDisposalApprovalGranted datetime,
	@sDisposalDetails nvarchar(max),
	@daActivityDate datetime,
	@sActivityBq nvarchar(max),
	@sMaxActivityBq nvarchar(max),
	@sMax_kVp nvarchar(255),
	@sMax_mA nvarchar(255),
	@sRecommendedWorkingLife nvarchar(20),
	@sCurrentActivity nvarchar(max),
	@sSourceAE nvarchar(max),
	@sSourceAD nvarchar(max),
	@daWipeTestDate datetime,
	@sComments nvarchar(max),
	@sInternalComments nvarchar(max),
	@sASNOPermitNo nvarchar(20),
	@sASNOBatchNo nvarchar(20),
	@sNonIonisingSource nvarchar(500),
	@sNonIonisingApparatusType nvarchar(max),
	@sIonisingSource nvarchar(max),
	@sIonisingApparatusType nvarchar(max),
	@sUnsealedSource nvarchar(max),
	@daLastSightedDate datetime,
	@sLastSightedBy varchar(30),
	@sLastSightedComment varchar(max),
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@sLicencePermitNo nvarchar(100),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sEquipmentModel nvarchar(180),
	@sDxSourceCustodian nvarchar(200),
	@sDxAreaCustodian nvarchar(200),
	@sDxLineManager nvarchar(200),
	@sDxRSO nvarchar(200),
	@sASNOMaterial nvarchar(10),
	@sASNOInventoryBatchNo nvarchar(20),
	@sExemptLimitBq nvarchar(20),
	@sComputedAD nvarchar(20),
	@sComputedAE nvarchar(20),
	@sSourceCertificateNo nvarchar(30),
	@sSourceCertificateID nvarchar(20),
	@sLicencedActivityBq nvarchar(max),
	@daDateOfReceipt datetime,
	@daDateOfLastSurvey datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipmentView]
SET 
	[EquipmentType] = @sEquipmentType,
	[EquipmentStatus] = @sEquipmentStatus,
	[ApparatusType] = @sApparatusType,
	[SourceType] = @sSourceType,
	[DateRegistered] = @daDateRegistered,
	[Brand] = @sBrand,
	[Model] = @sModel,
	[Classification] = @sClassification,
	[ContactDetails] = @sContactDetails,
	[RegAuthorityIDNo] = @sRegAuthorityIDNo,
	[LicenceNumber] = @sLicenceNumber,
	[DateAcquired] = @daDateAcquired,
	[DateOfDisposal] = @daDateOfDisposal,
	[SerialNo] = @sSerialNo,
	[ISONumber] = @sISONumber,
	[AssetNumber] = @sAssetNumber,
	[DateManufactured] = @daDateManufactured,
	[DateLastTested] = @daDateLastTested,
	[WorkingLife] = @sWorkingLife,
	[DateWorkingLifeExpiry] = @daDateWorkingLifeExpiry,
	[Radionuclide] = @sRadionuclide,
	[EquipmentNotes] = @sEquipmentNotes,
	[EquipmentName] = @sEquipmentName,
	[Manufacturer] = @sManufacturer,
	[BuildingPrefixName] = @sBuildingPrefixName,
	[BuildingNumber] = @sBuildingNumber,
	[UnitNumber] = @sUnitNumber,
	[StreetName] = @sStreetName,
	[Suburb] = @sSuburb,
	[State] = @sState,
	[Postcode] = @sPostcode,
	[ControlGenManufacturer] = @sControlGenManufacturer,
	[ControlGenModel] = @sControlGenModel,
	[ControlGenSerial] = @sControlGenSerial,
	[TubeHousingManufacturer] = @sTubeHousingManufacturer,
	[TubeHousingModel] = @sTubeHousingModel,
	[TubeHousingSerial] = @sTubeHousingSerial,
	[TubeInsertManufacturer] = @sTubeInsertManufacturer,
	[TubeInsertModel] = @sTubeInsertModel,
	[TubeInsertSerial] = @sTubeInsertSerial,
	[Category] = @sCategory,
	[NominalActivity] = @sNominalActivity,
	[RegAuthorityIDNoPrev] = @sRegAuthorityIDNoPrev,
	[LicenceNumberPrev] = @sLicenceNumberPrev,
	[HasComplianceCertificate] = @sHasComplianceCertificate,
	[AssayDate] = @daAssayDate,
	[ComplianceCertExpiry] = @daComplianceCertExpiry,
	[SendComplianceCertReminder] = @sSendComplianceCertReminder,
	[SendComplianceCertReminderTo] = @sSendComplianceCertReminderTo,
	[ApparatusDescription] = @sApparatusDescription,
	[CostGroup] = @sCostGroup,
	[SealedSourceDescription] = @sSealedSourceDescription,
	[SecurityClassification] = @sSecurityClassification,
	[Campus] = @sCampus,
	[SiteLocationName] = @sSiteLocationName,
	[BusinessUnitName] = @sBusinessUnitName,
	[CentreNo] = @sCentreNo,
	[CentreName] = @sCentreName,
	[NameOfPremises] = @sNameOfPremises,
	[OtherApparatus] = @sOtherApparatus,
	[OtherSealedSourceDevice] = @sOtherSealedSourceDevice,
	[PermittedPractice] = @sPermittedPractice,
	[PermittedLocation] = @sPermittedLocation,
	[PermittedIonisingApparatus] = @sPermittedIonisingApparatus,
	[PermittedPurpose] = @sPermittedPurpose,
	[PermittedSealedSource] = @sPermittedSealedSource,
	[PermittedRadionuclide] = @sPermittedRadionuclide,
	[MaxPermittedActivity] = @sMaxPermittedActivity,
	[ResponsibleDepartment] = @sResponsibleDepartment,
	[RequiresTesting] = @sRequiresTesting,
	[Vendor] = @sVendor,
	[VendorDetails] = @sVendorDetails,
	[TypicalProcedure] = @sTypicalProcedure,
	[TypicalShielding] = @sTypicalShielding,
	[ServiceCost] = @sServiceCost,
	[TestingCost] = @sTestingCost,
	[ReplacementCost] = @sReplacementCost,
	[TotalDepreciation] = @sTotalDepreciation,
	[DepreciationDesc] = @sDepreciationDesc,
	[RentalCost] = @sRentalCost,
	[RunningCost] = @sRunningCost,
	[OtherCostA] = @sOtherCostA,
	[OtherCostADesc] = @sOtherCostADesc,
	[OtherCostB] = @sOtherCostB,
	[OtherCostBDesc] = @sOtherCostBDesc,
	[CostsNote] = @sCostsNote,
	[DatePurchased] = @daDatePurchased,
	[DateWarrantyExpires] = @daDateWarrantyExpires,
	[DateGuaranteeExpires] = @daDateGuaranteeExpires,
	[WarrantyConditions] = @sWarrantyConditions,
	[GuranteeConditions] = @sGuranteeConditions,
	[PurchaseCost] = @sPurchaseCost,
	[DatePlannedExpiration] = @daDatePlannedExpiration,
	[DisposalCost] = @sDisposalCost,
	[DisposalVendorContact] = @sDisposalVendorContact,
	[DisposalMethod] = @sDisposalMethod,
	[DisposalConfirmed] = @sDisposalConfirmed,
	[DisposalConfirmation] = @sDisposalConfirmation,
	[DisposalEnvironmental] = @sDisposalEnvironmental,
	[DisposalPermitRequired] = @sDisposalPermitRequired,
	[DisposalPermitObtained] = @sDisposalPermitObtained,
	[DisposalPermitNumber] = @sDisposalPermitNumber,
	[DisposalPermitDate] = @daDisposalPermitDate,
	[DisposalPermitConditions] = @sDisposalPermitConditions,
	[TestingFrequency] = @sTestingFrequency,
	[DateNextTestExpected] = @daDateNextTestExpected,
	[DateNextTestScheduled] = @daDateNextTestScheduled,
	[RequiresAuditing] = @sRequiresAuditing,
	[AuditFrequency] = @sAuditFrequency,
	[DateLastAudit] = @daDateLastAudit,
	[LastAuditConductedBy] = @sLastAuditConductedBy,
	[LastAuditConductedLicenceNo] = @sLastAuditConductedLicenceNo,
	[DateNextAuditExpected] = @daDateNextAuditExpected,
	[DateNextAuditScheduled] = @daDateNextAuditScheduled,
	[LastAuditOutcomeSummary] = @sLastAuditOutcomeSummary,
	[LastAuditOutcomeDetail] = @sLastAuditOutcomeDetail,
	[DateDecommissioned] = @daDateDecommissioned,
	[EquipmentFlagFollowup] = @sEquipmentFlagFollowup,
	[Facility] = @sFacility,
	[LocalEquipmentID] = @sLocalEquipmentID,
	[AltLocalEquipmentID] = @sAltLocalEquipmentID,
	[ARPANSALADNumber] = @sARPANSALADNumber,
	[IntendedPurpose] = @sIntendedPurpose,
	[ARPANSAStatus] = @sARPANSAStatus,
	[InventoryStatus] = @sInventoryStatus,
	[DisposalStatus] = @sDisposalStatus,
	[OperatingParameter] = @sOperatingParameter,
	[LikelyExposure] = @sLikelyExposure,
	[ChemicalForm] = @sChemicalForm,
	[PhysicalForm] = @sPhysicalForm,
	[Portability] = @sPortability,
	[EncapsulationMaterial] = @sEncapsulationMaterial,
	[RoomName] = @sRoomName,
	[LocationOther] = @sLocationOther,
	[ApprovalSubmissionDate] = @daApprovalSubmissionDate,
	[Approval] = @daApproval,
	[DisposalApprovalGranted] = @daDisposalApprovalGranted,
	[DisposalDetails] = @sDisposalDetails,
	[ActivityDate] = @daActivityDate,
	[ActivityBq] = @sActivityBq,
	[MaxActivityBq] = @sMaxActivityBq,
	[Max_kVp] = @sMax_kVp,
	[Max_mA] = @sMax_mA,
	[RecommendedWorkingLife] = @sRecommendedWorkingLife,
	[CurrentActivity] = @sCurrentActivity,
	[SourceAE] = @sSourceAE,
	[SourceAD] = @sSourceAD,
	[WipeTestDate] = @daWipeTestDate,
	[Comments] = @sComments,
	[InternalComments] = @sInternalComments,
	[ASNOPermitNo] = @sASNOPermitNo,
	[ASNOBatchNo] = @sASNOBatchNo,
	[NonIonisingSource] = @sNonIonisingSource,
	[NonIonisingApparatusType] = @sNonIonisingApparatusType,
	[IonisingSource] = @sIonisingSource,
	[IonisingApparatusType] = @sIonisingApparatusType,
	[UnsealedSource] = @sUnsealedSource,
	[LastSightedDate] = @daLastSightedDate,
	[LastSightedBy] = @sLastSightedBy,
	[LastSightedComment] = @sLastSightedComment,
	[AddedBy] = @sAddedBy,
	[AddedDateTime] = @daAddedDateTime,
	[ModifiedBy] = @sModifiedBy,
	[ModifiedDateTime] = @daModifiedDateTime,
	[LicencePermitNo] = @sLicencePermitNo,
	[Latitude] = @sLatitude,
	[Longitude] = @sLongitude,
	[EquipmentModel] = @sEquipmentModel,
	[DxSourceCustodian] = @sDxSourceCustodian,
	[DxAreaCustodian] = @sDxAreaCustodian,
	[DxLineManager] = @sDxLineManager,
	[DxRSO] = @sDxRSO,
	[ASNOMaterial] = @sASNOMaterial,
	[ASNOInventoryBatchNo] = @sASNOInventoryBatchNo,
	[ExemptLimitBq] = @sExemptLimitBq,
	[ComputedAD] = @sComputedAD,
	[ComputedAE] = @sComputedAE,
	[SourceCertificateNo] = @sSourceCertificateNo,
	[SourceCertificateID] = @sSourceCertificateID,
	[LicencedActivityBq] = @sLicencedActivityBq,
	[DateOfReceipt] = @daDateOfReceipt,
	[DateOfLastSurvey] = @daDateOfLastSurvey
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_Delete]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblEquipmentView]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_SelectOne]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentView]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentView_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentView_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentView_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentView]
ORDER BY 
	[EquipmentID] ASC
SELECT @iErrorCode=@@ERROR
GO



------------------------------------------
-- End tblEquipmentView replacement SPROCS
------------------------------------------


-- ================================================================================================================================================
-- tblOrganisation replacement SPROCS
-- ================================================================================================================================================


SET NOCOUNT ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblOrganisation_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblOrganisation_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblOrganisation_Insert]
	@sTradingName varchar(255),
	@sLegalName varchar(255),
	@iOrgStatusID int,
	@bIsWearerDefault bit,
	@iReportingGroupNumber int,
	@lABN bigint,
	@lACN bigint,
	@sOrgNotes nvarchar(max),
	@bIsANRDREmployer bit,
	@iOrganisationID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblOrganisation]
(
	[TradingName],
	[LegalName],
	[OrgStatusID],
	[IsWearerDefault],
	[ReportingGroupNumber],
	[ABN],
	[ACN],
	[OrgNotes],
	[IsANRDREmployer]
)
VALUES
(
	@sTradingName,
	@sLegalName,
	@iOrgStatusID,
	@bIsWearerDefault,
	@iReportingGroupNumber,
	@lABN,
	@lACN,
	@sOrgNotes,
	@bIsANRDREmployer
)
SELECT @iErrorCode=@@ERROR
SELECT @iOrganisationID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblOrganisation_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblOrganisation_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblOrganisation_Update]
	@iOrganisationID int,
	@sTradingName varchar(255),
	@sLegalName varchar(255),
	@iOrgStatusID int,
	@bIsWearerDefault bit,
	@iReportingGroupNumber int,
	@lABN bigint,
	@lACN bigint,
	@sOrgNotes nvarchar(max),
	@bIsANRDREmployer bit,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblOrganisation]
SET 
	[TradingName] = @sTradingName,
	[LegalName] = @sLegalName,
	[OrgStatusID] = @iOrgStatusID,
	[IsWearerDefault] = @bIsWearerDefault,
	[ReportingGroupNumber] = @iReportingGroupNumber,
	[ABN] = @lABN,
	[ACN] = @lACN,
	[OrgNotes] = @sOrgNotes,
	[IsANRDREmployer] = @bIsANRDREmployer
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblOrganisation_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblOrganisation_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblOrganisation_Delete]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblOrganisation]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblOrganisation_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblOrganisation_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblOrganisation_SelectOne]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblOrganisation]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblOrganisation_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblOrganisation_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblOrganisation_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblOrganisation]
ORDER BY 
	[OrganisationID] ASC
SELECT @iErrorCode=@@ERROR
GO



-- ===========================
-- End tblOrganisation SPROCS
-- ===========================




if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_Insert]
	@iReferenceGroupID int,
	@iContextID int,
	@blobContent image,
	@iReferenceDomainID int,
	@iReferenceFunctionID int,
	@iJurisdictionID int,
	@iReferenceSourceTypeID int,
	@sTitle nvarchar(140),
	@sURL nvarchar(max),
	@sReferenceDescription nvarchar(max),
	@sAuthors nvarchar(136),
	@sEditors nvarchar(136),
	@sCitation nvarchar(max),
	@sReferenceCode nvarchar(20),
	@sReferenceCodePrior nvarchar(20),
	@sCopyright nvarchar(136),
	@sDOI nvarchar(136),
	@daDownloaded datetime,
	@sReferenceFormat nvarchar(11),
	@sISBN nvarchar(136),
	@sItemNo nvarchar(20),
	@sItemNoPrior nvarchar(20),
	@daLastViewed datetime,
	@sReferenceLibrary nvarchar(136),
	@sReferenceNotes nvarchar(max),
	@sReferenceOrganisation nvarchar(136),
	@sOwnership nvarchar(136),
	@sReferencePage nvarchar(11),
	@sParagraph nvarchar(136),
	@sReferenceParent nvarchar(136),
	@sPatent nvarchar(136),
	@sReferenceProcessId nvarchar(136),
	@sPublishedAt nvarchar(136),
	@sQMSReference nvarchar(136),
	@sRecordNo nvarchar(20),
	@sReferenceRevision nvarchar(136),
	@sReferenceSection nvarchar(136),
	@sSectionNo nvarchar(20),
	@sSerialNo nvarchar(20),
	@sStandards nvarchar(136),
	@sSummary nvarchar(230),
	@sTrademark nvarchar(136),
	@sTRIMno nvarchar(20),
	@sURLAlternative nvarchar(max),
	@sUNC nvarchar(259),
	@sVerified nvarchar(136),
	@sReferenceVersion nvarchar(136),
	@sYearPublished nvarchar(4),
	@sOtheri nvarchar(max),
	@sOtherii nvarchar(max),
	@bIsHelp bit,
	@bIsInternal bit,
	@iRefFormID int,
	@iRefFieldID int,
	@iHxContextID int,
	@iHxPKeyID int,
	@iImageID int,
	@iBusinessUnitID int,
	@iBusinessUnitContactID int,
	@iCentreInternalID int,
	@iCustomNotificationID int,
	@iDoseAlertSettingID int,
	@iDoseReportTypeID int,
	@iDxContactID int,
	@iDxGroupID int,
	@iDxJobID int,
	@iEquipmentID int,
	@iEquipmentDefectID int,
	@iEquipmentServiceID int,
	@iEquipmentSourceID int,
	@iEquipmentTestID int,
	@iEquipmentWearerID int,
	@iFileNoteID int,
	@iHxRoleID int,
	@iLicencePermitID int,
	@iOrganisationID int,
	@iPregnancyID int,
	@iPremisesID int,
	@iProtectiveDeviceModelID int,
	@iProtectiveDeviceModelSafetyAssessmentID int,
	@iProtectiveDeviceTestID int,
	@iProviderID int,
	@iRadioNuclideID int,
	@iRoomID int,
	@iSiteLocationID int,
	@iSourceID int,
	@iSpecificationID int,
	@iUserTemplateID int,
	@sUserID varchar(50),
	@iWearerInternalID int,
	@iWearerLicenceID int,
	@iSortSequence int,
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@iEquipmentModelID int,
	@iReferenceID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblReference]
(
	[ReferenceGroupID],
	[ContextID],
	[Content],
	[ReferenceDomainID],
	[ReferenceFunctionID],
	[JurisdictionID],
	[ReferenceSourceTypeID],
	[Title],
	[URL],
	[ReferenceDescription],
	[Authors],
	[Editors],
	[Citation],
	[ReferenceCode],
	[ReferenceCodePrior],
	[Copyright],
	[DOI],
	[Downloaded],
	[ReferenceFormat],
	[ISBN],
	[ItemNo],
	[ItemNoPrior],
	[LastViewed],
	[ReferenceLibrary],
	[ReferenceNotes],
	[ReferenceOrganisation],
	[Ownership],
	[ReferencePage],
	[Paragraph],
	[ReferenceParent],
	[Patent],
	[ReferenceProcessId],
	[PublishedAt],
	[QMSReference],
	[RecordNo],
	[ReferenceRevision],
	[ReferenceSection],
	[SectionNo],
	[SerialNo],
	[Standards],
	[Summary],
	[Trademark],
	[TRIMno],
	[URLAlternative],
	[UNC],
	[Verified],
	[ReferenceVersion],
	[YearPublished],
	[Otheri],
	[Otherii],
	[IsHelp],
	[IsInternal],
	[RefFormID],
	[RefFieldID],
	[HxContextID],
	[HxPKeyID],
	[ImageID],
	[BusinessUnitID],
	[BusinessUnitContactID],
	[CentreInternalID],
	[CustomNotificationID],
	[DoseAlertSettingID],
	[DoseReportTypeID],
	[DxContactID],
	[DxGroupID],
	[DxJobID],
	[EquipmentID],
	[EquipmentDefectID],
	[EquipmentServiceID],
	[EquipmentSourceID],
	[EquipmentTestID],
	[EquipmentWearerID],
	[FileNoteID],
	[HxRoleID],
	[LicencePermitID],
	[OrganisationID],
	[PregnancyID],
	[PremisesID],
	[ProtectiveDeviceModelID],
	[ProtectiveDeviceModelSafetyAssessmentID],
	[ProtectiveDeviceTestID],
	[ProviderID],
	[RadioNuclideID],
	[RoomID],
	[SiteLocationID],
	[SourceID],
	[SpecificationID],
	[UserTemplateID],
	[UserID],
	[WearerInternalID],
	[WearerLicenceID],
	[SortSequence],
	[AddedBy],
	[AddedDateTime],
	[ModifiedBy],
	[ModifiedDateTime],
	[EquipmentModelID]
)
VALUES
(
	@iReferenceGroupID,
	@iContextID,
	@blobContent,
	@iReferenceDomainID,
	@iReferenceFunctionID,
	@iJurisdictionID,
	@iReferenceSourceTypeID,
	@sTitle,
	@sURL,
	@sReferenceDescription,
	@sAuthors,
	@sEditors,
	@sCitation,
	@sReferenceCode,
	@sReferenceCodePrior,
	@sCopyright,
	@sDOI,
	@daDownloaded,
	@sReferenceFormat,
	@sISBN,
	@sItemNo,
	@sItemNoPrior,
	@daLastViewed,
	@sReferenceLibrary,
	@sReferenceNotes,
	@sReferenceOrganisation,
	@sOwnership,
	@sReferencePage,
	@sParagraph,
	@sReferenceParent,
	@sPatent,
	@sReferenceProcessId,
	@sPublishedAt,
	@sQMSReference,
	@sRecordNo,
	@sReferenceRevision,
	@sReferenceSection,
	@sSectionNo,
	@sSerialNo,
	@sStandards,
	@sSummary,
	@sTrademark,
	@sTRIMno,
	@sURLAlternative,
	@sUNC,
	@sVerified,
	@sReferenceVersion,
	@sYearPublished,
	@sOtheri,
	@sOtherii,
	@bIsHelp,
	@bIsInternal,
	@iRefFormID,
	@iRefFieldID,
	@iHxContextID,
	@iHxPKeyID,
	@iImageID,
	@iBusinessUnitID,
	@iBusinessUnitContactID,
	@iCentreInternalID,
	@iCustomNotificationID,
	@iDoseAlertSettingID,
	@iDoseReportTypeID,
	@iDxContactID,
	@iDxGroupID,
	@iDxJobID,
	@iEquipmentID,
	@iEquipmentDefectID,
	@iEquipmentServiceID,
	@iEquipmentSourceID,
	@iEquipmentTestID,
	@iEquipmentWearerID,
	@iFileNoteID,
	@iHxRoleID,
	@iLicencePermitID,
	@iOrganisationID,
	@iPregnancyID,
	@iPremisesID,
	@iProtectiveDeviceModelID,
	@iProtectiveDeviceModelSafetyAssessmentID,
	@iProtectiveDeviceTestID,
	@iProviderID,
	@iRadioNuclideID,
	@iRoomID,
	@iSiteLocationID,
	@iSourceID,
	@iSpecificationID,
	@iUserTemplateID,
	@sUserID,
	@iWearerInternalID,
	@iWearerLicenceID,
	@iSortSequence,
	@sAddedBy,
	@daAddedDateTime,
	@sModifiedBy,
	@daModifiedDateTime,
	@iEquipmentModelID
)
SELECT @iErrorCode=@@ERROR
SELECT @iReferenceID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_Update]
	@iReferenceID int,
	@iReferenceGroupID int,
	@iContextID int,
	@blobContent image,
	@iReferenceDomainID int,
	@iReferenceFunctionID int,
	@iJurisdictionID int,
	@iReferenceSourceTypeID int,
	@sTitle nvarchar(140),
	@sURL nvarchar(max),
	@sReferenceDescription nvarchar(max),
	@sAuthors nvarchar(136),
	@sEditors nvarchar(136),
	@sCitation nvarchar(max),
	@sReferenceCode nvarchar(20),
	@sReferenceCodePrior nvarchar(20),
	@sCopyright nvarchar(136),
	@sDOI nvarchar(136),
	@daDownloaded datetime,
	@sReferenceFormat nvarchar(11),
	@sISBN nvarchar(136),
	@sItemNo nvarchar(20),
	@sItemNoPrior nvarchar(20),
	@daLastViewed datetime,
	@sReferenceLibrary nvarchar(136),
	@sReferenceNotes nvarchar(max),
	@sReferenceOrganisation nvarchar(136),
	@sOwnership nvarchar(136),
	@sReferencePage nvarchar(11),
	@sParagraph nvarchar(136),
	@sReferenceParent nvarchar(136),
	@sPatent nvarchar(136),
	@sReferenceProcessId nvarchar(136),
	@sPublishedAt nvarchar(136),
	@sQMSReference nvarchar(136),
	@sRecordNo nvarchar(20),
	@sReferenceRevision nvarchar(136),
	@sReferenceSection nvarchar(136),
	@sSectionNo nvarchar(20),
	@sSerialNo nvarchar(20),
	@sStandards nvarchar(136),
	@sSummary nvarchar(230),
	@sTrademark nvarchar(136),
	@sTRIMno nvarchar(20),
	@sURLAlternative nvarchar(max),
	@sUNC nvarchar(259),
	@sVerified nvarchar(136),
	@sReferenceVersion nvarchar(136),
	@sYearPublished nvarchar(4),
	@sOtheri nvarchar(max),
	@sOtherii nvarchar(max),
	@bIsHelp bit,
	@bIsInternal bit,
	@iRefFormID int,
	@iRefFieldID int,
	@iHxContextID int,
	@iHxPKeyID int,
	@iImageID int,
	@iBusinessUnitID int,
	@iBusinessUnitContactID int,
	@iCentreInternalID int,
	@iCustomNotificationID int,
	@iDoseAlertSettingID int,
	@iDoseReportTypeID int,
	@iDxContactID int,
	@iDxGroupID int,
	@iDxJobID int,
	@iEquipmentID int,
	@iEquipmentDefectID int,
	@iEquipmentServiceID int,
	@iEquipmentSourceID int,
	@iEquipmentTestID int,
	@iEquipmentWearerID int,
	@iFileNoteID int,
	@iHxRoleID int,
	@iLicencePermitID int,
	@iOrganisationID int,
	@iPregnancyID int,
	@iPremisesID int,
	@iProtectiveDeviceModelID int,
	@iProtectiveDeviceModelSafetyAssessmentID int,
	@iProtectiveDeviceTestID int,
	@iProviderID int,
	@iRadioNuclideID int,
	@iRoomID int,
	@iSiteLocationID int,
	@iSourceID int,
	@iSpecificationID int,
	@iUserTemplateID int,
	@sUserID varchar(50),
	@iWearerInternalID int,
	@iWearerLicenceID int,
	@iSortSequence int,
	@sAddedBy nvarchar(20),
	@daAddedDateTime datetime,
	@sModifiedBy nvarchar(20),
	@daModifiedDateTime datetime,
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET 
	[ReferenceGroupID] = @iReferenceGroupID,
	[ContextID] = @iContextID,
	[Content] = @blobContent,
	[ReferenceDomainID] = @iReferenceDomainID,
	[ReferenceFunctionID] = @iReferenceFunctionID,
	[JurisdictionID] = @iJurisdictionID,
	[ReferenceSourceTypeID] = @iReferenceSourceTypeID,
	[Title] = @sTitle,
	[URL] = @sURL,
	[ReferenceDescription] = @sReferenceDescription,
	[Authors] = @sAuthors,
	[Editors] = @sEditors,
	[Citation] = @sCitation,
	[ReferenceCode] = @sReferenceCode,
	[ReferenceCodePrior] = @sReferenceCodePrior,
	[Copyright] = @sCopyright,
	[DOI] = @sDOI,
	[Downloaded] = @daDownloaded,
	[ReferenceFormat] = @sReferenceFormat,
	[ISBN] = @sISBN,
	[ItemNo] = @sItemNo,
	[ItemNoPrior] = @sItemNoPrior,
	[LastViewed] = @daLastViewed,
	[ReferenceLibrary] = @sReferenceLibrary,
	[ReferenceNotes] = @sReferenceNotes,
	[ReferenceOrganisation] = @sReferenceOrganisation,
	[Ownership] = @sOwnership,
	[ReferencePage] = @sReferencePage,
	[Paragraph] = @sParagraph,
	[ReferenceParent] = @sReferenceParent,
	[Patent] = @sPatent,
	[ReferenceProcessId] = @sReferenceProcessId,
	[PublishedAt] = @sPublishedAt,
	[QMSReference] = @sQMSReference,
	[RecordNo] = @sRecordNo,
	[ReferenceRevision] = @sReferenceRevision,
	[ReferenceSection] = @sReferenceSection,
	[SectionNo] = @sSectionNo,
	[SerialNo] = @sSerialNo,
	[Standards] = @sStandards,
	[Summary] = @sSummary,
	[Trademark] = @sTrademark,
	[TRIMno] = @sTRIMno,
	[URLAlternative] = @sURLAlternative,
	[UNC] = @sUNC,
	[Verified] = @sVerified,
	[ReferenceVersion] = @sReferenceVersion,
	[YearPublished] = @sYearPublished,
	[Otheri] = @sOtheri,
	[Otherii] = @sOtherii,
	[IsHelp] = @bIsHelp,
	[IsInternal] = @bIsInternal,
	[RefFormID] = @iRefFormID,
	[RefFieldID] = @iRefFieldID,
	[HxContextID] = @iHxContextID,
	[HxPKeyID] = @iHxPKeyID,
	[ImageID] = @iImageID,
	[BusinessUnitID] = @iBusinessUnitID,
	[BusinessUnitContactID] = @iBusinessUnitContactID,
	[CentreInternalID] = @iCentreInternalID,
	[CustomNotificationID] = @iCustomNotificationID,
	[DoseAlertSettingID] = @iDoseAlertSettingID,
	[DoseReportTypeID] = @iDoseReportTypeID,
	[DxContactID] = @iDxContactID,
	[DxGroupID] = @iDxGroupID,
	[DxJobID] = @iDxJobID,
	[EquipmentID] = @iEquipmentID,
	[EquipmentDefectID] = @iEquipmentDefectID,
	[EquipmentServiceID] = @iEquipmentServiceID,
	[EquipmentSourceID] = @iEquipmentSourceID,
	[EquipmentTestID] = @iEquipmentTestID,
	[EquipmentWearerID] = @iEquipmentWearerID,
	[FileNoteID] = @iFileNoteID,
	[HxRoleID] = @iHxRoleID,
	[LicencePermitID] = @iLicencePermitID,
	[OrganisationID] = @iOrganisationID,
	[PregnancyID] = @iPregnancyID,
	[PremisesID] = @iPremisesID,
	[ProtectiveDeviceModelID] = @iProtectiveDeviceModelID,
	[ProtectiveDeviceModelSafetyAssessmentID] = @iProtectiveDeviceModelSafetyAssessmentID,
	[ProtectiveDeviceTestID] = @iProtectiveDeviceTestID,
	[ProviderID] = @iProviderID,
	[RadioNuclideID] = @iRadioNuclideID,
	[RoomID] = @iRoomID,
	[SiteLocationID] = @iSiteLocationID,
	[SourceID] = @iSourceID,
	[SpecificationID] = @iSpecificationID,
	[UserTemplateID] = @iUserTemplateID,
	[UserID] = @sUserID,
	[WearerInternalID] = @iWearerInternalID,
	[WearerLicenceID] = @iWearerLicenceID,
	[SortSequence] = @iSortSequence,
	[AddedBy] = @sAddedBy,
	[AddedDateTime] = @daAddedDateTime,
	[ModifiedBy] = @sModifiedBy,
	[ModifiedDateTime] = @daModifiedDateTime,
	[EquipmentModelID] = @iEquipmentModelID
WHERE
	[ReferenceID] = @iReferenceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iBusinessUnitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[BusinessUnitID] = @iBusinessUnitID
WHERE
	[BusinessUnitID] = @iBusinessUnitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWBusinessUnitContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWBusinessUnitContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWBusinessUnitContactIDLogic]
	@iBusinessUnitContactID int,
	@iBusinessUnitContactIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[BusinessUnitContactID] = @iBusinessUnitContactID
WHERE
	[BusinessUnitContactID] = @iBusinessUnitContactIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iCentreInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[CentreInternalID] = @iCentreInternalID
WHERE
	[CentreInternalID] = @iCentreInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWCustomNotificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWCustomNotificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWCustomNotificationIDLogic]
	@iCustomNotificationID int,
	@iCustomNotificationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[CustomNotificationID] = @iCustomNotificationID
WHERE
	[CustomNotificationID] = @iCustomNotificationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWDoseAlertSettingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWDoseAlertSettingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWDoseAlertSettingIDLogic]
	@iDoseAlertSettingID int,
	@iDoseAlertSettingIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[DoseAlertSettingID] = @iDoseAlertSettingID
WHERE
	[DoseAlertSettingID] = @iDoseAlertSettingIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWDoseReportTypeIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWDoseReportTypeIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWDoseReportTypeIDLogic]
	@iDoseReportTypeID int,
	@iDoseReportTypeIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[DoseReportTypeID] = @iDoseReportTypeID
WHERE
	[DoseReportTypeID] = @iDoseReportTypeIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWDxContactIDLogic]
	@iDxContactID int,
	@iDxContactIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[DxContactID] = @iDxContactID
WHERE
	[DxContactID] = @iDxContactIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iDxGroupIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[DxGroupID] = @iDxGroupID
WHERE
	[DxGroupID] = @iDxGroupIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iEquipmentIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentID] = @iEquipmentID
WHERE
	[EquipmentID] = @iEquipmentIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentDefectIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentDefectIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentDefectIDLogic]
	@iEquipmentDefectID int,
	@iEquipmentDefectIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentDefectID] = @iEquipmentDefectID
WHERE
	[EquipmentDefectID] = @iEquipmentDefectIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentServiceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentServiceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentServiceIDLogic]
	@iEquipmentServiceID int,
	@iEquipmentServiceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentServiceID] = @iEquipmentServiceID
WHERE
	[EquipmentServiceID] = @iEquipmentServiceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentSourceIDLogic]
	@iEquipmentSourceID int,
	@iEquipmentSourceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentSourceID] = @iEquipmentSourceID
WHERE
	[EquipmentSourceID] = @iEquipmentSourceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentTestIDLogic]
	@iEquipmentTestID int,
	@iEquipmentTestIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentTestID] = @iEquipmentTestID
WHERE
	[EquipmentTestID] = @iEquipmentTestIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentWearerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentWearerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentWearerIDLogic]
	@iEquipmentWearerID int,
	@iEquipmentWearerIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentWearerID] = @iEquipmentWearerID
WHERE
	[EquipmentWearerID] = @iEquipmentWearerIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWFileNoteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWFileNoteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWFileNoteIDLogic]
	@iFileNoteID int,
	@iFileNoteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[FileNoteID] = @iFileNoteID
WHERE
	[FileNoteID] = @iFileNoteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWHxRoleIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWHxRoleIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWHxRoleIDLogic]
	@iHxRoleID int,
	@iHxRoleIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[HxRoleID] = @iHxRoleID
WHERE
	[HxRoleID] = @iHxRoleIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iLicencePermitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[LicencePermitID] = @iLicencePermitID
WHERE
	[LicencePermitID] = @iLicencePermitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWPregnancyIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWPregnancyIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWPregnancyIDLogic]
	@iPregnancyID int,
	@iPregnancyIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[PregnancyID] = @iPregnancyID
WHERE
	[PregnancyID] = @iPregnancyIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWProtectiveDeviceModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWProtectiveDeviceModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWProtectiveDeviceModelIDLogic]
	@iProtectiveDeviceModelID int,
	@iProtectiveDeviceModelIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[ProtectiveDeviceModelID] = @iProtectiveDeviceModelID
WHERE
	[ProtectiveDeviceModelID] = @iProtectiveDeviceModelIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWProtectiveDeviceModelSafetyAssessmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWProtectiveDeviceModelSafetyAssessmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWProtectiveDeviceModelSafetyAssessmentIDLogic]
	@iProtectiveDeviceModelSafetyAssessmentID int,
	@iProtectiveDeviceModelSafetyAssessmentIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[ProtectiveDeviceModelSafetyAssessmentID] = @iProtectiveDeviceModelSafetyAssessmentID
WHERE
	[ProtectiveDeviceModelSafetyAssessmentID] = @iProtectiveDeviceModelSafetyAssessmentIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWProtectiveDeviceTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWProtectiveDeviceTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWProtectiveDeviceTestIDLogic]
	@iProtectiveDeviceTestID int,
	@iProtectiveDeviceTestIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[ProtectiveDeviceTestID] = @iProtectiveDeviceTestID
WHERE
	[ProtectiveDeviceTestID] = @iProtectiveDeviceTestIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWProviderIDLogic]
	@iProviderID int,
	@iProviderIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[ProviderID] = @iProviderID
WHERE
	[ProviderID] = @iProviderIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWRadioNuclideIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWRadioNuclideIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWRadioNuclideIDLogic]
	@iRadioNuclideID int,
	@iRadioNuclideIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[RadioNuclideID] = @iRadioNuclideID
WHERE
	[RadioNuclideID] = @iRadioNuclideIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWRoomIDLogic]
	@iRoomID int,
	@iRoomIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[RoomID] = @iRoomID
WHERE
	[RoomID] = @iRoomIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWSourceIDLogic]
	@iSourceID int,
	@iSourceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[SourceID] = @iSourceID
WHERE
	[SourceID] = @iSourceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWSpecificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWSpecificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWSpecificationIDLogic]
	@iSpecificationID int,
	@iSpecificationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[SpecificationID] = @iSpecificationID
WHERE
	[SpecificationID] = @iSpecificationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWUserTemplateIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWUserTemplateIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWUserTemplateIDLogic]
	@iUserTemplateID int,
	@iUserTemplateIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[UserTemplateID] = @iUserTemplateID
WHERE
	[UserTemplateID] = @iUserTemplateIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_UpdateAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_UpdateAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_UpdateAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iEquipmentModelIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblReference]
SET
	[EquipmentModelID] = @iEquipmentModelID
WHERE
	[EquipmentModelID] = @iEquipmentModelIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_Delete]
	@iReferenceID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblReference]
WHERE
	[ReferenceID] = @iReferenceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWBusinessUnitContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWBusinessUnitContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWBusinessUnitContactIDLogic]
	@iBusinessUnitContactID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[BusinessUnitContactID] = @iBusinessUnitContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWCustomNotificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWCustomNotificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWCustomNotificationIDLogic]
	@iCustomNotificationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[CustomNotificationID] = @iCustomNotificationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWDoseAlertSettingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWDoseAlertSettingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWDoseAlertSettingIDLogic]
	@iDoseAlertSettingID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[DoseAlertSettingID] = @iDoseAlertSettingID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWDoseReportTypeIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWDoseReportTypeIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWDoseReportTypeIDLogic]
	@iDoseReportTypeID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[DoseReportTypeID] = @iDoseReportTypeID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[DxGroupID] = @iDxGroupID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentDefectIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentDefectIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentDefectIDLogic]
	@iEquipmentDefectID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentDefectID] = @iEquipmentDefectID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentServiceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentServiceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentServiceIDLogic]
	@iEquipmentServiceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentServiceID] = @iEquipmentServiceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentSourceIDLogic]
	@iEquipmentSourceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentSourceID] = @iEquipmentSourceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentTestIDLogic]
	@iEquipmentTestID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentTestID] = @iEquipmentTestID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentWearerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentWearerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentWearerIDLogic]
	@iEquipmentWearerID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentWearerID] = @iEquipmentWearerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWFileNoteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWFileNoteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWFileNoteIDLogic]
	@iFileNoteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[FileNoteID] = @iFileNoteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWHxRoleIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWHxRoleIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWHxRoleIDLogic]
	@iHxRoleID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[HxRoleID] = @iHxRoleID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[LicencePermitID] = @iLicencePermitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWPregnancyIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWPregnancyIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWPregnancyIDLogic]
	@iPregnancyID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[PregnancyID] = @iPregnancyID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWProtectiveDeviceModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWProtectiveDeviceModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWProtectiveDeviceModelIDLogic]
	@iProtectiveDeviceModelID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[ProtectiveDeviceModelID] = @iProtectiveDeviceModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWProtectiveDeviceModelSafetyAssessmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWProtectiveDeviceModelSafetyAssessmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWProtectiveDeviceModelSafetyAssessmentIDLogic]
	@iProtectiveDeviceModelSafetyAssessmentID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[ProtectiveDeviceModelSafetyAssessmentID] = @iProtectiveDeviceModelSafetyAssessmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWProtectiveDeviceTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWProtectiveDeviceTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWProtectiveDeviceTestIDLogic]
	@iProtectiveDeviceTestID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[ProtectiveDeviceTestID] = @iProtectiveDeviceTestID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWProviderIDLogic]
	@iProviderID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[ProviderID] = @iProviderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWRadioNuclideIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWRadioNuclideIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWRadioNuclideIDLogic]
	@iRadioNuclideID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[RadioNuclideID] = @iRadioNuclideID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWSourceIDLogic]
	@iSourceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[SourceID] = @iSourceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWSpecificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWSpecificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWSpecificationIDLogic]
	@iSpecificationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[SpecificationID] = @iSpecificationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWUserTemplateIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWUserTemplateIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWUserTemplateIDLogic]
	@iUserTemplateID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[UserTemplateID] = @iUserTemplateID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_DeleteAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_DeleteAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_DeleteAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblReference]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectOne]
	@iReferenceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[ReferenceID] = @iReferenceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWBusinessUnitContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWBusinessUnitContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWBusinessUnitContactIDLogic]
	@iBusinessUnitContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[BusinessUnitContactID] = @iBusinessUnitContactID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[CentreInternalID] = @iCentreInternalID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWCustomNotificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWCustomNotificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWCustomNotificationIDLogic]
	@iCustomNotificationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[CustomNotificationID] = @iCustomNotificationID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWDoseAlertSettingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWDoseAlertSettingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWDoseAlertSettingIDLogic]
	@iDoseAlertSettingID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[DoseAlertSettingID] = @iDoseAlertSettingID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWDoseReportTypeIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWDoseReportTypeIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWDoseReportTypeIDLogic]
	@iDoseReportTypeID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[DoseReportTypeID] = @iDoseReportTypeID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[DxContactID] = @iDxContactID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[DxGroupID] = @iDxGroupID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentID] = @iEquipmentID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentDefectIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentDefectIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentDefectIDLogic]
	@iEquipmentDefectID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentDefectID] = @iEquipmentDefectID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentServiceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentServiceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentServiceIDLogic]
	@iEquipmentServiceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentServiceID] = @iEquipmentServiceID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentSourceIDLogic]
	@iEquipmentSourceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentSourceID] = @iEquipmentSourceID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentTestIDLogic]
	@iEquipmentTestID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentTestID] = @iEquipmentTestID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentWearerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentWearerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentWearerIDLogic]
	@iEquipmentWearerID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentWearerID] = @iEquipmentWearerID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWFileNoteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWFileNoteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWFileNoteIDLogic]
	@iFileNoteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[FileNoteID] = @iFileNoteID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWHxRoleIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWHxRoleIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWHxRoleIDLogic]
	@iHxRoleID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[HxRoleID] = @iHxRoleID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWLicencePermitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWLicencePermitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWLicencePermitIDLogic]
	@iLicencePermitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[LicencePermitID] = @iLicencePermitID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWPregnancyIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWPregnancyIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWPregnancyIDLogic]
	@iPregnancyID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[PregnancyID] = @iPregnancyID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWProtectiveDeviceModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWProtectiveDeviceModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWProtectiveDeviceModelIDLogic]
	@iProtectiveDeviceModelID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[ProtectiveDeviceModelID] = @iProtectiveDeviceModelID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWProtectiveDeviceModelSafetyAssessmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWProtectiveDeviceModelSafetyAssessmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWProtectiveDeviceModelSafetyAssessmentIDLogic]
	@iProtectiveDeviceModelSafetyAssessmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[ProtectiveDeviceModelSafetyAssessmentID] = @iProtectiveDeviceModelSafetyAssessmentID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWProtectiveDeviceTestIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWProtectiveDeviceTestIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWProtectiveDeviceTestIDLogic]
	@iProtectiveDeviceTestID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[ProtectiveDeviceTestID] = @iProtectiveDeviceTestID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWProviderIDLogic]
	@iProviderID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[ProviderID] = @iProviderID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWRadioNuclideIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWRadioNuclideIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWRadioNuclideIDLogic]
	@iRadioNuclideID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[RadioNuclideID] = @iRadioNuclideID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[RoomID] = @iRoomID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWSourceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWSourceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWSourceIDLogic]
	@iSourceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[SourceID] = @iSourceID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWSpecificationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWSpecificationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWSpecificationIDLogic]
	@iSpecificationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[SpecificationID] = @iSpecificationID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWUserTemplateIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWUserTemplateIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWUserTemplateIDLogic]
	@iUserTemplateID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[UserTemplateID] = @iUserTemplateID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblReference_SelectAllWEquipmentModelIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblReference_SelectAllWEquipmentModelIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblReference_SelectAllWEquipmentModelIDLogic]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblReference]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
ORDER BY 
	[ReferenceID] ASC
SELECT @iErrorCode=@@ERROR
GO




-- ===========================================================================================================
-- New SPROCS 
-- ===========================================================================================================

Print   '====================================================================================================='
GO
Print   ' '
GO
Print   'New SPROCS'
GO
Print   '====================================================================================================='
GO

Print ''
Go
Print 'Equipment Model Entity Level'
GO

SET NOCOUNT ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_Insert]
	@iManufacturerID int,
	@sModelName nvarchar(150),
	@sModelNumber nvarchar(30),
	@sModelNumberPrior nvarchar(30),
	@sModelCode nvarchar(30),
	@sModelDescription nvarchar(max),
	@iModelTypeID int,
	@sOtherModelType nvarchar(100),
	@iModelStatusID int,
	@sModelSeries nvarchar(100),
	@sModelCategory nvarchar(100),
	@sModelGenre nvarchar(100),
	@sOtherClassification nvarchar(50),
	@sGeneralSpecifications nvarchar(max),
	@sDeviceLifeExpectancy nvarchar(20),
	@sTypicalProcedure nvarchar(200),
	@dcPurchaseCost decimal(10, 2),
	@dcTestingCost decimal(10, 2),
	@dcReplacementCost decimal(10, 2),
	@iRequiredTestFrequencyMonths int,
	@iPlannedReplacementFrequencyYears int,
	@sDeviceModelOtherNote nvarchar(max),
	@iDeviceModelFlagFollowup int,
	@sOtherCodeOrNumber nvarchar(50),
	@daDateCommissioned datetime,
	@daDateDecommissioned datetime,
	@sModelNotes nvarchar(max),
	@iEquipmentModelID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblEquipmentModel]
(
	[ManufacturerID],
	[ModelName],
	[ModelNumber],
	[ModelNumberPrior],
	[ModelCode],
	[ModelDescription],
	[ModelTypeID],
	[OtherModelType],
	[ModelStatusID],
	[ModelSeries],
	[ModelCategory],
	[ModelGenre],
	[OtherClassification],
	[GeneralSpecifications],
	[DeviceLifeExpectancy],
	[TypicalProcedure],
	[PurchaseCost],
	[TestingCost],
	[ReplacementCost],
	[RequiredTestFrequencyMonths],
	[PlannedReplacementFrequencyYears],
	[DeviceModelOtherNote],
	[DeviceModelFlagFollowup],
	[OtherCodeOrNumber],
	[DateCommissioned],
	[DateDecommissioned],
	[ModelNotes]
)
VALUES
(
	@iManufacturerID,
	@sModelName,
	@sModelNumber,
	@sModelNumberPrior,
	@sModelCode,
	@sModelDescription,
	@iModelTypeID,
	@sOtherModelType,
	ISNULL(@iModelStatusID, ((1))),
	@sModelSeries,
	@sModelCategory,
	@sModelGenre,
	@sOtherClassification,
	@sGeneralSpecifications,
	@sDeviceLifeExpectancy,
	@sTypicalProcedure,
	@dcPurchaseCost,
	@dcTestingCost,
	@dcReplacementCost,
	@iRequiredTestFrequencyMonths,
	@iPlannedReplacementFrequencyYears,
	@sDeviceModelOtherNote,
	@iDeviceModelFlagFollowup,
	@sOtherCodeOrNumber,
	@daDateCommissioned,
	@daDateDecommissioned,
	@sModelNotes
)
SELECT @iErrorCode=@@ERROR
SELECT @iEquipmentModelID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_Update]
	@iEquipmentModelID int,
	@iManufacturerID int,
	@sModelName nvarchar(150),
	@sModelNumber nvarchar(30),
	@sModelNumberPrior nvarchar(30),
	@sModelCode nvarchar(30),
	@sModelDescription nvarchar(max),
	@iModelTypeID int,
	@sOtherModelType nvarchar(100),
	@iModelStatusID int,
	@sModelSeries nvarchar(100),
	@sModelCategory nvarchar(100),
	@sModelGenre nvarchar(100),
	@sOtherClassification nvarchar(50),
	@sGeneralSpecifications nvarchar(max),
	@sDeviceLifeExpectancy nvarchar(20),
	@sTypicalProcedure nvarchar(200),
	@dcPurchaseCost decimal(10, 2),
	@dcTestingCost decimal(10, 2),
	@dcReplacementCost decimal(10, 2),
	@iRequiredTestFrequencyMonths int,
	@iPlannedReplacementFrequencyYears int,
	@sDeviceModelOtherNote nvarchar(max),
	@iDeviceModelFlagFollowup int,
	@sOtherCodeOrNumber nvarchar(50),
	@daDateCommissioned datetime,
	@daDateDecommissioned datetime,
	@sModelNotes nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipmentModel]
SET 
	[ManufacturerID] = @iManufacturerID,
	[ModelName] = @sModelName,
	[ModelNumber] = @sModelNumber,
	[ModelNumberPrior] = @sModelNumberPrior,
	[ModelCode] = @sModelCode,
	[ModelDescription] = @sModelDescription,
	[ModelTypeID] = @iModelTypeID,
	[OtherModelType] = @sOtherModelType,
	[ModelStatusID] = @iModelStatusID,
	[ModelSeries] = @sModelSeries,
	[ModelCategory] = @sModelCategory,
	[ModelGenre] = @sModelGenre,
	[OtherClassification] = @sOtherClassification,
	[GeneralSpecifications] = @sGeneralSpecifications,
	[DeviceLifeExpectancy] = @sDeviceLifeExpectancy,
	[TypicalProcedure] = @sTypicalProcedure,
	[PurchaseCost] = @dcPurchaseCost,
	[TestingCost] = @dcTestingCost,
	[ReplacementCost] = @dcReplacementCost,
	[RequiredTestFrequencyMonths] = @iRequiredTestFrequencyMonths,
	[PlannedReplacementFrequencyYears] = @iPlannedReplacementFrequencyYears,
	[DeviceModelOtherNote] = @sDeviceModelOtherNote,
	[DeviceModelFlagFollowup] = @iDeviceModelFlagFollowup,
	[OtherCodeOrNumber] = @sOtherCodeOrNumber,
	[DateCommissioned] = @daDateCommissioned,
	[DateDecommissioned] = @daDateDecommissioned,
	[ModelNotes] = @sModelNotes
WHERE
	[EquipmentModelID] = @iEquipmentModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_UpdateAllWManufacturerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_UpdateAllWManufacturerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_UpdateAllWManufacturerIDLogic]
	@iManufacturerID int,
	@iManufacturerIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipmentModel]
SET
	[ManufacturerID] = @iManufacturerID
WHERE
	[ManufacturerID] = @iManufacturerIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_Delete]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblEquipmentModel]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_DeleteAllWManufacturerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_DeleteAllWManufacturerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_DeleteAllWManufacturerIDLogic]
	@iManufacturerID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipmentModel]
WHERE
	[ManufacturerID] = @iManufacturerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_SelectOne]
	@iEquipmentModelID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentModel]
WHERE
	[EquipmentModelID] = @iEquipmentModelID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentModel]
ORDER BY 
	[EquipmentModelID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentModel_SelectAllWManufacturerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentModel_SelectAllWManufacturerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentModel_SelectAllWManufacturerIDLogic]
	@iManufacturerID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentModel]
WHERE
	[ManufacturerID] = @iManufacturerID
ORDER BY 
	[EquipmentModelID] ASC
SELECT @iErrorCode=@@ERROR
GO



-- ===================================================================================================================
-- New SPROCS
-- ===================================================================================================================

-- vwEquipmentModels --------------------------------------------------------------------

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwEquipmentModels_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwEquipmentModels_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwEquipmentModels_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwEquipmentModels]
SELECT @iErrorCode=@@ERROR
GO




-- ===============


SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwLicencesPermits_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwLicencesPermits_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwLicencesPermits_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwLicencesPermits]
SELECT @iErrorCode=@@ERROR
GO

-- tblSourceRefItem Revised Structure
SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSourceRefItem_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSourceRefItem_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblSourceRefItem_Insert]
	@iPrimaryTypeID int,
	@iHxSourceTypeID int,
	@iSourceID int,
	@iRefItemTypeID int,
	@iSourceRefItemID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblSourceRefItem]
(
	[PrimaryTypeID],
	[HxSourceTypeID],
	[SourceID],
	[RefItemTypeID]
)
VALUES
(
	@iPrimaryTypeID,
	@iHxSourceTypeID,
	@iSourceID,
	@iRefItemTypeID
)
SELECT @iErrorCode=@@ERROR
SELECT @iSourceRefItemID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSourceRefItem_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSourceRefItem_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblSourceRefItem_Update]
	@iSourceRefItemID int,
	@iPrimaryTypeID int,
	@iHxSourceTypeID int,
	@iSourceID int,
	@iRefItemTypeID int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblSourceRefItem]
SET 
	[PrimaryTypeID] = @iPrimaryTypeID,
	[HxSourceTypeID] = @iHxSourceTypeID,
	[SourceID] = @iSourceID,
	[RefItemTypeID] = @iRefItemTypeID
WHERE
	[SourceRefItemID] = @iSourceRefItemID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSourceRefItem_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSourceRefItem_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblSourceRefItem_Delete]
	@iSourceRefItemID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblSourceRefItem]
WHERE
	[SourceRefItemID] = @iSourceRefItemID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSourceRefItem_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSourceRefItem_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblSourceRefItem_SelectOne]
	@iSourceRefItemID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblSourceRefItem]
WHERE
	[SourceRefItemID] = @iSourceRefItemID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSourceRefItem_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSourceRefItem_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblSourceRefItem_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblSourceRefItem]
ORDER BY 
	[SourceRefItemID] ASC
SELECT @iErrorCode=@@ERROR
GO

-- Final Business Unit, Premises, Room, Site Location and their contact tables revisions


-- ----------------------------------------------------------------


SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnit_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblBusinessUnit_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblBusinessUnit_Insert]
	@sBusinessUnitName nvarchar(max),
	@sBusinessUnitDescription nvarchar(max),
	@sBusinessUnitOther nvarchar(max),
	@sBusinessUnitNote nvarchar(max),
	@daStartDate datetime,
	@daEndDate datetime,
	@iBusinessUnitID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblBusinessUnit]
(
	[BusinessUnitName],
	[BusinessUnitDescription],
	[BusinessUnitOther],
	[BusinessUnitNote],
	[StartDate],
	[EndDate]
)
VALUES
(
	@sBusinessUnitName,
	@sBusinessUnitDescription,
	@sBusinessUnitOther,
	@sBusinessUnitNote,
	@daStartDate,
	@daEndDate
)
SELECT @iErrorCode=@@ERROR
SELECT @iBusinessUnitID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnit_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblBusinessUnit_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblBusinessUnit_Update]
	@iBusinessUnitID int,
	@sBusinessUnitName nvarchar(max),
	@sBusinessUnitDescription nvarchar(max),
	@sBusinessUnitOther nvarchar(max),
	@sBusinessUnitNote nvarchar(max),
	@daStartDate datetime,
	@daEndDate datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblBusinessUnit]
SET 
	[BusinessUnitName] = @sBusinessUnitName,
	[BusinessUnitDescription] = @sBusinessUnitDescription,
	[BusinessUnitOther] = @sBusinessUnitOther,
	[BusinessUnitNote] = @sBusinessUnitNote,
	[StartDate] = @daStartDate,
	[EndDate] = @daEndDate
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnit_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblBusinessUnit_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblBusinessUnit_Delete]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblBusinessUnit]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnit_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblBusinessUnit_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblBusinessUnit_SelectOne]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblBusinessUnit]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblBusinessUnit_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblBusinessUnit_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblBusinessUnit_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblBusinessUnit]
ORDER BY 
	[BusinessUnitID] ASC
SELECT @iErrorCode=@@ERROR
GO


-- ==============================================================================================
-- tblPremises replacement SPROCS
-- ==============================================================================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_Insert]
	@daDateRegistered datetime,
	@sNameOfPremises nvarchar(100),
	@sClassification nvarchar(30),
	@sType nvarchar(30),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@sPremisesNotes nvarchar(max),
	@iSiteLocationID int,
	@iLocalPremisesID int,
	@sAltLocalPremisesID nvarchar(20),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sPremisesDescription nvarchar(max),
	@sPremisesLocalGroup nvarchar(40),
	@sPremisesLocalCategory nvarchar(40),
	@daStartDate datetime,
	@daEndDate datetime,
	@iPremisesID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblPremises]
(
	[DateRegistered],
	[NameOfPremises],
	[Classification],
	[Type],
	[RegAuthorityIDNo],
	[LicenceNumber],
	[PremisesNotes],
	[SiteLocationID],
	[LocalPremisesID],
	[AltLocalPremisesID],
	[Latitude],
	[Longitude],
	[PremisesDescription],
	[PremisesLocalGroup],
	[PremisesLocalCategory],
	[StartDate],
	[EndDate]
)
VALUES
(
	@daDateRegistered,
	@sNameOfPremises,
	@sClassification,
	@sType,
	@sRegAuthorityIDNo,
	@sLicenceNumber,
	@sPremisesNotes,
	@iSiteLocationID,
	@iLocalPremisesID,
	@sAltLocalPremisesID,
	@sLatitude,
	@sLongitude,
	@sPremisesDescription,
	@sPremisesLocalGroup,
	@sPremisesLocalCategory,
	@daStartDate,
	@daEndDate
)
SELECT @iErrorCode=@@ERROR
SELECT @iPremisesID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_Update]
	@iPremisesID int,
	@daDateRegistered datetime,
	@sNameOfPremises nvarchar(100),
	@sClassification nvarchar(30),
	@sType nvarchar(30),
	@sRegAuthorityIDNo nvarchar(30),
	@sLicenceNumber nvarchar(30),
	@sPremisesNotes nvarchar(max),
	@iSiteLocationID int,
	@iLocalPremisesID int,
	@sAltLocalPremisesID nvarchar(20),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@sPremisesDescription nvarchar(max),
	@sPremisesLocalGroup nvarchar(40),
	@sPremisesLocalCategory nvarchar(40),
	@daStartDate datetime,
	@daEndDate datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblPremises]
SET 
	[DateRegistered] = @daDateRegistered,
	[NameOfPremises] = @sNameOfPremises,
	[Classification] = @sClassification,
	[Type] = @sType,
	[RegAuthorityIDNo] = @sRegAuthorityIDNo,
	[LicenceNumber] = @sLicenceNumber,
	[PremisesNotes] = @sPremisesNotes,
	[SiteLocationID] = @iSiteLocationID,
	[LocalPremisesID] = @iLocalPremisesID,
	[AltLocalPremisesID] = @sAltLocalPremisesID,
	[Latitude] = @sLatitude,
	[Longitude] = @sLongitude,
	[PremisesDescription] = @sPremisesDescription,
	[PremisesLocalGroup] = @sPremisesLocalGroup,
	[PremisesLocalCategory] = @sPremisesLocalCategory,
	[StartDate] = @daStartDate,
	[EndDate] = @daEndDate
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblPremises]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_Delete]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblPremises]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblPremises]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_SelectOne]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblPremises]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblPremises]
ORDER BY 
	[PremisesID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblPremises_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblPremises_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblPremises_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblPremises]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[PremisesID] ASC
SELECT @iErrorCode=@@ERROR
GO



-- ==============================================================================================
-- End tblPremises replacement SPROCS
-- ==============================================================================================



if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_Insert]
	@iRoomTypeID int,
	@iPremisesID int,
	@sRoomName nvarchar(100),
	@sRoomNumber nvarchar(20),
	@sRoomCode nvarchar(20),
	@sFloorLevel nvarchar(20),
	@iLocalRoomID int,
	@sAltLocalRoomID nvarchar(20),
	@sRoomDescription nvarchar(max),
	@sCapacity nvarchar(40),
	@sDimensions nvarchar(40),
	@sVentilation nvarchar(200),
	@sSafetyFeatures nvarchar(max),
	@sEmergencyAssembly nvarchar(max),
	@sRoomNotes nvarchar(max),
	@sRoomLocalGroup nvarchar(40),
	@sRoomLocalCategory nvarchar(40),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@daStartDate datetime,
	@daEndDate datetime,
	@iRoomID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblRoom]
(
	[RoomTypeID],
	[PremisesID],
	[RoomName],
	[RoomNumber],
	[RoomCode],
	[FloorLevel],
	[LocalRoomID],
	[AltLocalRoomID],
	[RoomDescription],
	[Capacity],
	[Dimensions],
	[Ventilation],
	[SafetyFeatures],
	[EmergencyAssembly],
	[RoomNotes],
	[RoomLocalGroup],
	[RoomLocalCategory],
	[Latitude],
	[Longitude],
	[StartDate],
	[EndDate]
)
VALUES
(
	@iRoomTypeID,
	@iPremisesID,
	@sRoomName,
	@sRoomNumber,
	@sRoomCode,
	@sFloorLevel,
	@iLocalRoomID,
	@sAltLocalRoomID,
	@sRoomDescription,
	@sCapacity,
	@sDimensions,
	@sVentilation,
	@sSafetyFeatures,
	@sEmergencyAssembly,
	@sRoomNotes,
	@sRoomLocalGroup,
	@sRoomLocalCategory,
	@sLatitude,
	@sLongitude,
	@daStartDate,
	@daEndDate
)
SELECT @iErrorCode=@@ERROR
SELECT @iRoomID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_Update]
	@iRoomID int,
	@iRoomTypeID int,
	@iPremisesID int,
	@sRoomName nvarchar(100),
	@sRoomNumber nvarchar(20),
	@sRoomCode nvarchar(20),
	@sFloorLevel nvarchar(20),
	@iLocalRoomID int,
	@sAltLocalRoomID nvarchar(20),
	@sRoomDescription nvarchar(max),
	@sCapacity nvarchar(40),
	@sDimensions nvarchar(40),
	@sVentilation nvarchar(200),
	@sSafetyFeatures nvarchar(max),
	@sEmergencyAssembly nvarchar(max),
	@sRoomNotes nvarchar(max),
	@sRoomLocalGroup nvarchar(40),
	@sRoomLocalCategory nvarchar(40),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@daStartDate datetime,
	@daEndDate datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblRoom]
SET 
	[RoomTypeID] = @iRoomTypeID,
	[PremisesID] = @iPremisesID,
	[RoomName] = @sRoomName,
	[RoomNumber] = @sRoomNumber,
	[RoomCode] = @sRoomCode,
	[FloorLevel] = @sFloorLevel,
	[LocalRoomID] = @iLocalRoomID,
	[AltLocalRoomID] = @sAltLocalRoomID,
	[RoomDescription] = @sRoomDescription,
	[Capacity] = @sCapacity,
	[Dimensions] = @sDimensions,
	[Ventilation] = @sVentilation,
	[SafetyFeatures] = @sSafetyFeatures,
	[EmergencyAssembly] = @sEmergencyAssembly,
	[RoomNotes] = @sRoomNotes,
	[RoomLocalGroup] = @sRoomLocalGroup,
	[RoomLocalCategory] = @sRoomLocalCategory,
	[Latitude] = @sLatitude,
	[Longitude] = @sLongitude,
	[StartDate] = @daStartDate,
	[EndDate] = @daEndDate
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblRoom]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_Delete]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblRoom]
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblRoom]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_SelectOne]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblRoom]
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblRoom]
ORDER BY 
	[RoomID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblRoom_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblRoom_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblRoom_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblRoom]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[RoomID] ASC
SELECT @iErrorCode=@@ERROR
GO

-- ==================================================================
-- tblSiteLocation replacement SPROCS
-- ==================================================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSiteLocation_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSiteLocation_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblSiteLocation_Insert]
	@sSiteLocationName nvarchar(max),
	@sSiteLocationDescription nvarchar(max),
	@sSiteLocationNote nvarchar(max),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@iCampusID int,
	@iLocalSiteLocationID int,
	@sAltLocalSiteLocationID nvarchar(20),
	@iRegionID int,
	@sSiteLocationLocalGroup nvarchar(40),
	@sSiteLocationLocalCategory nvarchar(40),
	@iSiteLocationID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblSiteLocation]
(
	[SiteLocationName],
	[SiteLocationDescription],
	[SiteLocationNote],
	[Latitude],
	[Longitude],
	[CampusID],
	[LocalSiteLocationID],
	[AltLocalSiteLocationID],
	[RegionID],
	[SiteLocationLocalGroup],
	[SiteLocationLocalCategory]
)
VALUES
(
	@sSiteLocationName,
	@sSiteLocationDescription,
	@sSiteLocationNote,
	@sLatitude,
	@sLongitude,
	@iCampusID,
	@iLocalSiteLocationID,
	@sAltLocalSiteLocationID,
	@iRegionID,
	@sSiteLocationLocalGroup,
	@sSiteLocationLocalCategory
)
SELECT @iErrorCode=@@ERROR
SELECT @iSiteLocationID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSiteLocation_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSiteLocation_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblSiteLocation_Update]
	@iSiteLocationID int,
	@sSiteLocationName nvarchar(max),
	@sSiteLocationDescription nvarchar(max),
	@sSiteLocationNote nvarchar(max),
	@sLatitude nvarchar(20),
	@sLongitude nvarchar(20),
	@iCampusID int,
	@iLocalSiteLocationID int,
	@sAltLocalSiteLocationID nvarchar(20),
	@iRegionID int,
	@sSiteLocationLocalGroup nvarchar(40),
	@sSiteLocationLocalCategory nvarchar(40),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblSiteLocation]
SET 
	[SiteLocationName] = @sSiteLocationName,
	[SiteLocationDescription] = @sSiteLocationDescription,
	[SiteLocationNote] = @sSiteLocationNote,
	[Latitude] = @sLatitude,
	[Longitude] = @sLongitude,
	[CampusID] = @iCampusID,
	[LocalSiteLocationID] = @iLocalSiteLocationID,
	[AltLocalSiteLocationID] = @sAltLocalSiteLocationID,
	[RegionID] = @iRegionID,
	[SiteLocationLocalGroup] = @sSiteLocationLocalGroup,
	[SiteLocationLocalCategory] = @sSiteLocationLocalCategory
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSiteLocation_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSiteLocation_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblSiteLocation_Delete]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblSiteLocation]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSiteLocation_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSiteLocation_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblSiteLocation_SelectOne]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblSiteLocation]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblSiteLocation_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblSiteLocation_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblSiteLocation_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblSiteLocation]
ORDER BY 
	[SiteLocationID] ASC
SELECT @iErrorCode=@@ERROR
GO



-- ==================================================================
-- End SiteLocation replacement SPROCS
-- ==================================================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwContactNames_SelectOneWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwContactNames_SelectOneWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_vwContactNames_SelectOneWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwContactNames]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwContactNames_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwContactNames_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwContactNames_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwContactNames]
SELECT @iErrorCode=@@ERROR
GO

-- ----------------------------------------

SET NOCOUNT ON
GO

GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwSiteLocationContacts_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwSiteLocationContacts_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwSiteLocationContacts_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwSiteLocationContacts]
SELECT @iErrorCode=@@ERROR
GO


-- ----------------------------------------

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwPostcodes_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwPostcodes_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwPostcodes_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwPostcodes]
SELECT @iErrorCode=@@ERROR
GO

-- ====================================
-- Dx related changes/new SPROCS
-- ====================================


SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_Insert]
	@iDxContactID int,
	@iOrganisationID int,
	@iSiteLocationID int,
	@bIsActive bit,
	@iPrivacyRating int,
	@iAddressContext int,
	@iAddressType int,
	@sAddressLine1 nvarchar(max),
	@sAddressLine2 nvarchar(max),
	@sSuburb nvarchar(max),
	@sState nvarchar(max),
	@sPostcode nvarchar(max),
	@iCountryCode int,
	@sAddressOther nvarchar(max),
	@sUseNote nvarchar(max),
	@iListPriority int,
	@iDxAddressID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxAddress]
(
	[DxContactID],
	[OrganisationID],
	[SiteLocationID],
	[IsActive],
	[PrivacyRating],
	[AddressContext],
	[AddressType],
	[AddressLine1],
	[AddressLine2],
	[Suburb],
	[State],
	[Postcode],
	[CountryCode],
	[AddressOther],
	[UseNote],
	[ListPriority]
)
VALUES
(
	@iDxContactID,
	@iOrganisationID,
	@iSiteLocationID,
	@bIsActive,
	@iPrivacyRating,
	@iAddressContext,
	@iAddressType,
	@sAddressLine1,
	@sAddressLine2,
	@sSuburb,
	@sState,
	@sPostcode,
	@iCountryCode,
	@sAddressOther,
	@sUseNote,
	@iListPriority
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxAddressID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_Update]
	@iDxAddressID int,
	@iDxContactID int,
	@iOrganisationID int,
	@iSiteLocationID int,
	@bIsActive bit,
	@iPrivacyRating int,
	@iAddressContext int,
	@iAddressType int,
	@sAddressLine1 nvarchar(max),
	@sAddressLine2 nvarchar(max),
	@sSuburb nvarchar(max),
	@sState nvarchar(max),
	@sPostcode nvarchar(max),
	@iCountryCode int,
	@sAddressOther nvarchar(max),
	@sUseNote nvarchar(max),
	@iListPriority int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxAddress]
SET 
	[DxContactID] = @iDxContactID,
	[OrganisationID] = @iOrganisationID,
	[SiteLocationID] = @iSiteLocationID,
	[IsActive] = @bIsActive,
	[PrivacyRating] = @iPrivacyRating,
	[AddressContext] = @iAddressContext,
	[AddressType] = @iAddressType,
	[AddressLine1] = @sAddressLine1,
	[AddressLine2] = @sAddressLine2,
	[Suburb] = @sSuburb,
	[State] = @sState,
	[Postcode] = @sPostcode,
	[CountryCode] = @iCountryCode,
	[AddressOther] = @sAddressOther,
	[UseNote] = @sUseNote,
	[ListPriority] = @iListPriority
WHERE
	[DxAddressID] = @iDxAddressID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_UpdateAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_UpdateAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_UpdateAllWDxContactIDLogic]
	@iDxContactID int,
	@iDxContactIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxAddress]
SET
	[DxContactID] = @iDxContactID
WHERE
	[DxContactID] = @iDxContactIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxAddress]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxAddress]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_Delete]
	@iDxAddressID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxAddress]
WHERE
	[DxAddressID] = @iDxAddressID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_DeleteAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_DeleteAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_DeleteAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxAddress]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxAddress]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxAddress]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_SelectOne]
	@iDxAddressID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxAddress]
WHERE
	[DxAddressID] = @iDxAddressID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxAddress]
ORDER BY 
	[DxAddressID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_SelectAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_SelectAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_SelectAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxAddress]
WHERE
	[DxContactID] = @iDxContactID
ORDER BY 
	[DxAddressID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxAddress]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[DxAddressID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxAddress_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxAddress_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxAddress_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxAddress]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[DxAddressID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxConfig_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxConfig_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxConfig_Insert]
	@daDisallowJobsFromTime1 datetime,
	@daDisallowJobsToTime1 datetime,
	@daDisallowJobsFromTime2 datetime,
	@daDisallowJobsToTime2 datetime,
	@iDisallowJobsOnWeekday1 int,
	@iDisallowJobsOnWeekday2 int,
	@sSMTPServer nvarchar(200),
	@iSMTPPort int,
	@bSMTPAuthenticate bit,
	@sSMTPUserName varchar(max),
	@sSMTPPassword varchar(max),
	@sSMTPEmailFromAddress nvarchar(200),
	@bSMTPUseSSL bit,
	@iJobCheckLeadTimeHrs int,
	@iDeleteEmailsAfterHrs int,
	@bUseVerboseEventLoggingWindows bit,
	@bUseVerboseEventLoggingDiagnostic bit,
	@iSecTimerHeartbeatLength int,
	@iScheduleTimerHeartbeats int,
	@iFetchQueueMinsJobs int,
	@iFetchQueueHoursJobs int,
	@iFetchQueueDaysJobs int,
	@iFetchQueueWeeksJobs int,
	@iFetchQueueMonthsJobs int,
	@iFetchQueueYearsJobs int,
	@iRetainQueueMinsJobs int,
	@iRetainQueueHoursJobs int,
	@iRetainQueueDaysJobs int,
	@iRetainQueueWeeksJobs int,
	@iRetainQueueMonthsJobs int,
	@iRetainQueueYearsJobs int,
	@iDxConfigID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxConfig]
(
	[DisallowJobsFromTime1],
	[DisallowJobsToTime1],
	[DisallowJobsFromTime2],
	[DisallowJobsToTime2],
	[DisallowJobsOnWeekday1],
	[DisallowJobsOnWeekday2],
	[SMTPServer],
	[SMTPPort],
	[SMTPAuthenticate],
	[SMTPUserName],
	[SMTPPassword],
	[SMTPEmailFromAddress],
	[SMTPUseSSL],
	[JobCheckLeadTimeHrs],
	[DeleteEmailsAfterHrs],
	[UseVerboseEventLoggingWindows],
	[UseVerboseEventLoggingDiagnostic],
	[SecTimerHeartbeatLength],
	[ScheduleTimerHeartbeats],
	[FetchQueueMinsJobs],
	[FetchQueueHoursJobs],
	[FetchQueueDaysJobs],
	[FetchQueueWeeksJobs],
	[FetchQueueMonthsJobs],
	[FetchQueueYearsJobs],
	[RetainQueueMinsJobs],
	[RetainQueueHoursJobs],
	[RetainQueueDaysJobs],
	[RetainQueueWeeksJobs],
	[RetainQueueMonthsJobs],
	[RetainQueueYearsJobs]
)
VALUES
(
	@daDisallowJobsFromTime1,
	@daDisallowJobsToTime1,
	@daDisallowJobsFromTime2,
	@daDisallowJobsToTime2,
	@iDisallowJobsOnWeekday1,
	@iDisallowJobsOnWeekday2,
	@sSMTPServer,
	@iSMTPPort,
	ISNULL(@bSMTPAuthenticate, ((0))),
	@sSMTPUserName,
	@sSMTPPassword,
	@sSMTPEmailFromAddress,
	ISNULL(@bSMTPUseSSL, ((0))),
	ISNULL(@iJobCheckLeadTimeHrs, ((24))),
	ISNULL(@iDeleteEmailsAfterHrs, ((24))),
	@bUseVerboseEventLoggingWindows,
	@bUseVerboseEventLoggingDiagnostic,
	@iSecTimerHeartbeatLength,
	@iScheduleTimerHeartbeats,
	@iFetchQueueMinsJobs,
	@iFetchQueueHoursJobs,
	@iFetchQueueDaysJobs,
	@iFetchQueueWeeksJobs,
	@iFetchQueueMonthsJobs,
	@iFetchQueueYearsJobs,
	@iRetainQueueMinsJobs,
	@iRetainQueueHoursJobs,
	@iRetainQueueDaysJobs,
	@iRetainQueueWeeksJobs,
	@iRetainQueueMonthsJobs,
	@iRetainQueueYearsJobs
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxConfigID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxConfig_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxConfig_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxConfig_Update]
	@iDxConfigID int,
	@daDisallowJobsFromTime1 datetime,
	@daDisallowJobsToTime1 datetime,
	@daDisallowJobsFromTime2 datetime,
	@daDisallowJobsToTime2 datetime,
	@iDisallowJobsOnWeekday1 int,
	@iDisallowJobsOnWeekday2 int,
	@sSMTPServer nvarchar(200),
	@iSMTPPort int,
	@bSMTPAuthenticate bit,
	@sSMTPUserName varchar(max),
	@sSMTPPassword varchar(max),
	@sSMTPEmailFromAddress nvarchar(200),
	@bSMTPUseSSL bit,
	@iJobCheckLeadTimeHrs int,
	@iDeleteEmailsAfterHrs int,
	@bUseVerboseEventLoggingWindows bit,
	@bUseVerboseEventLoggingDiagnostic bit,
	@iSecTimerHeartbeatLength int,
	@iScheduleTimerHeartbeats int,
	@iFetchQueueMinsJobs int,
	@iFetchQueueHoursJobs int,
	@iFetchQueueDaysJobs int,
	@iFetchQueueWeeksJobs int,
	@iFetchQueueMonthsJobs int,
	@iFetchQueueYearsJobs int,
	@iRetainQueueMinsJobs int,
	@iRetainQueueHoursJobs int,
	@iRetainQueueDaysJobs int,
	@iRetainQueueWeeksJobs int,
	@iRetainQueueMonthsJobs int,
	@iRetainQueueYearsJobs int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxConfig]
SET 
	[DisallowJobsFromTime1] = @daDisallowJobsFromTime1,
	[DisallowJobsToTime1] = @daDisallowJobsToTime1,
	[DisallowJobsFromTime2] = @daDisallowJobsFromTime2,
	[DisallowJobsToTime2] = @daDisallowJobsToTime2,
	[DisallowJobsOnWeekday1] = @iDisallowJobsOnWeekday1,
	[DisallowJobsOnWeekday2] = @iDisallowJobsOnWeekday2,
	[SMTPServer] = @sSMTPServer,
	[SMTPPort] = @iSMTPPort,
	[SMTPAuthenticate] = @bSMTPAuthenticate,
	[SMTPUserName] = @sSMTPUserName,
	[SMTPPassword] = @sSMTPPassword,
	[SMTPEmailFromAddress] = @sSMTPEmailFromAddress,
	[SMTPUseSSL] = @bSMTPUseSSL,
	[JobCheckLeadTimeHrs] = @iJobCheckLeadTimeHrs,
	[DeleteEmailsAfterHrs] = @iDeleteEmailsAfterHrs,
	[UseVerboseEventLoggingWindows] = @bUseVerboseEventLoggingWindows,
	[UseVerboseEventLoggingDiagnostic] = @bUseVerboseEventLoggingDiagnostic,
	[SecTimerHeartbeatLength] = @iSecTimerHeartbeatLength,
	[ScheduleTimerHeartbeats] = @iScheduleTimerHeartbeats,
	[FetchQueueMinsJobs] = @iFetchQueueMinsJobs,
	[FetchQueueHoursJobs] = @iFetchQueueHoursJobs,
	[FetchQueueDaysJobs] = @iFetchQueueDaysJobs,
	[FetchQueueWeeksJobs] = @iFetchQueueWeeksJobs,
	[FetchQueueMonthsJobs] = @iFetchQueueMonthsJobs,
	[FetchQueueYearsJobs] = @iFetchQueueYearsJobs,
	[RetainQueueMinsJobs] = @iRetainQueueMinsJobs,
	[RetainQueueHoursJobs] = @iRetainQueueHoursJobs,
	[RetainQueueDaysJobs] = @iRetainQueueDaysJobs,
	[RetainQueueWeeksJobs] = @iRetainQueueWeeksJobs,
	[RetainQueueMonthsJobs] = @iRetainQueueMonthsJobs,
	[RetainQueueYearsJobs] = @iRetainQueueYearsJobs
WHERE
	[DxConfigID] = @iDxConfigID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxConfig_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxConfig_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxConfig_Delete]
	@iDxConfigID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxConfig]
WHERE
	[DxConfigID] = @iDxConfigID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxConfig_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxConfig_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxConfig_SelectOne]
	@iDxConfigID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxConfig]
WHERE
	[DxConfigID] = @iDxConfigID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxConfig_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxConfig_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxConfig_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxConfig]
ORDER BY 
	[DxConfigID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_Insert]
	@bIsActive bit,
	@iDetailSetting int,
	@iPrivacyRating int,
	@iWearerInternalID int,
	@sUserID varchar(50),
	@sTitle nvarchar(100),
	@sFirstName nvarchar(max),
	@sSurname nvarchar(max),
	@sOtherGivenNames nvarchar(max),
	@sSex nvarchar(1),
	@daDOB datetime,
	@sNotes nvarchar(max),
	@iDxContactID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxContact]
(
	[IsActive],
	[DetailSetting],
	[PrivacyRating],
	[WearerInternalID],
	[UserID],
	[Title],
	[FirstName],
	[Surname],
	[OtherGivenNames],
	[Sex],
	[DOB],
	[Notes]
)
VALUES
(
	ISNULL(@bIsActive, ((1))),
	ISNULL(@iDetailSetting, ((1))),
	@iPrivacyRating,
	@iWearerInternalID,
	@sUserID,
	@sTitle,
	@sFirstName,
	@sSurname,
	@sOtherGivenNames,
	@sSex,
	@daDOB,
	@sNotes
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxContactID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_Update]
	@iDxContactID int,
	@bIsActive bit,
	@iDetailSetting int,
	@iPrivacyRating int,
	@iWearerInternalID int,
	@sUserID varchar(50),
	@sTitle nvarchar(100),
	@sFirstName nvarchar(max),
	@sSurname nvarchar(max),
	@sOtherGivenNames nvarchar(max),
	@sSex nvarchar(1),
	@daDOB datetime,
	@sNotes nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxContact]
SET 
	[IsActive] = @bIsActive,
	[DetailSetting] = @iDetailSetting,
	[PrivacyRating] = @iPrivacyRating,
	[WearerInternalID] = @iWearerInternalID,
	[UserID] = @sUserID,
	[Title] = @sTitle,
	[FirstName] = @sFirstName,
	[Surname] = @sSurname,
	[OtherGivenNames] = @sOtherGivenNames,
	[Sex] = @sSex,
	[DOB] = @daDOB,
	[Notes] = @sNotes
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_UpdateAllWWearerInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_UpdateAllWWearerInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_UpdateAllWWearerInternalIDLogic]
	@iWearerInternalID int,
	@iWearerInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxContact]
SET
	[WearerInternalID] = @iWearerInternalID
WHERE
	[WearerInternalID] = @iWearerInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_UpdateAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_UpdateAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_UpdateAllWUserIDLogic]
	@sUserID varchar(50),
	@sUserIDOld varchar(50),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxContact]
SET
	[UserID] = @sUserID
WHERE
	[UserID] = @sUserIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_Delete]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxContact]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_DeleteAllWWearerInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_DeleteAllWWearerInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_DeleteAllWWearerInternalIDLogic]
	@iWearerInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxContact]
WHERE
	[WearerInternalID] = @iWearerInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_DeleteAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_DeleteAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_DeleteAllWUserIDLogic]
	@sUserID varchar(50),
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxContact]
WHERE
	[UserID] = @sUserID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_SelectOne]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxContact]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxContact]
ORDER BY 
	[DxContactID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_SelectAllWWearerInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_SelectAllWWearerInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_SelectAllWWearerInternalIDLogic]
	@iWearerInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxContact]
WHERE
	[WearerInternalID] = @iWearerInternalID
ORDER BY 
	[DxContactID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxContact_SelectAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxContact_SelectAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxContact_SelectAllWUserIDLogic]
	@sUserID varchar(50),
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxContact]
WHERE
	[UserID] = @sUserID
ORDER BY 
	[DxContactID] ASC
SELECT @iErrorCode=@@ERROR
GO



if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxGroup_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxGroup_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxGroup_Insert]
	@bIsSystemGroup bit,
	@bIsActive bit,
	@sGroupName nvarchar(150),
	@sGroupDescription nvarchar(max),
	@iGroupTypeID int,
	@sGroupNotes nvarchar(max),
	@iGroupCode int,
	@iDxGroupID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxGroup]
(
	[IsSystemGroup],
	[IsActive],
	[GroupName],
	[GroupDescription],
	[GroupTypeID],
	[GroupNotes],
	[GroupCode]
)
VALUES
(
	ISNULL(@bIsSystemGroup, ((0))),
	ISNULL(@bIsActive, ((1))),
	@sGroupName,
	@sGroupDescription,
	ISNULL(@iGroupTypeID, ((1))),
	@sGroupNotes,
	@iGroupCode
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxGroupID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxGroup_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxGroup_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxGroup_Update]
	@iDxGroupID int,
	@bIsSystemGroup bit,
	@bIsActive bit,
	@sGroupName nvarchar(150),
	@sGroupDescription nvarchar(max),
	@iGroupTypeID int,
	@sGroupNotes nvarchar(max),
	@iGroupCode int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxGroup]
SET 
	[IsSystemGroup] = @bIsSystemGroup,
	[IsActive] = @bIsActive,
	[GroupName] = @sGroupName,
	[GroupDescription] = @sGroupDescription,
	[GroupTypeID] = @iGroupTypeID,
	[GroupNotes] = @sGroupNotes,
	[GroupCode] = @iGroupCode
WHERE
	[DxGroupID] = @iDxGroupID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxGroup_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxGroup_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxGroup_Delete]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxGroup]
WHERE
	[DxGroupID] = @iDxGroupID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxGroup_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxGroup_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxGroup_SelectOne]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxGroup]
WHERE
	[DxGroupID] = @iDxGroupID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxGroup_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxGroup_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxGroup_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxGroup]
ORDER BY 
	[DxGroupID] ASC
SELECT @iErrorCode=@@ERROR
GO






if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJob_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJob_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJob_Insert]
	@iJobTypeID int,
	@sJobName nvarchar(100),
	@sJobDescription nvarchar(max),
	@daStartDate datetime,
	@daEndDate datetime,
	@sJobUserNotes nvarchar(max),
	@iReportNo int,
	@iUserReportID int,
	@iUserTemplateID int,
	@iLandauerID int,
	@iMaxDoseReports int,
	@daWearingPeriodFrom datetime,
	@daLandauerImportFrom datetime,
	@bAllowJobIntercept bit,
	@sDefaultEmailSubject nvarchar(100),
	@sDefaultEmailText nvarchar(max),
	@iDxJobID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxJob]
(
	[JobTypeID],
	[JobName],
	[JobDescription],
	[StartDate],
	[EndDate],
	[JobUserNotes],
	[ReportNo],
	[UserReportID],
	[UserTemplateID],
	[LandauerID],
	[MaxDoseReports],
	[WearingPeriodFrom],
	[LandauerImportFrom],
	[AllowJobIntercept],
	[DefaultEmailSubject],
	[DefaultEmailText]
)
VALUES
(
	@iJobTypeID,
	@sJobName,
	@sJobDescription,
	@daStartDate,
	@daEndDate,
	@sJobUserNotes,
	@iReportNo,
	@iUserReportID,
	@iUserTemplateID,
	@iLandauerID,
	@iMaxDoseReports,
	@daWearingPeriodFrom,
	@daLandauerImportFrom,
	@bAllowJobIntercept,
	@sDefaultEmailSubject,
	@sDefaultEmailText
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxJobID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJob_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJob_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJob_Update]
	@iDxJobID int,
	@iJobTypeID int,
	@sJobName nvarchar(100),
	@sJobDescription nvarchar(max),
	@daStartDate datetime,
	@daEndDate datetime,
	@sJobUserNotes nvarchar(max),
	@iReportNo int,
	@iUserReportID int,
	@iUserTemplateID int,
	@iLandauerID int,
	@iMaxDoseReports int,
	@daWearingPeriodFrom datetime,
	@daLandauerImportFrom datetime,
	@bAllowJobIntercept bit,
	@sDefaultEmailSubject nvarchar(100),
	@sDefaultEmailText nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxJob]
SET 
	[JobTypeID] = @iJobTypeID,
	[JobName] = @sJobName,
	[JobDescription] = @sJobDescription,
	[StartDate] = @daStartDate,
	[EndDate] = @daEndDate,
	[JobUserNotes] = @sJobUserNotes,
	[ReportNo] = @iReportNo,
	[UserReportID] = @iUserReportID,
	[UserTemplateID] = @iUserTemplateID,
	[LandauerID] = @iLandauerID,
	[MaxDoseReports] = @iMaxDoseReports,
	[WearingPeriodFrom] = @daWearingPeriodFrom,
	[LandauerImportFrom] = @daLandauerImportFrom,
	[AllowJobIntercept] = @bAllowJobIntercept,
	[DefaultEmailSubject] = @sDefaultEmailSubject,
	[DefaultEmailText] = @sDefaultEmailText
WHERE
	[DxJobID] = @iDxJobID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJob_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJob_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJob_Delete]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxJob]
WHERE
	[DxJobID] = @iDxJobID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJob_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJob_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJob_SelectOne]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJob]
WHERE
	[DxJobID] = @iDxJobID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJob_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJob_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJob_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJob]
ORDER BY 
	[DxJobID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_Insert]
	@iDxJobID int,
	@sAttachmentFileName nvarchar(max),
	@sAttachmentType nvarchar(max),
	@blobAttachmentContent image,
	@iDxJobEmailAttachmentID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxJobEmailAttachment]
(
	[DxJobID],
	[AttachmentFileName],
	[AttachmentType],
	[AttachmentContent]
)
VALUES
(
	@iDxJobID,
	@sAttachmentFileName,
	@sAttachmentType,
	@blobAttachmentContent
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxJobEmailAttachmentID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_Update]
	@iDxJobEmailAttachmentID int,
	@iDxJobID int,
	@sAttachmentFileName nvarchar(max),
	@sAttachmentType nvarchar(max),
	@blobAttachmentContent image,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxJobEmailAttachment]
SET 
	[DxJobID] = @iDxJobID,
	[AttachmentFileName] = @sAttachmentFileName,
	[AttachmentType] = @sAttachmentType,
	[AttachmentContent] = @blobAttachmentContent
WHERE
	[DxJobEmailAttachmentID] = @iDxJobEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_UpdateAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_UpdateAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_UpdateAllWDxJobIDLogic]
	@iDxJobID int,
	@iDxJobIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxJobEmailAttachment]
SET
	[DxJobID] = @iDxJobID
WHERE
	[DxJobID] = @iDxJobIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_Delete]
	@iDxJobEmailAttachmentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxJobEmailAttachment]
WHERE
	[DxJobEmailAttachmentID] = @iDxJobEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_DeleteAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_DeleteAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_DeleteAllWDxJobIDLogic]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxJobEmailAttachment]
WHERE
	[DxJobID] = @iDxJobID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_SelectOne]
	@iDxJobEmailAttachmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJobEmailAttachment]
WHERE
	[DxJobEmailAttachmentID] = @iDxJobEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJobEmailAttachment]
ORDER BY 
	[DxJobEmailAttachmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobEmailAttachment_SelectAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobEmailAttachment_SelectAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobEmailAttachment_SelectAllWDxJobIDLogic]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJobEmailAttachment]
WHERE
	[DxJobID] = @iDxJobID
ORDER BY 
	[DxJobEmailAttachmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_Insert]
	@iDxJobQueueID int,
	@iDxSchedID int,
	@daRunDateTime datetime,
	@iJobStatusID int,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxJobQueue]
(
	[DxJobQueueID],
	[DxSchedID],
	[RunDateTime],
	[JobStatusID]
)
VALUES
(
	@iDxJobQueueID,
	@iDxSchedID,
	@daRunDateTime,
	@iJobStatusID
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_Update]
	@iDxJobQueueID int,
	@iDxSchedID int,
	@daRunDateTime datetime,
	@iJobStatusID int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxJobQueue]
SET 
	[DxSchedID] = @iDxSchedID,
	[RunDateTime] = @daRunDateTime,
	[JobStatusID] = @iJobStatusID
WHERE
	[DxJobQueueID] = @iDxJobQueueID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_UpdateAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_UpdateAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_UpdateAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iDxSchedIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxJobQueue]
SET
	[DxSchedID] = @iDxSchedID
WHERE
	[DxSchedID] = @iDxSchedIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_Delete]
	@iDxJobQueueID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxJobQueue]
WHERE
	[DxJobQueueID] = @iDxJobQueueID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_DeleteAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_DeleteAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_DeleteAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxJobQueue]
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_SelectOne]
	@iDxJobQueueID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJobQueue]
WHERE
	[DxJobQueueID] = @iDxJobQueueID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJobQueue]
ORDER BY 
	[DxJobQueueID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxJobQueue_SelectAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxJobQueue_SelectAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxJobQueue_SelectAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxJobQueue]
WHERE
	[DxSchedID] = @iDxSchedID
ORDER BY 
	[DxJobQueueID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_Insert]
	@iDxJobID int,
	@iDxSchedID int,
	@iDxJobQueueID int,
	@daJobStarted datetime,
	@daJobEnded datetime,
	@iJobRunTime int,
	@sJobNameLogged nvarchar(100),
	@sJobLogSummary nvarchar(100),
	@sJobLogDetail nvarchar(max),
	@sJobLogUserNote nvarchar(max),
	@iDxLogID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxLog]
(
	[DxJobID],
	[DxSchedID],
	[DxJobQueueID],
	[JobStarted],
	[JobEnded],
	[JobRunTime],
	[JobNameLogged],
	[JobLogSummary],
	[JobLogDetail],
	[JobLogUserNote]
)
VALUES
(
	@iDxJobID,
	@iDxSchedID,
	@iDxJobQueueID,
	@daJobStarted,
	@daJobEnded,
	@iJobRunTime,
	@sJobNameLogged,
	@sJobLogSummary,
	@sJobLogDetail,
	@sJobLogUserNote
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxLogID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_Update]
	@iDxLogID int,
	@iDxJobID int,
	@iDxSchedID int,
	@iDxJobQueueID int,
	@daJobStarted datetime,
	@daJobEnded datetime,
	@iJobRunTime int,
	@sJobNameLogged nvarchar(100),
	@sJobLogSummary nvarchar(100),
	@sJobLogDetail nvarchar(max),
	@sJobLogUserNote nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxLog]
SET 
	[DxJobID] = @iDxJobID,
	[DxSchedID] = @iDxSchedID,
	[DxJobQueueID] = @iDxJobQueueID,
	[JobStarted] = @daJobStarted,
	[JobEnded] = @daJobEnded,
	[JobRunTime] = @iJobRunTime,
	[JobNameLogged] = @sJobNameLogged,
	[JobLogSummary] = @sJobLogSummary,
	[JobLogDetail] = @sJobLogDetail,
	[JobLogUserNote] = @sJobLogUserNote
WHERE
	[DxLogID] = @iDxLogID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_UpdateAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_UpdateAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_UpdateAllWDxJobIDLogic]
	@iDxJobID int,
	@iDxJobIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxLog]
SET
	[DxJobID] = @iDxJobID
WHERE
	[DxJobID] = @iDxJobIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_UpdateAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_UpdateAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_UpdateAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iDxSchedIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxLog]
SET
	[DxSchedID] = @iDxSchedID
WHERE
	[DxSchedID] = @iDxSchedIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_UpdateAllWDxJobQueueIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_UpdateAllWDxJobQueueIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_UpdateAllWDxJobQueueIDLogic]
	@iDxJobQueueID int,
	@iDxJobQueueIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxLog]
SET
	[DxJobQueueID] = @iDxJobQueueID
WHERE
	[DxJobQueueID] = @iDxJobQueueIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_Delete]
	@iDxLogID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxLog]
WHERE
	[DxLogID] = @iDxLogID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_DeleteAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_DeleteAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_DeleteAllWDxJobIDLogic]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxLog]
WHERE
	[DxJobID] = @iDxJobID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_DeleteAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_DeleteAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_DeleteAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxLog]
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_DeleteAllWDxJobQueueIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_DeleteAllWDxJobQueueIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_DeleteAllWDxJobQueueIDLogic]
	@iDxJobQueueID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxLog]
WHERE
	[DxJobQueueID] = @iDxJobQueueID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_SelectOne]
	@iDxLogID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxLog]
WHERE
	[DxLogID] = @iDxLogID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxLog]
ORDER BY 
	[DxLogID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_SelectAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_SelectAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_SelectAllWDxJobIDLogic]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxLog]
WHERE
	[DxJobID] = @iDxJobID
ORDER BY 
	[DxLogID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_SelectAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_SelectAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_SelectAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxLog]
WHERE
	[DxSchedID] = @iDxSchedID
ORDER BY 
	[DxLogID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxLog_SelectAllWDxJobQueueIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxLog_SelectAllWDxJobQueueIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxLog_SelectAllWDxJobQueueIDLogic]
	@iDxJobQueueID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxLog]
WHERE
	[DxJobQueueID] = @iDxJobQueueID
ORDER BY 
	[DxLogID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_Insert]
	@iDxContactID int,
	@iOrganisationID int,
	@iSiteLocationID int,
	@bIsActive bit,
	@iPrivacyRating int,
	@iMediumType int,
	@sDxMedium nvarchar(max),
	@iAvailability int,
	@sUseNote nvarchar(max),
	@iListPriority int,
	@iDxMediumID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxMedium]
(
	[DxContactID],
	[OrganisationID],
	[SiteLocationID],
	[IsActive],
	[PrivacyRating],
	[MediumType],
	[DxMedium],
	[Availability],
	[UseNote],
	[ListPriority]
)
VALUES
(
	@iDxContactID,
	@iOrganisationID,
	@iSiteLocationID,
	@bIsActive,
	@iPrivacyRating,
	@iMediumType,
	@sDxMedium,
	@iAvailability,
	@sUseNote,
	@iListPriority
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxMediumID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_Update]
	@iDxMediumID int,
	@iDxContactID int,
	@iOrganisationID int,
	@iSiteLocationID int,
	@bIsActive bit,
	@iPrivacyRating int,
	@iMediumType int,
	@sDxMedium nvarchar(max),
	@iAvailability int,
	@sUseNote nvarchar(max),
	@iListPriority int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxMedium]
SET 
	[DxContactID] = @iDxContactID,
	[OrganisationID] = @iOrganisationID,
	[SiteLocationID] = @iSiteLocationID,
	[IsActive] = @bIsActive,
	[PrivacyRating] = @iPrivacyRating,
	[MediumType] = @iMediumType,
	[DxMedium] = @sDxMedium,
	[Availability] = @iAvailability,
	[UseNote] = @sUseNote,
	[ListPriority] = @iListPriority
WHERE
	[DxMediumID] = @iDxMediumID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_UpdateAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_UpdateAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_UpdateAllWDxContactIDLogic]
	@iDxContactID int,
	@iDxContactIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxMedium]
SET
	[DxContactID] = @iDxContactID
WHERE
	[DxContactID] = @iDxContactIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxMedium]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxMedium]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_Delete]
	@iDxMediumID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxMedium]
WHERE
	[DxMediumID] = @iDxMediumID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_DeleteAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_DeleteAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_DeleteAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxMedium]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxMedium]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxMedium]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_SelectOne]
	@iDxMediumID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxMedium]
WHERE
	[DxMediumID] = @iDxMediumID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxMedium]
ORDER BY 
	[DxMediumID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_SelectAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_SelectAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_SelectAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxMedium]
WHERE
	[DxContactID] = @iDxContactID
ORDER BY 
	[DxMediumID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxMedium]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[DxMediumID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxMedium_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxMedium_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxMedium_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxMedium]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[DxMediumID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamRef_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamRef_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamRef_Insert]
	@iDxParamRefID int,
	@iParamTypeID int,
	@sParamType nvarchar(100),
	@sParamTypeDesc nvarchar(max),
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxParamRef]
(
	[DxParamRefID],
	[ParamTypeID],
	[ParamType],
	[ParamTypeDesc]
)
VALUES
(
	@iDxParamRefID,
	@iParamTypeID,
	@sParamType,
	@sParamTypeDesc
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamRef_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamRef_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamRef_Update]
	@iDxParamRefID int,
	@iParamTypeID int,
	@sParamType nvarchar(100),
	@sParamTypeDesc nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxParamRef]
SET 
	[ParamTypeID] = @iParamTypeID,
	[ParamType] = @sParamType,
	[ParamTypeDesc] = @sParamTypeDesc
WHERE
	[DxParamRefID] = @iDxParamRefID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamRef_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamRef_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamRef_Delete]
	@iDxParamRefID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxParamRef]
WHERE
	[DxParamRefID] = @iDxParamRefID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamRef_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamRef_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamRef_SelectOne]
	@iDxParamRefID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxParamRef]
WHERE
	[DxParamRefID] = @iDxParamRefID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamRef_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamRef_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamRef_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxParamRef]
ORDER BY 
	[DxParamRefID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_Insert]
	@iDxSchedID int,
	@iDxParamRefID int,
	@sParameterValue nvarchar(max),
	@sParameterName nvarchar(max),
	@sParameterDisplay nvarchar(max),
	@iCustomReminderDateID int,
	@iSystemReminderDateID int,
	@iDaysFromDate int,
	@iDxParamSchID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxParamSch]
(
	[DxSchedID],
	[DxParamRefID],
	[ParameterValue],
	[ParameterName],
	[ParameterDisplay],
	[CustomReminderDateID],
	[SystemReminderDateID],
	[DaysFromDate]
)
VALUES
(
	@iDxSchedID,
	@iDxParamRefID,
	@sParameterValue,
	@sParameterName,
	@sParameterDisplay,
	@iCustomReminderDateID,
	@iSystemReminderDateID,
	@iDaysFromDate
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxParamSchID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_Update]
	@iDxParamSchID int,
	@iDxSchedID int,
	@iDxParamRefID int,
	@sParameterValue nvarchar(max),
	@sParameterName nvarchar(max),
	@sParameterDisplay nvarchar(max),
	@iCustomReminderDateID int,
	@iSystemReminderDateID int,
	@iDaysFromDate int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxParamSch]
SET 
	[DxSchedID] = @iDxSchedID,
	[DxParamRefID] = @iDxParamRefID,
	[ParameterValue] = @sParameterValue,
	[ParameterName] = @sParameterName,
	[ParameterDisplay] = @sParameterDisplay,
	[CustomReminderDateID] = @iCustomReminderDateID,
	[SystemReminderDateID] = @iSystemReminderDateID,
	[DaysFromDate] = @iDaysFromDate
WHERE
	[DxParamSchID] = @iDxParamSchID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_UpdateAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_UpdateAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_UpdateAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iDxSchedIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxParamSch]
SET
	[DxSchedID] = @iDxSchedID
WHERE
	[DxSchedID] = @iDxSchedIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_UpdateAllWDxParamRefIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_UpdateAllWDxParamRefIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_UpdateAllWDxParamRefIDLogic]
	@iDxParamRefID int,
	@iDxParamRefIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxParamSch]
SET
	[DxParamRefID] = @iDxParamRefID
WHERE
	[DxParamRefID] = @iDxParamRefIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_Delete]
	@iDxParamSchID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxParamSch]
WHERE
	[DxParamSchID] = @iDxParamSchID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_DeleteAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_DeleteAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_DeleteAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxParamSch]
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_DeleteAllWDxParamRefIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_DeleteAllWDxParamRefIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_DeleteAllWDxParamRefIDLogic]
	@iDxParamRefID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxParamSch]
WHERE
	[DxParamRefID] = @iDxParamRefID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_SelectOne]
	@iDxParamSchID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxParamSch]
WHERE
	[DxParamSchID] = @iDxParamSchID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxParamSch]
ORDER BY 
	[DxParamSchID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_SelectAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_SelectAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_SelectAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxParamSch]
WHERE
	[DxSchedID] = @iDxSchedID
ORDER BY 
	[DxParamSchID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxParamSch_SelectAllWDxParamRefIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxParamSch_SelectAllWDxParamRefIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxParamSch_SelectAllWDxParamRefIDLogic]
	@iDxParamRefID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxParamSch]
WHERE
	[DxParamRefID] = @iDxParamRefID
ORDER BY 
	[DxParamSchID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_Insert]
	@iDxContactID int,
	@iRoleType int,
	@bIsActive bit,
	@iDxContactLinkID int,
	@iDxContactRelationshipType int,
	@iBusinessUnitID int,
	@iBusinessUnitRole int,
	@iCentreInternalID int,
	@iCentreRole int,
	@iEquipmentID int,
	@iEquipmentRole int,
	@iDxGroupID int,
	@iDxGroupRole int,
	@iOrganisationID int,
	@iOrganisationRole int,
	@iPremisesID int,
	@iPremisesRole int,
	@iRoomID int,
	@iRoomRole int,
	@iSiteLocationID int,
	@iSiteLocationRole int,
	@iTrainingCourseID int,
	@iTrainingCourseRole int,
	@iTrainingInstituteID int,
	@iTrainingInstituteRole int,
	@sRoleNote nvarchar(max),
	@iListPriority int,
	@iDxRoleID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxRole]
(
	[DxContactID],
	[RoleType],
	[IsActive],
	[DxContactLinkID],
	[DxContactRelationshipType],
	[BusinessUnitID],
	[BusinessUnitRole],
	[CentreInternalID],
	[CentreRole],
	[EquipmentID],
	[EquipmentRole],
	[DxGroupID],
	[DxGroupRole],
	[OrganisationID],
	[OrganisationRole],
	[PremisesID],
	[PremisesRole],
	[RoomID],
	[RoomRole],
	[SiteLocationID],
	[SiteLocationRole],
	[TrainingCourseID],
	[TrainingCourseRole],
	[TrainingInstituteID],
	[TrainingInstituteRole],
	[RoleNote],
	[ListPriority]
)
VALUES
(
	@iDxContactID,
	@iRoleType,
	@bIsActive,
	@iDxContactLinkID,
	@iDxContactRelationshipType,
	@iBusinessUnitID,
	@iBusinessUnitRole,
	@iCentreInternalID,
	@iCentreRole,
	@iEquipmentID,
	@iEquipmentRole,
	@iDxGroupID,
	@iDxGroupRole,
	@iOrganisationID,
	@iOrganisationRole,
	@iPremisesID,
	@iPremisesRole,
	@iRoomID,
	@iRoomRole,
	@iSiteLocationID,
	@iSiteLocationRole,
	@iTrainingCourseID,
	@iTrainingCourseRole,
	@iTrainingInstituteID,
	@iTrainingInstituteRole,
	@sRoleNote,
	@iListPriority
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxRoleID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_Update]
	@iDxRoleID int,
	@iDxContactID int,
	@iRoleType int,
	@bIsActive bit,
	@iDxContactLinkID int,
	@iDxContactRelationshipType int,
	@iBusinessUnitID int,
	@iBusinessUnitRole int,
	@iCentreInternalID int,
	@iCentreRole int,
	@iEquipmentID int,
	@iEquipmentRole int,
	@iDxGroupID int,
	@iDxGroupRole int,
	@iOrganisationID int,
	@iOrganisationRole int,
	@iPremisesID int,
	@iPremisesRole int,
	@iRoomID int,
	@iRoomRole int,
	@iSiteLocationID int,
	@iSiteLocationRole int,
	@iTrainingCourseID int,
	@iTrainingCourseRole int,
	@iTrainingInstituteID int,
	@iTrainingInstituteRole int,
	@sRoleNote nvarchar(max),
	@iListPriority int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET 
	[DxContactID] = @iDxContactID,
	[RoleType] = @iRoleType,
	[IsActive] = @bIsActive,
	[DxContactLinkID] = @iDxContactLinkID,
	[DxContactRelationshipType] = @iDxContactRelationshipType,
	[BusinessUnitID] = @iBusinessUnitID,
	[BusinessUnitRole] = @iBusinessUnitRole,
	[CentreInternalID] = @iCentreInternalID,
	[CentreRole] = @iCentreRole,
	[EquipmentID] = @iEquipmentID,
	[EquipmentRole] = @iEquipmentRole,
	[DxGroupID] = @iDxGroupID,
	[DxGroupRole] = @iDxGroupRole,
	[OrganisationID] = @iOrganisationID,
	[OrganisationRole] = @iOrganisationRole,
	[PremisesID] = @iPremisesID,
	[PremisesRole] = @iPremisesRole,
	[RoomID] = @iRoomID,
	[RoomRole] = @iRoomRole,
	[SiteLocationID] = @iSiteLocationID,
	[SiteLocationRole] = @iSiteLocationRole,
	[TrainingCourseID] = @iTrainingCourseID,
	[TrainingCourseRole] = @iTrainingCourseRole,
	[TrainingInstituteID] = @iTrainingInstituteID,
	[TrainingInstituteRole] = @iTrainingInstituteRole,
	[RoleNote] = @sRoleNote,
	[ListPriority] = @iListPriority
WHERE
	[DxRoleID] = @iDxRoleID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWDxContactIDLogic]
	@iDxContactID int,
	@iDxContactIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[DxContactID] = @iDxContactID
WHERE
	[DxContactID] = @iDxContactIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWDxContactLinkIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWDxContactLinkIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWDxContactLinkIDLogic]
	@iDxContactLinkID int,
	@iDxContactLinkIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[DxContactLinkID] = @iDxContactLinkID
WHERE
	[DxContactLinkID] = @iDxContactLinkIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iBusinessUnitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[BusinessUnitID] = @iBusinessUnitID
WHERE
	[BusinessUnitID] = @iBusinessUnitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iCentreInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[CentreInternalID] = @iCentreInternalID
WHERE
	[CentreInternalID] = @iCentreInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iEquipmentIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[EquipmentID] = @iEquipmentID
WHERE
	[EquipmentID] = @iEquipmentIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iDxGroupIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[DxGroupID] = @iDxGroupID
WHERE
	[DxGroupID] = @iDxGroupIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWRoomIDLogic]
	@iRoomID int,
	@iRoomIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[RoomID] = @iRoomID
WHERE
	[RoomID] = @iRoomIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWTrainingCourseIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWTrainingCourseIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWTrainingCourseIDLogic]
	@iTrainingCourseID int,
	@iTrainingCourseIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[TrainingCourseID] = @iTrainingCourseID
WHERE
	[TrainingCourseID] = @iTrainingCourseIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_UpdateAllWTrainingInstituteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_UpdateAllWTrainingInstituteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_UpdateAllWTrainingInstituteIDLogic]
	@iTrainingInstituteID int,
	@iTrainingInstituteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxRole]
SET
	[TrainingInstituteID] = @iTrainingInstituteID
WHERE
	[TrainingInstituteID] = @iTrainingInstituteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_Delete]
	@iDxRoleID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxRole]
WHERE
	[DxRoleID] = @iDxRoleID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[DxContactID] = @iDxContactID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWDxContactLinkIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWDxContactLinkIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWDxContactLinkIDLogic]
	@iDxContactLinkID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[DxContactLinkID] = @iDxContactLinkID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[DxGroupID] = @iDxGroupID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[RoomID] = @iRoomID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWTrainingCourseIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWTrainingCourseIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWTrainingCourseIDLogic]
	@iTrainingCourseID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[TrainingCourseID] = @iTrainingCourseID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_DeleteAllWTrainingInstituteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_DeleteAllWTrainingInstituteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_DeleteAllWTrainingInstituteIDLogic]
	@iTrainingInstituteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxRole]
WHERE
	[TrainingInstituteID] = @iTrainingInstituteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectOne]
	@iDxRoleID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[DxRoleID] = @iDxRoleID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWDxContactIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWDxContactIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWDxContactIDLogic]
	@iDxContactID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[DxContactID] = @iDxContactID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWDxContactLinkIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWDxContactLinkIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWDxContactLinkIDLogic]
	@iDxContactLinkID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[DxContactLinkID] = @iDxContactLinkID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[CentreInternalID] = @iCentreInternalID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[EquipmentID] = @iEquipmentID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[DxGroupID] = @iDxGroupID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWRoomIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWRoomIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWRoomIDLogic]
	@iRoomID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[RoomID] = @iRoomID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWTrainingCourseIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWTrainingCourseIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWTrainingCourseIDLogic]
	@iTrainingCourseID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[TrainingCourseID] = @iTrainingCourseID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxRole_SelectAllWTrainingInstituteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxRole_SelectAllWTrainingInstituteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxRole_SelectAllWTrainingInstituteIDLogic]
	@iTrainingInstituteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxRole]
WHERE
	[TrainingInstituteID] = @iTrainingInstituteID
ORDER BY 
	[DxRoleID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_Insert]
	@iDxSubscrID int,
	@iScheduleStatusID int,
	@iMaxCycles int,
	@iCyclesRun int,
	@sScheduleName nvarchar(100),
	@sScheduleDescription nvarchar(max),
	@sIntervalDesc nvarchar(100),
	@daStartDate datetime,
	@daEndDate datetime,
	@daRunAfter datetime,
	@daRunBefore datetime,
	@iScheduleCycleID int,
	@iScheduleCycleOptionID int,
	@iMinutelyEverynMinutes int,
	@iHourlyEverynHours int,
	@iDailyEverynDays int,
	@iWeeklyEverynWeeks int,
	@bWeeklyMonday bit,
	@bWeeklyTuesday bit,
	@bWeeklyWednesday bit,
	@bWeeklyThursday bit,
	@bWeeklyFriday bit,
	@bWeeklySaturday bit,
	@bWeeklySunday bit,
	@iMonthlyDayofMonth int,
	@iMonthlyEveryNmonths int,
	@iMonthlyNthXDay int,
	@iMonthdayOfWeek int,
	@iYearlyEveryNYears int,
	@iYearlyMonth int,
	@iYearlyMonthDay int,
	@iYearlyNthXday int,
	@iYearlyDayOfWeek int,
	@iSendLogsEverynCycle int,
	@iMaxLogsToRetain int,
	@bAllowEmailRetention bit,
	@iMaxEmailsToRetain int,
	@iDxSchedID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxSched]
(
	[DxSubscrID],
	[ScheduleStatusID],
	[MaxCycles],
	[CyclesRun],
	[ScheduleName],
	[ScheduleDescription],
	[IntervalDesc],
	[StartDate],
	[EndDate],
	[RunAfter],
	[RunBefore],
	[ScheduleCycleID],
	[ScheduleCycleOptionID],
	[MinutelyEverynMinutes],
	[HourlyEverynHours],
	[DailyEverynDays],
	[WeeklyEverynWeeks],
	[WeeklyMonday],
	[WeeklyTuesday],
	[WeeklyWednesday],
	[WeeklyThursday],
	[WeeklyFriday],
	[WeeklySaturday],
	[WeeklySunday],
	[MonthlyDayofMonth],
	[MonthlyEveryNmonths],
	[MonthlyNthXDay],
	[MonthdayOfWeek],
	[YearlyEveryNYears],
	[YearlyMonth],
	[YearlyMonthDay],
	[YearlyNthXday],
	[YearlyDayOfWeek],
	[SendLogsEverynCycle],
	[MaxLogsToRetain],
	[AllowEmailRetention],
	[MaxEmailsToRetain]
)
VALUES
(
	@iDxSubscrID,
	ISNULL(@iScheduleStatusID, ((1))),
	@iMaxCycles,
	ISNULL(@iCyclesRun, ((0))),
	@sScheduleName,
	@sScheduleDescription,
	@sIntervalDesc,
	@daStartDate,
	@daEndDate,
	@daRunAfter,
	@daRunBefore,
	@iScheduleCycleID,
	@iScheduleCycleOptionID,
	@iMinutelyEverynMinutes,
	@iHourlyEverynHours,
	@iDailyEverynDays,
	@iWeeklyEverynWeeks,
	ISNULL(@bWeeklyMonday, ((0))),
	ISNULL(@bWeeklyTuesday, ((0))),
	ISNULL(@bWeeklyWednesday, ((0))),
	ISNULL(@bWeeklyThursday, ((0))),
	ISNULL(@bWeeklyFriday, ((0))),
	ISNULL(@bWeeklySaturday, ((0))),
	ISNULL(@bWeeklySunday, ((0))),
	@iMonthlyDayofMonth,
	@iMonthlyEveryNmonths,
	@iMonthlyNthXDay,
	@iMonthdayOfWeek,
	@iYearlyEveryNYears,
	@iYearlyMonth,
	@iYearlyMonthDay,
	@iYearlyNthXday,
	@iYearlyDayOfWeek,
	@iSendLogsEverynCycle,
	@iMaxLogsToRetain,
	ISNULL(@bAllowEmailRetention, ((0))),
	@iMaxEmailsToRetain
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxSchedID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_Update]
	@iDxSchedID int,
	@iDxSubscrID int,
	@iScheduleStatusID int,
	@iMaxCycles int,
	@iCyclesRun int,
	@sScheduleName nvarchar(100),
	@sScheduleDescription nvarchar(max),
	@sIntervalDesc nvarchar(100),
	@daStartDate datetime,
	@daEndDate datetime,
	@daRunAfter datetime,
	@daRunBefore datetime,
	@iScheduleCycleID int,
	@iScheduleCycleOptionID int,
	@iMinutelyEverynMinutes int,
	@iHourlyEverynHours int,
	@iDailyEverynDays int,
	@iWeeklyEverynWeeks int,
	@bWeeklyMonday bit,
	@bWeeklyTuesday bit,
	@bWeeklyWednesday bit,
	@bWeeklyThursday bit,
	@bWeeklyFriday bit,
	@bWeeklySaturday bit,
	@bWeeklySunday bit,
	@iMonthlyDayofMonth int,
	@iMonthlyEveryNmonths int,
	@iMonthlyNthXDay int,
	@iMonthdayOfWeek int,
	@iYearlyEveryNYears int,
	@iYearlyMonth int,
	@iYearlyMonthDay int,
	@iYearlyNthXday int,
	@iYearlyDayOfWeek int,
	@iSendLogsEverynCycle int,
	@iMaxLogsToRetain int,
	@bAllowEmailRetention bit,
	@iMaxEmailsToRetain int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSched]
SET 
	[DxSubscrID] = @iDxSubscrID,
	[ScheduleStatusID] = @iScheduleStatusID,
	[MaxCycles] = @iMaxCycles,
	[CyclesRun] = @iCyclesRun,
	[ScheduleName] = @sScheduleName,
	[ScheduleDescription] = @sScheduleDescription,
	[IntervalDesc] = @sIntervalDesc,
	[StartDate] = @daStartDate,
	[EndDate] = @daEndDate,
	[RunAfter] = @daRunAfter,
	[RunBefore] = @daRunBefore,
	[ScheduleCycleID] = @iScheduleCycleID,
	[ScheduleCycleOptionID] = @iScheduleCycleOptionID,
	[MinutelyEverynMinutes] = @iMinutelyEverynMinutes,
	[HourlyEverynHours] = @iHourlyEverynHours,
	[DailyEverynDays] = @iDailyEverynDays,
	[WeeklyEverynWeeks] = @iWeeklyEverynWeeks,
	[WeeklyMonday] = @bWeeklyMonday,
	[WeeklyTuesday] = @bWeeklyTuesday,
	[WeeklyWednesday] = @bWeeklyWednesday,
	[WeeklyThursday] = @bWeeklyThursday,
	[WeeklyFriday] = @bWeeklyFriday,
	[WeeklySaturday] = @bWeeklySaturday,
	[WeeklySunday] = @bWeeklySunday,
	[MonthlyDayofMonth] = @iMonthlyDayofMonth,
	[MonthlyEveryNmonths] = @iMonthlyEveryNmonths,
	[MonthlyNthXDay] = @iMonthlyNthXDay,
	[MonthdayOfWeek] = @iMonthdayOfWeek,
	[YearlyEveryNYears] = @iYearlyEveryNYears,
	[YearlyMonth] = @iYearlyMonth,
	[YearlyMonthDay] = @iYearlyMonthDay,
	[YearlyNthXday] = @iYearlyNthXday,
	[YearlyDayOfWeek] = @iYearlyDayOfWeek,
	[SendLogsEverynCycle] = @iSendLogsEverynCycle,
	[MaxLogsToRetain] = @iMaxLogsToRetain,
	[AllowEmailRetention] = @bAllowEmailRetention,
	[MaxEmailsToRetain] = @iMaxEmailsToRetain
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_UpdateAllWDxSubscrIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_UpdateAllWDxSubscrIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_UpdateAllWDxSubscrIDLogic]
	@iDxSubscrID int,
	@iDxSubscrIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSched]
SET
	[DxSubscrID] = @iDxSubscrID
WHERE
	[DxSubscrID] = @iDxSubscrIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_Delete]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxSched]
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_DeleteAllWDxSubscrIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_DeleteAllWDxSubscrIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_DeleteAllWDxSubscrIDLogic]
	@iDxSubscrID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxSched]
WHERE
	[DxSubscrID] = @iDxSubscrID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_SelectOne]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSched]
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSched]
ORDER BY 
	[DxSchedID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSched_SelectAllWDxSubscrIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSched_SelectAllWDxSubscrIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSched_SelectAllWDxSubscrIDLogic]
	@iDxSubscrID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSched]
WHERE
	[DxSubscrID] = @iDxSubscrID
ORDER BY 
	[DxSchedID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_Insert]
	@iDxSchedEmailID int,
	@iDxSchedID int,
	@sRecipients nvarchar(max),
	@sCC nvarchar(max),
	@sBCC nvarchar(max),
	@sSubject nvarchar(100),
	@sEmailText nvarchar(max),
	@bIsJobNotification bit,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxSchedEmail]
(
	[DxSchedEmailID],
	[DxSchedID],
	[Recipients],
	[CC],
	[BCC],
	[Subject],
	[EmailText],
	[IsJobNotification]
)
VALUES
(
	@iDxSchedEmailID,
	@iDxSchedID,
	@sRecipients,
	@sCC,
	@sBCC,
	@sSubject,
	@sEmailText,
	ISNULL(@bIsJobNotification, ((0)))
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_Update]
	@iDxSchedEmailID int,
	@iDxSchedID int,
	@sRecipients nvarchar(max),
	@sCC nvarchar(max),
	@sBCC nvarchar(max),
	@sSubject nvarchar(100),
	@sEmailText nvarchar(max),
	@bIsJobNotification bit,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSchedEmail]
SET 
	[DxSchedID] = @iDxSchedID,
	[Recipients] = @sRecipients,
	[CC] = @sCC,
	[BCC] = @sBCC,
	[Subject] = @sSubject,
	[EmailText] = @sEmailText,
	[IsJobNotification] = @bIsJobNotification
WHERE
	[DxSchedEmailID] = @iDxSchedEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_UpdateAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_UpdateAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_UpdateAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iDxSchedIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSchedEmail]
SET
	[DxSchedID] = @iDxSchedID
WHERE
	[DxSchedID] = @iDxSchedIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_Delete]
	@iDxSchedEmailID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxSchedEmail]
WHERE
	[DxSchedEmailID] = @iDxSchedEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_DeleteAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_DeleteAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_DeleteAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxSchedEmail]
WHERE
	[DxSchedID] = @iDxSchedID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_SelectOne]
	@iDxSchedEmailID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSchedEmail]
WHERE
	[DxSchedEmailID] = @iDxSchedEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSchedEmail]
ORDER BY 
	[DxSchedEmailID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmail_SelectAllWDxSchedIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmail_SelectAllWDxSchedIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmail_SelectAllWDxSchedIDLogic]
	@iDxSchedID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSchedEmail]
WHERE
	[DxSchedID] = @iDxSchedID
ORDER BY 
	[DxSchedEmailID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_Insert]
	@iDxSchedEmailID int,
	@sAttachmentFileName nvarchar(max),
	@sAttachmentType nvarchar(max),
	@blobAttachmentContent image,
	@iDxSchedEmailAttachmentID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxSchedEmailAttachment]
(
	[DxSchedEmailID],
	[AttachmentFileName],
	[AttachmentType],
	[AttachmentContent]
)
VALUES
(
	@iDxSchedEmailID,
	@sAttachmentFileName,
	@sAttachmentType,
	@blobAttachmentContent
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxSchedEmailAttachmentID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_Update]
	@iDxSchedEmailAttachmentID int,
	@iDxSchedEmailID int,
	@sAttachmentFileName nvarchar(max),
	@sAttachmentType nvarchar(max),
	@blobAttachmentContent image,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSchedEmailAttachment]
SET 
	[DxSchedEmailID] = @iDxSchedEmailID,
	[AttachmentFileName] = @sAttachmentFileName,
	[AttachmentType] = @sAttachmentType,
	[AttachmentContent] = @blobAttachmentContent
WHERE
	[DxSchedEmailAttachmentID] = @iDxSchedEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_UpdateAllWDxSchedEmailIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_UpdateAllWDxSchedEmailIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_UpdateAllWDxSchedEmailIDLogic]
	@iDxSchedEmailID int,
	@iDxSchedEmailIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSchedEmailAttachment]
SET
	[DxSchedEmailID] = @iDxSchedEmailID
WHERE
	[DxSchedEmailID] = @iDxSchedEmailIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_Delete]
	@iDxSchedEmailAttachmentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxSchedEmailAttachment]
WHERE
	[DxSchedEmailAttachmentID] = @iDxSchedEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_DeleteAllWDxSchedEmailIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_DeleteAllWDxSchedEmailIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_DeleteAllWDxSchedEmailIDLogic]
	@iDxSchedEmailID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxSchedEmailAttachment]
WHERE
	[DxSchedEmailID] = @iDxSchedEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_SelectOne]
	@iDxSchedEmailAttachmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSchedEmailAttachment]
WHERE
	[DxSchedEmailAttachmentID] = @iDxSchedEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSchedEmailAttachment]
ORDER BY 
	[DxSchedEmailAttachmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSchedEmailAttachment_SelectAllWDxSchedEmailIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSchedEmailAttachment_SelectAllWDxSchedEmailIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSchedEmailAttachment_SelectAllWDxSchedEmailIDLogic]
	@iDxSchedEmailID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSchedEmailAttachment]
WHERE
	[DxSchedEmailID] = @iDxSchedEmailID
ORDER BY 
	[DxSchedEmailAttachmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_Insert]
	@iDxJobID int,
	@iDxContactID int,
	@iDxGroupID int,
	@iSubscrReasonID int,
	@daStartDate datetime,
	@daEndDate datetime,
	@sSubscrNote nvarchar(max),
	@iDxSubscrID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxSubscr]
(
	[DxJobID],
	[DxContactID],
	[DxGroupID],
	[SubscrReasonID],
	[StartDate],
	[EndDate],
	[SubscrNote]
)
VALUES
(
	@iDxJobID,
	@iDxContactID,
	@iDxGroupID,
	ISNULL(@iSubscrReasonID, ((1))),
	@daStartDate,
	@daEndDate,
	@sSubscrNote
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxSubscrID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_Update]
	@iDxSubscrID int,
	@iDxJobID int,
	@iDxContactID int,
	@iDxGroupID int,
	@iSubscrReasonID int,
	@daStartDate datetime,
	@daEndDate datetime,
	@sSubscrNote nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSubscr]
SET 
	[DxJobID] = @iDxJobID,
	[DxContactID] = @iDxContactID,
	[DxGroupID] = @iDxGroupID,
	[SubscrReasonID] = @iSubscrReasonID,
	[StartDate] = @daStartDate,
	[EndDate] = @daEndDate,
	[SubscrNote] = @sSubscrNote
WHERE
	[DxSubscrID] = @iDxSubscrID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_UpdateAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_UpdateAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_UpdateAllWDxJobIDLogic]
	@iDxJobID int,
	@iDxJobIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSubscr]
SET
	[DxJobID] = @iDxJobID
WHERE
	[DxJobID] = @iDxJobIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_UpdateAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_UpdateAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_UpdateAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iDxGroupIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxSubscr]
SET
	[DxGroupID] = @iDxGroupID
WHERE
	[DxGroupID] = @iDxGroupIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_Delete]
	@iDxSubscrID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxSubscr]
WHERE
	[DxSubscrID] = @iDxSubscrID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_DeleteAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_DeleteAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_DeleteAllWDxJobIDLogic]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxSubscr]
WHERE
	[DxJobID] = @iDxJobID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_DeleteAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_DeleteAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_DeleteAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxSubscr]
WHERE
	[DxGroupID] = @iDxGroupID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_SelectOne]
	@iDxSubscrID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSubscr]
WHERE
	[DxSubscrID] = @iDxSubscrID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSubscr]
ORDER BY 
	[DxSubscrID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_SelectAllWDxJobIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_SelectAllWDxJobIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_SelectAllWDxJobIDLogic]
	@iDxJobID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSubscr]
WHERE
	[DxJobID] = @iDxJobID
ORDER BY 
	[DxSubscrID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxSubscr_SelectAllWDxGroupIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxSubscr_SelectAllWDxGroupIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxSubscr_SelectAllWDxGroupIDLogic]
	@iDxGroupID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxSubscr]
WHERE
	[DxGroupID] = @iDxGroupID
ORDER BY 
	[DxSubscrID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_Insert]
	@iDxTempEmailID int,
	@iDxJobQueueID int,
	@sSubject varchar(50),
	@sEmailText text,
	@sRecipients nvarchar(max),
	@sCC nvarchar(max),
	@sBCC nvarchar(max),
	@daAttemptedToSendDate datetime,
	@daSentDateTime datetime,
	@bResendMessage bit,
	@bAdminHold bit,
	@sErrorLog nvarchar(max),
	@bKeepEmail bit,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxTempEmail]
(
	[DxTempEmailID],
	[DxJobQueueID],
	[Subject],
	[EmailText],
	[Recipients],
	[CC],
	[BCC],
	[AttemptedToSendDate],
	[SentDateTime],
	[ResendMessage],
	[AdminHold],
	[ErrorLog],
	[KeepEmail]
)
VALUES
(
	@iDxTempEmailID,
	@iDxJobQueueID,
	@sSubject,
	@sEmailText,
	@sRecipients,
	@sCC,
	@sBCC,
	@daAttemptedToSendDate,
	@daSentDateTime,
	ISNULL(@bResendMessage, ((0))),
	ISNULL(@bAdminHold, ((0))),
	@sErrorLog,
	ISNULL(@bKeepEmail, ((0)))
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_Update]
	@iDxTempEmailID int,
	@iDxJobQueueID int,
	@sSubject varchar(50),
	@sEmailText text,
	@sRecipients nvarchar(max),
	@sCC nvarchar(max),
	@sBCC nvarchar(max),
	@daAttemptedToSendDate datetime,
	@daSentDateTime datetime,
	@bResendMessage bit,
	@bAdminHold bit,
	@sErrorLog nvarchar(max),
	@bKeepEmail bit,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxTempEmail]
SET 
	[DxJobQueueID] = @iDxJobQueueID,
	[Subject] = @sSubject,
	[EmailText] = @sEmailText,
	[Recipients] = @sRecipients,
	[CC] = @sCC,
	[BCC] = @sBCC,
	[AttemptedToSendDate] = @daAttemptedToSendDate,
	[SentDateTime] = @daSentDateTime,
	[ResendMessage] = @bResendMessage,
	[AdminHold] = @bAdminHold,
	[ErrorLog] = @sErrorLog,
	[KeepEmail] = @bKeepEmail
WHERE
	[DxTempEmailID] = @iDxTempEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_UpdateAllWDxJobQueueIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_UpdateAllWDxJobQueueIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_UpdateAllWDxJobQueueIDLogic]
	@iDxJobQueueID int,
	@iDxJobQueueIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxTempEmail]
SET
	[DxJobQueueID] = @iDxJobQueueID
WHERE
	[DxJobQueueID] = @iDxJobQueueIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_Delete]
	@iDxTempEmailID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxTempEmail]
WHERE
	[DxTempEmailID] = @iDxTempEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_DeleteAllWDxJobQueueIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_DeleteAllWDxJobQueueIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_DeleteAllWDxJobQueueIDLogic]
	@iDxJobQueueID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxTempEmail]
WHERE
	[DxJobQueueID] = @iDxJobQueueID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_SelectOne]
	@iDxTempEmailID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxTempEmail]
WHERE
	[DxTempEmailID] = @iDxTempEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxTempEmail]
ORDER BY 
	[DxTempEmailID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmail_SelectAllWDxJobQueueIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmail_SelectAllWDxJobQueueIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmail_SelectAllWDxJobQueueIDLogic]
	@iDxJobQueueID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxTempEmail]
WHERE
	[DxJobQueueID] = @iDxJobQueueID
ORDER BY 
	[DxTempEmailID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_Insert]
	@iDxTempEmailID int,
	@sAttachmentFileName varchar(max),
	@sAttachmentType varchar(max),
	@blobAttachmentContent image,
	@iDxTempEmailAttachmentID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblDxTempEmailAttachment]
(
	[DxTempEmailID],
	[AttachmentFileName],
	[AttachmentType],
	[AttachmentContent]
)
VALUES
(
	@iDxTempEmailID,
	@sAttachmentFileName,
	@sAttachmentType,
	@blobAttachmentContent
)
SELECT @iErrorCode=@@ERROR
SELECT @iDxTempEmailAttachmentID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_Update]
	@iDxTempEmailAttachmentID int,
	@iDxTempEmailID int,
	@sAttachmentFileName varchar(max),
	@sAttachmentType varchar(max),
	@blobAttachmentContent image,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxTempEmailAttachment]
SET 
	[DxTempEmailID] = @iDxTempEmailID,
	[AttachmentFileName] = @sAttachmentFileName,
	[AttachmentType] = @sAttachmentType,
	[AttachmentContent] = @blobAttachmentContent
WHERE
	[DxTempEmailAttachmentID] = @iDxTempEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_UpdateAllWDxTempEmailIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_UpdateAllWDxTempEmailIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_UpdateAllWDxTempEmailIDLogic]
	@iDxTempEmailID int,
	@iDxTempEmailIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblDxTempEmailAttachment]
SET
	[DxTempEmailID] = @iDxTempEmailID
WHERE
	[DxTempEmailID] = @iDxTempEmailIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_Delete]
	@iDxTempEmailAttachmentID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblDxTempEmailAttachment]
WHERE
	[DxTempEmailAttachmentID] = @iDxTempEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_DeleteAllWDxTempEmailIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_DeleteAllWDxTempEmailIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_DeleteAllWDxTempEmailIDLogic]
	@iDxTempEmailID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblDxTempEmailAttachment]
WHERE
	[DxTempEmailID] = @iDxTempEmailID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_SelectOne]
	@iDxTempEmailAttachmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxTempEmailAttachment]
WHERE
	[DxTempEmailAttachmentID] = @iDxTempEmailAttachmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxTempEmailAttachment]
ORDER BY 
	[DxTempEmailAttachmentID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblDxTempEmailAttachment_SelectAllWDxTempEmailIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblDxTempEmailAttachment_SelectAllWDxTempEmailIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblDxTempEmailAttachment_SelectAllWDxTempEmailIDLogic]
	@iDxTempEmailID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblDxTempEmailAttachment]
WHERE
	[DxTempEmailID] = @iDxTempEmailID
ORDER BY 
	[DxTempEmailAttachmentID] ASC
SELECT @iErrorCode=@@ERROR
GO




-- ====================================
-- End Dx related changes/new SPROCS
-- ====================================

-- ====================================
-- ANRDR Constellation SPROCS
-- ====================================


SET NOCOUNT ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmission_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmission_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmission_Insert]
	@daDateCreated datetime,
	@sUserID varchar(50),
	@iYear int,
	@iQuarter int,
	@iReportingGroupNumber int,
	@sCompanyName varchar(max),
	@sTradingName varchar(max),
	@sABN varchar(max),
	@iNoOfWorksites int,
	@iNoOfReadings int,
	@sFileLocation varchar(max),
	@blobFileContent image,
	@sReceiptNo varchar(max),
	@iDoseMappingTypeUsed int,
	@iVersion int,
	@iANRDRSubmissionID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRSubmission]
(
	[DateCreated],
	[UserID],
	[Year],
	[Quarter],
	[ReportingGroupNumber],
	[CompanyName],
	[TradingName],
	[ABN],
	[NoOfWorksites],
	[NoOfReadings],
	[FileLocation],
	[FileContent],
	[ReceiptNo],
	[DoseMappingTypeUsed],
	[Version]
)
VALUES
(
	@daDateCreated,
	@sUserID,
	@iYear,
	@iQuarter,
	@iReportingGroupNumber,
	@sCompanyName,
	@sTradingName,
	@sABN,
	@iNoOfWorksites,
	@iNoOfReadings,
	@sFileLocation,
	@blobFileContent,
	@sReceiptNo,
	@iDoseMappingTypeUsed,
	@iVersion
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRSubmissionID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmission_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmission_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmission_Update]
	@iANRDRSubmissionID int,
	@daDateCreated datetime,
	@sUserID varchar(50),
	@iYear int,
	@iQuarter int,
	@iReportingGroupNumber int,
	@sCompanyName varchar(max),
	@sTradingName varchar(max),
	@sABN varchar(max),
	@iNoOfWorksites int,
	@iNoOfReadings int,
	@sFileLocation varchar(max),
	@blobFileContent image,
	@sReceiptNo varchar(max),
	@iDoseMappingTypeUsed int,
	@iVersion int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmission]
SET 
	[DateCreated] = @daDateCreated,
	[UserID] = @sUserID,
	[Year] = @iYear,
	[Quarter] = @iQuarter,
	[ReportingGroupNumber] = @iReportingGroupNumber,
	[CompanyName] = @sCompanyName,
	[TradingName] = @sTradingName,
	[ABN] = @sABN,
	[NoOfWorksites] = @iNoOfWorksites,
	[NoOfReadings] = @iNoOfReadings,
	[FileLocation] = @sFileLocation,
	[FileContent] = @blobFileContent,
	[ReceiptNo] = @sReceiptNo,
	[DoseMappingTypeUsed] = @iDoseMappingTypeUsed,
	[Version] = @iVersion
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmission_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmission_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmission_Delete]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRSubmission]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmission_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmission_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmission_SelectOne]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmission]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmission_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmission_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmission_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmission]
ORDER BY 
	[ANRDRSubmissionID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_Insert]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionHistoryWorksiteID int,
	@iCentreInternalID int,
	@sCentreNo varchar(max),
	@sCentreName varchar(max),
	@sCentreDescription varchar(max),
	@iANRDRSubmissionHistoryCentreID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRSubmissionHistoryCentre]
(
	[ANRDRSubmissionID],
	[ANRDRSubmissionHistoryWorksiteID],
	[CentreInternalID],
	[CentreNo],
	[CentreName],
	[CentreDescription]
)
VALUES
(
	@iANRDRSubmissionID,
	@iANRDRSubmissionHistoryWorksiteID,
	@iCentreInternalID,
	@sCentreNo,
	@sCentreName,
	@sCentreDescription
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRSubmissionHistoryCentreID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_Update]
	@iANRDRSubmissionHistoryCentreID int,
	@iANRDRSubmissionID int,
	@iANRDRSubmissionHistoryWorksiteID int,
	@iCentreInternalID int,
	@sCentreNo varchar(max),
	@sCentreName varchar(max),
	@sCentreDescription varchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryCentre]
SET 
	[ANRDRSubmissionID] = @iANRDRSubmissionID,
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID,
	[CentreInternalID] = @iCentreInternalID,
	[CentreNo] = @sCentreNo,
	[CentreName] = @sCentreName,
	[CentreDescription] = @sCentreDescription
WHERE
	[ANRDRSubmissionHistoryCentreID] = @iANRDRSubmissionHistoryCentreID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryCentre]
SET
	[ANRDRSubmissionID] = @iANRDRSubmissionID
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iANRDRSubmissionHistoryWorksiteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryCentre]
SET
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_UpdateAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iCentreInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryCentre]
SET
	[CentreInternalID] = @iCentreInternalID
WHERE
	[CentreInternalID] = @iCentreInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_Delete]
	@iANRDRSubmissionHistoryCentreID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[ANRDRSubmissionHistoryCentreID] = @iANRDRSubmissionHistoryCentreID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_DeleteAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectOne]
	@iANRDRSubmissionHistoryCentreID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[ANRDRSubmissionHistoryCentreID] = @iANRDRSubmissionHistoryCentreID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryCentre]
ORDER BY 
	[ANRDRSubmissionHistoryCentreID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
ORDER BY 
	[ANRDRSubmissionHistoryCentreID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
ORDER BY 
	[ANRDRSubmissionHistoryCentreID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryCentre_SelectAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryCentre]
WHERE
	[CentreInternalID] = @iCentreInternalID
ORDER BY 
	[ANRDRSubmissionHistoryCentreID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_Insert]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionHistoryWorkerID int,
	@iDoseReportReadingID int,
	@iDoseTypeCode int,
	@dcDoseValue decimal(18, 4),
	@iDoseReasonCode int,
	@iSequenceNo int,
	@iReadingDaysIncluded int,
	@iReadingDaysTotal int,
	@iANRDRDosimetryProviderCode int,
	@iANRDRSubmissionHistoryDoseID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRSubmissionHistoryDose]
(
	[ANRDRSubmissionID],
	[ANRDRSubmissionHistoryWorkerID],
	[DoseReportReadingID],
	[DoseTypeCode],
	[DoseValue],
	[DoseReasonCode],
	[SequenceNo],
	[ReadingDaysIncluded],
	[ReadingDaysTotal],
	[ANRDRDosimetryProviderCode]
)
VALUES
(
	@iANRDRSubmissionID,
	@iANRDRSubmissionHistoryWorkerID,
	@iDoseReportReadingID,
	@iDoseTypeCode,
	@dcDoseValue,
	@iDoseReasonCode,
	@iSequenceNo,
	@iReadingDaysIncluded,
	@iReadingDaysTotal,
	@iANRDRDosimetryProviderCode
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRSubmissionHistoryDoseID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_Update]
	@iANRDRSubmissionHistoryDoseID int,
	@iANRDRSubmissionID int,
	@iANRDRSubmissionHistoryWorkerID int,
	@iDoseReportReadingID int,
	@iDoseTypeCode int,
	@dcDoseValue decimal(18, 4),
	@iDoseReasonCode int,
	@iSequenceNo int,
	@iReadingDaysIncluded int,
	@iReadingDaysTotal int,
	@iANRDRDosimetryProviderCode int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDose]
SET 
	[ANRDRSubmissionID] = @iANRDRSubmissionID,
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID,
	[DoseReportReadingID] = @iDoseReportReadingID,
	[DoseTypeCode] = @iDoseTypeCode,
	[DoseValue] = @dcDoseValue,
	[DoseReasonCode] = @iDoseReasonCode,
	[SequenceNo] = @iSequenceNo,
	[ReadingDaysIncluded] = @iReadingDaysIncluded,
	[ReadingDaysTotal] = @iReadingDaysTotal,
	[ANRDRDosimetryProviderCode] = @iANRDRDosimetryProviderCode
WHERE
	[ANRDRSubmissionHistoryDoseID] = @iANRDRSubmissionHistoryDoseID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDose]
SET
	[ANRDRSubmissionID] = @iANRDRSubmissionID
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWANRDRSubmissionHistoryWorkerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWANRDRSubmissionHistoryWorkerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWANRDRSubmissionHistoryWorkerIDLogic]
	@iANRDRSubmissionHistoryWorkerID int,
	@iANRDRSubmissionHistoryWorkerIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDose]
SET
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID
WHERE
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWDoseReportReadingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWDoseReportReadingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_UpdateAllWDoseReportReadingIDLogic]
	@iDoseReportReadingID int,
	@iDoseReportReadingIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDose]
SET
	[DoseReportReadingID] = @iDoseReportReadingID
WHERE
	[DoseReportReadingID] = @iDoseReportReadingIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_Delete]
	@iANRDRSubmissionHistoryDoseID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[ANRDRSubmissionHistoryDoseID] = @iANRDRSubmissionHistoryDoseID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWANRDRSubmissionHistoryWorkerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWANRDRSubmissionHistoryWorkerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWANRDRSubmissionHistoryWorkerIDLogic]
	@iANRDRSubmissionHistoryWorkerID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWDoseReportReadingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWDoseReportReadingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_DeleteAllWDoseReportReadingIDLogic]
	@iDoseReportReadingID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[DoseReportReadingID] = @iDoseReportReadingID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectOne]
	@iANRDRSubmissionHistoryDoseID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[ANRDRSubmissionHistoryDoseID] = @iANRDRSubmissionHistoryDoseID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDose]
ORDER BY 
	[ANRDRSubmissionHistoryDoseID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
ORDER BY 
	[ANRDRSubmissionHistoryDoseID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWANRDRSubmissionHistoryWorkerIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWANRDRSubmissionHistoryWorkerIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWANRDRSubmissionHistoryWorkerIDLogic]
	@iANRDRSubmissionHistoryWorkerID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID
ORDER BY 
	[ANRDRSubmissionHistoryDoseID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWDoseReportReadingIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWDoseReportReadingIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDose_SelectAllWDoseReportReadingIDLogic]
	@iDoseReportReadingID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDose]
WHERE
	[DoseReportReadingID] = @iDoseReportReadingID
ORDER BY 
	[ANRDRSubmissionHistoryDoseID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Insert]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionHistoryWorksiteID int,
	@iDoseParameterTypeCode int,
	@sDoseParameterValue varchar(max),
	@iANRDRSubmissionHistoryDoseParameterID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRSubmissionHistoryDoseParameter]
(
	[ANRDRSubmissionID],
	[ANRDRSubmissionHistoryWorksiteID],
	[DoseParameterTypeCode],
	[DoseParameterValue]
)
VALUES
(
	@iANRDRSubmissionID,
	@iANRDRSubmissionHistoryWorksiteID,
	@iDoseParameterTypeCode,
	@sDoseParameterValue
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRSubmissionHistoryDoseParameterID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Update]
	@iANRDRSubmissionHistoryDoseParameterID int,
	@iANRDRSubmissionID int,
	@iANRDRSubmissionHistoryWorksiteID int,
	@iDoseParameterTypeCode int,
	@sDoseParameterValue varchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDoseParameter]
SET 
	[ANRDRSubmissionID] = @iANRDRSubmissionID,
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID,
	[DoseParameterTypeCode] = @iDoseParameterTypeCode,
	[DoseParameterValue] = @sDoseParameterValue
WHERE
	[ANRDRSubmissionHistoryDoseParameterID] = @iANRDRSubmissionHistoryDoseParameterID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_UpdateAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_UpdateAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_UpdateAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDoseParameter]
SET
	[ANRDRSubmissionID] = @iANRDRSubmissionID
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iANRDRSubmissionHistoryWorksiteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryDoseParameter]
SET
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_Delete]
	@iANRDRSubmissionHistoryDoseParameterID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
WHERE
	[ANRDRSubmissionHistoryDoseParameterID] = @iANRDRSubmissionHistoryDoseParameterID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_DeleteAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_DeleteAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_DeleteAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectOne]
	@iANRDRSubmissionHistoryDoseParameterID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
WHERE
	[ANRDRSubmissionHistoryDoseParameterID] = @iANRDRSubmissionHistoryDoseParameterID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
ORDER BY 
	[ANRDRSubmissionHistoryDoseParameterID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
ORDER BY 
	[ANRDRSubmissionHistoryDoseParameterID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryDoseParameter_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryDoseParameter]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
ORDER BY 
	[ANRDRSubmissionHistoryDoseParameterID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_Insert]
	@iANRDRSubmissionID int,
	@iWearerInternalID int,
	@iCentreInternalID int,
	@iANRDRSubmissionHistoryWorksiteID int,
	@sCentreNo varchar(max),
	@sANRDRNumber nvarchar(max),
	@sEmployeeNumber varchar(max),
	@sWearerNo varchar(max),
	@sWearer varchar(max),
	@sSurname varchar(max),
	@sGivenName varchar(max),
	@sSecondGivenName varchar(max),
	@sGender nvarchar(1),
	@daDateOfBirth datetime,
	@sWorkerClassification varchar(max),
	@sNoOfDoseTypes varchar(max),
	@iANRDRSubmissionHistoryWorkerID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRSubmissionHistoryWorker]
(
	[ANRDRSubmissionID],
	[WearerInternalID],
	[CentreInternalID],
	[ANRDRSubmissionHistoryWorksiteID],
	[CentreNo],
	[ANRDRNumber],
	[EmployeeNumber],
	[WearerNo],
	[Wearer],
	[Surname],
	[GivenName],
	[SecondGivenName],
	[Gender],
	[DateOfBirth],
	[WorkerClassification],
	[NoOfDoseTypes]
)
VALUES
(
	@iANRDRSubmissionID,
	@iWearerInternalID,
	@iCentreInternalID,
	@iANRDRSubmissionHistoryWorksiteID,
	@sCentreNo,
	@sANRDRNumber,
	@sEmployeeNumber,
	@sWearerNo,
	@sWearer,
	@sSurname,
	@sGivenName,
	@sSecondGivenName,
	@sGender,
	@daDateOfBirth,
	@sWorkerClassification,
	@sNoOfDoseTypes
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRSubmissionHistoryWorkerID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_Update]
	@iANRDRSubmissionHistoryWorkerID int,
	@iANRDRSubmissionID int,
	@iWearerInternalID int,
	@iCentreInternalID int,
	@iANRDRSubmissionHistoryWorksiteID int,
	@sCentreNo varchar(max),
	@sANRDRNumber nvarchar(max),
	@sEmployeeNumber varchar(max),
	@sWearerNo varchar(max),
	@sWearer varchar(max),
	@sSurname varchar(max),
	@sGivenName varchar(max),
	@sSecondGivenName varchar(max),
	@sGender nvarchar(1),
	@daDateOfBirth datetime,
	@sWorkerClassification varchar(max),
	@sNoOfDoseTypes varchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorker]
SET 
	[ANRDRSubmissionID] = @iANRDRSubmissionID,
	[WearerInternalID] = @iWearerInternalID,
	[CentreInternalID] = @iCentreInternalID,
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID,
	[CentreNo] = @sCentreNo,
	[ANRDRNumber] = @sANRDRNumber,
	[EmployeeNumber] = @sEmployeeNumber,
	[WearerNo] = @sWearerNo,
	[Wearer] = @sWearer,
	[Surname] = @sSurname,
	[GivenName] = @sGivenName,
	[SecondGivenName] = @sSecondGivenName,
	[Gender] = @sGender,
	[DateOfBirth] = @daDateOfBirth,
	[WorkerClassification] = @sWorkerClassification,
	[NoOfDoseTypes] = @sNoOfDoseTypes
WHERE
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorker]
SET
	[ANRDRSubmissionID] = @iANRDRSubmissionID
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWWearerInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWWearerInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWWearerInternalIDLogic]
	@iWearerInternalID int,
	@iWearerInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorker]
SET
	[WearerInternalID] = @iWearerInternalID
WHERE
	[WearerInternalID] = @iWearerInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iCentreInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorker]
SET
	[CentreInternalID] = @iCentreInternalID
WHERE
	[CentreInternalID] = @iCentreInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_UpdateAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iANRDRSubmissionHistoryWorksiteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorker]
SET
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_Delete]
	@iANRDRSubmissionHistoryWorkerID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWWearerInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWWearerInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWWearerInternalIDLogic]
	@iWearerInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[WearerInternalID] = @iWearerInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_DeleteAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectOne]
	@iANRDRSubmissionHistoryWorkerID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[ANRDRSubmissionHistoryWorkerID] = @iANRDRSubmissionHistoryWorkerID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorker]
ORDER BY 
	[ANRDRSubmissionHistoryWorkerID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
ORDER BY 
	[ANRDRSubmissionHistoryWorkerID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWWearerInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWWearerInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWWearerInternalIDLogic]
	@iWearerInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[WearerInternalID] = @iWearerInternalID
ORDER BY 
	[ANRDRSubmissionHistoryWorkerID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWCentreInternalIDLogic]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[CentreInternalID] = @iCentreInternalID
ORDER BY 
	[ANRDRSubmissionHistoryWorkerID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorker_SelectAllWANRDRSubmissionHistoryWorksiteIDLogic]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorker]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
ORDER BY 
	[ANRDRSubmissionHistoryWorkerID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_Insert]
	@iANRDRSubmissionID int,
	@iANRDRWorksiteID int,
	@sANRDRWorksiteName nvarchar(150),
	@iANRDRIndustryClassification int,
	@iANRDRWorksiteNumber int,
	@sANRDRStandardNameOrDoseEvaluationProcedure varchar(max),
	@iANRDRSubmissionHistoryWorksiteID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRSubmissionHistoryWorksite]
(
	[ANRDRSubmissionID],
	[ANRDRWorksiteID],
	[ANRDRWorksiteName],
	[ANRDRIndustryClassification],
	[ANRDRWorksiteNumber],
	[ANRDRStandardNameOrDoseEvaluationProcedure]
)
VALUES
(
	@iANRDRSubmissionID,
	@iANRDRWorksiteID,
	@sANRDRWorksiteName,
	@iANRDRIndustryClassification,
	@iANRDRWorksiteNumber,
	@sANRDRStandardNameOrDoseEvaluationProcedure
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRSubmissionHistoryWorksiteID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_Update]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iANRDRSubmissionID int,
	@iANRDRWorksiteID int,
	@sANRDRWorksiteName nvarchar(150),
	@iANRDRIndustryClassification int,
	@iANRDRWorksiteNumber int,
	@sANRDRStandardNameOrDoseEvaluationProcedure varchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorksite]
SET 
	[ANRDRSubmissionID] = @iANRDRSubmissionID,
	[ANRDRWorksiteID] = @iANRDRWorksiteID,
	[ANRDRWorksiteName] = @sANRDRWorksiteName,
	[ANRDRIndustryClassification] = @iANRDRIndustryClassification,
	[ANRDRWorksiteNumber] = @iANRDRWorksiteNumber,
	[ANRDRStandardNameOrDoseEvaluationProcedure] = @sANRDRStandardNameOrDoseEvaluationProcedure
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_UpdateAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_UpdateAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_UpdateAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iANRDRSubmissionIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorksite]
SET
	[ANRDRSubmissionID] = @iANRDRSubmissionID
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_UpdateAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_UpdateAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_UpdateAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iANRDRWorksiteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRSubmissionHistoryWorksite]
SET
	[ANRDRWorksiteID] = @iANRDRWorksiteID
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_Delete]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_DeleteAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_DeleteAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_DeleteAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_DeleteAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_DeleteAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_DeleteAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectOne]
	@iANRDRSubmissionHistoryWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
WHERE
	[ANRDRSubmissionHistoryWorksiteID] = @iANRDRSubmissionHistoryWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
ORDER BY 
	[ANRDRSubmissionHistoryWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAllWANRDRSubmissionIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAllWANRDRSubmissionIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAllWANRDRSubmissionIDLogic]
	@iANRDRSubmissionID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
WHERE
	[ANRDRSubmissionID] = @iANRDRSubmissionID
ORDER BY 
	[ANRDRSubmissionHistoryWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRSubmissionHistoryWorksite_SelectAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRSubmissionHistoryWorksite]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
ORDER BY 
	[ANRDRSubmissionHistoryWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_Insert]
	@sANRDRWorksiteName nvarchar(150),
	@iDefaultProviderID int,
	@iSystemInstanceID int,
	@iOrganisationID int,
	@iANRDRIndustryClassification int,
	@iANRDRWorksiteNumber int,
	@sANRDRStandardNameOrDoseEvaluationProcedure varchar(max),
	@iANRDRWorksiteID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRWorksite]
(
	[ANRDRWorksiteName],
	[DefaultProviderID],
	[SystemInstanceID],
	[OrganisationID],
	[ANRDRIndustryClassification],
	[ANRDRWorksiteNumber],
	[ANRDRStandardNameOrDoseEvaluationProcedure]
)
VALUES
(
	@sANRDRWorksiteName,
	@iDefaultProviderID,
	@iSystemInstanceID,
	@iOrganisationID,
	@iANRDRIndustryClassification,
	@iANRDRWorksiteNumber,
	@sANRDRStandardNameOrDoseEvaluationProcedure
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRWorksiteID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_Update]
	@iANRDRWorksiteID int,
	@sANRDRWorksiteName nvarchar(150),
	@iDefaultProviderID int,
	@iSystemInstanceID int,
	@iOrganisationID int,
	@iANRDRIndustryClassification int,
	@iANRDRWorksiteNumber int,
	@sANRDRStandardNameOrDoseEvaluationProcedure varchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRWorksite]
SET 
	[ANRDRWorksiteName] = @sANRDRWorksiteName,
	[DefaultProviderID] = @iDefaultProviderID,
	[SystemInstanceID] = @iSystemInstanceID,
	[OrganisationID] = @iOrganisationID,
	[ANRDRIndustryClassification] = @iANRDRIndustryClassification,
	[ANRDRWorksiteNumber] = @iANRDRWorksiteNumber,
	[ANRDRStandardNameOrDoseEvaluationProcedure] = @sANRDRStandardNameOrDoseEvaluationProcedure
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_UpdateAllWDefaultProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_UpdateAllWDefaultProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_UpdateAllWDefaultProviderIDLogic]
	@iDefaultProviderID int,
	@iDefaultProviderIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRWorksite]
SET
	[DefaultProviderID] = @iDefaultProviderID
WHERE
	[DefaultProviderID] = @iDefaultProviderIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_UpdateAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_UpdateAllWSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_UpdateAllWSystemInstanceIDLogic]
	@iSystemInstanceID int,
	@iSystemInstanceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRWorksite]
SET
	[SystemInstanceID] = @iSystemInstanceID
WHERE
	[SystemInstanceID] = @iSystemInstanceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRWorksite]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_Delete]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRWorksite]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_DeleteAllWDefaultProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_DeleteAllWDefaultProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_DeleteAllWDefaultProviderIDLogic]
	@iDefaultProviderID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRWorksite]
WHERE
	[DefaultProviderID] = @iDefaultProviderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_DeleteAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_DeleteAllWSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_DeleteAllWSystemInstanceIDLogic]
	@iSystemInstanceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRWorksite]
WHERE
	[SystemInstanceID] = @iSystemInstanceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRWorksite]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_SelectOne]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksite]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksite]
ORDER BY 
	[ANRDRWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_SelectAllWDefaultProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_SelectAllWDefaultProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_SelectAllWDefaultProviderIDLogic]
	@iDefaultProviderID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksite]
WHERE
	[DefaultProviderID] = @iDefaultProviderID
ORDER BY 
	[ANRDRWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_SelectAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_SelectAllWSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_SelectAllWSystemInstanceIDLogic]
	@iSystemInstanceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksite]
WHERE
	[SystemInstanceID] = @iSystemInstanceID
ORDER BY 
	[ANRDRWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksite_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksite_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksite_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksite]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[ANRDRWorksiteID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Insert]
	@iANRDRWorksiteID int,
	@iDoseParameterTypeCode int,
	@sDoseParameterValue varchar(max),
	@iANRDRWorksiteDefaultDoseParameterID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblANRDRWorksiteDefaultDoseParameter]
(
	[ANRDRWorksiteID],
	[DoseParameterTypeCode],
	[DoseParameterValue]
)
VALUES
(
	@iANRDRWorksiteID,
	@iDoseParameterTypeCode,
	@sDoseParameterValue
)
SELECT @iErrorCode=@@ERROR
SELECT @iANRDRWorksiteDefaultDoseParameterID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Update]
	@iANRDRWorksiteDefaultDoseParameterID int,
	@iANRDRWorksiteID int,
	@iDoseParameterTypeCode int,
	@sDoseParameterValue varchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRWorksiteDefaultDoseParameter]
SET 
	[ANRDRWorksiteID] = @iANRDRWorksiteID,
	[DoseParameterTypeCode] = @iDoseParameterTypeCode,
	[DoseParameterValue] = @sDoseParameterValue
WHERE
	[ANRDRWorksiteDefaultDoseParameterID] = @iANRDRWorksiteDefaultDoseParameterID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_UpdateAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_UpdateAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_UpdateAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iANRDRWorksiteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblANRDRWorksiteDefaultDoseParameter]
SET
	[ANRDRWorksiteID] = @iANRDRWorksiteID
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_Delete]
	@iANRDRWorksiteDefaultDoseParameterID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblANRDRWorksiteDefaultDoseParameter]
WHERE
	[ANRDRWorksiteDefaultDoseParameterID] = @iANRDRWorksiteDefaultDoseParameterID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_DeleteAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_DeleteAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_DeleteAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblANRDRWorksiteDefaultDoseParameter]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectOne]
	@iANRDRWorksiteDefaultDoseParameterID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksiteDefaultDoseParameter]
WHERE
	[ANRDRWorksiteDefaultDoseParameterID] = @iANRDRWorksiteDefaultDoseParameterID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksiteDefaultDoseParameter]
ORDER BY 
	[ANRDRWorksiteDefaultDoseParameterID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblANRDRWorksiteDefaultDoseParameter_SelectAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblANRDRWorksiteDefaultDoseParameter]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
ORDER BY 
	[ANRDRWorksiteDefaultDoseParameterID] ASC
SELECT @iErrorCode=@@ERROR
GO




-- ====================================
-- End ANRDR Constellation SPROCS
-- ====================================

-- vwDxContacts ==================================================================================================

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwDxContacts_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwDxContacts_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwDxContacts_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwDxContacts]
SELECT @iErrorCode=@@ERROR
GO

-- ===============================================================================================================

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_Insert]
	@iCentreInternalID int,
	@iANRDRWorksiteID int,
	@sDescription nvarchar(255),
	@sLocation nvarchar(255),
	@sCostCentre nvarchar(255),
	@sNotes nvarchar(255),
	@iStatusID int,
	@iProviderID int,
	@sCentreNo varchar(max),
	@iSystemInstanceID int,
	@sName varchar(255),
	@bIsDefaultCentre bit,
	@iOrganisationID int,
	@sReportingDescription nvarchar(max),
	@iCampusID int,
	@iBusinessUnitID int,
	@iSiteLocationID int,
	@iPremisesID int,
	@iReportAsCentreInternalID int,
	@iWearerDefaultNationalRegisterClassification int,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblCentre]
(
	[CentreInternalID],
	[ANRDRWorksiteID],
	[Description],
	[Location],
	[CostCentre],
	[Notes],
	[StatusID],
	[ProviderID],
	[CentreNo],
	[SystemInstanceID],
	[Name],
	[IsDefaultCentre],
	[OrganisationID],
	[ReportingDescription],
	[CampusID],
	[BusinessUnitID],
	[SiteLocationID],
	[PremisesID],
	[ReportAsCentreInternalID],
	[WearerDefaultNationalRegisterClassification]
)
VALUES
(
	@iCentreInternalID,
	@iANRDRWorksiteID,
	@sDescription,
	@sLocation,
	@sCostCentre,
	@sNotes,
	@iStatusID,
	@iProviderID,
	@sCentreNo,
	@iSystemInstanceID,
	@sName,
	@bIsDefaultCentre,
	@iOrganisationID,
	@sReportingDescription,
	@iCampusID,
	@iBusinessUnitID,
	@iSiteLocationID,
	@iPremisesID,
	@iReportAsCentreInternalID,
	@iWearerDefaultNationalRegisterClassification
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_Update]
	@iCentreInternalID int,
	@iANRDRWorksiteID int,
	@sDescription nvarchar(255),
	@sLocation nvarchar(255),
	@sCostCentre nvarchar(255),
	@sNotes nvarchar(255),
	@iStatusID int,
	@iProviderID int,
	@sCentreNo varchar(max),
	@iSystemInstanceID int,
	@sName varchar(255),
	@bIsDefaultCentre bit,
	@iOrganisationID int,
	@sReportingDescription nvarchar(max),
	@iCampusID int,
	@iBusinessUnitID int,
	@iSiteLocationID int,
	@iPremisesID int,
	@iReportAsCentreInternalID int,
	@iWearerDefaultNationalRegisterClassification int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET 
	[ANRDRWorksiteID] = @iANRDRWorksiteID,
	[Description] = @sDescription,
	[Location] = @sLocation,
	[CostCentre] = @sCostCentre,
	[Notes] = @sNotes,
	[StatusID] = @iStatusID,
	[ProviderID] = @iProviderID,
	[CentreNo] = @sCentreNo,
	[SystemInstanceID] = @iSystemInstanceID,
	[Name] = @sName,
	[IsDefaultCentre] = @bIsDefaultCentre,
	[OrganisationID] = @iOrganisationID,
	[ReportingDescription] = @sReportingDescription,
	[CampusID] = @iCampusID,
	[BusinessUnitID] = @iBusinessUnitID,
	[SiteLocationID] = @iSiteLocationID,
	[PremisesID] = @iPremisesID,
	[ReportAsCentreInternalID] = @iReportAsCentreInternalID,
	[WearerDefaultNationalRegisterClassification] = @iWearerDefaultNationalRegisterClassification
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iANRDRWorksiteIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[ANRDRWorksiteID] = @iANRDRWorksiteID
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWProviderIDLogic]
	@iProviderID int,
	@iProviderIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[ProviderID] = @iProviderID
WHERE
	[ProviderID] = @iProviderIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWSystemInstanceIDLogic]
	@iSystemInstanceID int,
	@iSystemInstanceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[SystemInstanceID] = @iSystemInstanceID
WHERE
	[SystemInstanceID] = @iSystemInstanceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iBusinessUnitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[BusinessUnitID] = @iBusinessUnitID
WHERE
	[BusinessUnitID] = @iBusinessUnitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_UpdateAllWReportAsCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_UpdateAllWReportAsCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_UpdateAllWReportAsCentreInternalIDLogic]
	@iReportAsCentreInternalID int,
	@iReportAsCentreInternalIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblCentre]
SET
	[ReportAsCentreInternalID] = @iReportAsCentreInternalID
WHERE
	[ReportAsCentreInternalID] = @iReportAsCentreInternalIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_Delete]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblCentre]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWProviderIDLogic]
	@iProviderID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[ProviderID] = @iProviderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWSystemInstanceIDLogic]
	@iSystemInstanceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[SystemInstanceID] = @iSystemInstanceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_DeleteAllWReportAsCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_DeleteAllWReportAsCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_DeleteAllWReportAsCentreInternalIDLogic]
	@iReportAsCentreInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblCentre]
WHERE
	[ReportAsCentreInternalID] = @iReportAsCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectOne]
	@iCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[CentreInternalID] = @iCentreInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWANRDRWorksiteIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWANRDRWorksiteIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWANRDRWorksiteIDLogic]
	@iANRDRWorksiteID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[ANRDRWorksiteID] = @iANRDRWorksiteID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWProviderIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWProviderIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWProviderIDLogic]
	@iProviderID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[ProviderID] = @iProviderID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWSystemInstanceIDLogic]
	@iSystemInstanceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[SystemInstanceID] = @iSystemInstanceID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblCentre_SelectAllWReportAsCentreInternalIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblCentre_SelectAllWReportAsCentreInternalIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblCentre_SelectAllWReportAsCentreInternalIDLogic]
	@iReportAsCentreInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblCentre]
WHERE
	[ReportAsCentreInternalID] = @iReportAsCentreInternalID
ORDER BY 
	[CentreInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

-- ====================================
--  UserFolder and Wearer SPROCS
-- ====================================

SET NOCOUNT ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_Insert]
	@sUserID varchar(50),
	@sBulkDoseReportImportFolder nvarchar(500),
	@bBulkDoseReportImportFolderSaveLastUsed bit,
	@sDoseReportFolder nvarchar(500),
	@bDoseReportFolderSaveLastUsed bit,
	@sEquipmentDefectFolder nvarchar(500),
	@bEquipmentDefectFolderSaveLastUsed bit,
	@sEquipmentFolder nvarchar(500),
	@bEquipmentFolderSaveLastUsed bit,
	@sEquipmentImportFolder nvarchar(500),
	@bEquipmentImportFolderSaveLastUsed bit,
	@sEquipmentOperatorFolder nvarchar(500),
	@bEquipmentOperatorFolderSaveLastUsed bit,
	@sEquipmentServiceFolder nvarchar(500),
	@bEquipmentServiceFolderSaveLastUsed bit,
	@sEquipmentTestFolder nvarchar(500),
	@bEquipmentTestFolderSaveLastUsed bit,
	@sFileDocumentFolder nvarchar(500),
	@bFileDocumentFolderSaveLastUsed bit,
	@sLicenceFileFolder nvarchar(500),
	@bLicenceFileFolderSaveLastUsed bit,
	@sLicencePermitFolder nvarchar(500),
	@bLicencePermitFolderSaveLastUsed bit,
	@sProtectiveDeviceFolder nvarchar(500),
	@bProtectiveDeviceFolderSaveLastUsed bit,
	@sProtectiveDeviceImportFolder nvarchar(500),
	@bProtectiveDeviceImportFolderSaveLastUsed bit,
	@sReportExportToFolder nvarchar(500),
	@bReportExportToFolderSaveLastUsed bit,
	@sSpecificationFolder nvarchar(500),
	@bSpecificationFolderSaveLastUsed bit,
	@sTrainingCourseFolder nvarchar(500),
	@bTrainingCourseFolderSaveLastUsed bit,
	@sTrainingQualificationFolder nvarchar(500),
	@bTrainingQualificationFolderSaveLastUsed bit,
	@sWearerDataImportFolder nvarchar(500),
	@bWearerDataImportFolderSaveLastUsed bit,
	@sWearerPhotoFolder nvarchar(500),
	@bWearerPhotoFolderSaveLastUsed bit,
	@sWearerTrainingFolder nvarchar(500),
	@bWearerTrainingFolderSaveLastUsed bit,
	@sXTfrReportExport nvarchar(500),
	@bXTfrReportExportSaveLastUsed bit,
	@sXTfrReportImport nvarchar(500),
	@bXTfrReportImportSaveLastUsed bit,
	@sXTfrWearerExport nvarchar(500),
	@bXTfrWearerExportSaveLastUsed bit,
	@sXTfrWearerImport nvarchar(500),
	@bXTfrWearerImportSaveLastUsed bit,
	@iUserFolderID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblUserFolder]
(
	[UserID],
	[BulkDoseReportImportFolder],
	[BulkDoseReportImportFolderSaveLastUsed],
	[DoseReportFolder],
	[DoseReportFolderSaveLastUsed],
	[EquipmentDefectFolder],
	[EquipmentDefectFolderSaveLastUsed],
	[EquipmentFolder],
	[EquipmentFolderSaveLastUsed],
	[EquipmentImportFolder],
	[EquipmentImportFolderSaveLastUsed],
	[EquipmentOperatorFolder],
	[EquipmentOperatorFolderSaveLastUsed],
	[EquipmentServiceFolder],
	[EquipmentServiceFolderSaveLastUsed],
	[EquipmentTestFolder],
	[EquipmentTestFolderSaveLastUsed],
	[FileDocumentFolder],
	[FileDocumentFolderSaveLastUsed],
	[LicenceFileFolder],
	[LicenceFileFolderSaveLastUsed],
	[LicencePermitFolder],
	[LicencePermitFolderSaveLastUsed],
	[ProtectiveDeviceFolder],
	[ProtectiveDeviceFolderSaveLastUsed],
	[ProtectiveDeviceImportFolder],
	[ProtectiveDeviceImportFolderSaveLastUsed],
	[ReportExportToFolder],
	[ReportExportToFolderSaveLastUsed],
	[SpecificationFolder],
	[SpecificationFolderSaveLastUsed],
	[TrainingCourseFolder],
	[TrainingCourseFolderSaveLastUsed],
	[TrainingQualificationFolder],
	[TrainingQualificationFolderSaveLastUsed],
	[WearerDataImportFolder],
	[WearerDataImportFolderSaveLastUsed],
	[WearerPhotoFolder],
	[WearerPhotoFolderSaveLastUsed],
	[WearerTrainingFolder],
	[WearerTrainingFolderSaveLastUsed],
	[XTfrReportExport],
	[XTfrReportExportSaveLastUsed],
	[XTfrReportImport],
	[XTfrReportImportSaveLastUsed],
	[XTfrWearerExport],
	[XTfrWearerExportSaveLastUsed],
	[XTfrWearerImport],
	[XTfrWearerImportSaveLastUsed]
)
VALUES
(
	@sUserID,
	@sBulkDoseReportImportFolder,
	ISNULL(@bBulkDoseReportImportFolderSaveLastUsed, ((1))),
	@sDoseReportFolder,
	ISNULL(@bDoseReportFolderSaveLastUsed, ((1))),
	@sEquipmentDefectFolder,
	ISNULL(@bEquipmentDefectFolderSaveLastUsed, ((1))),
	@sEquipmentFolder,
	ISNULL(@bEquipmentFolderSaveLastUsed, ((1))),
	@sEquipmentImportFolder,
	ISNULL(@bEquipmentImportFolderSaveLastUsed, ((1))),
	@sEquipmentOperatorFolder,
	ISNULL(@bEquipmentOperatorFolderSaveLastUsed, ((1))),
	@sEquipmentServiceFolder,
	ISNULL(@bEquipmentServiceFolderSaveLastUsed, ((1))),
	@sEquipmentTestFolder,
	ISNULL(@bEquipmentTestFolderSaveLastUsed, ((1))),
	@sFileDocumentFolder,
	ISNULL(@bFileDocumentFolderSaveLastUsed, ((1))),
	@sLicenceFileFolder,
	ISNULL(@bLicenceFileFolderSaveLastUsed, ((1))),
	@sLicencePermitFolder,
	ISNULL(@bLicencePermitFolderSaveLastUsed, ((1))),
	@sProtectiveDeviceFolder,
	ISNULL(@bProtectiveDeviceFolderSaveLastUsed, ((1))),
	@sProtectiveDeviceImportFolder,
	ISNULL(@bProtectiveDeviceImportFolderSaveLastUsed, ((1))),
	@sReportExportToFolder,
	ISNULL(@bReportExportToFolderSaveLastUsed, ((1))),
	@sSpecificationFolder,
	ISNULL(@bSpecificationFolderSaveLastUsed, ((1))),
	@sTrainingCourseFolder,
	ISNULL(@bTrainingCourseFolderSaveLastUsed, ((1))),
	@sTrainingQualificationFolder,
	ISNULL(@bTrainingQualificationFolderSaveLastUsed, ((1))),
	@sWearerDataImportFolder,
	ISNULL(@bWearerDataImportFolderSaveLastUsed, ((1))),
	@sWearerPhotoFolder,
	ISNULL(@bWearerPhotoFolderSaveLastUsed, ((1))),
	@sWearerTrainingFolder,
	ISNULL(@bWearerTrainingFolderSaveLastUsed, ((1))),
	@sXTfrReportExport,
	ISNULL(@bXTfrReportExportSaveLastUsed, ((1))),
	@sXTfrReportImport,
	ISNULL(@bXTfrReportImportSaveLastUsed, ((1))),
	@sXTfrWearerExport,
	ISNULL(@bXTfrWearerExportSaveLastUsed, ((1))),
	@sXTfrWearerImport,
	ISNULL(@bXTfrWearerImportSaveLastUsed, ((1)))
)
SELECT @iErrorCode=@@ERROR
SELECT @iUserFolderID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_Update]
	@iUserFolderID int,
	@sUserID varchar(50),
	@sBulkDoseReportImportFolder nvarchar(500),
	@bBulkDoseReportImportFolderSaveLastUsed bit,
	@sDoseReportFolder nvarchar(500),
	@bDoseReportFolderSaveLastUsed bit,
	@sEquipmentDefectFolder nvarchar(500),
	@bEquipmentDefectFolderSaveLastUsed bit,
	@sEquipmentFolder nvarchar(500),
	@bEquipmentFolderSaveLastUsed bit,
	@sEquipmentImportFolder nvarchar(500),
	@bEquipmentImportFolderSaveLastUsed bit,
	@sEquipmentOperatorFolder nvarchar(500),
	@bEquipmentOperatorFolderSaveLastUsed bit,
	@sEquipmentServiceFolder nvarchar(500),
	@bEquipmentServiceFolderSaveLastUsed bit,
	@sEquipmentTestFolder nvarchar(500),
	@bEquipmentTestFolderSaveLastUsed bit,
	@sFileDocumentFolder nvarchar(500),
	@bFileDocumentFolderSaveLastUsed bit,
	@sLicenceFileFolder nvarchar(500),
	@bLicenceFileFolderSaveLastUsed bit,
	@sLicencePermitFolder nvarchar(500),
	@bLicencePermitFolderSaveLastUsed bit,
	@sProtectiveDeviceFolder nvarchar(500),
	@bProtectiveDeviceFolderSaveLastUsed bit,
	@sProtectiveDeviceImportFolder nvarchar(500),
	@bProtectiveDeviceImportFolderSaveLastUsed bit,
	@sReportExportToFolder nvarchar(500),
	@bReportExportToFolderSaveLastUsed bit,
	@sSpecificationFolder nvarchar(500),
	@bSpecificationFolderSaveLastUsed bit,
	@sTrainingCourseFolder nvarchar(500),
	@bTrainingCourseFolderSaveLastUsed bit,
	@sTrainingQualificationFolder nvarchar(500),
	@bTrainingQualificationFolderSaveLastUsed bit,
	@sWearerDataImportFolder nvarchar(500),
	@bWearerDataImportFolderSaveLastUsed bit,
	@sWearerPhotoFolder nvarchar(500),
	@bWearerPhotoFolderSaveLastUsed bit,
	@sWearerTrainingFolder nvarchar(500),
	@bWearerTrainingFolderSaveLastUsed bit,
	@sXTfrReportExport nvarchar(500),
	@bXTfrReportExportSaveLastUsed bit,
	@sXTfrReportImport nvarchar(500),
	@bXTfrReportImportSaveLastUsed bit,
	@sXTfrWearerExport nvarchar(500),
	@bXTfrWearerExportSaveLastUsed bit,
	@sXTfrWearerImport nvarchar(500),
	@bXTfrWearerImportSaveLastUsed bit,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblUserFolder]
SET 
	[UserID] = @sUserID,
	[BulkDoseReportImportFolder] = @sBulkDoseReportImportFolder,
	[BulkDoseReportImportFolderSaveLastUsed] = @bBulkDoseReportImportFolderSaveLastUsed,
	[DoseReportFolder] = @sDoseReportFolder,
	[DoseReportFolderSaveLastUsed] = @bDoseReportFolderSaveLastUsed,
	[EquipmentDefectFolder] = @sEquipmentDefectFolder,
	[EquipmentDefectFolderSaveLastUsed] = @bEquipmentDefectFolderSaveLastUsed,
	[EquipmentFolder] = @sEquipmentFolder,
	[EquipmentFolderSaveLastUsed] = @bEquipmentFolderSaveLastUsed,
	[EquipmentImportFolder] = @sEquipmentImportFolder,
	[EquipmentImportFolderSaveLastUsed] = @bEquipmentImportFolderSaveLastUsed,
	[EquipmentOperatorFolder] = @sEquipmentOperatorFolder,
	[EquipmentOperatorFolderSaveLastUsed] = @bEquipmentOperatorFolderSaveLastUsed,
	[EquipmentServiceFolder] = @sEquipmentServiceFolder,
	[EquipmentServiceFolderSaveLastUsed] = @bEquipmentServiceFolderSaveLastUsed,
	[EquipmentTestFolder] = @sEquipmentTestFolder,
	[EquipmentTestFolderSaveLastUsed] = @bEquipmentTestFolderSaveLastUsed,
	[FileDocumentFolder] = @sFileDocumentFolder,
	[FileDocumentFolderSaveLastUsed] = @bFileDocumentFolderSaveLastUsed,
	[LicenceFileFolder] = @sLicenceFileFolder,
	[LicenceFileFolderSaveLastUsed] = @bLicenceFileFolderSaveLastUsed,
	[LicencePermitFolder] = @sLicencePermitFolder,
	[LicencePermitFolderSaveLastUsed] = @bLicencePermitFolderSaveLastUsed,
	[ProtectiveDeviceFolder] = @sProtectiveDeviceFolder,
	[ProtectiveDeviceFolderSaveLastUsed] = @bProtectiveDeviceFolderSaveLastUsed,
	[ProtectiveDeviceImportFolder] = @sProtectiveDeviceImportFolder,
	[ProtectiveDeviceImportFolderSaveLastUsed] = @bProtectiveDeviceImportFolderSaveLastUsed,
	[ReportExportToFolder] = @sReportExportToFolder,
	[ReportExportToFolderSaveLastUsed] = @bReportExportToFolderSaveLastUsed,
	[SpecificationFolder] = @sSpecificationFolder,
	[SpecificationFolderSaveLastUsed] = @bSpecificationFolderSaveLastUsed,
	[TrainingCourseFolder] = @sTrainingCourseFolder,
	[TrainingCourseFolderSaveLastUsed] = @bTrainingCourseFolderSaveLastUsed,
	[TrainingQualificationFolder] = @sTrainingQualificationFolder,
	[TrainingQualificationFolderSaveLastUsed] = @bTrainingQualificationFolderSaveLastUsed,
	[WearerDataImportFolder] = @sWearerDataImportFolder,
	[WearerDataImportFolderSaveLastUsed] = @bWearerDataImportFolderSaveLastUsed,
	[WearerPhotoFolder] = @sWearerPhotoFolder,
	[WearerPhotoFolderSaveLastUsed] = @bWearerPhotoFolderSaveLastUsed,
	[WearerTrainingFolder] = @sWearerTrainingFolder,
	[WearerTrainingFolderSaveLastUsed] = @bWearerTrainingFolderSaveLastUsed,
	[XTfrReportExport] = @sXTfrReportExport,
	[XTfrReportExportSaveLastUsed] = @bXTfrReportExportSaveLastUsed,
	[XTfrReportImport] = @sXTfrReportImport,
	[XTfrReportImportSaveLastUsed] = @bXTfrReportImportSaveLastUsed,
	[XTfrWearerExport] = @sXTfrWearerExport,
	[XTfrWearerExportSaveLastUsed] = @bXTfrWearerExportSaveLastUsed,
	[XTfrWearerImport] = @sXTfrWearerImport,
	[XTfrWearerImportSaveLastUsed] = @bXTfrWearerImportSaveLastUsed
WHERE
	[UserFolderID] = @iUserFolderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_UpdateAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_UpdateAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_UpdateAllWUserIDLogic]
	@sUserID varchar(50),
	@sUserIDOld varchar(50),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblUserFolder]
SET
	[UserID] = @sUserID
WHERE
	[UserID] = @sUserIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_Delete]
	@iUserFolderID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblUserFolder]
WHERE
	[UserFolderID] = @iUserFolderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_DeleteAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_DeleteAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_DeleteAllWUserIDLogic]
	@sUserID varchar(50),
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblUserFolder]
WHERE
	[UserID] = @sUserID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_SelectOne]
	@iUserFolderID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblUserFolder]
WHERE
	[UserFolderID] = @iUserFolderID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblUserFolder]
ORDER BY 
	[UserFolderID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblUserFolder_SelectAllWUserIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblUserFolder_SelectAllWUserIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblUserFolder_SelectAllWUserIDLogic]
	@sUserID varchar(50),
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblUserFolder]
WHERE
	[UserID] = @sUserID
ORDER BY 
	[UserFolderID] ASC
SELECT @iErrorCode=@@ERROR
GO

-- ------------------------------------------
-- tblWearer
-- ------------------------------------------


SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_Insert]
	@iWearerInternalID int,
	@iCurrentCentreInternalID int,
	@sWearer nvarchar(100),
	@sSurname varchar(max),
	@sFirstName varchar(max),
	@sExtension nvarchar(50),
	@sEmail nvarchar(100),
	@sLocation nvarchar(255),
	@iStatusID int,
	@sNotes ntext,
	@iImportedInDoseReportID int,
	@iImportedInCumulativeDoseReportID int,
	@iOccupationCode int,
	@iBusinessUnitID int,
	@iSiteLocationID int,
	@sSex nvarchar(1),
	@daDOB datetime,
	@sHistorionNumber varchar(max),
	@iCreatedSystemInstanceID int,
	@iWearerTypeID int,
	@sOtherGivenNames varchar(max),
	@iANRDREmployeeClassification int,
	@sANRDREmployeeClassificationOther varchar(100),
	@sANRDREmployeeUniqueIdentifier varchar(20),
	@daDateEmploymentStarted datetime,
	@daDateEmploymentCeased datetime,
	@daDateExitReportProvided datetime,
	@iANRDRDefaultReasonCode int,
	@bANRDRReadiness bit,
	@bANRDRExcluded bit,
	@sANRDRExclusionReason nvarchar(255),
	@sANRDRExclusionChangedBy nvarchar(50),
	@daANRDRExclusionChangeDateTime datetime,
	@iCampusID int,
	@iPremisesID int,
	@iEmploymentStatusID int,
	@iOrganisationID int,
	@bRadiationLicenceHolder bit,
	@daLatestReadingEndDate datetime,
	@sANRDRNumber nvarchar(max),
	@sWearerType nvarchar(24),
	@sWearerStatus nvarchar(24),
	@sCurrentCentre nvarchar(max),
	@sEmploymentStatus nvarchar(40),
	@sOrgName nvarchar(200),
	@sBusinessUnitName nvarchar(max),
	@sSiteLocationName nvarchar(max),
	@sOccupationGroup nvarchar(50),
	@sOccupation nvarchar(250),
	@sPayrollNo nvarchar(24),
	@sStudentNo nvarchar(24),
	@sOtherNo nvarchar(24),
	@sOtherID nvarchar(24),
	@sOtherGroup nvarchar(100),
	@sOtherClassification nvarchar(100),
	@sANRDRReady nvarchar(3),
	@sLicenceNumber nvarchar(max),
	@daLicenceExpiryDate datetime,
	@iProjectID int,
	@sProjectName nvarchar(max),
	@daEarliestReadingStartDate datetime,
	@iPregnancyRecords int,
	@iCentresMonitored int,
	@iDoseReadings int,
	@iLicenceHistories int,
	@iFileNotes int,
	@iAttachments int,
	@iTrainingRecords int,
	@iEquipmentOperated int,
	@iProtectiveDevices int,
	@sRadiationLicenceHolderYesNo nvarchar(3),
	@daLatestReadingStartDate datetime,
	@sNameSearchOptimised nvarchar(max),
	@iLicenceIDCurrent int,
	@iAliasNames int,
	@sPrimaryWearerNumber nvarchar(max),
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblWearer]
(
	[WearerInternalID],
	[CurrentCentreInternalID],
	[Wearer],
	[Surname],
	[FirstName],
	[Extension],
	[Email],
	[Location],
	[StatusID],
	[Notes],
	[ImportedInDoseReportID],
	[ImportedInCumulativeDoseReportID],
	[OccupationCode],
	[BusinessUnitID],
	[SiteLocationID],
	[Sex],
	[DOB],
	[HistorionNumber],
	[CreatedSystemInstanceID],
	[WearerTypeID],
	[OtherGivenNames],
	[ANRDREmployeeClassification],
	[ANRDREmployeeClassificationOther],
	[ANRDREmployeeUniqueIdentifier],
	[DateEmploymentStarted],
	[DateEmploymentCeased],
	[DateExitReportProvided],
	[ANRDRDefaultReasonCode],
	[ANRDRReadiness],
	[ANRDRExcluded],
	[ANRDRExclusionReason],
	[ANRDRExclusionChangedBy],
	[ANRDRExclusionChangeDateTime],
	[CampusID],
	[PremisesID],
	[EmploymentStatusID],
	[OrganisationID],
	[RadiationLicenceHolder],
	[LatestReadingEndDate],
	[ANRDRNumber],
	[WearerType],
	[WearerStatus],
	[CurrentCentre],
	[EmploymentStatus],
	[OrgName],
	[BusinessUnitName],
	[SiteLocationName],
	[OccupationGroup],
	[Occupation],
	[PayrollNo],
	[StudentNo],
	[OtherNo],
	[OtherID],
	[OtherGroup],
	[OtherClassification],
	[ANRDRReady],
	[LicenceNumber],
	[LicenceExpiryDate],
	[ProjectID],
	[ProjectName],
	[EarliestReadingStartDate],
	[PregnancyRecords],
	[CentresMonitored],
	[DoseReadings],
	[LicenceHistories],
	[FileNotes],
	[Attachments],
	[TrainingRecords],
	[EquipmentOperated],
	[ProtectiveDevices],
	[RadiationLicenceHolderYesNo],
	[LatestReadingStartDate],
	[NameSearchOptimised],
	[LicenceIDCurrent],
	[AliasNames],
	[PrimaryWearerNumber]
)
VALUES
(
	@iWearerInternalID,
	@iCurrentCentreInternalID,
	@sWearer,
	@sSurname,
	@sFirstName,
	@sExtension,
	@sEmail,
	@sLocation,
	@iStatusID,
	@sNotes,
	@iImportedInDoseReportID,
	@iImportedInCumulativeDoseReportID,
	@iOccupationCode,
	@iBusinessUnitID,
	@iSiteLocationID,
	@sSex,
	@daDOB,
	@sHistorionNumber,
	@iCreatedSystemInstanceID,
	@iWearerTypeID,
	@sOtherGivenNames,
	@iANRDREmployeeClassification,
	@sANRDREmployeeClassificationOther,
	@sANRDREmployeeUniqueIdentifier,
	@daDateEmploymentStarted,
	@daDateEmploymentCeased,
	@daDateExitReportProvided,
	ISNULL(@iANRDRDefaultReasonCode, ((1))),
	ISNULL(@bANRDRReadiness, ((0))),
	@bANRDRExcluded,
	@sANRDRExclusionReason,
	@sANRDRExclusionChangedBy,
	@daANRDRExclusionChangeDateTime,
	@iCampusID,
	@iPremisesID,
	@iEmploymentStatusID,
	@iOrganisationID,
	@bRadiationLicenceHolder,
	@daLatestReadingEndDate,
	@sANRDRNumber,
	@sWearerType,
	@sWearerStatus,
	@sCurrentCentre,
	@sEmploymentStatus,
	@sOrgName,
	@sBusinessUnitName,
	@sSiteLocationName,
	@sOccupationGroup,
	@sOccupation,
	@sPayrollNo,
	@sStudentNo,
	@sOtherNo,
	@sOtherID,
	@sOtherGroup,
	@sOtherClassification,
	@sANRDRReady,
	@sLicenceNumber,
	@daLicenceExpiryDate,
	@iProjectID,
	@sProjectName,
	@daEarliestReadingStartDate,
	@iPregnancyRecords,
	@iCentresMonitored,
	@iDoseReadings,
	@iLicenceHistories,
	@iFileNotes,
	@iAttachments,
	@iTrainingRecords,
	@iEquipmentOperated,
	@iProtectiveDevices,
	@sRadiationLicenceHolderYesNo,
	@daLatestReadingStartDate,
	@sNameSearchOptimised,
	@iLicenceIDCurrent,
	@iAliasNames,
	@sPrimaryWearerNumber
)
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_Update]
	@iWearerInternalID int,
	@iCurrentCentreInternalID int,
	@sWearer nvarchar(100),
	@sSurname varchar(max),
	@sFirstName varchar(max),
	@sExtension nvarchar(50),
	@sEmail nvarchar(100),
	@sLocation nvarchar(255),
	@iStatusID int,
	@sNotes ntext,
	@iImportedInDoseReportID int,
	@iImportedInCumulativeDoseReportID int,
	@iOccupationCode int,
	@iBusinessUnitID int,
	@iSiteLocationID int,
	@sSex nvarchar(1),
	@daDOB datetime,
	@sHistorionNumber varchar(max),
	@iCreatedSystemInstanceID int,
	@iWearerTypeID int,
	@sOtherGivenNames varchar(max),
	@iANRDREmployeeClassification int,
	@sANRDREmployeeClassificationOther varchar(100),
	@sANRDREmployeeUniqueIdentifier varchar(20),
	@daDateEmploymentStarted datetime,
	@daDateEmploymentCeased datetime,
	@daDateExitReportProvided datetime,
	@iANRDRDefaultReasonCode int,
	@bANRDRReadiness bit,
	@bANRDRExcluded bit,
	@sANRDRExclusionReason nvarchar(255),
	@sANRDRExclusionChangedBy nvarchar(50),
	@daANRDRExclusionChangeDateTime datetime,
	@iCampusID int,
	@iPremisesID int,
	@iEmploymentStatusID int,
	@iOrganisationID int,
	@bRadiationLicenceHolder bit,
	@daLatestReadingEndDate datetime,
	@sANRDRNumber nvarchar(max),
	@sWearerType nvarchar(24),
	@sWearerStatus nvarchar(24),
	@sCurrentCentre nvarchar(max),
	@sEmploymentStatus nvarchar(40),
	@sOrgName nvarchar(200),
	@sBusinessUnitName nvarchar(max),
	@sSiteLocationName nvarchar(max),
	@sOccupationGroup nvarchar(50),
	@sOccupation nvarchar(250),
	@sPayrollNo nvarchar(24),
	@sStudentNo nvarchar(24),
	@sOtherNo nvarchar(24),
	@sOtherID nvarchar(24),
	@sOtherGroup nvarchar(100),
	@sOtherClassification nvarchar(100),
	@sANRDRReady nvarchar(3),
	@sLicenceNumber nvarchar(max),
	@daLicenceExpiryDate datetime,
	@iProjectID int,
	@sProjectName nvarchar(max),
	@daEarliestReadingStartDate datetime,
	@iPregnancyRecords int,
	@iCentresMonitored int,
	@iDoseReadings int,
	@iLicenceHistories int,
	@iFileNotes int,
	@iAttachments int,
	@iTrainingRecords int,
	@iEquipmentOperated int,
	@iProtectiveDevices int,
	@sRadiationLicenceHolderYesNo nvarchar(3),
	@daLatestReadingStartDate datetime,
	@sNameSearchOptimised nvarchar(max),
	@iLicenceIDCurrent int,
	@iAliasNames int,
	@sPrimaryWearerNumber nvarchar(max),
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblWearer]
SET 
	[CurrentCentreInternalID] = @iCurrentCentreInternalID,
	[Wearer] = @sWearer,
	[Surname] = @sSurname,
	[FirstName] = @sFirstName,
	[Extension] = @sExtension,
	[Email] = @sEmail,
	[Location] = @sLocation,
	[StatusID] = @iStatusID,
	[Notes] = @sNotes,
	[ImportedInDoseReportID] = @iImportedInDoseReportID,
	[ImportedInCumulativeDoseReportID] = @iImportedInCumulativeDoseReportID,
	[OccupationCode] = @iOccupationCode,
	[BusinessUnitID] = @iBusinessUnitID,
	[SiteLocationID] = @iSiteLocationID,
	[Sex] = @sSex,
	[DOB] = @daDOB,
	[HistorionNumber] = @sHistorionNumber,
	[CreatedSystemInstanceID] = @iCreatedSystemInstanceID,
	[WearerTypeID] = @iWearerTypeID,
	[OtherGivenNames] = @sOtherGivenNames,
	[ANRDREmployeeClassification] = @iANRDREmployeeClassification,
	[ANRDREmployeeClassificationOther] = @sANRDREmployeeClassificationOther,
	[ANRDREmployeeUniqueIdentifier] = @sANRDREmployeeUniqueIdentifier,
	[DateEmploymentStarted] = @daDateEmploymentStarted,
	[DateEmploymentCeased] = @daDateEmploymentCeased,
	[DateExitReportProvided] = @daDateExitReportProvided,
	[ANRDRDefaultReasonCode] = @iANRDRDefaultReasonCode,
	[ANRDRReadiness] = @bANRDRReadiness,
	[ANRDRExcluded] = @bANRDRExcluded,
	[ANRDRExclusionReason] = @sANRDRExclusionReason,
	[ANRDRExclusionChangedBy] = @sANRDRExclusionChangedBy,
	[ANRDRExclusionChangeDateTime] = @daANRDRExclusionChangeDateTime,
	[CampusID] = @iCampusID,
	[PremisesID] = @iPremisesID,
	[EmploymentStatusID] = @iEmploymentStatusID,
	[OrganisationID] = @iOrganisationID,
	[RadiationLicenceHolder] = @bRadiationLicenceHolder,
	[LatestReadingEndDate] = @daLatestReadingEndDate,
	[ANRDRNumber] = @sANRDRNumber,
	[WearerType] = @sWearerType,
	[WearerStatus] = @sWearerStatus,
	[CurrentCentre] = @sCurrentCentre,
	[EmploymentStatus] = @sEmploymentStatus,
	[OrgName] = @sOrgName,
	[BusinessUnitName] = @sBusinessUnitName,
	[SiteLocationName] = @sSiteLocationName,
	[OccupationGroup] = @sOccupationGroup,
	[Occupation] = @sOccupation,
	[PayrollNo] = @sPayrollNo,
	[StudentNo] = @sStudentNo,
	[OtherNo] = @sOtherNo,
	[OtherID] = @sOtherID,
	[OtherGroup] = @sOtherGroup,
	[OtherClassification] = @sOtherClassification,
	[ANRDRReady] = @sANRDRReady,
	[LicenceNumber] = @sLicenceNumber,
	[LicenceExpiryDate] = @daLicenceExpiryDate,
	[ProjectID] = @iProjectID,
	[ProjectName] = @sProjectName,
	[EarliestReadingStartDate] = @daEarliestReadingStartDate,
	[PregnancyRecords] = @iPregnancyRecords,
	[CentresMonitored] = @iCentresMonitored,
	[DoseReadings] = @iDoseReadings,
	[LicenceHistories] = @iLicenceHistories,
	[FileNotes] = @iFileNotes,
	[Attachments] = @iAttachments,
	[TrainingRecords] = @iTrainingRecords,
	[EquipmentOperated] = @iEquipmentOperated,
	[ProtectiveDevices] = @iProtectiveDevices,
	[RadiationLicenceHolderYesNo] = @sRadiationLicenceHolderYesNo,
	[LatestReadingStartDate] = @daLatestReadingStartDate,
	[NameSearchOptimised] = @sNameSearchOptimised,
	[LicenceIDCurrent] = @iLicenceIDCurrent,
	[AliasNames] = @iAliasNames,
	[PrimaryWearerNumber] = @sPrimaryWearerNumber
WHERE
	[WearerInternalID] = @iWearerInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_UpdateAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_UpdateAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_UpdateAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iBusinessUnitIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblWearer]
SET
	[BusinessUnitID] = @iBusinessUnitID
WHERE
	[BusinessUnitID] = @iBusinessUnitIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_UpdateAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_UpdateAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_UpdateAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iSiteLocationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblWearer]
SET
	[SiteLocationID] = @iSiteLocationID
WHERE
	[SiteLocationID] = @iSiteLocationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_UpdateAllWCreatedSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_UpdateAllWCreatedSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_UpdateAllWCreatedSystemInstanceIDLogic]
	@iCreatedSystemInstanceID int,
	@iCreatedSystemInstanceIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblWearer]
SET
	[CreatedSystemInstanceID] = @iCreatedSystemInstanceID
WHERE
	[CreatedSystemInstanceID] = @iCreatedSystemInstanceIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_UpdateAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_UpdateAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_UpdateAllWPremisesIDLogic]
	@iPremisesID int,
	@iPremisesIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblWearer]
SET
	[PremisesID] = @iPremisesID
WHERE
	[PremisesID] = @iPremisesIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_UpdateAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_UpdateAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_UpdateAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iOrganisationIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblWearer]
SET
	[OrganisationID] = @iOrganisationID
WHERE
	[OrganisationID] = @iOrganisationIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_Delete]
	@iWearerInternalID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblWearer]
WHERE
	[WearerInternalID] = @iWearerInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_DeleteAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_DeleteAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_DeleteAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblWearer]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_DeleteAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_DeleteAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_DeleteAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblWearer]
WHERE
	[SiteLocationID] = @iSiteLocationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_DeleteAllWCreatedSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_DeleteAllWCreatedSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_DeleteAllWCreatedSystemInstanceIDLogic]
	@iCreatedSystemInstanceID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblWearer]
WHERE
	[CreatedSystemInstanceID] = @iCreatedSystemInstanceID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_DeleteAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_DeleteAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_DeleteAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblWearer]
WHERE
	[PremisesID] = @iPremisesID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_DeleteAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_DeleteAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_DeleteAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblWearer]
WHERE
	[OrganisationID] = @iOrganisationID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectOne]
	@iWearerInternalID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
WHERE
	[WearerInternalID] = @iWearerInternalID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
ORDER BY 
	[WearerInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectAllWBusinessUnitIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectAllWBusinessUnitIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectAllWBusinessUnitIDLogic]
	@iBusinessUnitID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
WHERE
	[BusinessUnitID] = @iBusinessUnitID
ORDER BY 
	[WearerInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[WearerInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectAllWCreatedSystemInstanceIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectAllWCreatedSystemInstanceIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectAllWCreatedSystemInstanceIDLogic]
	@iCreatedSystemInstanceID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
WHERE
	[CreatedSystemInstanceID] = @iCreatedSystemInstanceID
ORDER BY 
	[WearerInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectAllWPremisesIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectAllWPremisesIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectAllWPremisesIDLogic]
	@iPremisesID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
WHERE
	[PremisesID] = @iPremisesID
ORDER BY 
	[WearerInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblWearer_SelectAllWOrganisationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblWearer_SelectAllWOrganisationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblWearer_SelectAllWOrganisationIDLogic]
	@iOrganisationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblWearer]
WHERE
	[OrganisationID] = @iOrganisationID
ORDER BY 
	[WearerInternalID] ASC
SELECT @iErrorCode=@@ERROR
GO

-- ====================================
-- vwDxGroup SPROC
-- ====================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwDxGroups_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwDxGroups_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwDxGroups_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwDxGroups]
SELECT @iErrorCode=@@ERROR
GO

-- ====================================
-- End vwDxGroup SPROC
-- ====================================

-- ====================================
-- vwDxGroupMembers SPROC
-- ====================================

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwDxGroupMembers_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwDxGroupMembers_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwDxGroupMembers_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwDxGroupMembers]
SELECT @iErrorCode=@@ERROR
GO

-- ====================================
-- End vwDxGroupMembers SPROC
-- ====================================

-- ====================================
-- Start tblEquipmentSecurity SPROCS
-- ====================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_Insert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_Insert]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_Insert]
	@iEquipmentID int,
	@iEquipmentSecurityGroupType int,
	@iEquipmentSecurityMemberID int,
	@iEquipmentSecurityMode int,
	@sEquipmentSecurityNote nvarchar(max),
	@sAddedBy varchar(50),
	@daAddedDateTime datetime,
	@sLastUpdatedBy varchar(50),
	@daLastUpdatedDateTime datetime,
	@iEquipmentSecurityID int OUTPUT,
	@iErrorCode int OUTPUT
AS
INSERT [dbo].[tblEquipmentSecurity]
(
	[EquipmentID],
	[EquipmentSecurityGroupType],
	[EquipmentSecurityMemberID],
	[EquipmentSecurityMode],
	[EquipmentSecurityNote],
	[AddedBy],
	[AddedDateTime],
	[LastUpdatedBy],
	[LastUpdatedDateTime]
)
VALUES
(
	@iEquipmentID,
	@iEquipmentSecurityGroupType,
	@iEquipmentSecurityMemberID,
	@iEquipmentSecurityMode,
	@sEquipmentSecurityNote,
	@sAddedBy,
	@daAddedDateTime,
	@sLastUpdatedBy,
	@daLastUpdatedDateTime
)
SELECT @iErrorCode=@@ERROR
SELECT @iEquipmentSecurityID=SCOPE_IDENTITY()
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_Update]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_Update]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_Update]
	@iEquipmentSecurityID int,
	@iEquipmentID int,
	@iEquipmentSecurityGroupType int,
	@iEquipmentSecurityMemberID int,
	@iEquipmentSecurityMode int,
	@sEquipmentSecurityNote nvarchar(max),
	@sAddedBy varchar(50),
	@daAddedDateTime datetime,
	@sLastUpdatedBy varchar(50),
	@daLastUpdatedDateTime datetime,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipmentSecurity]
SET 
	[EquipmentID] = @iEquipmentID,
	[EquipmentSecurityGroupType] = @iEquipmentSecurityGroupType,
	[EquipmentSecurityMemberID] = @iEquipmentSecurityMemberID,
	[EquipmentSecurityMode] = @iEquipmentSecurityMode,
	[EquipmentSecurityNote] = @sEquipmentSecurityNote,
	[AddedBy] = @sAddedBy,
	[AddedDateTime] = @daAddedDateTime,
	[LastUpdatedBy] = @sLastUpdatedBy,
	[LastUpdatedDateTime] = @daLastUpdatedDateTime
WHERE
	[EquipmentSecurityID] = @iEquipmentSecurityID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_UpdateAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_UpdateAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_UpdateAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iEquipmentIDOld int,
	@iErrorCode int OUTPUT
AS
UPDATE [dbo].[tblEquipmentSecurity]
SET
	[EquipmentID] = @iEquipmentID
WHERE
	[EquipmentID] = @iEquipmentIDOld
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_Delete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_Delete]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_Delete]
	@iEquipmentSecurityID int,
	@iErrorCode int OUTPUT
AS
DELETE FROM [dbo].[tblEquipmentSecurity]
WHERE
	[EquipmentSecurityID] = @iEquipmentSecurityID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_DeleteAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_DeleteAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_DeleteAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
DELETE
FROM [dbo].[tblEquipmentSecurity]
WHERE
	[EquipmentID] = @iEquipmentID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_SelectOne]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_SelectOne]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_SelectOne]
	@iEquipmentSecurityID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentSecurity]
WHERE
	[EquipmentSecurityID] = @iEquipmentSecurityID
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentSecurity]
ORDER BY 
	[EquipmentSecurityID] ASC
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_tblEquipmentSecurity_SelectAllWEquipmentIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_tblEquipmentSecurity_SelectAllWEquipmentIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_tblEquipmentSecurity_SelectAllWEquipmentIDLogic]
	@iEquipmentID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[tblEquipmentSecurity]
WHERE
	[EquipmentID] = @iEquipmentID
ORDER BY 
	[EquipmentSecurityID] ASC
SELECT @iErrorCode=@@ERROR
GO



-- ====================================
-- End tblEquipmentSecurity SPROCS
-- ====================================

-- ====================================
-- New Exceptions view SPROCS
-- ====================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwExceptionsAll_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwExceptionsAll_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwExceptionsAll_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwExceptionsAll]
SELECT @iErrorCode=@@ERROR
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwExceptionsWearers_SelectAll]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwExceptionsWearers_SelectAll]
GO

CREATE PROCEDURE [dbo].[pr_vwExceptionsWearers_SelectAll]
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwExceptionsWearers]
SELECT @iErrorCode=@@ERROR
GO

-- ====================================
-- End new Exceptions view SPROCS
-- ====================================


-- ====================================
-- Custom SPROCS
-- ====================================

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pr_vwSiteLocationContact_SelectAllWSiteLocationIDLogic]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[pr_vwSiteLocationContact_SelectAllWSiteLocationIDLogic]
GO

CREATE PROCEDURE [dbo].[pr_vwSiteLocationContact_SelectAllWSiteLocationIDLogic]
	@iSiteLocationID int,
	@iErrorCode int OUTPUT
AS
SELECT * FROM [dbo].[vwSiteLocationContacts]
WHERE
	[SiteLocationID] = @iSiteLocationID
ORDER BY 
	[Surname] ASC
SELECT @iErrorCode=@@ERROR
GO


-- =======================================================================================================================================
-- Start Equipment View Speed Transformation SPROC apr_CrossRef_Data_Equipment
-- =======================================================================================================================================

Print 'apr_CrossRef_Data_Equipment'
Print ' '
GO

SET NOCOUNT ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[apr_CrossRef_Data_Equipment]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[apr_CrossRef_Data_Equipment]
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =======================================================================================================================================
-- Start Equipment View Speed Transformation SPROC apr_CrossRef_Data_Equipment
-- =======================================================================================================================================
CREATE PROCEDURE [dbo].[apr_CrossRef_Data_Equipment]
	@EquipmentID int,
	@iErrorCode int OUTPUT
AS

	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

IF OBJECT_ID(N'tempdb..#Equiptemp') IS NOT NULL
BEGIN
DROP TABLE #Equiptemp
END


BEGIN
SELECT *
INTO #Equiptemp
FROM tblEquipment WHERE EquipmentID = @EquipmentID
END

-- ======================================================================================================================================= 
	BEGIN
		DELETE tblEquipmentView WHERE tblEquipmentView.EquipmentID = @EquipmentID
	END
-- =======================================================================================================================================

BEGIN
INSERT INTO [dbo].[tblEquipmentView] 
		   ([EquipmentID]
		   ,[EquipmentStatus]
           ,[DateRegistered]
           ,[Brand]
           ,[Model]
           ,[Classification]
           ,[RegAuthorityIDNo]
           ,[LicenceNumber]
           ,[DateAcquired]
           ,[DateOfDisposal]
           ,[SerialNo]
		   ,[ISONumber]
		   ,[AssetNumber]
		   ,[DateManufactured]
		   ,[DateLastTested]
		   ,[WorkingLife]
		   ,[DateWorkingLifeExpiry]
		   ,[EquipmentNotes]
		   ,[EquipmentName]
		   ,[Manufacturer]
		   ,[BuildingPrefixName]
		   ,[BuildingNumber]
		   ,[UnitNumber]
		   ,[StreetName]
		   ,[Suburb]
		   ,[State]
		   ,[Postcode]
		   ,[ControlGenManufacturer]
		   ,[ControlGenModel]
		   ,[ControlGenSerial]
		   ,[TubeHousingManufacturer]
		   ,[TubeHousingModel]
		   ,[TubeHousingSerial]
		   ,[TubeInsertManufacturer]
		   ,[TubeInsertModel]
		   ,[TubeInsertSerial]
		   ,[Category]
		   ,[NominalActivity]
		   ,[RegAuthorityIDNoPrev]
		   ,[LicenceNumberPrev]
		   ,[HasComplianceCertificate]
		   ,[AssayDate]
		   ,[ComplianceCertExpiry]
		   ,[SendComplianceCertReminder]
		   ,[SendComplianceCertReminderTo]
		   ,[OtherApparatus]
		   ,[OtherSealedSourceDevice]
		   ,[PermittedPractice]
		   ,[PermittedLocation]
		   ,[PermittedIonisingApparatus]
		   ,[PermittedPurpose]
		   ,[PermittedSealedSource]
		   ,[PermittedRadionuclide]
		   ,[MaxPermittedActivity]
		   ,[ResponsibleDepartment]
		   ,[EquipmentType]
		   ,[Vendor]
		   ,[VendorDetails]
		   ,[TypicalProcedure]
		   ,[TypicalShielding]
		   ,[ServiceCost]
		   ,[TestingCost]
		   ,[ReplacementCost]
		   ,[TotalDepreciation]
		   ,[DepreciationDesc]
		   ,[RentalCost]
		   ,[RunningCost]
		   ,[OtherCostA]
		   ,[OtherCostADesc]
		   ,[OtherCostB]
		   ,[OtherCostBDesc]
		   ,[CostsNote]
		   ,[DatePurchased]
		   ,[DateWarrantyExpires]
		   ,[DateGuaranteeExpires]
		   ,[WarrantyConditions]
		   ,[GuranteeConditions]
		   ,[PurchaseCost]
		   ,[DatePlannedExpiration]
		   ,[DisposalCost]
		   ,[DisposalVendorContact]
		   ,[DisposalMethod]
		   ,[DisposalConfirmation]
		   ,[DisposalEnvironmental]
		   ,[DisposalPermitNumber]
		   ,[DisposalPermitDate]
		   ,[DisposalPermitConditions]
		   ,[TestingFrequency]
		   ,[DateNextTestExpected]
		   ,[DateNextTestScheduled]
		   ,[AuditFrequency]
		   ,[DateLastAudit]
		   ,[LastAuditConductedBy]
		   ,[LastAuditConductedLicenceNo]
		   ,[DateNextAuditExpected]
		   ,[DateNextAuditScheduled]
		   ,[LastAuditOutcomeSummary]
		   ,[LastAuditOutcomeDetail]
		   ,[DateDecommissioned]
		   ,[AltLocalEquipmentID]
		   ,[ARPANSALADNumber]
		   ,[IntendedPurpose]
		   ,[OperatingParameter]
		   ,[LikelyExposure]
		   ,[LocationOther]
		   ,[ApprovalSubmissionDate]
		   ,[Approval]
		   ,[DisposalApprovalGranted]
		   ,[DisposalDetails]
		   ,[ActivityDate]
		   ,[ActivityBq]
		   ,[MaxActivityBq]
		   ,[Max_kVp]
		   ,[Max_mA]
		   ,[RecommendedWorkingLife]
		   ,[CurrentActivity]
		   ,[SourceAE]
		   ,[SourceAD]
		   ,[WipeTestDate]
		   ,[Comments]
		   ,[InternalComments]
		   ,[ASNOPermitNo]
		   ,[ASNOBatchNo]
		   ,[LastSightedDate]
		   ,[LastSightedBy]
		   ,[LastSightedComment]
		   ,[AddedBy]
		   ,[AddedDateTime]
		   ,[ModifiedBy]
		   ,[ModifiedDateTime]
		   ,[Latitude]
		   ,[Longitude]
		   )
     	 SELECT 
		   [EquipmentID]
		   ,[EquipmentStatus]
           ,[DateRegistered]
           ,[Brand]
           ,[Model]
           ,[Classification]
           ,[RegAuthorityIDNo]
           ,[LicenceNumber]
           ,[DateAcquired]
           ,[DateOfDisposal]
           ,[SerialNo]
		   ,[ISONumber]
		   ,[AssetNumber]
		   ,[DateManufactured]
		   ,[DateLastTested]
		   ,[WorkingLife]
		   ,[DateWorkingLifeExpiry]
		   ,[EquipmentNotes]
		   ,[EquipmentName]
		   ,[Manufacturer]
		   ,[BuildingPrefixName]
		   ,[BuildingNumber]
		   ,[UnitNumber]
		   ,[StreetName]
		   ,[Suburb]
		   ,[State]
		   ,[Postcode]
		   ,[ControlGenManufacturer]
		   ,[ControlGenModel]
		   ,[ControlGenSerial]
		   ,[TubeHousingManufacturer]
		   ,[TubeHousingModel]
		   ,[TubeHousingSerial]
		   ,[TubeInsertManufacturer]
		   ,[TubeInsertModel]
		   ,[TubeInsertSerial]
		   ,[Category]
		   ,[NominalActivity]
		   ,[RegAuthorityIDNoPrev]
		   ,[LicenceNumberPrev]
		   ,[HasComplianceCertificate]
		   ,[AssayDate]
		   ,[ComplianceCertExpiry]
		   ,[SendComplianceCertReminder]
		   ,[SendComplianceCertReminderTo]
		   ,[OtherApparatus]
		   ,[OtherSealedSourceDevice]
		   ,[PermittedPractice]
		   ,[PermittedLocation]
		   ,[PermittedIonisingApparatus]
		   ,[PermittedPurpose]
		   ,[PermittedSealedSource]
		   ,[PermittedRadionuclide]
		   ,[MaxPermittedActivity]
		   ,[ResponsibleDepartment]
		   ,[EquipmentType]
		   ,[Vendor]
		   ,[VendorDetails]
		   ,[TypicalProcedure]
		   ,[TypicalShielding]
		   ,[ServiceCost]
		   ,[TestingCost]
		   ,[ReplacementCost]
		   ,[TotalDepreciation]
		   ,[DepreciationDesc]
		   ,[RentalCost]
		   ,[RunningCost]
		   ,[OtherCostA]
		   ,[OtherCostADesc]
		   ,[OtherCostB]
		   ,[OtherCostBDesc]
		   ,[CostsNote]
		   ,[DatePurchased]
		   ,[DateWarrantyExpires]
		   ,[DateGuaranteeExpires]
		   ,[WarrantyConditions]
		   ,[GuranteeConditions]
		   ,[PurchaseCost]
		   ,[DatePlannedExpiration]
		   ,[DisposalCost]
		   ,[DisposalVendorContact]
		   ,[DisposalMethod]
		   ,[DisposalConfirmation]
		   ,[DisposalEnvironmental]
		   ,[DisposalPermitNumber]
		   ,[DisposalPermitDate]
		   ,[DisposalPermitConditions]
		   ,[TestingFrequency]
		   ,[DateNextTestExpected]
		   ,[DateNextTestScheduled]
		   ,[AuditFrequency]
		   ,[DateLastAudit]
		   ,[LastAuditConductedBy]
		   ,[LastAuditConductedLicenceNo]
		   ,[DateNextAuditExpected]
		   ,[DateNextAuditScheduled]
		   ,[LastAuditOutcomeSummary]
		   ,[LastAuditOutcomeDetail]
		   ,[DateDecommissioned]
		   ,[AltLocalEquipmentID]
		   ,[ARPANSALADNumber]
		   ,[IntendedPurpose]
		   ,[OperatingParameter]
		   ,[LikelyExposure]
		   ,[LocationOther]
		   ,[ApprovalSubmissionDate]
		   ,[Approval]
		   ,[DisposalApprovalGranted]
		   ,[DisposalDetails]
		   ,[ActivityDate]
		   ,[ActivityBq]
		   ,[MaxActivityBq]
		   ,[Max_kVp]
		   ,[Max_mA]
		   ,[RecommendedWorkingLife]
		   ,[CurrentActivity]
		   ,[SourceAE]
		   ,[SourceAD]
		   ,[WipeTestDate]
		   ,[Comments]
		   ,[InternalComments]
		   ,[ASNOPermitNo]
		   ,[ASNOBatchNo]
		   ,[LastSightedDate]
		   ,[LastSightedBy]
		   ,[LastSightedComment]
		   ,[AddedBy]
		   ,[AddedDateTime]
		   ,[ModifiedBy]
		   ,[ModifiedDateTime]
		   ,[Latitude]
		   ,[Longitude]
	FROM  [dbo].[tblEquipment]
	WHERE [dbo].[tblEquipment].[EquipmentID] = @EquipmentID
	END

--EquipmentTypeID > EquipmentType
BEGIN 
DECLARE @EquipmentType NVARCHAR(500);
SET @EquipmentType = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 48 AND Code = ISNULL((SELECT EquipmentTypeID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET EquipmentType = @EquipmentType WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--RadioNuclideID
BEGIN 
DECLARE @RadioNuclide NVARCHAR(400);
SET @RadioNuclide = (SELECT Description FROM tblRefRadioNuclide 
		WHERE RadioNuclideID = ISNULL((SELECT RadioNuclideID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET RadioNuclide = @RadioNuclide WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--EquipmentStatusID
BEGIN 
DECLARE @EquipmentStatus NVARCHAR(500);
SET @EquipmentStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 74 AND Code = ISNULL((SELECT EquipmentTypeID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET EquipmentStatus = @EquipmentStatus WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--ApparatusDescriptionID
BEGIN 
DECLARE @ApparatusDescription NVARCHAR(500);
SET @ApparatusDescription = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 71 AND Code = ISNULL((SELECT ApparatusDescriptionID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET ApparatusDescription = @ApparatusDescription WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--CostGroupID
BEGIN 
DECLARE @CostGroup NVARCHAR(max);
SET @CostGroup = (SELECT CostGroup + ' - ' + CostGroupDescriptor FROM tblRefCostGroup 
		WHERE CostGroupID = ISNULL((SELECT CostGroupID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET CostGroup = @CostGroup WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--SealedSourceDescriptionID
BEGIN 
DECLARE @SealedSourceDescription NVARCHAR(500);
SET @SealedSourceDescription = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 73 AND Code = ISNULL((SELECT SealedSourceDescriptionID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET SealedSourceDescription = @SealedSourceDescription WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--SecurityClassificationID
BEGIN 
DECLARE @SecurityClassification NVARCHAR(500);
SET @SecurityClassification = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 82 AND Code = ISNULL((SELECT SecurityClassificationID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET SecurityClassification = @SecurityClassification WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--CampusID
BEGIN 
DECLARE @Campus NVARCHAR(100);
SET @Campus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 70 AND Code = ISNULL((SELECT CampusID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET Campus = @Campus WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--SiteLocationID
BEGIN 
DECLARE @SiteLocationName NVARCHAR(max);
SET @SiteLocationName = (SELECT SiteLocationName FROM tblSiteLocation 
		WHERE SiteLocationID = ISNULL((SELECT SiteLocationID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET SiteLocationName = @SiteLocationName WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--BusinessUnitID
BEGIN 
DECLARE @BusinessUnitName NVARCHAR(max);
SET @BusinessUnitName = (SELECT BusinessUnitName FROM tblBusinessUnit 
		WHERE BusinessUnitID = ISNULL((SELECT BusinessUnitID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET BusinessUnitName = @BusinessUnitName WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--CentreInternalID
BEGIN 
DECLARE @CentreNo VARCHAR(max);
SET @CentreNo = (SELECT CentreNo FROM tblCentre 
		WHERE CentreInternalID = ISNULL((SELECT CentreInternalID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET CentreNo = @CentreNo WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

BEGIN 
DECLARE @CentreName VARCHAR(max);
SET @CentreName = (SELECT [Name] FROM tblCentre 
		WHERE CentreInternalID = ISNULL((SELECT CentreInternalID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET CentreName = @CentreName WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--PremisesID
BEGIN 
DECLARE @NameOfPremises VARCHAR(100);
SET @NameOfPremises = (SELECT NameOfPremises FROM tblPremises
		WHERE PremisesID = ISNULL((SELECT PremisesID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET NameOfPremises = @NameOfPremises WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--RequiresTesting
BEGIN 
DECLARE @RequiresTesting NVARCHAR(500);
SET @RequiresTesting = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 62 AND Code <> 4 AND Code = ISNULL((SELECT RequiresTesting FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET RequiresTesting = @RequiresTesting WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DisposalConfirmed
BEGIN 
DECLARE @DisposalConfirmed NVARCHAR(500);
SET @DisposalConfirmed = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 62 AND Code <> 4 AND Code = ISNULL((SELECT DisposalConfirmed FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DisposalConfirmed = @DisposalConfirmed WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DisposalPermitRequired
BEGIN 
DECLARE @DisposalPermitRequired NVARCHAR(500);
SET @DisposalPermitRequired = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 62 AND Code <> 4 AND Code = ISNULL((SELECT DisposalPermitRequired FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DisposalPermitRequired = @DisposalPermitRequired WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DisposalPermitObtained
BEGIN 
DECLARE @DisposalPermitObtained NVARCHAR(500);
SET @DisposalPermitObtained = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 62 AND Code <> 4 AND Code = ISNULL((SELECT DisposalPermitObtained FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DisposalPermitObtained = @DisposalPermitObtained WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--RequiresAuditing
BEGIN 
DECLARE @RequiresAuditing NVARCHAR(500);
SET @RequiresAuditing = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 62 AND Code <> 4 AND Code = ISNULL((SELECT RequiresAuditing FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET RequiresAuditing = @RequiresAuditing WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--EquipmentFlagFollowup
BEGIN 
DECLARE @EquipmentFlagFollowup NVARCHAR(500);
SET @EquipmentFlagFollowup = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 63 AND Code = ISNULL((SELECT EquipmentFlagFollowup FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET EquipmentFlagFollowup = @EquipmentFlagFollowup WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--FacilityID
BEGIN 
DECLARE @Facility NVARCHAR(200);
SET @Facility = (SELECT EquipmentName FROM tblEquipment
		WHERE EquipmentID = ISNULL((SELECT FacilityID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET Facility = @Facility WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--ARPANSAStatusID
BEGIN 
DECLARE @ARPANSAStatus NVARCHAR(500);
SET @ARPANSAStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 101 AND Code = ISNULL((SELECT ARPANSAStatusID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET ARPANSAStatus = @ARPANSAStatus WHERE tblEquipmentView.EquipmentID = @EquipmentID
END


--InventoryStatusID
BEGIN 
DECLARE @InventoryStatus NVARCHAR(500);
SET @InventoryStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 102 AND Code = ISNULL((SELECT InventoryStatusID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET InventoryStatus = @InventoryStatus WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DisposalStatusID
BEGIN 
DECLARE @DisposalStatus NVARCHAR(500);
SET @DisposalStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 103 AND Code = ISNULL((SELECT DisposalStatusID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DisposalStatus = @DisposalStatus WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--ChemicalFormID
BEGIN 
DECLARE @ChemicalForm NVARCHAR(500);
SET @ChemicalForm = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 108 AND Code = ISNULL((SELECT ChemicalFormID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET ChemicalForm = @ChemicalForm WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--PhysicalFormID
BEGIN 
DECLARE @PhysicalForm NVARCHAR(500);
SET @PhysicalForm = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 107 AND Code = ISNULL((SELECT PhysicalFormID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET PhysicalForm = @PhysicalForm WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--PortabilityID
BEGIN 
DECLARE @Portability NVARCHAR(500);
SET @Portability = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 109 AND Code = ISNULL((SELECT PortabilityID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET Portability = @Portability WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--EncapsulationMaterialID
BEGIN 
DECLARE @EncapsulationMaterial NVARCHAR(500);
SET @EncapsulationMaterial = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 104 AND Code = ISNULL((SELECT EncapsulationMaterialID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET EncapsulationMaterial = @EncapsulationMaterial WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--RoomID
BEGIN 
DECLARE @RoomName VARCHAR(100);
SET @RoomName = (SELECT RoomName FROM tblRoom
		WHERE RoomID = ISNULL((SELECT RoomID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET RoomName = @RoomName WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--NonIonisingSourceID
BEGIN 
DECLARE @NonIonisingSource NVARCHAR(500);
SET @NonIonisingSource = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 110 AND Code = ISNULL((SELECT NonIonisingSourceID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET NonIonisingSource = @NonIonisingSource WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--SourceType from NonIonising
BEGIN 
IF @NonIonisingSource IS NOT NULL
UPDATE tblEquipmentView SET SourceType = @NonIonisingSource WHERE tblEquipmentView.EquipmentID = @EquipmentID
END



--NonIonisingApparatusTypeID
BEGIN
DECLARE @NonIonisingSourceID int;
DECLARE @NonIonisingApparatusTypeID int;
DECLARE @NonIonisingApparatusType NVARCHAR(500);

SET @NonIonisingSourceID = ISNULL((SELECT NonIonisingSourceID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0)
SET @NonIonisingApparatusTypeID = ISNULL((SELECT NonIonisingApparatusTypeID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0)
SET @NonIonisingApparatusType = CASE @NonIonisingSourceID
                                     WHEN 1 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 117 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 2 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 116 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 3 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 130 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 4 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 119 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 5 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 118 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 6 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 111 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 7 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 112 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 8 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 113 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 9 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 114 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 10 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 115 AND Code = @NonIonisingApparatusTypeID)
                                     WHEN 11 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 120 AND Code = @NonIonisingApparatusTypeID)
								END
UPDATE tblEquipmentView SET NonIonisingApparatusType = @NonIonisingApparatusType WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--ApparatusType from nonIonising 
BEGIN
IF @NonIonisingApparatusType IS NOT NULL
UPDATE tblEquipmentView SET ApparatusType = @NonIonisingApparatusType WHERE tblEquipmentView.EquipmentID = @EquipmentID
END


----IonisingSourceID
BEGIN 
DECLARE @IonisingSource NVARCHAR(500);
SET @IonisingSource = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 122 AND Code = ISNULL((SELECT IonisingSourceID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET IonisingSource = @IonisingSource WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--SourceType from Ionising
BEGIN 
IF @IonisingSource IS NOT NULL
UPDATE tblEquipmentView SET SourceType = @IonisingSource WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

----IonisingApparatusTypeID

BEGIN
DECLARE @IonisingSourceID int;
DECLARE @IonisingApparatusTypeID int;
DECLARE @IonisingApparatusType NVARCHAR(500);

SET @IonisingSourceID = ISNULL((SELECT IonisingSourceID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0)
SET @IonisingApparatusTypeID = ISNULL((SELECT IonisingApparatusTypeID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0)
SET @IonisingApparatusType = CASE @IonisingSourceID
                                     WHEN 1 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 123 AND Code = @IonisingApparatusTypeID)
                                     WHEN 2 THEN (SELECT Description FROM tblReferenceItem WHERE ReferenceTypeID = 125 AND Code = @IonisingApparatusTypeID)
								END
UPDATE tblEquipmentView SET IonisingApparatusType = @IonisingApparatusType WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--ApparatusType from Ionising 
BEGIN
IF @IonisingApparatusType IS NOT NULL
UPDATE tblEquipmentView SET ApparatusType = @IonisingApparatusType WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

----UnsealedSourceID
BEGIN 
DECLARE @UnsealedSource NVARCHAR(500);
SET @UnsealedSource = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 126 AND Code = ISNULL((SELECT UnsealedSourceID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET UnsealedSource = @UnsealedSource WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--SourceType from UnSealedSource
BEGIN 
IF @UnsealedSource IS NOT NULL
UPDATE tblEquipmentView SET SourceType = @UnsealedSource WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

----LicencePermitID
BEGIN 
DECLARE @LicencePermitNo NVARCHAR(max);
SET @LicencePermitNo = (SELECT LicenceNumber FROM tblLicencePermit 
		WHERE LicencePermitID = ISNULL((SELECT LicencePermitID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET LicencePermitNo = @LicencePermitNo WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--EquipmentModelID
BEGIN 
DECLARE @EquipmentModel NVARCHAR(max);
SET @EquipmentModel = (SELECT RTRIM(LTRIM(ModelName + ' ' + ModelNumber)) FROM tblEquipmentModel 
		WHERE EquipmentModelID = ISNULL((SELECT EquipmentModelID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET EquipmentModel = @EquipmentModel WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--ManufacturerID
BEGIN 
DECLARE @Manufacturer VARCHAR(255);
SET @Manufacturer = (SELECT TradingName FROM tblOrganisation 
		WHERE OrganisationID = ISNULL((SELECT ManufacturerID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET Manufacturer = @Manufacturer WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DxSourceCustodianID
BEGIN 
DECLARE @DxSourceCustodian NVARCHAR(max);
SET @DxSourceCustodian = (SELECT FirstName + ' ' + Surname FROM tblDxContact 
		WHERE DxContactID = ISNULL((SELECT DxSourceCustodianID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DxSourceCustodian = @DxSourceCustodian WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DxAreaCustodianID
BEGIN 
DECLARE @DxAreaCustodian NVARCHAR(max);
SET @DxAreaCustodian = (SELECT FirstName + ' ' + Surname FROM tblDxContact 
		WHERE DxContactID = ISNULL((SELECT DxAreaCustodianID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DxAreaCustodian = @DxAreaCustodian WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DxLineManagerID
BEGIN 
DECLARE @DxLineManager NVARCHAR(max);
SET @DxLineManager = (SELECT FirstName + ' ' + Surname FROM tblDxContact 
		WHERE DxContactID = ISNULL((SELECT DxLineManagerID FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DxLineManager = @DxLineManager WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

--DxRSOid
BEGIN 
DECLARE @DxRSO NVARCHAR(max);
SET @DxRSO = (SELECT Surname + ', ' + FirstName FROM tblDxContact 
		WHERE DxContactID = ISNULL((SELECT DxRSOid FROM #Equiptemp WHERE EquipmentID = @EquipmentID),0))
UPDATE tblEquipmentView SET DxRSO = @DxRSO WHERE tblEquipmentView.EquipmentID = @EquipmentID
END

SELECT @iErrorCode=@@ERROR	
GO
-- =======================================================================================================================================
-- End Equipment View Speed Transformation SPROC apr_CrossRef_Data_Equipment
-- =======================================================================================================================================

-- =======================================================================================================================================
-- Start ALL Equipment version of View Speed Transformation SPROC apr_CrossRef_Data_Equipment_All
-- =======================================================================================================================================

SET ANSI_NULLS ON


SET QUOTED_IDENTIFIER ON
GO


if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[apr_CrossRef_Data_Equipment_All]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[apr_CrossRef_Data_Equipment_All]
GO

CREATE PROCEDURE [dbo].[apr_CrossRef_Data_Equipment_All]
	@iErrorCode int OUTPUT
AS

BEGIN
DELETE tblEquipmentView
END 


DECLARE @id INTEGER;
DECLARE @rows_processed INTEGER = 0;
DECLARE cur CURSOR LOCAL FAST_FORWARD

FOR 
SELECT EquipmentID
FROM tblEquipment;
OPEN cur;  
FETCH NEXT FROM cur INTO @id;  

WHILE @@FETCH_STATUS = 0  
BEGIN
DECLARE @iErrorCode2 int
    EXEC dbo.apr_CrossRef_Data_Equipment
			@EquipmentID = @id,
		@iErrorCode = @iErrorCode OUTPUT
    FETCH NEXT FROM cur INTO @id; 
END;
CLOSE cur;  
DEALLOCATE cur;  

SELECT @iErrorCode=@@ERROR	
GO

-- =======================================================================================================================================
-- End ALL Equipment version of View Speed Transformation SPROC apr_CrossRef_Data_Equipment_All
-- =======================================================================================================================================

-- =======================================================================================================================================
-- Replace apr_CrossRef_Data_Wearer to ensure ANRDR compliance includes a First Name and a Surname
-- =======================================================================================================================================

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[apr_CrossRef_Data_Wearer]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[apr_CrossRef_Data_Wearer]
GO

CREATE PROCEDURE [dbo].[apr_CrossRef_Data_Wearer]
	@WearerID int,
	@iErrorCode int OUTPUT
AS

	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

-- =======================================================================================================================================
-- NameSearchOptimised
-- =======================================================================================================================================
   BEGIN
		UPDATE tblWearer SET NameSearchOptimised = REPLACE((Wearer + ' ' + Surname + ' ' + FirstName + ' ' + OtherGivenNames + ' ' + FirstName + ' ' + Surname),',',' ')
		WHERE tblWearer.WearerInternalID = @WearerID
   END

-- =======================================================================================================================================
-- PrimaryWearerNumber
-- =======================================================================================================================================

	-- 5-Character padded prefix text to remove
	DECLARE @PrimaryPrefix varchar(MAX)
	SET @PrimaryPrefix = (SELECT TOP (1) SystemInstanceID FROM tblSystemInstance WHERE isThisSystem = 1)
	SET @PrimaryPrefix = STUFF(@PrimaryPrefix, 1, 0, REPLICATE('0', 5 - LEN(@PrimaryPrefix)))
	SET @PrimaryPrefix = @PrimaryPrefix + '-'
	
	BEGIN
		UPDATE tblWearer SET PrimaryWearerNumber = REPLACE((SELECT TOP 1 WearerNumber FROM tblWearerNumber 
		WHERE tblWearerNumber.WearerInternalID = @WearerID AND PrimaryNumber = 1 ORDER BY WearerNumberID DESC),@PrimaryPrefix,'') 
		WHERE tblWearer.WearerInternalID = @WearerID
	END
	
	BEGIN
		UPDATE tblWearerNumber SET PrimaryNumber = 0
		WHERE REPLACE(tblWearerNumber.WearerNumber,@PrimaryPrefix,'') NOT IN 
		(SELECT PrimaryWearerNumber 
		FROM tblWearer INNER JOIN tblWearerNumber 
		ON tblWearer.PrimaryWearerNumber = REPLACE(tblWearerNumber.WearerNumber,@PrimaryPrefix,''))
		AND WearerInternalID = @WearerID 
	END	


-- =======================================================================================================================================
-- Replace Wearer XRef includes ANRDR Readiness in SPROC
-- =======================================================================================================================================

-- Set Compliant

	BEGIN
		UPDATE tblWearer SET ANRDRReadiness = 1
		WHERE tblWearer.DOB IS NOT NULL
		  AND LEN(LTRIM(RTRIM(tblWearer.Surname))) > 0
		  AND LEN(LTRIM(RTRIM(tblWearer.FirstName))) > 0
		  AND LEN(LTRIM(RTRIM(tblWearer.SEX))) > 0
		  AND (LEN(LTRIM(RTRIM(tblWearer.ANRDRNumber))) > 0 OR LEN(LTRIM(RTRIM(tblWearer.ANRDREmployeeUniqueIdentifier))) > 0)
		  AND tblWearer.WearerInternalID = @WearerID
	END

-- Set Not Compliant

BEGIN
	UPDATE tblWearer SET ANRDRReadiness = 0
	WHERE tblWearer.DOB IS NULL
	  OR LEN(LTRIM(RTRIM(tblWearer.Surname))) = 0
	  OR LEN(LTRIM(RTRIM(tblWearer.FirstName)))  = 0
	  OR LEN(LTRIM(RTRIM(tblWearer.SEX))) = 0
	  OR tblWearer.ANRDREmployeeClassification IS NULL
	  OR (LEN(LTRIM(RTRIM(tblWearer.ANRDRNumber))) = 0 OR tblWearer.ANRDRNumber IS NULL) AND (LEN(LTRIM(RTRIM(tblWearer.ANRDREmployeeUniqueIdentifier))) = 0 OR tblWearer.ANRDREmployeeUniqueIdentifier IS NULL)
	  AND tblWearer.WearerInternalID = @WearerID
END


-- =======================================================================================================================================
-- WearerType
	BEGIN 
		UPDATE tblWearer SET WearerType = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 26 AND Code = ISNULL(tblWearer.WearerTypeID,0))
		WHERE tblWearer.WearerInternalID = @WearerID
	END
-- =======================================================================================================================================	
-- WearerStatus
	BEGIN 
		UPDATE tblWearer SET WearerStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 69 AND Code = ISNULL(tblWearer.StatusID,0))
		WHERE tblWearer.WearerInternalID = @WearerID
	END
-- =======================================================================================================================================
-- CurrentCentre
	BEGIN 
		UPDATE tblWearer SET CurrentCentre = (SELECT CentreNo + ' - ' + Name FROM tblCentre 
		WHERE CentreInternalID = ISNULL(tblWearer.CurrentCentreInternalID,0))
		WHERE tblWearer.WearerInternalID = @WearerID
	END
-- =======================================================================================================================================
-- EmploymentStatus
	BEGIN 
		UPDATE tblWearer SET EmploymentStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 96 AND Code = ISNULL(tblWearer.EmploymentStatusID,0))
		WHERE tblWearer.WearerInternalID = @WearerID
	END
-- =======================================================================================================================================
-- OrgName
	BEGIN 
		UPDATE tblWearer SET OrgName = (SELECT OrgName FROM tblOrganisation 
		WHERE OrganisationID = ISNULL(tblWearer.OrganisationID,0))
		WHERE tblWearer.WearerInternalID = @WearerID		
	END
-- =======================================================================================================================================
-- BusinessUnitName
	BEGIN 
		UPDATE tblWearer SET BusinessUnitName = (SELECT BusinessUnitName FROM tblBusinessUnit 
		WHERE BusinessUnitID = ISNULL(tblWearer.BusinessUnitID,0))
		WHERE tblWearer.WearerInternalID = @WearerID		
	END
-- =======================================================================================================================================
-- SiteLocationName
	BEGIN 
		UPDATE tblWearer SET SiteLocationName = (SELECT SiteLocationName FROM tblSiteLocation 
		WHERE SiteLocationID = ISNULL(tblWearer.SiteLocationID,0))
		WHERE tblWearer.WearerInternalID = @WearerID		
	END
-- =======================================================================================================================================
-- OccupationGroup
	BEGIN 
		UPDATE tblWearer SET OccupationGroup = (SELECT OccupationGroup FROM tblRefOccupationGroup 
		WHERE OccupationGroupID = (Select OccupationGroupID FROM tblRefOccupation WHERE RefOccupationID = ISNULL(tblWearer.OccupationCode,0)))
		WHERE tblWearer.WearerInternalID = @WearerID
	END
-- =======================================================================================================================================
-- Occupation
	BEGIN 
		UPDATE tblWearer SET Occupation = (SELECT Occupation FROM tblRefOccupation 
		WHERE RefOccupationID = ISNULL(tblWearer.OccupationCode,0))
		WHERE tblWearer.WearerInternalID = @WearerID		
	END
-- =======================================================================================================================================
-- ANRDRReady
	BEGIN 
		UPDATE tblWearer SET ANRDRReady = 'Yes' WHERE WearerInternalID = @WearerID AND ISNULL(ANRDRReadiness,0) = 1
	END	
	BEGIN 
		UPDATE tblWearer SET ANRDRReady = 'No' WHERE WearerInternalID = @WearerID AND ISNULL(ANRDRReadiness,0) = 0
	END
-- =======================================================================================================================================
-- LicenceIDCurrent

-- Remove current licence reference that cannot be there due to licence delete

    BEGIN
		UPDATE tblWearer SET LicenceIDCurrent = NULL WHERE NOT EXISTS(SELECT tblWearerLicence.WearerLicenceID FROM tblWearerLicence WHERE tblWearerLicence.WearerLicenceID = tblWearer.LicenceIDCurrent)
		AND tblWearer.WearerInternalID = @WearerID
    END

-- If only one licence update it to latest regardless of dates
	BEGIN
		UPDATE tblWearer SET LicenceIDCurrent = (SELECT MAX(tblWearerLicence.WearerLicenceID) FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND (SELECT COUNT(WearerInternalID) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID) = 1)
		WHERE tblWearer.WearerInternalID = @WearerID
	END 

-- -- Set correct current licence ID in Wearer table
    BEGIN
		UPDATE tblWearer SET LicenceIDCurrent = (SELECT MAX(WearerLicenceID) FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND LicenceExpiryDate = (SELECT MAX(LicenceExpiryDate) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)) 
		WHERE tblWearer.WearerInternalID = @WearerID
    END  

-- If any remaining they mustn't have dates so use first licence recorded         
   BEGIN UPDATE tblWearer SET LicenceIDCurrent = (SELECT MIN(WearerLicenceID) FROM tblWearerLicence
		 WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID) 
		 WHERE LicenceIDCurrent IS NULL AND tblWearer.WearerInternalID = @WearerID
   END

 -- Update the set licence to indicate it is the latest
	BEGIN UPDATE tblWearerLicence SET IsLatest = 1
		WHERE EXISTS(SELECT tblWearer.LicenceIDCurrent FROM tblWearer 
		WHERE tblWearer.LicenceIDCurrent = tblWearerLicence.WearerLicenceID)
		AND tblWearerLicence.WearerInternalID = @WearerID		
	END
   
 -- Update any other licences for the wearer to indicate not the latest if not the LicenceIDCurrent licence    
    BEGIN
		UPDATE tblWearerLicence SET IsLatest = 0 
		WHERE NOT EXISTS(SELECT tblWearer.WearerInternalID FROM tblWearer 
		WHERE tblWearer.LicenceIDCurrent = tblWearerLicence.WearerLicenceID) AND tblWearerLicence.WearerInternalID = @WearerID  
    END    
-- =======================================================================================================================================
-- LicenceNumber
    BEGIN
 		UPDATE tblWearer SET LicenceNumber = (SELECT LicenceNumber FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND IsLatest = 1)
		WHERE tblWearer.WearerInternalID = @WearerID
    END
    BEGIN
		UPDATE tblWearer SET LicenceNumber = (SELECT LicenceNumber FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND LicenceExpiryDate = (SELECT MAX(LicenceExpiryDate) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)) WHERE tblWearer.LicenceNumber IS NULL AND tblWearer.WearerInternalID = @WearerID
    END   
-- =======================================================================================================================================
-- LicenceExpiryDate
    BEGIN
		UPDATE tblWearer SET LicenceExpiryDate = (SELECT LicenceExpiryDate FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND IsLatest = 1)
		WHERE tblWearer.WearerInternalID = @WearerID
    END
    BEGIN
		UPDATE tblWearer SET LicenceExpiryDate = (SELECT LicenceExpiryDate FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND LicenceExpiryDate = (SELECT MAX(LicenceExpiryDate) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)) WHERE tblWearer.LicenceExpiryDate IS NULL AND tblWearer.WearerInternalID =  @WearerID
    END  
-- =======================================================================================================================================			
-- =======================================================================================================================================
-- ProjectName
-- Pending Project Schema
-- =======================================================================================================================================
-- EarliestReadingStartDate
	BEGIN 
		UPDATE tblWearer SET EarliestReadingStartDate = (SELECT MIN(StartDate) FROM tblDoseReportReadingViewField 
		WHERE tblDoseReportReadingViewField.WearerInternalID = @WearerID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END
-- =======================================================================================================================================

-- LatestReadingStartDate
	BEGIN 
		UPDATE tblWearer SET LatestReadingStartDate = (SELECT MIN(StartDate) FROM tblDoseReportReadingViewField 
		WHERE tblDoseReportReadingViewField.WearerInternalID = tblWearer.WearerInternalID AND 
		tblDoseReportReadingViewField.EndDate = (SELECT MAX(EndDate) FROM tblDoseReportReadingViewField 
		WHERE WearerInternalID = tblWearer.WearerInternalID))
		WHERE tblWearer.WearerInternalID = @WearerID	
	END

-- LatestReadingEndDate moved from Historion.exe function for speed improvement.
	BEGIN 
		UPDATE tblWearer SET LatestReadingEndDate = (SELECT MAX(EndDate) FROM tblDoseReportReadingViewField 
		WHERE WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END				
-- =======================================================================================================================================	
-- PregnancyRecords
	BEGIN 
		UPDATE tblWearer SET PregnancyRecords = (SELECT COUNT(PregnancyID) FROM tblPregnancy 
		WHERE tblPregnancy.WearerInternalID = @WearerID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================	
-- CentresMonitored
	BEGIN 
		UPDATE tblWearer SET CentresMonitored = (SELECT COUNT(DISTINCT CentreInternalID) FROM tblJoinCentreWearer 
		WHERE tblJoinCentreWearer.WearerInternalID = @WearerID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================	
-- DoseReadings
	BEGIN 
		UPDATE tblWearer SET DoseReadings = (SELECT COUNT(DoseReportReadingID) FROM tblDoseReportReading 
		WHERE tblDoseReportReading.WearerInternalID = @WearerID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END
	
-- =======================================================================================================================================
-- LicenceHistories
	BEGIN 
		UPDATE tblWearer SET LicenceHistories = (SELECT COUNT(WearerLicenceID) FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================
-- FileNotes
	BEGIN 
		UPDATE tblWearer SET FileNotes = (SELECT COUNT(FileNoteID) FROM tblFileNote 
		WHERE tblFileNote.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================
-- AliasNames
	BEGIN 
		UPDATE tblWearer SET AliasNames = (SELECT COUNT(WearerAlternateNameID) FROM tblWearerAlternateName 
		WHERE tblWearerAlternateName.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================
-- Update any missing document links so attachments lists populate as expected

	INSERT INTO tblLinkWearerDocument (DocumentID, WearerInternalID)
	SELECT tblDocument.DocumentID, tblFileNote.WearerInternalID FROM 
	tblDocument INNER JOIN tblFileNote ON tblDocument.FileNoteID = tblFileNote.FileNoteID
	WHERE DocumentID NOT IN (SELECT DocumentID FROM tblLinkWearerDocument 
	WHERE DocumentID = tblDocument.DocumentID AND WearerInternalID = tblFileNote.WearerInternalID)
	AND WearerInternalID = @WearerID

	INSERT INTO tblLinkWearerDocument (DocumentID, WearerInternalID)
	SELECT tblDocument.DocumentID, tblEquipmentWearer.WearerInternalID FROM 
	tblDocument INNER JOIN tblEquipmentWearer ON tblDocument.EquipmentWearerID = tblEquipmentWearer.EquipmentWearerID
	WHERE DocumentID NOT IN (SELECT DocumentID FROM tblLinkWearerDocument 
	WHERE DocumentID = tblDocument.DocumentID AND WearerInternalID = tblEquipmentWearer.WearerInternalID)
	AND WearerInternalID = @WearerID

	INSERT INTO tblLinkWearerDocument (DocumentID, WearerInternalID)
	SELECT tblDocument.DocumentID, tblWearerTraining.WearerInternalID FROM 
	tblDocument INNER JOIN tblWearerTraining ON tblDocument.WearerTrainingID = tblWearerTraining.WearerTrainingID
	WHERE DocumentID NOT IN (SELECT DocumentID FROM tblLinkWearerDocument 
	WHERE DocumentID = tblDocument.DocumentID AND WearerInternalID = tblWearerTraining.WearerInternalID)
	AND WearerInternalID = @WearerID	


-- Attachments
	BEGIN 
		UPDATE tblWearer SET Attachments = (SELECT COUNT(LinkWearerDocumentID) FROM tblLinkWearerDocument 
		WHERE tblLinkWearerDocument.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================
-- TrainingRecords
	BEGIN 
		UPDATE tblWearer SET TrainingRecords = (SELECT COUNT(WearerTrainingID) FROM tblWearerTraining 
		WHERE tblWearerTraining.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================
-- EquipmentOperated  
	BEGIN 
		UPDATE tblWearer SET EquipmentOperated = (SELECT COUNT(DISTINCT EquipmentID) FROM tblEquipmentWearer 
		WHERE tblEquipmentWearer.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	 
-- =======================================================================================================================================
-- ProtectiveDevices
	BEGIN 
		UPDATE tblWearer SET ProtectiveDevices = (SELECT COUNT(ProtectiveDeviceID) FROM tblProtectiveDevice 
		WHERE tblProtectiveDevice.WearerInternalID = tblWearer.WearerInternalID)
		WHERE tblWearer.WearerInternalID = @WearerID
	END	
-- =======================================================================================================================================		
-- RadiationLicenceHolderYesNo
	BEGIN 
		UPDATE tblWearer SET RadiationLicenceHolderYesNo = 'Yes' WHERE WearerInternalID = @WearerID AND ISNULL(RadiationLicenceHolder,0) = 1
	END	
	BEGIN 
		UPDATE tblWearer SET RadiationLicenceHolderYesNo = 'No' WHERE WearerInternalID = @WearerID AND ISNULL(RadiationLicenceHolder,0) = 0
	END	
-- =======================================================================================================================================
SELECT @iErrorCode=@@ERROR	

-- =======================================================================================================================================
-- End apr_CrossRef_Data_Wearer to ensure ANRDR compliance includes a First Name and a Surname
-- =======================================================================================================================================

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
-- =======================================================================================================================================
-- Replace apr_CrossRef_Data_Wearers to include checking for presence of Firstname and Surname in ANRDR submission readiness
-- =======================================================================================================================================
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[apr_CrossRef_Data_Wearers]') and OBJECTPROPERTY(id, N'IsProcedure') = 1) drop procedure [dbo].[apr_CrossRef_Data_Wearers]
GO


CREATE PROCEDURE [dbo].[apr_CrossRef_Data_Wearers]
	@iErrorCode int OUTPUT
AS

	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

-- =======================================================================================================================================
-- NameSearchOptimised
-- =======================================================================================================================================
   BEGIN
		UPDATE tblWearer SET NameSearchOptimised = REPLACE((Wearer + ' ' + Surname + ' ' + FirstName + ' ' + OtherGivenNames + ' ' + FirstName + ' ' + Surname),',',' ')
   END
   

-- =======================================================================================================================================
-- PrimaryWearerNumber
-- =======================================================================================================================================

	-- 5-Character padded prefix text to remove
	DECLARE @PrimaryPrefix varchar(MAX)
	SET @PrimaryPrefix = (SELECT TOP (1) SystemInstanceID FROM tblSystemInstance WHERE isThisSystem = 1)
	SET @PrimaryPrefix = STUFF(@PrimaryPrefix, 1, 0, REPLICATE('0', 5 - LEN(@PrimaryPrefix)))
	SET @PrimaryPrefix = @PrimaryPrefix + '-'

	--BEGIN
	--	UPDATE tblWearer SET PrimaryWearerNumber = REPLACE((SELECT WearerNumber FROM tblWearerNumber 
	--	WHERE ISNULL(PrimaryNumber,0) = 1 AND tblWearerNumber.WearerInternalID = tblWearer.WearerInternalID),@PrimaryPrefix,'')
	--END

Print '->39270'
	BEGIN
		UPDATE tblWearer SET PrimaryWearerNumber = REPLACE((SELECT TOP 1 WearerNumber FROM tblWearerNumber 
		WHERE ISNULL(PrimaryNumber,0) = 1 AND tblWearerNumber.WearerInternalID = tblWearer.WearerInternalID ORDER BY WearerNumberID DESC),@PrimaryPrefix,'')
	END
Print '->39275'
	BEGIN
		UPDATE tblWearerNumber SET PrimaryNumber = 0
		WHERE REPLACE(tblWearerNumber.WearerNumber,@PrimaryPrefix,'') NOT IN 
		(SELECT PrimaryWearerNumber
		FROM tblWearer INNER JOIN tblWearerNumber 
		ON tblWearer.PrimaryWearerNumber = REPLACE(tblWearerNumber.WearerNumber,@PrimaryPrefix,'')) 
	END	
Print '->39283'

-- =======================================================================================================================================
-- ANRDR Readiness
-- =======================================================================================================================================

-- SET COMPLIANT

-- Set Compliant

BEGIN
	UPDATE tblWearer SET ANRDRReadiness = 1
	WHERE tblWearer.DOB IS NOT NULL
	  AND LTRIM(RTRIM(tblWearer.Surname)) IS NOT NULL
	  AND LTRIM(RTRIM(tblWearer.FirstName)) IS NOT NULL
	  AND LEN(LTRIM(RTRIM(tblWearer.SEX))) > 0 
	  AND tblWearer.ANRDREmployeeClassification IS NOT NULL
	  AND (LEN(LTRIM(RTRIM(tblWearer.ANRDRNumber))) > 0 OR LEN(LTRIM(RTRIM(tblWearer.ANRDREmployeeUniqueIdentifier))) > 0)
END

-- SET NOT COMPLIANT

BEGIN
	UPDATE tblWearer SET ANRDRReadiness = 0
	WHERE tblWearer.DOB IS NULL
	  OR LTRIM(RTRIM(tblWearer.Surname)) IS NULL
	  OR LTRIM(RTRIM(tblWearer.FirstName)) IS NULL	
	  OR LEN(LTRIM(RTRIM(tblWearer.SEX))) = 0
	  OR tblWearer.ANRDREmployeeClassification IS NULL
      OR (LEN(LTRIM(RTRIM(tblWearer.ANRDRNumber))) = 0 OR tblWearer.ANRDRNumber IS NULL) AND (LEN(LTRIM(RTRIM(tblWearer.ANRDREmployeeUniqueIdentifier))) = 0 OR tblWearer.ANRDREmployeeUniqueIdentifier IS NULL)
END

-- =======================================================================================================================================

-- WearerType
	BEGIN 
		UPDATE tblWearer SET WearerType = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 26 AND Code = ISNULL(tblWearer.WearerTypeID,0))
	END
-- =======================================================================================================================================	
-- WearerStatus
	BEGIN 
		UPDATE tblWearer SET WearerStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 69 AND Code = ISNULL(tblWearer.StatusID,0))
	END
-- =======================================================================================================================================
-- CurrentCentre
	BEGIN 
		UPDATE tblWearer SET CurrentCentre = (SELECT CentreNo + ' - ' + Name FROM tblCentre 
		WHERE CentreInternalID = ISNULL(tblWearer.CurrentCentreInternalID,0))
	END
-- =======================================================================================================================================
-- EmploymentStatus
	BEGIN 
		UPDATE tblWearer SET EmploymentStatus = (SELECT Description FROM tblReferenceItem 
		WHERE ReferenceTypeID = 96 AND Code = ISNULL(tblWearer.EmploymentStatusID,0))
	END
-- =======================================================================================================================================
-- OrgName
	BEGIN 
		UPDATE tblWearer SET OrgName = (SELECT OrgName FROM tblOrganisation 
		WHERE OrganisationID = ISNULL(tblWearer.OrganisationID,0))
	END
-- =======================================================================================================================================
-- BusinessUnitName
	BEGIN 
		UPDATE tblWearer SET BusinessUnitName = (SELECT BusinessUnitName FROM tblBusinessUnit 
		WHERE BusinessUnitID = ISNULL(tblWearer.BusinessUnitID,0))
	END
-- =======================================================================================================================================
-- SiteLocationName
	BEGIN 
		UPDATE tblWearer SET SiteLocationName = (SELECT SiteLocationName FROM tblSiteLocation 
		WHERE SiteLocationID = ISNULL(tblWearer.SiteLocationID,0))
	END
-- =======================================================================================================================================
-- OccupationGroup
	BEGIN 
		UPDATE tblWearer SET OccupationGroup = (SELECT OccupationGroup FROM tblRefOccupationGroup 
		WHERE OccupationGroupID = (Select OccupationGroupID FROM tblRefOccupation WHERE RefOccupationID = ISNULL(tblWearer.OccupationCode,0)))
	END
-- =======================================================================================================================================
-- Occupation
	BEGIN 
		UPDATE tblWearer SET Occupation = (SELECT Occupation FROM tblRefOccupation 
		WHERE RefOccupationID = ISNULL(tblWearer.OccupationCode,0))
	END
-- =======================================================================================================================================
-- ANRDRReady
	BEGIN 
		UPDATE tblWearer SET ANRDRReady = 'Yes' WHERE ISNULL(ANRDRReadiness,0) = 1
	END	
	BEGIN 
		UPDATE tblWearer SET ANRDRReady = 'No' WHERE ISNULL(ANRDRReadiness,0) = 0
	END
-- =======================================================================================================================================
-- LicenceIDCurrent

   -- Remove current licence reference that cannot be there due to licence delete
    BEGIN
		UPDATE tblWearer SET LicenceIDCurrent = NULL 
		WHERE NOT EXISTS(SELECT tblWearerLicence.WearerLicenceID FROM tblWearerLicence WHERE tblWearerLicence.WearerLicenceID = tblWearer.LicenceIDCurrent)
    END

-- If only one licence update it to latest regardless of dates
	BEGIN
		UPDATE tblWearer SET LicenceIDCurrent = (SELECT MAX(tblWearerLicence.WearerLicenceID) FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND (SELECT COUNT(WearerInternalID) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID) = 1)
	END 

-- Set correct current licence ID in Wearer table
Print '->39389'
    BEGIN
		UPDATE tblWearer SET LicenceIDCurrent = (SELECT MAX(WearerLicenceID) FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND LicenceExpiryDate = (SELECT MAX(LicenceExpiryDate) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)) 
    END  
Print '->39395'

-- If any remaining they mustn't have dates so use first licence recorded         
   BEGIN UPDATE tblWearer SET LicenceIDCurrent = (SELECT MIN(WearerLicenceID) FROM tblWearerLicence
		 WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID) WHERE LicenceIDCurrent IS NULL
   END

-- Update the set licence to indicate it is the latest
	BEGIN UPDATE tblWearerLicence SET IsLatest = 1
		WHERE EXISTS(SELECT tblWearer.LicenceIDCurrent FROM tblWearer WHERE tblWearer.LicenceIDCurrent = tblWearerLicence.WearerLicenceID)
	END
   
-- Update any other licences for the wearer to indicate not the latest if not the LicenceIDCurrent licence    
    BEGIN
		UPDATE tblWearerLicence SET IsLatest = 0 
		WHERE NOT EXISTS(SELECT tblWearer.WearerInternalID FROM tblWearer WHERE tblWearer.LicenceIDCurrent = tblWearerLicence.WearerLicenceID)		
    END
    
     
-- =======================================================================================================================================
-- LicenceNumber
Print '->39416'
   BEGIN
		UPDATE tblWearer SET LicenceNumber = (SELECT LicenceNumber FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND IsLatest = 1)
   END
Print '->39421'
   BEGIN
		UPDATE tblWearer SET LicenceNumber = (SELECT LicenceNumber FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND LicenceExpiryDate = (SELECT MAX(LicenceExpiryDate) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)) WHERE tblWearer.LicenceNumber IS NULL
   END
Print '->39427'
-- =======================================================================================================================================
 --LicenceExpiryDate
   BEGIN
		UPDATE tblWearer SET LicenceExpiryDate = (SELECT LicenceExpiryDate FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND IsLatest = 1)
   END

    BEGIN
		UPDATE tblWearer SET LicenceExpiryDate = (SELECT LicenceExpiryDate FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID AND LicenceExpiryDate = (SELECT MAX(LicenceExpiryDate) FROM tblWearerLicence
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)) WHERE tblWearer.LicenceExpiryDate IS NULL
    END   
     
-- =======================================================================================================================================
-- ProjectName
-- Pending Project Schema
-- =======================================================================================================================================
-- EarliestReadingStartDate
	BEGIN 
		UPDATE tblWearer SET EarliestReadingStartDate = (SELECT MIN(StartDate) FROM tblDoseReportReadingViewField 
		WHERE WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================

-- LatestReadingStartDate
	BEGIN 
		UPDATE tblWearer SET LatestReadingStartDate = (SELECT MIN(StartDate) FROM tblDoseReportReadingViewField 
		WHERE tblDoseReportReadingViewField.WearerInternalID = tblWearer.WearerInternalID AND 
		tblDoseReportReadingViewField.EndDate = (SELECT MAX(EndDate) FROM tblDoseReportReadingViewField 
		WHERE WearerInternalID = tblWearer.WearerInternalID))	
	END

-- LatestReadingEndDate (Moved from Historion.exe function for speed improvement.)
	BEGIN 
		UPDATE tblWearer SET LatestReadingEndDate = (SELECT MAX(EndDate) FROM tblDoseReportReadingViewField 
		WHERE WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================	
-- PregnancyRecords
	BEGIN 
		UPDATE tblWearer SET PregnancyRecords = (SELECT COUNT(PregnancyID) FROM tblPregnancy 
		WHERE tblPregnancy.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================	
-- CentresMonitored
	BEGIN 
		UPDATE tblWearer SET CentresMonitored = (SELECT COUNT(DISTINCT CentreInternalID) FROM tblJoinCentreWearer 
		WHERE WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================	
-- DoseReadings
	BEGIN 
		UPDATE tblWearer SET DoseReadings = (SELECT COUNT(DoseReportReadingID) FROM tblDoseReportReading 
		WHERE tblDoseReportReading.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================
-- LicenceHistories
	BEGIN 
		UPDATE tblWearer SET LicenceHistories = (SELECT COUNT(WearerLicenceID) FROM tblWearerLicence 
		WHERE tblWearerLicence.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================
-- FileNotes
	BEGIN 
		UPDATE tblWearer SET FileNotes = (SELECT COUNT(FileNoteID) FROM tblFileNote 
		WHERE tblFileNote.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================
-- AliasNames
	BEGIN 
		UPDATE tblWearer SET AliasNames = (SELECT COUNT(WearerAlternateNameID) FROM tblWearerAlternateName 
		WHERE tblWearerAlternateName.WearerInternalID = tblWearer.WearerInternalID)
	END	

-- =======================================================================================================================================	
-- Update any missing document links so attachments lists populate as expected

	INSERT INTO tblLinkWearerDocument (DocumentID, WearerInternalID)
	SELECT tblDocument.DocumentID, tblFileNote.WearerInternalID FROM 
	tblDocument INNER JOIN tblFileNote ON tblDocument.FileNoteID = tblFileNote.FileNoteID
	WHERE DocumentID NOT IN (SELECT DocumentID FROM tblLinkWearerDocument 
	WHERE DocumentID = tblDocument.DocumentID AND WearerInternalID = tblFileNote.WearerInternalID)

	INSERT INTO tblLinkWearerDocument (DocumentID, WearerInternalID)
	SELECT tblDocument.DocumentID, tblEquipmentWearer.WearerInternalID FROM 
	tblDocument INNER JOIN tblEquipmentWearer ON tblDocument.EquipmentWearerID = tblEquipmentWearer.EquipmentWearerID
	WHERE DocumentID NOT IN (SELECT DocumentID FROM tblLinkWearerDocument 
	WHERE DocumentID = tblDocument.DocumentID AND WearerInternalID = tblEquipmentWearer.WearerInternalID)

	INSERT INTO tblLinkWearerDocument (DocumentID, WearerInternalID)
	SELECT tblDocument.DocumentID, tblWearerTraining.WearerInternalID FROM 
	tblDocument INNER JOIN tblWearerTraining ON tblDocument.WearerTrainingID = tblWearerTraining.WearerTrainingID
	WHERE DocumentID NOT IN (SELECT DocumentID FROM tblLinkWearerDocument 
	WHERE DocumentID = tblDocument.DocumentID AND WearerInternalID = tblWearerTraining.WearerInternalID)	
	
-- =======================================================================================================================================
-- Attachments
	BEGIN 
		UPDATE tblWearer SET Attachments = (SELECT COUNT(LinkWearerDocumentID) FROM tblLinkWearerDocument 
		WHERE tblLinkWearerDocument.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================
-- TrainingRecords
	BEGIN 
		UPDATE tblWearer SET TrainingRecords = (SELECT COUNT(WearerTrainingID) FROM tblWearerTraining 
		WHERE tblWearerTraining.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================
-- EquipmentOperated  
	BEGIN 
		UPDATE tblWearer SET EquipmentOperated = (SELECT COUNT(DISTINCT EquipmentID) FROM tblEquipmentWearer 
		WHERE tblEquipmentWearer.WearerInternalID = tblWearer.WearerInternalID)
	END	 
-- =======================================================================================================================================
-- ProtectiveDevices
	BEGIN 
		UPDATE tblWearer SET ProtectiveDevices = (SELECT COUNT(ProtectiveDeviceID) FROM tblProtectiveDevice 
		WHERE tblProtectiveDevice.WearerInternalID = tblWearer.WearerInternalID)
	END	
-- =======================================================================================================================================
-- RadiationLicenceHolderYesNo
	BEGIN 
		UPDATE tblWearer SET RadiationLicenceHolderYesNo = 'Yes' WHERE ISNULL(RadiationLicenceHolder,0) = 1
	END	
	BEGIN 
		UPDATE tblWearer SET RadiationLicenceHolderYesNo = 'No' WHERE ISNULL(RadiationLicenceHolder,0) = 0
	END
-- =======================================================================================================================================
SELECT @iErrorCode=@@ERROR	
GO
-- =======================================================================================================================================
-- End replace apr_CrossRef_Data_Wears (All Wearers SPROC, updated to include Firstname and Surname in ANRDR readiness check Nov 2020
-- =======================================================================================================================================

-- =======================================================================================================================================
-- Source Search SPROC apr_Sources_Search
-- =======================================================================================================================================

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[apr_Sources_Search]') ) drop procedure [dbo].[apr_Sources_Search]
GO

/****** Object:  StoredProcedure [dbo].[apr_Sources_Search]    Script Date: 31/10/2020 10:59:04 PM ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[apr_Sources_Search]
	@PrimaryType nvarchar(500),
	@SourceType nvarchar(500),
	@ApparatusType nvarchar(500),
	@BusinessUnit nvarchar(max),
	@SiteLocation nvarchar(max),
	@Premises nvarchar(100),
	@Room nvarchar(100),
	@LicenceNo nvarchar(30),
	@Campus nvarchar(100),
	@CentreNo varchar(max),
	@RSO nvarchar(200),
	@Custodian nvarchar(200),
	@Manager nvarchar(200),
	@ARPANSAStatus nvarchar(50),
	@InventoryStatus nvarchar(50),
	@Manufacturer nvarchar(200),
	@ARPANSALADNo int,
	@AssetNo nvarchar(12),
	@LocalID int,
	@SerialNo nvarchar(50),
	@AltLocalID nvarchar(12),
	@DisposalApprovalFrom datetime,
	@DisposalApprovalTo datetime,
	@DisposalDateFrom datetime,
	@DisposalDateTo datetime,
	@RecordAddedFrom datetime,
	@RecordAddedTo datetime,
	@AcquisitionFrom datetime,
	@AcquisitionTo datetime,
	@ApprovalFrom datetime,
	@ApprovalTo datetime,
	@RecordModifiedFrom datetime,
	@RecordModifiedTo datetime,
	@LastSightedFrom datetime,
	@LastSightedTo datetime,
	@WipeTestFrom datetime,
	@WipeTestTo datetime,
	@SearchAll nvarchar(max),
	@SearchInt int,
	@SearchDate datetime,
	@iErrorCode int OUTPUT
AS
-- SELECT an existing row from the table.
SELECT ev.* 
FROM [dbo].[tblEquipmentView] ev
WHERE
      (@PrimaryType is null OR [EquipmentType] like  @PrimaryType)
  AND (@SourceType is null OR [SourceType] like @SourceType)
  AND (@ApparatusType is null OR [ApparatusType] like @ApparatusType)
  AND (@BusinessUnit is null OR [BusinessUnitName] like @BusinessUnit)
  AND (@SiteLocation is null OR [SiteLocationName] like @SiteLocation)
  AND (@Premises is null OR [NameOfPremises] like @Premises)
  AND (@Room is null OR [RoomName] like @Room)
  AND (@LicenceNo is null OR [LicenceNumber] like @LicenceNo) 
  AND (@LicenceNo is null OR [LicenceNumberPrev] LIKE @LicenceNo) 
  AND (@LicenceNo is null OR [LicencePermitNo] LIKE @LicenceNo)
  AND (@Campus is null OR [Campus] LIKE @Campus)
  AND (@CentreNo is null OR [CentreNo] like @CentreNo)
  AND (@RSO is null OR [DxRSO] like @RSO)
  AND (@Custodian is null OR [DxSourceCustodian] like @Custodian) 
  AND (@Custodian is null OR [DxAreaCustodian] LIKE @Custodian)
  AND (@Manager is null OR [DxLineManager] like @Manager)
  AND (@ARPANSAStatus is null OR [ARPANSAStatus] like @ARPANSAStatus)
  AND (@InventoryStatus is null OR [InventoryStatus] like @InventoryStatus)
  AND (@Manufacturer is null OR [Manufacturer] like @Manufacturer)
  AND (@ARPANSALADNo is null OR [ARPANSALADNumber] = @ARPANSALADNo)
  AND (@AssetNo is null OR [AssetNumber] like @AssetNo)
  AND (@LocalID is null OR [LocalEquipmentID] = @LocalID)
  AND (@SerialNo is null OR [SerialNo] like @SerialNo)
  AND (@AltLocalID is null OR [AltLocalEquipmentID] like @AltLocalID)
  AND (@DisposalApprovalFrom is null OR [DisposalApprovalGranted] >= @DisposalApprovalFrom)
  AND (@DisposalApprovalTo is null OR [DisposalApprovalGranted] <= @DisposalApprovalTo)  
  AND (@DisposalDateFrom is null OR [DateOfDisposal] >= @DisposalDateFrom)
  AND (@DisposalDateTo is null OR [DateOfDisposal] <= @DisposalDateTo)  
  AND (@RecordAddedFrom is null OR [AddedDateTime] >= @RecordAddedFrom)
  AND (@RecordAddedTo is null OR [AddedDateTime] <= @RecordAddedTo)
  AND (@AcquisitionFrom is null OR [DateAcquired] >= @AcquisitionFrom)
  AND (@AcquisitionTo is null OR [DateAcquired] <= @AcquisitionTo)
  AND (@ApprovalFrom is null OR [Approval] >= @ApprovalFrom)
  AND (@ApprovalTo is null OR [Approval] <= @ApprovalTo)
  AND (@RecordModifiedFrom is null OR [ModifiedDateTime] >= @RecordModifiedFrom)
  AND (@RecordModifiedTo is null OR [ModifiedDateTime] <= @RecordModifiedTo)
  AND (@LastSightedFrom is null OR [LastSightedDate] >= @LastSightedFrom)
  AND (@LastSightedTo is null OR [LastSightedDate] <= @LastSightedTo)
  AND (@WipeTestFrom is null OR [WipeTestDate] >= @WipeTestFrom)
  AND (@WipeTestTo is null OR [WipeTestDate] <= @WipeTestTo)
  AND (@SearchAll is null OR [SourceType] like @SearchAll
						  OR [EquipmentStatus] like @SearchAll
						  OR [ApparatusType] like @SearchAll
						  OR [BusinessUnitName] like @SearchAll
						  OR [SiteLocationName] like @SearchAll
						  OR [NameOfPremises] like @SearchAll
						  OR [RoomName] like @SearchAll
						  OR [LicenceNumber] like @SearchAll
						  OR [LicenceNumberPrev] like @SearchAll
						  OR [LicencePermitNo] like @SearchAll
						  OR [Campus] like @SearchAll
						  OR [CentreNo] like @SearchAll
						  OR [CentreName] like @SearchAll
						  OR [DxRSO] like @SearchAll
						  OR [DxSourceCustodian] like @SearchAll
						  OR [DxAreaCustodian] like @SearchAll
						  OR [DxLineManager] like @SearchAll
						  OR [ARPANSAStatus] like @SearchAll
						  OR [InventoryStatus] like @SearchAll
						  OR [Manufacturer] like @SearchAll
						  OR [AssetNumber] like @SearchAll
						  OR [SerialNo] like @SearchAll
						  OR [AltLocalEquipmentID] like @SearchAll
						  OR [EquipmentModel] like @SearchAll
						  OR [Brand] like @SearchAll
						  OR [Model] like @SearchAll
						  OR [Classification] like @SearchAll
						  OR [ContactDetails] like @SearchAll
						  OR [RegAuthorityIDNo] like @SearchAll
						  OR [LicenceNumber] like @SearchAll
						  OR [ISONumber] like @SearchAll
						  OR [WorkingLife] like @SearchAll
						  OR [Radionuclide] like @SearchAll
						  OR [EquipmentNotes] like @SearchAll
						  OR [EquipmentName] like @SearchAll
						  OR [Manufacturer] like @SearchAll
						  OR [BuildingPrefixName] like @SearchAll
						  OR [BuildingNumber] like @SearchAll
						  OR [UnitNumber] like @SearchAll
						  OR [StreetName] like @SearchAll
						  OR [Suburb] like @SearchAll
						  OR [State] like @SearchAll
						  OR [Postcode] like @SearchAll
						  OR [ControlGenManufacturer] like @SearchAll
						  OR [ControlGenModel] like @SearchAll
						  OR [ControlGenSerial] like @SearchAll
						  OR [TubeHousingManufacturer] like @SearchAll
						  OR [TubeHousingModel] like @SearchAll
						  OR [TubeHousingSerial] like @SearchAll
						  OR [TubeInsertManufacturer] like @SearchAll
						  OR [TubeInsertModel] like @SearchAll
						  OR [TubeInsertSerial] like @SearchAll
						  OR [Category] like @SearchAll
						  OR [NominalActivity] like @SearchAll
						  OR [RegAuthorityIDNoPrev] like @SearchAll
						  OR [LicenceNumberPrev] like @SearchAll
						  OR [HasComplianceCertificate] like @SearchAll
						  OR [SendComplianceCertReminder] like @SearchAll
						  OR [SendComplianceCertReminderTo] like @SearchAll
						  OR [ApparatusDescription] like @SearchAll
						  OR [CostGroup] like @SearchAll
						  OR [SealedSourceDescription] like @SearchAll
						  OR [SecurityClassification] like @SearchAll
						  OR [DepreciationDesc] like @SearchAll
						  OR [OtherCostADesc] like @SearchAll
						  OR [OtherCostBDesc] like @SearchAll
						  OR [CostsNote] like @SearchAll
						  OR [WarrantyConditions] like @SearchAll
						  OR [GuranteeConditions] like @SearchAll
						  OR [DisposalVendorContact] like @SearchAll
						  OR [DisposalMethod] like @SearchAll
						  OR [DisposalConfirmed] like @SearchAll
						  OR [DisposalConfirmation] like @SearchAll
						  OR [DisposalEnvironmental] like @SearchAll
						  OR [DisposalPermitRequired] like @SearchAll
						  OR [DisposalPermitObtained] like @SearchAll
						  OR [DisposalPermitNumber] like @SearchAll
						  OR [DisposalPermitConditions] like @SearchAll
						  OR [RequiresAuditing] like @SearchAll
						  OR [LastAuditConductedBy] like @SearchAll
						  OR [LastAuditConductedLicenceNo] like @SearchAll
						  OR [LastAuditOutcomeSummary] like @SearchAll
						  OR [LastAuditOutcomeDetail] like @SearchAll
						  OR [EquipmentFlagFollowup] like @SearchAll
						  OR [Facility] like @SearchAll
						  OR [AltLocalEquipmentID] like @SearchAll
						  OR [IntendedPurpose] like @SearchAll
						  OR [DisposalStatus] like @SearchAll
						  OR [OperatingParameter] like @SearchAll
						  OR [LikelyExposure] like @SearchAll
						  OR [ChemicalForm] like @SearchAll
						  OR [PhysicalForm] like @SearchAll
						  OR [Portability] like @SearchAll
						  OR [EncapsulationMaterial] like @SearchAll
						  OR [RoomName] like @SearchAll
						  OR [LocationOther] like @SearchAll
						  OR [DisposalDetails] like @SearchAll
						  OR [Max_kVp] like @SearchAll
						  OR [Max_mA] like @SearchAll
						  OR [Comments] like @SearchAll
						  OR [InternalComments] like @SearchAll
						  OR [ASNOPermitNo] like @SearchAll
						  OR [ASNOBatchNo] like @SearchAll
						  OR [NonIonisingSource] like @SearchAll
						  OR [NonIonisingApparatusType] like @SearchAll
						  OR [IonisingSource] like @SearchAll
						  OR [IonisingApparatusType] like @SearchAll
						  OR [UnsealedSource] like @SearchAll
						  OR [LastSightedBy] like @SearchAll
						  OR [LastSightedComment] like @SearchAll
						  OR [AddedBy] like @SearchAll
						  OR [ModifiedBy] like @SearchAll
						  OR [LicencePermitNo] like @SearchAll
						  OR [Latitude] like @SearchAll
						  OR [Longitude] like @SearchAll
						  OR [EquipmentModel] like @SearchAll
						  OR [DxSourceCustodian] like @SearchAll
						  OR [DxAreaCustodian] like @SearchAll
						  OR [DxLineManager] like @SearchAll
						  OR [DxRSO] like @SearchAll
						  OR [ASNOMaterial] like @SearchAll
						  OR [ASNOInventoryBatchNo] like @SearchAll
						  OR [SourceCertificateNo] like @SearchAll
						  OR [ARPANSALADNumber] like @SearchAll
						  OR [LocalEquipmentID] like @SearchAll
						  OR [TestingFrequency] like @SearchAll
						  OR [AuditFrequency] like @SearchAll
						  OR [RecommendedWorkingLife] like @SearchAll
						  OR [ExemptLimitBq] like @SearchAll
						  OR [ComputedAD] like @SearchAll
						  OR [ComputedAE] like @SearchAll
						  OR [SourceCertificateID] like @SearchAll
						  OR [LicencedActivityBq] like @SearchAll
						  OR [ServiceCost] like @SearchAll
						  OR [TestingCost] like @SearchAll
						  OR [ReplacementCost] like @SearchAll
						  OR [TotalDepreciation] like @SearchAll
						  OR [RentalCost] like @SearchAll
						  OR [RunningCost] like @SearchAll
						  OR [OtherCostA] like @SearchAll
						  OR [OtherCostB] like @SearchAll
						  OR [PurchaseCost] like @SearchAll
						  OR [DisposalCost] like @SearchAll
						  OR [ActivityBq] like @SearchAll
						  OR [MaxActivityBq] like @SearchAll
						  OR [Max_kVp] like @SearchAll
						  OR [Max_mA] like @SearchAll
						  OR [RecommendedWorkingLife] like @SearchAll
						  OR [CurrentActivity] like @SearchAll
						  OR [SourceAE] like @SearchAll
						  OR [SourceAD] like @SearchAll)
  AND (@SearchDate is null OR [DisposalApprovalGranted] = @SearchDate
						  OR [DateRegistered] = @SearchDate
						  OR [DateOfDisposal] = @SearchDate
						  OR [AddedDateTime] = @SearchDate
						  OR [DateAcquired] = @SearchDate
						  OR [Approval] = @SearchDate
						  OR [ModifiedDateTime] = @SearchDate
						  OR [LastSightedDate] = @SearchDate
						  OR [WipeTestDate] = @SearchDate
						  OR [DateManufactured] = @SearchDate
						  OR [DateLastTested] = @SearchDate
						  OR [DateWorkingLifeExpiry] = @SearchDate
						  OR [AssayDate] = @SearchDate
						  OR [ComplianceCertExpiry] = @SearchDate
						  OR [DatePurchased] = @SearchDate
						  OR [DateWarrantyExpires] = @SearchDate
						  OR [DateGuaranteeExpires] = @SearchDate
						  OR [DatePlannedExpiration] = @SearchDate
						  OR [DisposalPermitDate] = @SearchDate
						  OR [DateNextTestExpected] = @SearchDate
						  OR [DateNextTestScheduled] = @SearchDate
						  OR [DateLastAudit] = @SearchDate
						  OR [DateNextAuditExpected] = @SearchDate
						  OR [DateNextAuditScheduled] = @SearchDate
						  OR [DateDecommissioned] = @SearchDate
						  OR [ApprovalSubmissionDate] = @SearchDate
						  OR [ActivityDate] = @SearchDate
						  OR [LastSightedDate] = @SearchDate
						  OR [DateOfReceipt] = @SearchDate
						  OR [DateOfLastSurvey] = @SearchDate)
-- Get the Error Code for the statement just executed.
SELECT @iErrorCode=@@ERROR

-- =======================================================================================================================================
-- End Source Search SPROC apr_Sources_Search
-- =======================================================================================================================================

Print   'Finalise'
Print   '-----------------------------------------------------------------------------------------------------'
GO

Print   'Clear user grid settings'
GO

delete tblGridSettings

-- Permissions

Print ' '
Print 'Update permissions'
GO
-- Ensure Historion_Role reference and execution permissions are correctly set for Historion_Role

dbo.spGrantExectoAllStoredProcs HistorION_Role
GO

dbo.spGrantExectoAllTables HistorION_Role
GO

dbo.spGrantExectoAllViews HistorION_Role
GO

GRANT REFERENCES ON TYPE::dbo.DoseReportReadingApplicationValueType TO Historion_Role
GO

GRANT EXECUTE ON TYPE::dbo.DoseReportReadingApplicationValueType TO Historion_Role
GO

GRANT REFERENCES ON TYPE::dbo.DeviceType TO Historion_Role
GO

GRANT EXECUTE ON TYPE::dbo.DeviceType TO Historion_Role
GO

GRANT REFERENCES ON TYPE::dbo.DoseReadingValueType TO Historion_Role
GO

GRANT EXECUTE ON TYPE::dbo.DoseReadingValueType TO Historion_Role
GO

GRANT REFERENCES ON TYPE::dbo.DoseReportReadingDuplicateType TO Historion_Role
GO

GRANT EXECUTE ON TYPE::dbo.DoseReportReadingDuplicateType TO Historion_Role
GO

GRANT UPDATE ON tblDoseReportReadingView TO HistorION_Role
GO

GRANT REFERENCES ON TYPE::dbo.DoseReportReadingOverlapType TO Historion_Role
GO

GRANT EXECUTE ON TYPE::dbo.DoseReportReadingOverlapType TO Historion_Role
GO 

GRANT REFERENCES ON TYPE::dbo.LinkDeviceReadingType TO Historion_Role
GO

GRANT EXECUTE ON TYPE::dbo.LinkDeviceReadingType TO Historion_Role
GO

Print 'Permissions updated'	
GO

-- =======================================================================================================================================
-- Process Equipment speed table
-- =======================================================================================================================================
DECLARE @iErrorCodeX int
exec dbo.apr_CrossRef_Data_Equipment_All
@iErrorCode = @iErrorCodeX OUTPUT
-- =======================================================================================================================================
-- End Process Equipment speed table
-- =======================================================================================================================================

-- =======================================================================================================================================
-- Process Wearer speed/search table includes setting ANRDR readiness
-- =======================================================================================================================================
DECLARE @iErrorCodeY int
exec dbo.apr_CrossRef_Data_Wearers
@iErrorCode = @iErrorCodeY OUTPUT
-- =======================================================================================================================================
-- End Process Wearers speed/search table
-- =======================================================================================================================================


BEGIN -- Script 6.1.7.5 record
-- ====================================================================================
-- If completed without error add final script record to ChangeScripts table
-- ====================================================================================
	IF NOT EXISTS(Select 1 from [ChangeScripts] where ScriptNo='6.1.7.5')

		BEGIN TRY
			INSERT INTO  [ChangeScripts]
			   ([ScriptNo],[ScriptName] ,[ScriptDescription],[DateApplied],[ColSeqOrder])
			VALUES
			   ('6.1.7.5'
			   ,'July 2020 update. Source Licensing and Business Unit expansion.'
			   ,'July 2020 update. Source Licensing and Business Unit expansion.'
			   ,getDate()
			   ,40)
			 print 'Script record 6.1.7.5 added to ChangeScripts history table (Script 40)'
		END TRY
		BEGIN CATCH
				Print 'Problem adding Script 6.1.7.5 record to ChangeScripts history table (Script 40)'
				SET NOEXEC ON
		END CATCH
Else
		print 'Script record 6.1.7.5 confirmed'
END
GO

BEGIN -- Resume SSMS Session Execution

SET NOEXEC OFF

END
GO
